/* Generated by Cython 3.0.0 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "playhouse/_pysqlite/connection.h"
        ],
        "include_dirs": [
            "playhouse"
        ],
        "libraries": [
            "sqlite3"
        ],
        "name": "playhouse._sqlite_ext",
        "sources": [
            "playhouse/_sqlite_ext.pyx"
        ]
    },
    "module_name": "playhouse._sqlite_ext"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"

    #if PY_MAJOR_VERSION >= 3
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj)
    #else
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj, NULL)
    #endif
    

    #if PY_MAJOR_VERSION <= 2
    #define PyDict_GetItemWithError _PyDict_GetItemWithError
    #endif
    

    #if (PY_VERSION_HEX < 0x030700b1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM < 0x07030600)) && !defined(PyContextVar_Get)
    #define PyContextVar_Get(var, d, v)         ((d) ?             ((void)(var), Py_INCREF(d), (v)[0] = (d), 0) :             ((v)[0] = NULL, 0)         )
    #endif
    
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#define CYTHON_ABI "3_0_0"
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030000F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030B00A1
    static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *kwds=NULL, *argcount=NULL, *posonlyargcount=NULL, *kwonlyargcount=NULL;
        PyObject *nlocals=NULL, *stacksize=NULL, *flags=NULL, *replace=NULL, *empty=NULL;
        const char *fn_cstr=NULL;
        const char *name_cstr=NULL;
        PyCodeObject *co=NULL, *result=NULL;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        if (!(kwds=PyDict_New())) goto end;
        if (!(argcount=PyLong_FromLong(a))) goto end;
        if (PyDict_SetItemString(kwds, "co_argcount", argcount) != 0) goto end;
        if (!(posonlyargcount=PyLong_FromLong(p))) goto end;
        if (PyDict_SetItemString(kwds, "co_posonlyargcount", posonlyargcount) != 0) goto end;
        if (!(kwonlyargcount=PyLong_FromLong(k))) goto end;
        if (PyDict_SetItemString(kwds, "co_kwonlyargcount", kwonlyargcount) != 0) goto end;
        if (!(nlocals=PyLong_FromLong(l))) goto end;
        if (PyDict_SetItemString(kwds, "co_nlocals", nlocals) != 0) goto end;
        if (!(stacksize=PyLong_FromLong(s))) goto end;
        if (PyDict_SetItemString(kwds, "co_stacksize", stacksize) != 0) goto end;
        if (!(flags=PyLong_FromLong(f))) goto end;
        if (PyDict_SetItemString(kwds, "co_flags", flags) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_code", code) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_consts", c) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_names", n) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_varnames", v) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_freevars", fv) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_cellvars", cell) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_linetable", lnos) != 0) goto end;
        if (!(fn_cstr=PyUnicode_AsUTF8AndSize(fn, NULL))) goto end;
        if (!(name_cstr=PyUnicode_AsUTF8AndSize(name, NULL))) goto end;
        if (!(co = PyCode_NewEmpty(fn_cstr, name_cstr, fline))) goto end;
        if (!(replace = PyObject_GetAttrString((PyObject*)co, "replace"))) goto end;
        if (!(empty = PyTuple_New(0))) goto end;
        result = (PyCodeObject*) PyObject_Call(replace, empty, kwds);
    end:
        Py_XDECREF((PyObject*) co);
        Py_XDECREF(kwds);
        Py_XDECREF(argcount);
        Py_XDECREF(posonlyargcount);
        Py_XDECREF(kwonlyargcount);
        Py_XDECREF(nlocals);
        Py_XDECREF(stacksize);
        Py_XDECREF(replace);
        Py_XDECREF(empty);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE(obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__playhouse___sqlite_ext
#define __PYX_HAVE_API__playhouse___sqlite_ext
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "pythread.h"
#include "datetime.h"

    /* Backport for Python 2.x */
    #if PY_MAJOR_VERSION < 3
        #ifndef PyDateTime_DELTA_GET_DAYS
            #define PyDateTime_DELTA_GET_DAYS(o) (((PyDateTime_Delta*)o)->days)
        #endif
        #ifndef PyDateTime_DELTA_GET_SECONDS
            #define PyDateTime_DELTA_GET_SECONDS(o) (((PyDateTime_Delta*)o)->seconds)
        #endif
        #ifndef PyDateTime_DELTA_GET_MICROSECONDS
            #define PyDateTime_DELTA_GET_MICROSECONDS(o) (((PyDateTime_Delta*)o)->microseconds)
        #endif
    #endif

    /* Backport for Python < 3.6 */
    #if PY_VERSION_HEX < 0x030600a4
        #ifndef PyDateTime_TIME_GET_FOLD
            #define PyDateTime_TIME_GET_FOLD(o) ((void)(o), 0)
        #endif
        #ifndef PyDateTime_DATE_GET_FOLD
            #define PyDateTime_DATE_GET_FOLD(o) ((void)(o), 0)
        #endif
    #endif

    /* Backport for Python < 3.6 */
    #if PY_VERSION_HEX < 0x030600a4
        #define __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)             ((void)(fold), PyDateTimeAPI->DateTime_FromDateAndTime(year, month, day, hour, minute, second,                 microsecond, tz, PyDateTimeAPI->DateTimeType))
        #define __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)             ((void)(fold), PyDateTimeAPI->Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI->TimeType))
    #else /* For Python 3.6+ so that we can pass tz */
        #define __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)             PyDateTimeAPI->DateTime_FromDateAndTimeAndFold(year, month, day, hour, minute, second,                 microsecond, tz, fold, PyDateTimeAPI->DateTimeType)
        #define __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)             PyDateTimeAPI->Time_FromTimeAndFold(hour, minute, second, microsecond, tz, fold, PyDateTimeAPI->TimeType)
    #endif

    /* Backport for Python < 3.7 */
    #if PY_VERSION_HEX < 0x030700b1
        #define __Pyx_TimeZone_UTC NULL
        #define __Pyx_TimeZone_FromOffsetAndName(offset, name) ((void)(offset), (void)(name), (PyObject*)NULL)
    #else
        #define __Pyx_TimeZone_UTC PyDateTime_TimeZone_UTC
        #define __Pyx_TimeZone_FromOffsetAndName(offset, name) PyTimeZone_FromOffsetAndName(offset, name)
    #endif

    /* Backport for Python < 3.10 */
    #if PY_VERSION_HEX < 0x030a00a1
        #ifndef PyDateTime_TIME_GET_TZINFO
            #define PyDateTime_TIME_GET_TZINFO(o)                 ((((PyDateTime_Time*)o)->hastzinfo) ? ((PyDateTime_Time*)o)->tzinfo : Py_None)
        #endif
        #ifndef PyDateTime_DATE_GET_TZINFO
            #define PyDateTime_DATE_GET_TZINFO(o)                 ((((PyDateTime_DateTime*)o)->hastzinfo) ? ((PyDateTime_DateTime*)o)->tzinfo : Py_None)
        #endif
    #endif
    
#include <float.h>
#include <math.h>
#include <stdint.h>
#include <stdlib.h>
#include "sqlite3.h"
#include "_pysqlite/connection.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else  // Py < 3.12
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "playhouse/_sqlite_ext.pyx",
  "<stringsource>",
  "contextvars.pxd",
  "datetime.pxd",
  "type.pxd",
  "bool.pxd",
  "complex.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl;
struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter;
struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate;
struct __pyx_obj_9playhouse_11_sqlite_ext_Blob;
struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper;
struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash;
struct __pyx_opt_args_7cpython_11contextvars_get_value;
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default;

/* "cpython/contextvars.pxd":112
 * 
 * 
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
 */
struct __pyx_opt_args_7cpython_11contextvars_get_value {
  int __pyx_n;
  PyObject *default_value;
};

/* "cpython/contextvars.pxd":129
 * 
 * 
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
 */
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default {
  int __pyx_n;
  PyObject *default_value;
};
struct __pyx_opt_args_7cpython_8datetime_time_new;
struct __pyx_opt_args_7cpython_8datetime_datetime_new;
struct __pyx_opt_args_7cpython_8datetime_timezone_new;
struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp;

/* "datetime.pxd":292
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
 */
struct __pyx_opt_args_7cpython_8datetime_time_new {
  int __pyx_n;
  int fold;
};

/* "datetime.pxd":297
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
 */
struct __pyx_opt_args_7cpython_8datetime_datetime_new {
  int __pyx_n;
  int fold;
};

/* "datetime.pxd":306
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */
struct __pyx_opt_args_7cpython_8datetime_timezone_new {
  int __pyx_n;
  PyObject *name;
};

/* "datetime.pxd":312
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 */
struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp {
  int __pyx_n;
  PyObject *tz;
};
struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_constraint;
struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_orderby;
struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_constraint_usage;
struct __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab;
typedef struct __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab;
struct __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor;
typedef struct __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor;
struct __pyx_t_9playhouse_11_sqlite_ext_bf_t;
typedef struct __pyx_t_9playhouse_11_sqlite_ext_bf_t __pyx_t_9playhouse_11_sqlite_ext_bf_t;

/* "playhouse/_sqlite_ext.pyx":34
 * 
 * 
 * cdef struct sqlite3_index_constraint:             # <<<<<<<<<<<<<<
 *     int iColumn  # Column constrained, -1 for rowid.
 *     unsigned char op  # Constraint operator.
 */
struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_constraint {
  int iColumn;
  unsigned char op;
  unsigned char usable;
  int iTermOffset;
};

/* "playhouse/_sqlite_ext.pyx":41
 * 
 * 
 * cdef struct sqlite3_index_orderby:             # <<<<<<<<<<<<<<
 *     int iColumn
 *     unsigned char desc
 */
struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_orderby {
  int iColumn;
  unsigned char desc;
};

/* "playhouse/_sqlite_ext.pyx":46
 * 
 * 
 * cdef struct sqlite3_index_constraint_usage:             # <<<<<<<<<<<<<<
 *     int argvIndex  # if > 0, constraint is part of argv to xFilter.
 *     unsigned char omit
 */
struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_constraint_usage {
  int argvIndex;
  unsigned char omit;
};

/* "playhouse/_sqlite_ext.pyx":369
 * # The peewee_vtab struct embeds the base sqlite3_vtab struct, and adds a field
 * # to store a reference to the Python implementation.
 * ctypedef struct peewee_vtab:             # <<<<<<<<<<<<<<
 *     sqlite3_vtab base
 *     void *table_func_cls
 */
struct __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab {
  sqlite3_vtab base;
  void *table_func_cls;
};

/* "playhouse/_sqlite_ext.pyx":378
 * # implementation, the current rows' data, and a flag for whether the cursor has
 * # been exhausted.
 * ctypedef struct peewee_cursor:             # <<<<<<<<<<<<<<
 *     sqlite3_vtab_cursor base
 *     long long idx
 */
struct __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor {
  sqlite3_vtab_cursor base;
  PY_LONG_LONG idx;
  void *table_func;
  void *row_data;
  int stopped;
};

/* "playhouse/_sqlite_ext.pyx":1057
 * 
 * 
 * ctypedef struct bf_t:             # <<<<<<<<<<<<<<
 *     void *bits
 *     size_t size
 */
struct __pyx_t_9playhouse_11_sqlite_ext_bf_t {
  void *bits;
  size_t size;
};

/* "playhouse/_sqlite_ext.pyx":625
 * 
 * 
 * cdef class _TableFunctionImpl(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         sqlite3_module module
 */
struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl {
  PyObject_HEAD
  struct __pyx_vtabstruct_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_vtab;
  sqlite3_module module;
  PyObject *table_function;
};


/* "playhouse/_sqlite_ext.pyx":1110
 * 
 * 
 * cdef class BloomFilter(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t *bf
 */
struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter {
  PyObject_HEAD
  __pyx_t_9playhouse_11_sqlite_ext_bf_t *bf;
};


/* "playhouse/_sqlite_ext.pyx":1162
 * 
 * 
 * cdef class BloomFilterAggregate(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         BloomFilter bf
 */
struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate {
  PyObject_HEAD
  struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *bf;
};


/* "playhouse/_sqlite_ext.pyx":1245
 * 
 * 
 * cdef class Blob(object)  # Forward declaration.             # <<<<<<<<<<<<<<
 * 
 * 
 */
struct __pyx_obj_9playhouse_11_sqlite_ext_Blob {
  PyObject_HEAD
  struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob *__pyx_vtab;
  int offset;
  pysqlite_Connection *conn;
  sqlite3_blob *pBlob;
};


/* "playhouse/_sqlite_ext.pyx":1436
 * 
 * 
 * cdef class ConnectionHelper(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         object _commit_hook, _rollback_hook, _update_hook
 */
struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper {
  PyObject_HEAD
  PyObject *_commit_hook;
  PyObject *_rollback_hook;
  PyObject *_update_hook;
  pysqlite_Connection *conn;
};


/* "playhouse/_sqlite_ext.pyx":1020
 * 
 * 
 * def make_hash(hash_impl):             # <<<<<<<<<<<<<<
 *     def inner(*items):
 *         state = hash_impl()
 */
struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash {
  PyObject_HEAD
  PyObject *__pyx_v_hash_impl;
};



/* "playhouse/_sqlite_ext.pyx":625
 * 
 * 
 * cdef class _TableFunctionImpl(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         sqlite3_module module
 */

struct __pyx_vtabstruct_9playhouse_11_sqlite_ext__TableFunctionImpl {
  PyObject *(*create_module)(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *, pysqlite_Connection *);
};
static struct __pyx_vtabstruct_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_vtabptr_9playhouse_11_sqlite_ext__TableFunctionImpl;


/* "playhouse/_sqlite_ext.pyx":1255
 * 
 * 
 * cdef class Blob(object):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int offset
 */

struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob {
  PyObject *(*_close)(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *);
};
static struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob *__pyx_vtabptr_9playhouse_11_sqlite_ext_Blob;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* IncludeStringH.proto */
#include <string.h>

/* ssize_strlen.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* PyObject_Unicode.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))
#else
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Unicode(obj))
#endif

/* RaiseClosureNameError.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_IsCyOrPyCFunction(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_TrueDivideCObj(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* pow2.proto */
#define __Pyx_PyNumber_Power2(a, b) PyNumber_Power(a, b, Py_None)

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_MultiplyObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* ModInt[long].proto */
static CYTHON_INLINE long __Pyx_mod_long(long, long);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type);
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_0_0
#define __PYX_HAVE_RT_ImportType_proto_3_0_0
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_0(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_0(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_0_0 {
   __Pyx_ImportType_CheckSize_Error_3_0_0 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_0_0 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_0_0 = 2
};
static PyTypeObject *__Pyx_ImportType_3_0_0(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_0 check_size);
#endif

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* ClassMethod.proto */
#include "descrobject.h"
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE sqlite3_int64 __Pyx_PyInt_As_sqlite3_int64(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_PY_LONG_LONG(PY_LONG_LONG value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint32_t(uint32_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_4year_year(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_5month_month(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_3day_day(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4hour_hour(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6minute_minute(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6second_second(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_11microsecond_microsecond(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_4time_6tzinfo_tzinfo(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4fold_fold(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4year_year(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_5month_month(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_3day_day(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4hour_hour(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6minute_minute(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6second_second(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4fold_fold(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_3day_day(PyDateTime_Delta *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_6second_second(PyDateTime_Delta *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_11microsecond_microsecond(PyDateTime_Delta *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_9playhouse_11_sqlite_ext_18_TableFunctionImpl_create_module(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self, pysqlite_Connection *__pyx_v_sqlite_conn); /* proto*/
static PyObject *__pyx_f_9playhouse_11_sqlite_ext_4Blob__close(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "cpython.version" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "cpython.exc" */

/* Module declarations from "cpython.module" */

/* Module declarations from "cpython.mem" */

/* Module declarations from "cpython.tuple" */

/* Module declarations from "cpython.list" */

/* Module declarations from "cpython.sequence" */

/* Module declarations from "cpython.mapping" */

/* Module declarations from "cpython.iterator" */

/* Module declarations from "cpython.number" */

/* Module declarations from "cpython.int" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.bool" */

/* Module declarations from "cpython.long" */

/* Module declarations from "cpython.float" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.complex" */

/* Module declarations from "cpython.string" */

/* Module declarations from "cpython.unicode" */

/* Module declarations from "cpython.pyport" */

/* Module declarations from "cpython.dict" */

/* Module declarations from "cpython.instance" */

/* Module declarations from "cpython.function" */

/* Module declarations from "cpython.method" */

/* Module declarations from "cpython.weakref" */

/* Module declarations from "cpython.getargs" */

/* Module declarations from "cpython.pythread" */

/* Module declarations from "cpython.pystate" */

/* Module declarations from "cpython.cobject" */

/* Module declarations from "cpython.oldbuffer" */

/* Module declarations from "cpython.set" */

/* Module declarations from "cpython.buffer" */

/* Module declarations from "cpython.bytes" */

/* Module declarations from "cpython.pycapsule" */

/* Module declarations from "cpython.contextvars" */

/* Module declarations from "cpython" */

/* Module declarations from "datetime" */

/* Module declarations from "cpython.datetime" */

/* Module declarations from "libc.float" */

/* Module declarations from "libc.math" */

/* Module declarations from "libc.stdint" */

/* Module declarations from "libc.stdlib" */

/* Module declarations from "playhouse._sqlite_ext" */
static int __pyx_v_9playhouse_11_sqlite_ext_SQLITE_CONSTRAINT;
static int __pyx_v_9playhouse_11_sqlite_ext_seeds[10];
static PyObject *__pyx_f_9playhouse_11_sqlite_ext_sqlite_to_python(int, sqlite3_value **); /*proto*/
static PyObject *__pyx_f_9playhouse_11_sqlite_ext_python_to_sqlite(sqlite3_context *, PyObject *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwConnect(sqlite3 *, void *, int, char const *const *, sqlite3_vtab **, char **); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwDisconnect(sqlite3_vtab *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwOpen(sqlite3_vtab *, sqlite3_vtab_cursor **); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwClose(sqlite3_vtab_cursor *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwNext(sqlite3_vtab_cursor *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwColumn(sqlite3_vtab_cursor *, sqlite3_context *, int); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwRowid(sqlite3_vtab_cursor *, sqlite3_int64 *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwEof(sqlite3_vtab_cursor *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwFilter(sqlite3_vtab_cursor *, int, char const *, int, sqlite3_value **); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_pwBestIndex(sqlite3_vtab *, sqlite3_index_info *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_9playhouse_11_sqlite_ext_encode(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_9playhouse_11_sqlite_ext_decode(PyObject *); /*proto*/
static double *__pyx_f_9playhouse_11_sqlite_ext_get_weights(int, PyObject *); /*proto*/
static uint32_t __pyx_f_9playhouse_11_sqlite_ext_murmurhash2(unsigned char const *, Py_ssize_t, uint32_t); /*proto*/
static __pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_f_9playhouse_11_sqlite_ext_bf_create(size_t); /*proto*/
static uint32_t __pyx_f_9playhouse_11_sqlite_ext_bf_bitindex(__pyx_t_9playhouse_11_sqlite_ext_bf_t *, unsigned char *, size_t, int); /*proto*/
static PyObject *__pyx_f_9playhouse_11_sqlite_ext_bf_add(__pyx_t_9playhouse_11_sqlite_ext_bf_t *, unsigned char *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext_bf_contains(__pyx_t_9playhouse_11_sqlite_ext_bf_t *, unsigned char *); /*proto*/
static PyObject *__pyx_f_9playhouse_11_sqlite_ext_bf_free(__pyx_t_9playhouse_11_sqlite_ext_bf_t *); /*proto*/
static CYTHON_INLINE int __pyx_f_9playhouse_11_sqlite_ext__check_connection(pysqlite_Connection *); /*proto*/
static CYTHON_INLINE int __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext__commit_callback(void *); /*proto*/
static void __pyx_f_9playhouse_11_sqlite_ext__rollback_callback(void *); /*proto*/
static void __pyx_f_9playhouse_11_sqlite_ext__update_callback(void *, int, char const *, char const *, sqlite3_int64); /*proto*/
static int __pyx_f_9playhouse_11_sqlite_ext__aggressive_busy_handler(void *, int); /*proto*/
static PyObject *__pyx_f_9playhouse_11_sqlite_ext___pyx_unpickle_BloomFilterAggregate__set_state(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "playhouse._sqlite_ext"
extern int __pyx_module_is_main_playhouse___sqlite_ext;
int __pyx_module_is_main_playhouse___sqlite_ext = 0;

/* Implementation of "playhouse._sqlite_ext" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_StopIteration;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_NotImplementedError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_RuntimeError;
/* #### Code section: string_decls ### */
static const char __pyx_k_B[] = "B";
static const char __pyx_k_K[] = "K";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_x[] = "x";
static const char __pyx_k__2[] = ",";
static const char __pyx_k__4[] = ", ";
static const char __pyx_k__9[] = ")";
static const char __pyx_k_bf[] = "bf";
static const char __pyx_k_fn[] = "fn";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_rc[] = "rc";
static const char __pyx_k_tf[] = "tf";
static const char __pyx_k_A_O[] = "A_O";
static const char __pyx_k_C_O[] = "C_O";
static const char __pyx_k_L_O[] = "L_O";
static const char __pyx_k_N_O[] = "N_O";
static const char __pyx_k_P_O[] = "P_O";
static const char __pyx_k_X_O[] = "X_O";
static const char __pyx_k__10[] = "";
static const char __pyx_k__16[] = ".";
static const char __pyx_k__17[] = "*";
static const char __pyx_k_add[] = "add";
static const char __pyx_k_buf[] = "buf";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_ctx[] = "ctx";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_idf[] = "idf";
static const char __pyx_k_idx[] = "idx";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_md5[] = "md5";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_num[] = "num";
static const char __pyx_k_rhs[] = "rhs";
static const char __pyx_k_s_s[] = "%s %s";
static const char __pyx_k_sql[] = "__sql__";
static const char __pyx_k_src[] = "src";
static const char __pyx_k_3_26[] = "3.26";
static const char __pyx_k_Blob[] = "Blob";
static const char __pyx_k_Node[] = "Node";
static const char __pyx_k__115[] = "?";
static const char __pyx_k_bkey[] = "bkey";
static const char __pyx_k_conn[] = "conn";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dest[] = "dest";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_flag[] = "flag";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_hits[] = "hits";
static const char __pyx_k_icol[] = "icol";
static const char __pyx_k_impl[] = "impl";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_item[] = "item";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_main[] = "main";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_ncol[] = "ncol";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_seed[] = "seed";
static const char __pyx_k_seek[] = "seek";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_sha1[] = "sha1";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_step[] = "step";
static const char __pyx_k_tell[] = "tell";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_zlib[] = "zlib";
static const char __pyx_k_accum[] = "accum";
static const char __pyx_k_bdata[] = "bdata";
static const char __pyx_k_bloom[] = "bloom";
static const char __pyx_k_bname[] = "bname";
static const char __pyx_k_cdata[] = "cdata";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_crc32[] = "crc32";
static const char __pyx_k_denom[] = "denom";
static const char __pyx_k_inner[] = "inner";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_ncols[] = "_ncols";
static const char __pyx_k_nseed[] = "nseed";
static const char __pyx_k_pages[] = "pages";
static const char __pyx_k_pairs[] = "pairs";
static const char __pyx_k_param[] = "param";
static const char __pyx_k_pybuf[] = "pybuf";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_ratio[] = "ratio";
static const char __pyx_k_rowid[] = "rowid";
static const char __pyx_k_score[] = "score";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_table[] = "table";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_Binary[] = "Binary";
static const char __pyx_k_DELETE[] = "DELETE";
static const char __pyx_k_INSERT[] = "INSERT";
static const char __pyx_k_UPDATE[] = "UPDATE";
static const char __pyx_k_b_part[] = "b_part";
static const char __pyx_k_backup[] = "backup";
static const char __pyx_k_buflen[] = "buflen";
static const char __pyx_k_c_conn[] = "c_conn";
static const char __pyx_k_column[] = "column";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_length[] = "length";
static const char __pyx_k_main_2[] = "__main__";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_offset[] = "offset";
static const char __pyx_k_params[] = "params";
static const char __pyx_k_peewee[] = "peewee";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_reopen[] = "reopen";
static const char __pyx_k_sha256[] = "sha256";
static const char __pyx_k_src_db[] = "src_db";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_weight[] = "weight";
static const char __pyx_k_adler32[] = "adler32";
static const char __pyx_k_changes[] = "changes";
static const char __pyx_k_columns[] = "columns";
static const char __pyx_k_connect[] = "connect";
static const char __pyx_k_current[] = "current";
static const char __pyx_k_dest_db[] = "dest_db";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_epsilon[] = "epsilon";
static const char __pyx_k_error_p[] = "error_p";
static const char __pyx_k_filters[] = "filters";
static const char __pyx_k_hashlib[] = "hashlib";
static const char __pyx_k_iphrase[] = "iphrase";
static const char __pyx_k_iterate[] = "iterate";
static const char __pyx_k_literal[] = "literal";
static const char __pyx_k_n_items[] = "n_items";
static const char __pyx_k_nphrase[] = "nphrase";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_sqlite3[] = "sqlite3";
static const char __pyx_k_state_2[] = "_state";
static const char __pyx_k_timeout[] = "timeout";
static const char __pyx_k_weights[] = "weights";
static const char __pyx_k_ZeroBlob[] = "ZeroBlob";
static const char __pyx_k_database[] = "database";
static const char __pyx_k_filename[] = "filename";
static const char __pyx_k_finalize[] = "finalize";
static const char __pyx_k_fts_bm25[] = "fts_bm25";
static const char __pyx_k_fts_rank[] = "fts_rank";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_pc_score[] = "pc_score";
static const char __pyx_k_progress[] = "progress";
static const char __pyx_k_pysqlite[] = "pysqlite";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_register[] = "register";
static const char __pyx_k_s_HIDDEN[] = "%s HIDDEN";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_src_conn[] = "src_conn";
static const char __pyx_k_Blob_read[] = "Blob.read";
static const char __pyx_k_Blob_seek[] = "Blob.seek";
static const char __pyx_k_Blob_tell[] = "Blob.tell";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_dest_conn[] = "dest_conn";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_fts_bm25f[] = "fts_bm25f";
static const char __pyx_k_hash_impl[] = "hash_impl";
static const char __pyx_k_hexdigest[] = "hexdigest";
static const char __pyx_k_highwater[] = "highwater";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_make_hash[] = "make_hash";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_page_step[] = "page_step";
static const char __pyx_k_print_exc[] = "print_exc";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_read_only[] = "read_only";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_remaining[] = "remaining";
static const char __pyx_k_to_buffer[] = "to_buffer";
static const char __pyx_k_traceback[] = "traceback";
static const char __pyx_k_Blob_close[] = "Blob.close";
static const char __pyx_k_Blob_write[] = "Blob.write";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_autocommit[] = "autocommit";
static const char __pyx_k_avg_length[] = "avg_length";
static const char __pyx_k_connection[] = "connection";
static const char __pyx_k_doc_length[] = "doc_length";
static const char __pyx_k_fieldNorms[] = "fieldNorms";
static const char __pyx_k_fts_lucene[] = "fts_lucene";
static const char __pyx_k_initialize[] = "initialize";
static const char __pyx_k_match_info[] = "match_info";
static const char __pyx_k_max_length[] = "max_length";
static const char __pyx_k_murmurhash[] = "murmurhash";
static const char __pyx_k_page_count[] = "page_count";
static const char __pyx_k_peewee_md5[] = "peewee_md5";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_total_docs[] = "total_docs";
static const char __pyx_k_zeroblob_s[] = "zeroblob(%s)";
static const char __pyx_k_Blob_reopen[] = "Blob.reopen";
static const char __pyx_k_BloomFilter[] = "BloomFilter";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_bloomfilter[] = "bloomfilter";
static const char __pyx_k_from_buffer[] = "from_buffer";
static const char __pyx_k_global_hits[] = "global_hits";
static const char __pyx_k_mro_entries[] = "__mro_entries__";
static const char __pyx_k_no_row_data[] = "no row data";
static const char __pyx_k_peewee_bm25[] = "peewee_bm25";
static const char __pyx_k_peewee_rank[] = "peewee_rank";
static const char __pyx_k_peewee_sha1[] = "peewee_sha1";
static const char __pyx_k_phrase_info[] = "phrase_info";
static const char __pyx_k_raw_weights[] = "raw_weights";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_peewee_bm25f[] = "peewee_bm25f";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_StopIteration[] = "StopIteration";
static const char __pyx_k_TableFunction[] = "TableFunction";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_peewee_lucene[] = "peewee_lucene";
static const char __pyx_k_peewee_sha256[] = "peewee_sha256";
static const char __pyx_k_py_match_info[] = "py_match_info";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_InterfaceError[] = "InterfaceError";
static const char __pyx_k_ZeroBlob___sql[] = "ZeroBlob.__sql__";
static const char __pyx_k_backup_to_file[] = "backup_to_file";
static const char __pyx_k_calculate_size[] = "calculate_size";
static const char __pyx_k_docs_with_term[] = "docs_with_term";
static const char __pyx_k_match_info_buf[] = "_match_info_buf";
static const char __pyx_k_table_function[] = "table_function";
static const char __pyx_k_term_frequency[] = "term_frequency";
static const char __pyx_k_BloomFilter_add[] = "BloomFilter.add";
static const char __pyx_k_ZeroBlob___init[] = "ZeroBlob.__init__";
static const char __pyx_k_bloomfilter_add[] = "bloomfilter_add";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_set_commit_hook[] = "set_commit_hook";
static const char __pyx_k_set_update_hook[] = "set_update_hook";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_CREATE_TABLE_x_s[] = "CREATE TABLE x(%s);";
static const char __pyx_k_ConnectionHelper[] = "ConnectionHelper";
static const char __pyx_k_OperationalError[] = "OperationalError";
static const char __pyx_k_match_info_buf_2[] = "match_info_buf";
static const char __pyx_k_print_tracebacks[] = "print_tracebacks";
static const char __pyx_k_set_busy_handler[] = "set_busy_handler";
static const char __pyx_k_TableFunctionImpl[] = "_TableFunctionImpl";
static const char __pyx_k_last_insert_rowid[] = "last_insert_rowid";
static const char __pyx_k_peewee_murmurhash[] = "peewee_murmurhash";
static const char __pyx_k_register_function[] = "register_function";
static const char __pyx_k_set_rollback_hook[] = "set_rollback_hook";
static const char __pyx_k_sqlite_get_status[] = "sqlite_get_status";
static const char __pyx_k_Unsupported_type_s[] = "Unsupported type %s";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_frame_of_reference[] = "frame_of_reference";
static const char __pyx_k_register_aggregate[] = "register_aggregate";
static const char __pyx_k_register_functions[] = "_register_functions";
static const char __pyx_k_NotImplementedError[] = "NotImplementedError";
static const char __pyx_k_Unable_to_open_blob[] = "Unable to open blob.";
static const char __pyx_k_Blob___reduce_cython[] = "Blob.__reduce_cython__";
static const char __pyx_k_BloomFilterAggregate[] = "BloomFilterAggregate";
static const char __pyx_k_bloomfilter_contains[] = "bloomfilter_contains";
static const char __pyx_k_register_bloomfilter[] = "register_bloomfilter";
static const char __pyx_k_sqlite_get_db_status[] = "sqlite_get_db_status";
static const char __pyx_k_BloomFilter_to_buffer[] = "BloomFilter.to_buffer";
static const char __pyx_k_Error_writing_to_blob[] = "Error writing to blob.";
static const char __pyx_k_TableFunction_iterate[] = "TableFunction.iterate";
static const char __pyx_k_USE_SQLITE_CONSTRAINT[] = "USE_SQLITE_CONSTRAINT";
static const char __pyx_k_playhouse__sqlite_ext[] = "playhouse._sqlite_ext";
static const char __pyx_k_Blob___setstate_cython[] = "Blob.__setstate_cython__";
static const char __pyx_k_TableFunction_register[] = "TableFunction.register";
static const char __pyx_k_Unable_to_re_open_blob[] = "Unable to re-open blob.";
static const char __pyx_k_make_hash_locals_inner[] = "make_hash.<locals>.inner";
static const char __pyx_k_peewee_bloomfilter_add[] = "peewee_bloomfilter_add";
static const char __pyx_k_Blob_index_out_of_range[] = "Blob index out of range (";
static const char __pyx_k_BloomFilter_from_buffer[] = "BloomFilter.from_buffer";
static const char __pyx_k_Error_reading_from_blob[] = "Error reading from blob.";
static const char __pyx_k_Unable_to_allocate_blob[] = "Unable to allocate blob.";
static const char __pyx_k_register_hash_functions[] = "register_hash_functions";
static const char __pyx_k_register_rank_functions[] = "register_rank_functions";
static const char __pyx_k_ConnectionHelper_changes[] = "ConnectionHelper.changes";
static const char __pyx_k_TableFunction_initialize[] = "TableFunction.initialize";
static const char __pyx_k_BloomFilterAggregate_step[] = "BloomFilterAggregate.step";
static const char __pyx_k_Error_requesting_status_s[] = "Error requesting status: %s";
static const char __pyx_k_playhouse__sqlite_ext_pyx[] = "playhouse/_sqlite_ext.pyx";
static const char __pyx_k_BloomFilter_calculate_size[] = "BloomFilter.calculate_size";
static const char __pyx_k_bloomfilter_calculate_size[] = "bloomfilter_calculate_size";
static const char __pyx_k_BloomFilter___reduce_cython[] = "BloomFilter.__reduce_cython__";
static const char __pyx_k_ConnectionHelper_autocommit[] = "ConnectionHelper.autocommit";
static const char __pyx_k_Unable_to_initialize_backup[] = "Unable to initialize backup.";
static const char __pyx_k_peewee_bloomfilter_contains[] = "peewee_bloomfilter_contains";
static const char __pyx_k_Error_requesting_db_status_s[] = "Error requesting db status: %s";
static const char __pyx_k_BloomFilterAggregate_finalize[] = "BloomFilterAggregate.finalize";
static const char __pyx_k_BloomFilter___setstate_cython[] = "BloomFilter.__setstate_cython__";
static const char __pyx_k_Cannot_operate_on_closed_blob[] = "Cannot operate on closed blob.";
static const char __pyx_k_Error_backuping_up_database_s[] = "Error backuping up database: %s";
static const char __pyx_k_get_table_columns_declaration[] = "get_table_columns_declaration";
static const char __pyx_k_pyx_unpickle_BloomFilterAggreg[] = "__pyx_unpickle_BloomFilterAggregate";
static const char __pyx_k_BloomFilterAggregate___setstate[] = "BloomFilterAggregate.__setstate_cython__";
static const char __pyx_k_TableFunctionImpl___reduce_cyth[] = "_TableFunctionImpl.__reduce_cython__";
static const char __pyx_k_TableFunctionImpl___setstate_cy[] = "_TableFunctionImpl.__setstate_cython__";
static const char __pyx_k_TableFunction_get_table_columns[] = "TableFunction.get_table_columns_declaration";
static const char __pyx_k_seek_frame_of_reference_must_be[] = "seek() frame of reference must be 0, 1 or 2.";
static const char __pyx_k_BloomFilterAggregate___reduce_cy[] = "BloomFilterAggregate.__reduce_cython__";
static const char __pyx_k_Cannot_operate_on_closed_databas[] = "Cannot operate on closed database.";
static const char __pyx_k_Column_must_be_either_a_string_o[] = "Column must be either a string or a 2-tuple of name, type";
static const char __pyx_k_ConnectionHelper___reduce_cython[] = "ConnectionHelper.__reduce_cython__";
static const char __pyx_k_ConnectionHelper___setstate_cyth[] = "ConnectionHelper.__setstate_cython__";
static const char __pyx_k_ConnectionHelper_last_insert_row[] = "ConnectionHelper.last_insert_rowid";
static const char __pyx_k_ConnectionHelper_set_busy_handle[] = "ConnectionHelper.set_busy_handler";
static const char __pyx_k_ConnectionHelper_set_commit_hook[] = "ConnectionHelper.set_commit_hook";
static const char __pyx_k_ConnectionHelper_set_rollback_ho[] = "ConnectionHelper.set_rollback_hook";
static const char __pyx_k_ConnectionHelper_set_update_hook[] = "ConnectionHelper.set_update_hook";
static const char __pyx_k_Data_would_go_beyond_end_of_blob[] = "Data would go beyond end of blob";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))";
static const char __pyx_k_Length_must_be_a_positive_intege[] = "Length must be a positive integer.";
static const char __pyx_k_Time_zones_are_not_available_fro[] = "Time zones are not available from the C-API.";
static const char __pyx_k_cannot_backup_to_or_from_a_close[] = "cannot backup to or from a closed database";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_peewee_bloomfilter_calculate_siz[] = "peewee_bloomfilter_calculate_size";
static const char __pyx_k_seek_offset_outside_of_valid_ran[] = "seek() offset outside of valid range.";
static const char __pyx_k_self_bf_cannot_be_converted_to_a[] = "self.bf cannot be converted to a Python object for pickling";
static const char __pyx_k_self_conn_cannot_be_converted_to[] = "self.conn cannot be converted to a Python object for pickling";
static const char __pyx_k_self_conn_self_pBlob_cannot_be_c[] = "self.conn,self.pBlob cannot be converted to a Python object for pickling";
/* #### Code section: decls ### */
static int __pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl___cinit__(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self, PyObject *__pyx_v_table_function); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_register(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_conn); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_2initialize(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_filters); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_4iterate(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_idx); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_6get_table_columns_declaration(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_peewee_rank(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_2peewee_lucene(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4peewee_bm25(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_6peewee_bm25f(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_8peewee_murmurhash(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_seed); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_9make_hash_inner(PyObject *__pyx_self, PyObject *__pyx_v_items); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_10make_hash(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_hash_impl); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_12_register_functions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database, PyObject *__pyx_v_pairs); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_14register_hash_functions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16register_rank_functions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database); /* proto */
static int __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, PyObject *__pyx_v_size); /* proto */
static void __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_2__dealloc__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_4__len__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_6add(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, PyObject *__pyx_v_keys); /* proto */
static int __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_8__contains__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_10to_buffer(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_12from_buffer(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_14calculate_size(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, double __pyx_v_n, double __pyx_v_p); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_2step(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_size); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_4finalize(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_6__reduce_cython__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_8__setstate_cython__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_18peewee_bloomfilter_contains(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20peewee_bloomfilter_add(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_22peewee_bloomfilter_calculate_size(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_n_items, PyObject *__pyx_v_error_p); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_24register_bloomfilter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_8ZeroBlob___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_length); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_8ZeroBlob_2__sql__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ctx); /* proto */
static int __pyx_pf_9playhouse_11_sqlite_ext_4Blob___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_database, PyObject *__pyx_v_table, PyObject *__pyx_v_column, PyObject *__pyx_v_rowid, PyObject *__pyx_v_read_only); /* proto */
static void __pyx_pf_9playhouse_11_sqlite_ext_4Blob_2__dealloc__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_9playhouse_11_sqlite_ext_4Blob_4__len__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_6__getitem__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_idx); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_8read(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_10seek(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_offset, PyObject *__pyx_v_frame_of_reference); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_12tell(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_14write(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_16close(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_18reopen(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_rowid); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_20__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_22__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_26sqlite_get_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_28sqlite_get_db_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_conn, PyObject *__pyx_v_flag); /* proto */
static int __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_connection); /* proto */
static void __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_2__dealloc__(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_4set_commit_hook(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_fn); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_6set_rollback_hook(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_fn); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_8set_update_hook(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_fn); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_10set_busy_handler(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_12changes(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_14last_insert_rowid(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_16autocommit(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_18__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_20__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_30backup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_src_conn, PyObject *__pyx_v_dest_conn, PyObject *__pyx_v_pages, PyObject *__pyx_v_name, PyObject *__pyx_v_progress); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_32backup_to_file(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_src_conn, PyObject *__pyx_v_filename, PyObject *__pyx_v_pages, PyObject *__pyx_v_name, PyObject *__pyx_v_progress); /* proto */
static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_34__pyx_unpickle_BloomFilterAggregate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext__TableFunctionImpl(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilterAggregate(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_Blob(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_ConnectionHelper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4bool_bool;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_7complex_complex;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_8datetime_date;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_time;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_datetime;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_timedelta;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_tzinfo;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl;
  PyObject *__pyx_type_9playhouse_11_sqlite_ext_BloomFilter;
  PyObject *__pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate;
  PyObject *__pyx_type_9playhouse_11_sqlite_ext_Blob;
  PyObject *__pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper;
  PyObject *__pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash;
  #endif
  PyTypeObject *__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl;
  PyTypeObject *__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter;
  PyTypeObject *__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate;
  PyTypeObject *__pyx_ptype_9playhouse_11_sqlite_ext_Blob;
  PyTypeObject *__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper;
  PyTypeObject *__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash;
  PyObject *__pyx_kp_b_3_26;
  PyObject *__pyx_n_s_A_O;
  PyObject *__pyx_n_s_B;
  PyObject *__pyx_n_s_Binary;
  PyObject *__pyx_n_s_Blob;
  PyObject *__pyx_n_s_Blob___reduce_cython;
  PyObject *__pyx_n_s_Blob___setstate_cython;
  PyObject *__pyx_n_s_Blob_close;
  PyObject *__pyx_kp_u_Blob_index_out_of_range;
  PyObject *__pyx_n_s_Blob_read;
  PyObject *__pyx_n_s_Blob_reopen;
  PyObject *__pyx_n_s_Blob_seek;
  PyObject *__pyx_n_s_Blob_tell;
  PyObject *__pyx_n_s_Blob_write;
  PyObject *__pyx_n_s_BloomFilter;
  PyObject *__pyx_n_s_BloomFilterAggregate;
  PyObject *__pyx_n_s_BloomFilterAggregate___reduce_cy;
  PyObject *__pyx_n_s_BloomFilterAggregate___setstate;
  PyObject *__pyx_n_s_BloomFilterAggregate_finalize;
  PyObject *__pyx_n_s_BloomFilterAggregate_step;
  PyObject *__pyx_n_s_BloomFilter___reduce_cython;
  PyObject *__pyx_n_s_BloomFilter___setstate_cython;
  PyObject *__pyx_n_s_BloomFilter_add;
  PyObject *__pyx_n_s_BloomFilter_calculate_size;
  PyObject *__pyx_n_s_BloomFilter_from_buffer;
  PyObject *__pyx_n_s_BloomFilter_to_buffer;
  PyObject *__pyx_kp_u_CREATE_TABLE_x_s;
  PyObject *__pyx_n_s_C_O;
  PyObject *__pyx_kp_u_Cannot_operate_on_closed_blob;
  PyObject *__pyx_kp_u_Cannot_operate_on_closed_databas;
  PyObject *__pyx_kp_u_Column_must_be_either_a_string_o;
  PyObject *__pyx_n_s_ConnectionHelper;
  PyObject *__pyx_n_s_ConnectionHelper___reduce_cython;
  PyObject *__pyx_n_s_ConnectionHelper___setstate_cyth;
  PyObject *__pyx_n_s_ConnectionHelper_autocommit;
  PyObject *__pyx_n_s_ConnectionHelper_changes;
  PyObject *__pyx_n_s_ConnectionHelper_last_insert_row;
  PyObject *__pyx_n_s_ConnectionHelper_set_busy_handle;
  PyObject *__pyx_n_s_ConnectionHelper_set_commit_hook;
  PyObject *__pyx_n_s_ConnectionHelper_set_rollback_ho;
  PyObject *__pyx_n_s_ConnectionHelper_set_update_hook;
  PyObject *__pyx_n_u_DELETE;
  PyObject *__pyx_kp_u_Data_would_go_beyond_end_of_blob;
  PyObject *__pyx_kp_u_Error_backuping_up_database_s;
  PyObject *__pyx_kp_u_Error_reading_from_blob;
  PyObject *__pyx_kp_u_Error_requesting_db_status_s;
  PyObject *__pyx_kp_u_Error_requesting_status_s;
  PyObject *__pyx_kp_u_Error_writing_to_blob;
  PyObject *__pyx_n_u_INSERT;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_n_s_IndexError;
  PyObject *__pyx_n_s_InterfaceError;
  PyObject *__pyx_n_s_K;
  PyObject *__pyx_n_s_L_O;
  PyObject *__pyx_kp_u_Length_must_be_a_positive_intege;
  PyObject *__pyx_n_s_MemoryError;
  PyObject *__pyx_n_s_N_O;
  PyObject *__pyx_n_s_Node;
  PyObject *__pyx_n_s_NotImplementedError;
  PyObject *__pyx_n_s_OperationalError;
  PyObject *__pyx_n_s_P_O;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_n_s_RuntimeError;
  PyObject *__pyx_n_s_StopIteration;
  PyObject *__pyx_n_s_TableFunction;
  PyObject *__pyx_n_s_TableFunctionImpl;
  PyObject *__pyx_n_s_TableFunctionImpl___reduce_cyth;
  PyObject *__pyx_n_s_TableFunctionImpl___setstate_cy;
  PyObject *__pyx_n_s_TableFunction_get_table_columns;
  PyObject *__pyx_n_s_TableFunction_initialize;
  PyObject *__pyx_n_s_TableFunction_iterate;
  PyObject *__pyx_n_s_TableFunction_register;
  PyObject *__pyx_kp_u_Time_zones_are_not_available_fro;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_n_u_UPDATE;
  PyObject *__pyx_n_s_USE_SQLITE_CONSTRAINT;
  PyObject *__pyx_kp_u_Unable_to_allocate_blob;
  PyObject *__pyx_kp_u_Unable_to_initialize_backup;
  PyObject *__pyx_kp_u_Unable_to_open_blob;
  PyObject *__pyx_kp_u_Unable_to_re_open_blob;
  PyObject *__pyx_kp_u_Unsupported_type_s;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s_X_O;
  PyObject *__pyx_n_s_ZeroBlob;
  PyObject *__pyx_n_s_ZeroBlob___init;
  PyObject *__pyx_n_s_ZeroBlob___sql;
  PyObject *__pyx_kp_b__10;
  PyObject *__pyx_kp_u__10;
  PyObject *__pyx_n_s__115;
  PyObject *__pyx_kp_u__16;
  PyObject *__pyx_n_s__17;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_kp_u__4;
  PyObject *__pyx_kp_u__9;
  PyObject *__pyx_n_s_accum;
  PyObject *__pyx_n_s_add;
  PyObject *__pyx_n_s_adler32;
  PyObject *__pyx_n_u_adler32;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_autocommit;
  PyObject *__pyx_n_s_avg_length;
  PyObject *__pyx_n_s_b_part;
  PyObject *__pyx_n_s_backup;
  PyObject *__pyx_n_s_backup_to_file;
  PyObject *__pyx_n_s_bdata;
  PyObject *__pyx_n_s_bf;
  PyObject *__pyx_n_s_bkey;
  PyObject *__pyx_n_s_bloom;
  PyObject *__pyx_n_u_bloomfilter;
  PyObject *__pyx_n_u_bloomfilter_add;
  PyObject *__pyx_n_u_bloomfilter_calculate_size;
  PyObject *__pyx_n_u_bloomfilter_contains;
  PyObject *__pyx_n_s_bname;
  PyObject *__pyx_n_s_buf;
  PyObject *__pyx_n_s_buflen;
  PyObject *__pyx_n_s_c_conn;
  PyObject *__pyx_n_s_calculate_size;
  PyObject *__pyx_kp_u_cannot_backup_to_or_from_a_close;
  PyObject *__pyx_n_s_cdata;
  PyObject *__pyx_n_s_changes;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_cls;
  PyObject *__pyx_n_s_column;
  PyObject *__pyx_n_s_columns;
  PyObject *__pyx_n_s_conn;
  PyObject *__pyx_n_s_connect;
  PyObject *__pyx_n_s_connection;
  PyObject *__pyx_n_s_crc32;
  PyObject *__pyx_n_u_crc32;
  PyObject *__pyx_n_s_ctx;
  PyObject *__pyx_n_s_current;
  PyObject *__pyx_n_s_data;
  PyObject *__pyx_n_s_database;
  PyObject *__pyx_n_s_decode;
  PyObject *__pyx_n_s_denom;
  PyObject *__pyx_n_s_dest;
  PyObject *__pyx_n_s_dest_conn;
  PyObject *__pyx_n_s_dest_db;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_doc;
  PyObject *__pyx_n_s_doc_length;
  PyObject *__pyx_n_s_docs_with_term;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_enumerate;
  PyObject *__pyx_n_s_epsilon;
  PyObject *__pyx_n_s_error_p;
  PyObject *__pyx_n_s_fieldNorms;
  PyObject *__pyx_n_s_filename;
  PyObject *__pyx_n_s_filters;
  PyObject *__pyx_n_s_finalize;
  PyObject *__pyx_n_s_flag;
  PyObject *__pyx_n_s_fn;
  PyObject *__pyx_n_s_frame_of_reference;
  PyObject *__pyx_n_s_from_buffer;
  PyObject *__pyx_n_u_fts_bm25;
  PyObject *__pyx_n_u_fts_bm25f;
  PyObject *__pyx_n_u_fts_lucene;
  PyObject *__pyx_n_u_fts_rank;
  PyObject *__pyx_n_s_func;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_get_table_columns_declaration;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_n_s_global_hits;
  PyObject *__pyx_n_s_hash_impl;
  PyObject *__pyx_n_s_hashlib;
  PyObject *__pyx_n_s_hexdigest;
  PyObject *__pyx_n_s_highwater;
  PyObject *__pyx_n_s_hits;
  PyObject *__pyx_n_s_icol;
  PyObject *__pyx_n_s_idf;
  PyObject *__pyx_n_s_idx;
  PyObject *__pyx_n_s_impl;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initialize;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_inner;
  PyObject *__pyx_n_s_iphrase;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_item;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_iterate;
  PyObject *__pyx_n_s_key;
  PyObject *__pyx_n_s_keys;
  PyObject *__pyx_n_s_last_insert_rowid;
  PyObject *__pyx_n_s_length;
  PyObject *__pyx_n_s_literal;
  PyObject *__pyx_n_s_m;
  PyObject *__pyx_n_u_main;
  PyObject *__pyx_n_s_main_2;
  PyObject *__pyx_n_s_make_hash;
  PyObject *__pyx_n_s_make_hash_locals_inner;
  PyObject *__pyx_n_s_match_info;
  PyObject *__pyx_n_s_match_info_buf;
  PyObject *__pyx_n_s_match_info_buf_2;
  PyObject *__pyx_n_s_max_length;
  PyObject *__pyx_n_s_md5;
  PyObject *__pyx_n_u_md5;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_n_s_mro_entries;
  PyObject *__pyx_n_u_murmurhash;
  PyObject *__pyx_n_s_n;
  PyObject *__pyx_n_s_n_items;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_ncol;
  PyObject *__pyx_n_s_ncols;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
  PyObject *__pyx_kp_u_no_row_data;
  PyObject *__pyx_n_s_nphrase;
  PyObject *__pyx_n_s_nseed;
  PyObject *__pyx_n_s_num;
  PyObject *__pyx_n_s_object;
  PyObject *__pyx_n_s_offset;
  PyObject *__pyx_n_s_p;
  PyObject *__pyx_n_s_page_count;
  PyObject *__pyx_n_s_page_step;
  PyObject *__pyx_n_s_pages;
  PyObject *__pyx_n_s_pairs;
  PyObject *__pyx_n_s_param;
  PyObject *__pyx_n_s_params;
  PyObject *__pyx_n_s_pc_score;
  PyObject *__pyx_n_s_peewee;
  PyObject *__pyx_n_s_peewee_bloomfilter_add;
  PyObject *__pyx_n_s_peewee_bloomfilter_calculate_siz;
  PyObject *__pyx_n_s_peewee_bloomfilter_contains;
  PyObject *__pyx_n_s_peewee_bm25;
  PyObject *__pyx_n_s_peewee_bm25f;
  PyObject *__pyx_n_s_peewee_lucene;
  PyObject *__pyx_n_s_peewee_md5;
  PyObject *__pyx_n_s_peewee_murmurhash;
  PyObject *__pyx_n_s_peewee_rank;
  PyObject *__pyx_n_s_peewee_sha1;
  PyObject *__pyx_n_s_peewee_sha256;
  PyObject *__pyx_n_s_phrase_info;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_playhouse__sqlite_ext;
  PyObject *__pyx_kp_s_playhouse__sqlite_ext_pyx;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_s_print_exc;
  PyObject *__pyx_n_s_print_tracebacks;
  PyObject *__pyx_n_s_progress;
  PyObject *__pyx_n_s_py_match_info;
  PyObject *__pyx_n_s_pybuf;
  PyObject *__pyx_n_s_pysqlite;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_BloomFilterAggreg;
  PyObject *__pyx_n_s_pyx_vtable;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_ratio;
  PyObject *__pyx_n_s_raw_weights;
  PyObject *__pyx_n_s_rc;
  PyObject *__pyx_n_s_read;
  PyObject *__pyx_n_s_read_only;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_register;
  PyObject *__pyx_n_s_register_aggregate;
  PyObject *__pyx_n_s_register_bloomfilter;
  PyObject *__pyx_n_s_register_function;
  PyObject *__pyx_n_s_register_functions;
  PyObject *__pyx_n_s_register_hash_functions;
  PyObject *__pyx_n_s_register_rank_functions;
  PyObject *__pyx_n_s_remaining;
  PyObject *__pyx_n_s_reopen;
  PyObject *__pyx_n_s_rhs;
  PyObject *__pyx_n_s_rowid;
  PyObject *__pyx_kp_u_s_HIDDEN;
  PyObject *__pyx_kp_u_s_s;
  PyObject *__pyx_n_s_score;
  PyObject *__pyx_n_s_seed;
  PyObject *__pyx_n_s_seek;
  PyObject *__pyx_kp_u_seek_frame_of_reference_must_be;
  PyObject *__pyx_kp_u_seek_offset_outside_of_valid_ran;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_kp_s_self_bf_cannot_be_converted_to_a;
  PyObject *__pyx_kp_s_self_conn_cannot_be_converted_to;
  PyObject *__pyx_kp_s_self_conn_self_pBlob_cannot_be_c;
  PyObject *__pyx_n_s_set_busy_handler;
  PyObject *__pyx_n_s_set_commit_hook;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_set_rollback_hook;
  PyObject *__pyx_n_s_set_update_hook;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_sha1;
  PyObject *__pyx_n_u_sha1;
  PyObject *__pyx_n_s_sha256;
  PyObject *__pyx_n_u_sha256;
  PyObject *__pyx_n_s_size;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_sql;
  PyObject *__pyx_n_s_sqlite3;
  PyObject *__pyx_n_s_sqlite_get_db_status;
  PyObject *__pyx_n_s_sqlite_get_status;
  PyObject *__pyx_n_s_src;
  PyObject *__pyx_n_s_src_conn;
  PyObject *__pyx_n_s_src_db;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_state_2;
  PyObject *__pyx_n_s_step;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_table;
  PyObject *__pyx_n_s_table_function;
  PyObject *__pyx_n_s_tell;
  PyObject *__pyx_n_s_term_frequency;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_tf;
  PyObject *__pyx_n_s_timeout;
  PyObject *__pyx_n_s_to_buffer;
  PyObject *__pyx_n_s_total_docs;
  PyObject *__pyx_n_s_traceback;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_use_setstate;
  PyObject *__pyx_kp_u_utf_8;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_n_s_weight;
  PyObject *__pyx_n_s_weights;
  PyObject *__pyx_n_s_write;
  PyObject *__pyx_n_s_x;
  PyObject *__pyx_kp_u_zeroblob_s;
  PyObject *__pyx_n_s_zlib;
  PyObject *__pyx_float_1_0;
  PyObject *__pyx_float_2_0;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_5;
  PyObject *__pyx_int_1000;
  PyObject *__pyx_int_32768;
  PyObject *__pyx_int_5135835;
  PyObject *__pyx_int_211787133;
  PyObject *__pyx_int_230328617;
  PyObject *__pyx_tuple_;
  PyObject *__pyx_tuple__3;
  PyObject *__pyx_tuple__5;
  PyObject *__pyx_tuple__7;
  PyObject *__pyx_tuple__8;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__12;
  PyObject *__pyx_tuple__13;
  PyObject *__pyx_tuple__14;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__18;
  PyObject *__pyx_tuple__20;
  PyObject *__pyx_tuple__22;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_tuple__26;
  PyObject *__pyx_tuple__28;
  PyObject *__pyx_tuple__30;
  PyObject *__pyx_tuple__32;
  PyObject *__pyx_tuple__34;
  PyObject *__pyx_tuple__36;
  PyObject *__pyx_tuple__38;
  PyObject *__pyx_tuple__40;
  PyObject *__pyx_tuple__42;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__45;
  PyObject *__pyx_tuple__47;
  PyObject *__pyx_tuple__50;
  PyObject *__pyx_tuple__52;
  PyObject *__pyx_tuple__54;
  PyObject *__pyx_tuple__56;
  PyObject *__pyx_tuple__60;
  PyObject *__pyx_tuple__62;
  PyObject *__pyx_tuple__64;
  PyObject *__pyx_tuple__67;
  PyObject *__pyx_tuple__69;
  PyObject *__pyx_tuple__71;
  PyObject *__pyx_tuple__74;
  PyObject *__pyx_tuple__76;
  PyObject *__pyx_tuple__78;
  PyObject *__pyx_tuple__80;
  PyObject *__pyx_tuple__82;
  PyObject *__pyx_tuple__84;
  PyObject *__pyx_tuple__87;
  PyObject *__pyx_tuple__91;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_tuple__95;
  PyObject *__pyx_tuple__99;
  PyObject *__pyx_codeobj__6;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__107;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_tuple__110;
  PyObject *__pyx_tuple__112;
  PyObject *__pyx_tuple__113;
  PyObject *__pyx_codeobj__19;
  PyObject *__pyx_codeobj__21;
  PyObject *__pyx_codeobj__25;
  PyObject *__pyx_codeobj__27;
  PyObject *__pyx_codeobj__29;
  PyObject *__pyx_codeobj__31;
  PyObject *__pyx_codeobj__33;
  PyObject *__pyx_codeobj__35;
  PyObject *__pyx_codeobj__37;
  PyObject *__pyx_codeobj__39;
  PyObject *__pyx_codeobj__41;
  PyObject *__pyx_codeobj__44;
  PyObject *__pyx_codeobj__46;
  PyObject *__pyx_codeobj__48;
  PyObject *__pyx_codeobj__49;
  PyObject *__pyx_codeobj__51;
  PyObject *__pyx_codeobj__53;
  PyObject *__pyx_codeobj__55;
  PyObject *__pyx_codeobj__57;
  PyObject *__pyx_codeobj__58;
  PyObject *__pyx_codeobj__59;
  PyObject *__pyx_codeobj__61;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__65;
  PyObject *__pyx_codeobj__66;
  PyObject *__pyx_codeobj__68;
  PyObject *__pyx_codeobj__70;
  PyObject *__pyx_codeobj__72;
  PyObject *__pyx_codeobj__73;
  PyObject *__pyx_codeobj__75;
  PyObject *__pyx_codeobj__77;
  PyObject *__pyx_codeobj__79;
  PyObject *__pyx_codeobj__81;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__85;
  PyObject *__pyx_codeobj__86;
  PyObject *__pyx_codeobj__88;
  PyObject *__pyx_codeobj__89;
  PyObject *__pyx_codeobj__90;
  PyObject *__pyx_codeobj__92;
  PyObject *__pyx_codeobj__94;
  PyObject *__pyx_codeobj__96;
  PyObject *__pyx_codeobj__97;
  PyObject *__pyx_codeobj__98;
  PyObject *__pyx_codeobj__100;
  PyObject *__pyx_codeobj__102;
  PyObject *__pyx_codeobj__103;
  PyObject *__pyx_codeobj__104;
  PyObject *__pyx_codeobj__105;
  PyObject *__pyx_codeobj__106;
  PyObject *__pyx_codeobj__108;
  PyObject *__pyx_codeobj__111;
  PyObject *__pyx_codeobj__114;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_date);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_time);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_datetime);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_timedelta);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_tzinfo);
  Py_CLEAR(clear_module_state->__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl);
  Py_CLEAR(clear_module_state->__pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl);
  Py_CLEAR(clear_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);
  Py_CLEAR(clear_module_state->__pyx_type_9playhouse_11_sqlite_ext_BloomFilter);
  Py_CLEAR(clear_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate);
  Py_CLEAR(clear_module_state->__pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate);
  Py_CLEAR(clear_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_Blob);
  Py_CLEAR(clear_module_state->__pyx_type_9playhouse_11_sqlite_ext_Blob);
  Py_CLEAR(clear_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);
  Py_CLEAR(clear_module_state->__pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash);
  Py_CLEAR(clear_module_state->__pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash);
  Py_CLEAR(clear_module_state->__pyx_kp_b_3_26);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_O);
  Py_CLEAR(clear_module_state->__pyx_n_s_B);
  Py_CLEAR(clear_module_state->__pyx_n_s_Binary);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob_close);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Blob_index_out_of_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob_read);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob_reopen);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob_seek);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob_tell);
  Py_CLEAR(clear_module_state->__pyx_n_s_Blob_write);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilter);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilterAggregate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilterAggregate___reduce_cy);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilterAggregate___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilterAggregate_finalize);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilterAggregate_step);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilter___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilter___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilter_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilter_calculate_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilter_from_buffer);
  Py_CLEAR(clear_module_state->__pyx_n_s_BloomFilter_to_buffer);
  Py_CLEAR(clear_module_state->__pyx_kp_u_CREATE_TABLE_x_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_C_O);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_operate_on_closed_blob);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_operate_on_closed_databas);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Column_must_be_either_a_string_o);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper_autocommit);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper_changes);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper_last_insert_row);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper_set_busy_handle);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper_set_commit_hook);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper_set_rollback_ho);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConnectionHelper_set_update_hook);
  Py_CLEAR(clear_module_state->__pyx_n_u_DELETE);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Data_would_go_beyond_end_of_blob);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Error_backuping_up_database_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Error_reading_from_blob);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Error_requesting_db_status_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Error_requesting_status_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Error_writing_to_blob);
  Py_CLEAR(clear_module_state->__pyx_n_u_INSERT);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_IndexError);
  Py_CLEAR(clear_module_state->__pyx_n_s_InterfaceError);
  Py_CLEAR(clear_module_state->__pyx_n_s_K);
  Py_CLEAR(clear_module_state->__pyx_n_s_L_O);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Length_must_be_a_positive_intege);
  Py_CLEAR(clear_module_state->__pyx_n_s_MemoryError);
  Py_CLEAR(clear_module_state->__pyx_n_s_N_O);
  Py_CLEAR(clear_module_state->__pyx_n_s_Node);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotImplementedError);
  Py_CLEAR(clear_module_state->__pyx_n_s_OperationalError);
  Py_CLEAR(clear_module_state->__pyx_n_s_P_O);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_RuntimeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_StopIteration);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunction);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunctionImpl);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunctionImpl___reduce_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunctionImpl___setstate_cy);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunction_get_table_columns);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunction_initialize);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunction_iterate);
  Py_CLEAR(clear_module_state->__pyx_n_s_TableFunction_register);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Time_zones_are_not_available_fro);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_n_u_UPDATE);
  Py_CLEAR(clear_module_state->__pyx_n_s_USE_SQLITE_CONSTRAINT);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unable_to_allocate_blob);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unable_to_initialize_backup);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unable_to_open_blob);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unable_to_re_open_blob);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unsupported_type_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s_X_O);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZeroBlob);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZeroBlob___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_ZeroBlob___sql);
  Py_CLEAR(clear_module_state->__pyx_kp_b__10);
  Py_CLEAR(clear_module_state->__pyx_kp_u__10);
  Py_CLEAR(clear_module_state->__pyx_n_s__115);
  Py_CLEAR(clear_module_state->__pyx_kp_u__16);
  Py_CLEAR(clear_module_state->__pyx_n_s__17);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_kp_u__4);
  Py_CLEAR(clear_module_state->__pyx_kp_u__9);
  Py_CLEAR(clear_module_state->__pyx_n_s_accum);
  Py_CLEAR(clear_module_state->__pyx_n_s_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_adler32);
  Py_CLEAR(clear_module_state->__pyx_n_u_adler32);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_autocommit);
  Py_CLEAR(clear_module_state->__pyx_n_s_avg_length);
  Py_CLEAR(clear_module_state->__pyx_n_s_b_part);
  Py_CLEAR(clear_module_state->__pyx_n_s_backup);
  Py_CLEAR(clear_module_state->__pyx_n_s_backup_to_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_bdata);
  Py_CLEAR(clear_module_state->__pyx_n_s_bf);
  Py_CLEAR(clear_module_state->__pyx_n_s_bkey);
  Py_CLEAR(clear_module_state->__pyx_n_s_bloom);
  Py_CLEAR(clear_module_state->__pyx_n_u_bloomfilter);
  Py_CLEAR(clear_module_state->__pyx_n_u_bloomfilter_add);
  Py_CLEAR(clear_module_state->__pyx_n_u_bloomfilter_calculate_size);
  Py_CLEAR(clear_module_state->__pyx_n_u_bloomfilter_contains);
  Py_CLEAR(clear_module_state->__pyx_n_s_bname);
  Py_CLEAR(clear_module_state->__pyx_n_s_buf);
  Py_CLEAR(clear_module_state->__pyx_n_s_buflen);
  Py_CLEAR(clear_module_state->__pyx_n_s_c_conn);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_size);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cannot_backup_to_or_from_a_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_cdata);
  Py_CLEAR(clear_module_state->__pyx_n_s_changes);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_cls);
  Py_CLEAR(clear_module_state->__pyx_n_s_column);
  Py_CLEAR(clear_module_state->__pyx_n_s_columns);
  Py_CLEAR(clear_module_state->__pyx_n_s_conn);
  Py_CLEAR(clear_module_state->__pyx_n_s_connect);
  Py_CLEAR(clear_module_state->__pyx_n_s_connection);
  Py_CLEAR(clear_module_state->__pyx_n_s_crc32);
  Py_CLEAR(clear_module_state->__pyx_n_u_crc32);
  Py_CLEAR(clear_module_state->__pyx_n_s_ctx);
  Py_CLEAR(clear_module_state->__pyx_n_s_current);
  Py_CLEAR(clear_module_state->__pyx_n_s_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_database);
  Py_CLEAR(clear_module_state->__pyx_n_s_decode);
  Py_CLEAR(clear_module_state->__pyx_n_s_denom);
  Py_CLEAR(clear_module_state->__pyx_n_s_dest);
  Py_CLEAR(clear_module_state->__pyx_n_s_dest_conn);
  Py_CLEAR(clear_module_state->__pyx_n_s_dest_db);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc_length);
  Py_CLEAR(clear_module_state->__pyx_n_s_docs_with_term);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_enumerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_epsilon);
  Py_CLEAR(clear_module_state->__pyx_n_s_error_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_fieldNorms);
  Py_CLEAR(clear_module_state->__pyx_n_s_filename);
  Py_CLEAR(clear_module_state->__pyx_n_s_filters);
  Py_CLEAR(clear_module_state->__pyx_n_s_finalize);
  Py_CLEAR(clear_module_state->__pyx_n_s_flag);
  Py_CLEAR(clear_module_state->__pyx_n_s_fn);
  Py_CLEAR(clear_module_state->__pyx_n_s_frame_of_reference);
  Py_CLEAR(clear_module_state->__pyx_n_s_from_buffer);
  Py_CLEAR(clear_module_state->__pyx_n_u_fts_bm25);
  Py_CLEAR(clear_module_state->__pyx_n_u_fts_bm25f);
  Py_CLEAR(clear_module_state->__pyx_n_u_fts_lucene);
  Py_CLEAR(clear_module_state->__pyx_n_u_fts_rank);
  Py_CLEAR(clear_module_state->__pyx_n_s_func);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_table_columns_declaration);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_global_hits);
  Py_CLEAR(clear_module_state->__pyx_n_s_hash_impl);
  Py_CLEAR(clear_module_state->__pyx_n_s_hashlib);
  Py_CLEAR(clear_module_state->__pyx_n_s_hexdigest);
  Py_CLEAR(clear_module_state->__pyx_n_s_highwater);
  Py_CLEAR(clear_module_state->__pyx_n_s_hits);
  Py_CLEAR(clear_module_state->__pyx_n_s_icol);
  Py_CLEAR(clear_module_state->__pyx_n_s_idf);
  Py_CLEAR(clear_module_state->__pyx_n_s_idx);
  Py_CLEAR(clear_module_state->__pyx_n_s_impl);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initialize);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_inner);
  Py_CLEAR(clear_module_state->__pyx_n_s_iphrase);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_iterate);
  Py_CLEAR(clear_module_state->__pyx_n_s_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_last_insert_rowid);
  Py_CLEAR(clear_module_state->__pyx_n_s_length);
  Py_CLEAR(clear_module_state->__pyx_n_s_literal);
  Py_CLEAR(clear_module_state->__pyx_n_s_m);
  Py_CLEAR(clear_module_state->__pyx_n_u_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_main_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_hash);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_hash_locals_inner);
  Py_CLEAR(clear_module_state->__pyx_n_s_match_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_match_info_buf);
  Py_CLEAR(clear_module_state->__pyx_n_s_match_info_buf_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_max_length);
  Py_CLEAR(clear_module_state->__pyx_n_s_md5);
  Py_CLEAR(clear_module_state->__pyx_n_u_md5);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro_entries);
  Py_CLEAR(clear_module_state->__pyx_n_u_murmurhash);
  Py_CLEAR(clear_module_state->__pyx_n_s_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_n_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ncol);
  Py_CLEAR(clear_module_state->__pyx_n_s_ncols);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_CLEAR(clear_module_state->__pyx_kp_u_no_row_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_nphrase);
  Py_CLEAR(clear_module_state->__pyx_n_s_nseed);
  Py_CLEAR(clear_module_state->__pyx_n_s_num);
  Py_CLEAR(clear_module_state->__pyx_n_s_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_page_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_page_step);
  Py_CLEAR(clear_module_state->__pyx_n_s_pages);
  Py_CLEAR(clear_module_state->__pyx_n_s_pairs);
  Py_CLEAR(clear_module_state->__pyx_n_s_param);
  Py_CLEAR(clear_module_state->__pyx_n_s_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_pc_score);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_bloomfilter_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_bloomfilter_calculate_siz);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_bloomfilter_contains);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_bm25);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_bm25f);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_lucene);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_md5);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_murmurhash);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_rank);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_sha1);
  Py_CLEAR(clear_module_state->__pyx_n_s_peewee_sha256);
  Py_CLEAR(clear_module_state->__pyx_n_s_phrase_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_playhouse__sqlite_ext);
  Py_CLEAR(clear_module_state->__pyx_kp_s_playhouse__sqlite_ext_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_s_print_exc);
  Py_CLEAR(clear_module_state->__pyx_n_s_print_tracebacks);
  Py_CLEAR(clear_module_state->__pyx_n_s_progress);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_match_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_pybuf);
  Py_CLEAR(clear_module_state->__pyx_n_s_pysqlite);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_BloomFilterAggreg);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_vtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_raw_weights);
  Py_CLEAR(clear_module_state->__pyx_n_s_rc);
  Py_CLEAR(clear_module_state->__pyx_n_s_read);
  Py_CLEAR(clear_module_state->__pyx_n_s_read_only);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_register);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_aggregate);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_bloomfilter);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_function);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_functions);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_hash_functions);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_rank_functions);
  Py_CLEAR(clear_module_state->__pyx_n_s_remaining);
  Py_CLEAR(clear_module_state->__pyx_n_s_reopen);
  Py_CLEAR(clear_module_state->__pyx_n_s_rhs);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowid);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_HIDDEN);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_score);
  Py_CLEAR(clear_module_state->__pyx_n_s_seed);
  Py_CLEAR(clear_module_state->__pyx_n_s_seek);
  Py_CLEAR(clear_module_state->__pyx_kp_u_seek_frame_of_reference_must_be);
  Py_CLEAR(clear_module_state->__pyx_kp_u_seek_offset_outside_of_valid_ran);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_bf_cannot_be_converted_to_a);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_conn_cannot_be_converted_to);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_conn_self_pBlob_cannot_be_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_busy_handler);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_commit_hook);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_rollback_hook);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_update_hook);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_sha1);
  Py_CLEAR(clear_module_state->__pyx_n_u_sha1);
  Py_CLEAR(clear_module_state->__pyx_n_s_sha256);
  Py_CLEAR(clear_module_state->__pyx_n_u_sha256);
  Py_CLEAR(clear_module_state->__pyx_n_s_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_sql);
  Py_CLEAR(clear_module_state->__pyx_n_s_sqlite3);
  Py_CLEAR(clear_module_state->__pyx_n_s_sqlite_get_db_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_sqlite_get_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_src);
  Py_CLEAR(clear_module_state->__pyx_n_s_src_conn);
  Py_CLEAR(clear_module_state->__pyx_n_s_src_db);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_state_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_step);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_table);
  Py_CLEAR(clear_module_state->__pyx_n_s_table_function);
  Py_CLEAR(clear_module_state->__pyx_n_s_tell);
  Py_CLEAR(clear_module_state->__pyx_n_s_term_frequency);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_tf);
  Py_CLEAR(clear_module_state->__pyx_n_s_timeout);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_buffer);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_docs);
  Py_CLEAR(clear_module_state->__pyx_n_s_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_setstate);
  Py_CLEAR(clear_module_state->__pyx_kp_u_utf_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_weights);
  Py_CLEAR(clear_module_state->__pyx_n_s_write);
  Py_CLEAR(clear_module_state->__pyx_n_s_x);
  Py_CLEAR(clear_module_state->__pyx_kp_u_zeroblob_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_zlib);
  Py_CLEAR(clear_module_state->__pyx_float_1_0);
  Py_CLEAR(clear_module_state->__pyx_float_2_0);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_5);
  Py_CLEAR(clear_module_state->__pyx_int_1000);
  Py_CLEAR(clear_module_state->__pyx_int_32768);
  Py_CLEAR(clear_module_state->__pyx_int_5135835);
  Py_CLEAR(clear_module_state->__pyx_int_211787133);
  Py_CLEAR(clear_module_state->__pyx_int_230328617);
  Py_CLEAR(clear_module_state->__pyx_tuple_);
  Py_CLEAR(clear_module_state->__pyx_tuple__3);
  Py_CLEAR(clear_module_state->__pyx_tuple__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__7);
  Py_CLEAR(clear_module_state->__pyx_tuple__8);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__12);
  Py_CLEAR(clear_module_state->__pyx_tuple__13);
  Py_CLEAR(clear_module_state->__pyx_tuple__14);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__18);
  Py_CLEAR(clear_module_state->__pyx_tuple__20);
  Py_CLEAR(clear_module_state->__pyx_tuple__22);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__26);
  Py_CLEAR(clear_module_state->__pyx_tuple__28);
  Py_CLEAR(clear_module_state->__pyx_tuple__30);
  Py_CLEAR(clear_module_state->__pyx_tuple__32);
  Py_CLEAR(clear_module_state->__pyx_tuple__34);
  Py_CLEAR(clear_module_state->__pyx_tuple__36);
  Py_CLEAR(clear_module_state->__pyx_tuple__38);
  Py_CLEAR(clear_module_state->__pyx_tuple__40);
  Py_CLEAR(clear_module_state->__pyx_tuple__42);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__45);
  Py_CLEAR(clear_module_state->__pyx_tuple__47);
  Py_CLEAR(clear_module_state->__pyx_tuple__50);
  Py_CLEAR(clear_module_state->__pyx_tuple__52);
  Py_CLEAR(clear_module_state->__pyx_tuple__54);
  Py_CLEAR(clear_module_state->__pyx_tuple__56);
  Py_CLEAR(clear_module_state->__pyx_tuple__60);
  Py_CLEAR(clear_module_state->__pyx_tuple__62);
  Py_CLEAR(clear_module_state->__pyx_tuple__64);
  Py_CLEAR(clear_module_state->__pyx_tuple__67);
  Py_CLEAR(clear_module_state->__pyx_tuple__69);
  Py_CLEAR(clear_module_state->__pyx_tuple__71);
  Py_CLEAR(clear_module_state->__pyx_tuple__74);
  Py_CLEAR(clear_module_state->__pyx_tuple__76);
  Py_CLEAR(clear_module_state->__pyx_tuple__78);
  Py_CLEAR(clear_module_state->__pyx_tuple__80);
  Py_CLEAR(clear_module_state->__pyx_tuple__82);
  Py_CLEAR(clear_module_state->__pyx_tuple__84);
  Py_CLEAR(clear_module_state->__pyx_tuple__87);
  Py_CLEAR(clear_module_state->__pyx_tuple__91);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_tuple__95);
  Py_CLEAR(clear_module_state->__pyx_tuple__99);
  Py_CLEAR(clear_module_state->__pyx_codeobj__6);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__107);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_tuple__110);
  Py_CLEAR(clear_module_state->__pyx_tuple__112);
  Py_CLEAR(clear_module_state->__pyx_tuple__113);
  Py_CLEAR(clear_module_state->__pyx_codeobj__19);
  Py_CLEAR(clear_module_state->__pyx_codeobj__21);
  Py_CLEAR(clear_module_state->__pyx_codeobj__25);
  Py_CLEAR(clear_module_state->__pyx_codeobj__27);
  Py_CLEAR(clear_module_state->__pyx_codeobj__29);
  Py_CLEAR(clear_module_state->__pyx_codeobj__31);
  Py_CLEAR(clear_module_state->__pyx_codeobj__33);
  Py_CLEAR(clear_module_state->__pyx_codeobj__35);
  Py_CLEAR(clear_module_state->__pyx_codeobj__37);
  Py_CLEAR(clear_module_state->__pyx_codeobj__39);
  Py_CLEAR(clear_module_state->__pyx_codeobj__41);
  Py_CLEAR(clear_module_state->__pyx_codeobj__44);
  Py_CLEAR(clear_module_state->__pyx_codeobj__46);
  Py_CLEAR(clear_module_state->__pyx_codeobj__48);
  Py_CLEAR(clear_module_state->__pyx_codeobj__49);
  Py_CLEAR(clear_module_state->__pyx_codeobj__51);
  Py_CLEAR(clear_module_state->__pyx_codeobj__53);
  Py_CLEAR(clear_module_state->__pyx_codeobj__55);
  Py_CLEAR(clear_module_state->__pyx_codeobj__57);
  Py_CLEAR(clear_module_state->__pyx_codeobj__58);
  Py_CLEAR(clear_module_state->__pyx_codeobj__59);
  Py_CLEAR(clear_module_state->__pyx_codeobj__61);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__65);
  Py_CLEAR(clear_module_state->__pyx_codeobj__66);
  Py_CLEAR(clear_module_state->__pyx_codeobj__68);
  Py_CLEAR(clear_module_state->__pyx_codeobj__70);
  Py_CLEAR(clear_module_state->__pyx_codeobj__72);
  Py_CLEAR(clear_module_state->__pyx_codeobj__73);
  Py_CLEAR(clear_module_state->__pyx_codeobj__75);
  Py_CLEAR(clear_module_state->__pyx_codeobj__77);
  Py_CLEAR(clear_module_state->__pyx_codeobj__79);
  Py_CLEAR(clear_module_state->__pyx_codeobj__81);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__85);
  Py_CLEAR(clear_module_state->__pyx_codeobj__86);
  Py_CLEAR(clear_module_state->__pyx_codeobj__88);
  Py_CLEAR(clear_module_state->__pyx_codeobj__89);
  Py_CLEAR(clear_module_state->__pyx_codeobj__90);
  Py_CLEAR(clear_module_state->__pyx_codeobj__92);
  Py_CLEAR(clear_module_state->__pyx_codeobj__94);
  Py_CLEAR(clear_module_state->__pyx_codeobj__96);
  Py_CLEAR(clear_module_state->__pyx_codeobj__97);
  Py_CLEAR(clear_module_state->__pyx_codeobj__98);
  Py_CLEAR(clear_module_state->__pyx_codeobj__100);
  Py_CLEAR(clear_module_state->__pyx_codeobj__102);
  Py_CLEAR(clear_module_state->__pyx_codeobj__103);
  Py_CLEAR(clear_module_state->__pyx_codeobj__104);
  Py_CLEAR(clear_module_state->__pyx_codeobj__105);
  Py_CLEAR(clear_module_state->__pyx_codeobj__106);
  Py_CLEAR(clear_module_state->__pyx_codeobj__108);
  Py_CLEAR(clear_module_state->__pyx_codeobj__111);
  Py_CLEAR(clear_module_state->__pyx_codeobj__114);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_date);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_time);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_datetime);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_timedelta);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_tzinfo);
  Py_VISIT(traverse_module_state->__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl);
  Py_VISIT(traverse_module_state->__pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl);
  Py_VISIT(traverse_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);
  Py_VISIT(traverse_module_state->__pyx_type_9playhouse_11_sqlite_ext_BloomFilter);
  Py_VISIT(traverse_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate);
  Py_VISIT(traverse_module_state->__pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate);
  Py_VISIT(traverse_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_Blob);
  Py_VISIT(traverse_module_state->__pyx_type_9playhouse_11_sqlite_ext_Blob);
  Py_VISIT(traverse_module_state->__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);
  Py_VISIT(traverse_module_state->__pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash);
  Py_VISIT(traverse_module_state->__pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash);
  Py_VISIT(traverse_module_state->__pyx_kp_b_3_26);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_O);
  Py_VISIT(traverse_module_state->__pyx_n_s_B);
  Py_VISIT(traverse_module_state->__pyx_n_s_Binary);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob_close);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Blob_index_out_of_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob_read);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob_reopen);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob_seek);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob_tell);
  Py_VISIT(traverse_module_state->__pyx_n_s_Blob_write);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilter);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilterAggregate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilterAggregate___reduce_cy);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilterAggregate___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilterAggregate_finalize);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilterAggregate_step);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilter___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilter___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilter_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilter_calculate_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilter_from_buffer);
  Py_VISIT(traverse_module_state->__pyx_n_s_BloomFilter_to_buffer);
  Py_VISIT(traverse_module_state->__pyx_kp_u_CREATE_TABLE_x_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_C_O);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_operate_on_closed_blob);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_operate_on_closed_databas);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Column_must_be_either_a_string_o);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper_autocommit);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper_changes);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper_last_insert_row);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper_set_busy_handle);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper_set_commit_hook);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper_set_rollback_ho);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConnectionHelper_set_update_hook);
  Py_VISIT(traverse_module_state->__pyx_n_u_DELETE);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Data_would_go_beyond_end_of_blob);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Error_backuping_up_database_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Error_reading_from_blob);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Error_requesting_db_status_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Error_requesting_status_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Error_writing_to_blob);
  Py_VISIT(traverse_module_state->__pyx_n_u_INSERT);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_IndexError);
  Py_VISIT(traverse_module_state->__pyx_n_s_InterfaceError);
  Py_VISIT(traverse_module_state->__pyx_n_s_K);
  Py_VISIT(traverse_module_state->__pyx_n_s_L_O);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Length_must_be_a_positive_intege);
  Py_VISIT(traverse_module_state->__pyx_n_s_MemoryError);
  Py_VISIT(traverse_module_state->__pyx_n_s_N_O);
  Py_VISIT(traverse_module_state->__pyx_n_s_Node);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotImplementedError);
  Py_VISIT(traverse_module_state->__pyx_n_s_OperationalError);
  Py_VISIT(traverse_module_state->__pyx_n_s_P_O);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_RuntimeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_StopIteration);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunction);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunctionImpl);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunctionImpl___reduce_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunctionImpl___setstate_cy);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunction_get_table_columns);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunction_initialize);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunction_iterate);
  Py_VISIT(traverse_module_state->__pyx_n_s_TableFunction_register);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Time_zones_are_not_available_fro);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_n_u_UPDATE);
  Py_VISIT(traverse_module_state->__pyx_n_s_USE_SQLITE_CONSTRAINT);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unable_to_allocate_blob);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unable_to_initialize_backup);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unable_to_open_blob);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unable_to_re_open_blob);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unsupported_type_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s_X_O);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZeroBlob);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZeroBlob___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_ZeroBlob___sql);
  Py_VISIT(traverse_module_state->__pyx_kp_b__10);
  Py_VISIT(traverse_module_state->__pyx_kp_u__10);
  Py_VISIT(traverse_module_state->__pyx_n_s__115);
  Py_VISIT(traverse_module_state->__pyx_kp_u__16);
  Py_VISIT(traverse_module_state->__pyx_n_s__17);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_kp_u__4);
  Py_VISIT(traverse_module_state->__pyx_kp_u__9);
  Py_VISIT(traverse_module_state->__pyx_n_s_accum);
  Py_VISIT(traverse_module_state->__pyx_n_s_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_adler32);
  Py_VISIT(traverse_module_state->__pyx_n_u_adler32);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_autocommit);
  Py_VISIT(traverse_module_state->__pyx_n_s_avg_length);
  Py_VISIT(traverse_module_state->__pyx_n_s_b_part);
  Py_VISIT(traverse_module_state->__pyx_n_s_backup);
  Py_VISIT(traverse_module_state->__pyx_n_s_backup_to_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_bdata);
  Py_VISIT(traverse_module_state->__pyx_n_s_bf);
  Py_VISIT(traverse_module_state->__pyx_n_s_bkey);
  Py_VISIT(traverse_module_state->__pyx_n_s_bloom);
  Py_VISIT(traverse_module_state->__pyx_n_u_bloomfilter);
  Py_VISIT(traverse_module_state->__pyx_n_u_bloomfilter_add);
  Py_VISIT(traverse_module_state->__pyx_n_u_bloomfilter_calculate_size);
  Py_VISIT(traverse_module_state->__pyx_n_u_bloomfilter_contains);
  Py_VISIT(traverse_module_state->__pyx_n_s_bname);
  Py_VISIT(traverse_module_state->__pyx_n_s_buf);
  Py_VISIT(traverse_module_state->__pyx_n_s_buflen);
  Py_VISIT(traverse_module_state->__pyx_n_s_c_conn);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_size);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cannot_backup_to_or_from_a_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_cdata);
  Py_VISIT(traverse_module_state->__pyx_n_s_changes);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_cls);
  Py_VISIT(traverse_module_state->__pyx_n_s_column);
  Py_VISIT(traverse_module_state->__pyx_n_s_columns);
  Py_VISIT(traverse_module_state->__pyx_n_s_conn);
  Py_VISIT(traverse_module_state->__pyx_n_s_connect);
  Py_VISIT(traverse_module_state->__pyx_n_s_connection);
  Py_VISIT(traverse_module_state->__pyx_n_s_crc32);
  Py_VISIT(traverse_module_state->__pyx_n_u_crc32);
  Py_VISIT(traverse_module_state->__pyx_n_s_ctx);
  Py_VISIT(traverse_module_state->__pyx_n_s_current);
  Py_VISIT(traverse_module_state->__pyx_n_s_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_database);
  Py_VISIT(traverse_module_state->__pyx_n_s_decode);
  Py_VISIT(traverse_module_state->__pyx_n_s_denom);
  Py_VISIT(traverse_module_state->__pyx_n_s_dest);
  Py_VISIT(traverse_module_state->__pyx_n_s_dest_conn);
  Py_VISIT(traverse_module_state->__pyx_n_s_dest_db);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc_length);
  Py_VISIT(traverse_module_state->__pyx_n_s_docs_with_term);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_enumerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_epsilon);
  Py_VISIT(traverse_module_state->__pyx_n_s_error_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_fieldNorms);
  Py_VISIT(traverse_module_state->__pyx_n_s_filename);
  Py_VISIT(traverse_module_state->__pyx_n_s_filters);
  Py_VISIT(traverse_module_state->__pyx_n_s_finalize);
  Py_VISIT(traverse_module_state->__pyx_n_s_flag);
  Py_VISIT(traverse_module_state->__pyx_n_s_fn);
  Py_VISIT(traverse_module_state->__pyx_n_s_frame_of_reference);
  Py_VISIT(traverse_module_state->__pyx_n_s_from_buffer);
  Py_VISIT(traverse_module_state->__pyx_n_u_fts_bm25);
  Py_VISIT(traverse_module_state->__pyx_n_u_fts_bm25f);
  Py_VISIT(traverse_module_state->__pyx_n_u_fts_lucene);
  Py_VISIT(traverse_module_state->__pyx_n_u_fts_rank);
  Py_VISIT(traverse_module_state->__pyx_n_s_func);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_table_columns_declaration);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_global_hits);
  Py_VISIT(traverse_module_state->__pyx_n_s_hash_impl);
  Py_VISIT(traverse_module_state->__pyx_n_s_hashlib);
  Py_VISIT(traverse_module_state->__pyx_n_s_hexdigest);
  Py_VISIT(traverse_module_state->__pyx_n_s_highwater);
  Py_VISIT(traverse_module_state->__pyx_n_s_hits);
  Py_VISIT(traverse_module_state->__pyx_n_s_icol);
  Py_VISIT(traverse_module_state->__pyx_n_s_idf);
  Py_VISIT(traverse_module_state->__pyx_n_s_idx);
  Py_VISIT(traverse_module_state->__pyx_n_s_impl);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initialize);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_inner);
  Py_VISIT(traverse_module_state->__pyx_n_s_iphrase);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_iterate);
  Py_VISIT(traverse_module_state->__pyx_n_s_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_last_insert_rowid);
  Py_VISIT(traverse_module_state->__pyx_n_s_length);
  Py_VISIT(traverse_module_state->__pyx_n_s_literal);
  Py_VISIT(traverse_module_state->__pyx_n_s_m);
  Py_VISIT(traverse_module_state->__pyx_n_u_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_main_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_hash);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_hash_locals_inner);
  Py_VISIT(traverse_module_state->__pyx_n_s_match_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_match_info_buf);
  Py_VISIT(traverse_module_state->__pyx_n_s_match_info_buf_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_max_length);
  Py_VISIT(traverse_module_state->__pyx_n_s_md5);
  Py_VISIT(traverse_module_state->__pyx_n_u_md5);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro_entries);
  Py_VISIT(traverse_module_state->__pyx_n_u_murmurhash);
  Py_VISIT(traverse_module_state->__pyx_n_s_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_n_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ncol);
  Py_VISIT(traverse_module_state->__pyx_n_s_ncols);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_VISIT(traverse_module_state->__pyx_kp_u_no_row_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_nphrase);
  Py_VISIT(traverse_module_state->__pyx_n_s_nseed);
  Py_VISIT(traverse_module_state->__pyx_n_s_num);
  Py_VISIT(traverse_module_state->__pyx_n_s_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_page_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_page_step);
  Py_VISIT(traverse_module_state->__pyx_n_s_pages);
  Py_VISIT(traverse_module_state->__pyx_n_s_pairs);
  Py_VISIT(traverse_module_state->__pyx_n_s_param);
  Py_VISIT(traverse_module_state->__pyx_n_s_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_pc_score);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_bloomfilter_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_bloomfilter_calculate_siz);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_bloomfilter_contains);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_bm25);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_bm25f);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_lucene);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_md5);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_murmurhash);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_rank);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_sha1);
  Py_VISIT(traverse_module_state->__pyx_n_s_peewee_sha256);
  Py_VISIT(traverse_module_state->__pyx_n_s_phrase_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_playhouse__sqlite_ext);
  Py_VISIT(traverse_module_state->__pyx_kp_s_playhouse__sqlite_ext_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_s_print_exc);
  Py_VISIT(traverse_module_state->__pyx_n_s_print_tracebacks);
  Py_VISIT(traverse_module_state->__pyx_n_s_progress);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_match_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_pybuf);
  Py_VISIT(traverse_module_state->__pyx_n_s_pysqlite);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_BloomFilterAggreg);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_vtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_raw_weights);
  Py_VISIT(traverse_module_state->__pyx_n_s_rc);
  Py_VISIT(traverse_module_state->__pyx_n_s_read);
  Py_VISIT(traverse_module_state->__pyx_n_s_read_only);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_register);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_aggregate);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_bloomfilter);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_function);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_functions);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_hash_functions);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_rank_functions);
  Py_VISIT(traverse_module_state->__pyx_n_s_remaining);
  Py_VISIT(traverse_module_state->__pyx_n_s_reopen);
  Py_VISIT(traverse_module_state->__pyx_n_s_rhs);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowid);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_HIDDEN);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_score);
  Py_VISIT(traverse_module_state->__pyx_n_s_seed);
  Py_VISIT(traverse_module_state->__pyx_n_s_seek);
  Py_VISIT(traverse_module_state->__pyx_kp_u_seek_frame_of_reference_must_be);
  Py_VISIT(traverse_module_state->__pyx_kp_u_seek_offset_outside_of_valid_ran);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_bf_cannot_be_converted_to_a);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_conn_cannot_be_converted_to);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_conn_self_pBlob_cannot_be_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_busy_handler);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_commit_hook);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_rollback_hook);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_update_hook);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_sha1);
  Py_VISIT(traverse_module_state->__pyx_n_u_sha1);
  Py_VISIT(traverse_module_state->__pyx_n_s_sha256);
  Py_VISIT(traverse_module_state->__pyx_n_u_sha256);
  Py_VISIT(traverse_module_state->__pyx_n_s_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_sql);
  Py_VISIT(traverse_module_state->__pyx_n_s_sqlite3);
  Py_VISIT(traverse_module_state->__pyx_n_s_sqlite_get_db_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_sqlite_get_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_src);
  Py_VISIT(traverse_module_state->__pyx_n_s_src_conn);
  Py_VISIT(traverse_module_state->__pyx_n_s_src_db);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_state_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_step);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_table);
  Py_VISIT(traverse_module_state->__pyx_n_s_table_function);
  Py_VISIT(traverse_module_state->__pyx_n_s_tell);
  Py_VISIT(traverse_module_state->__pyx_n_s_term_frequency);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_tf);
  Py_VISIT(traverse_module_state->__pyx_n_s_timeout);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_buffer);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_docs);
  Py_VISIT(traverse_module_state->__pyx_n_s_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_setstate);
  Py_VISIT(traverse_module_state->__pyx_kp_u_utf_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_weights);
  Py_VISIT(traverse_module_state->__pyx_n_s_write);
  Py_VISIT(traverse_module_state->__pyx_n_s_x);
  Py_VISIT(traverse_module_state->__pyx_kp_u_zeroblob_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_zlib);
  Py_VISIT(traverse_module_state->__pyx_float_1_0);
  Py_VISIT(traverse_module_state->__pyx_float_2_0);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_5);
  Py_VISIT(traverse_module_state->__pyx_int_1000);
  Py_VISIT(traverse_module_state->__pyx_int_32768);
  Py_VISIT(traverse_module_state->__pyx_int_5135835);
  Py_VISIT(traverse_module_state->__pyx_int_211787133);
  Py_VISIT(traverse_module_state->__pyx_int_230328617);
  Py_VISIT(traverse_module_state->__pyx_tuple_);
  Py_VISIT(traverse_module_state->__pyx_tuple__3);
  Py_VISIT(traverse_module_state->__pyx_tuple__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__7);
  Py_VISIT(traverse_module_state->__pyx_tuple__8);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__12);
  Py_VISIT(traverse_module_state->__pyx_tuple__13);
  Py_VISIT(traverse_module_state->__pyx_tuple__14);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__18);
  Py_VISIT(traverse_module_state->__pyx_tuple__20);
  Py_VISIT(traverse_module_state->__pyx_tuple__22);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__26);
  Py_VISIT(traverse_module_state->__pyx_tuple__28);
  Py_VISIT(traverse_module_state->__pyx_tuple__30);
  Py_VISIT(traverse_module_state->__pyx_tuple__32);
  Py_VISIT(traverse_module_state->__pyx_tuple__34);
  Py_VISIT(traverse_module_state->__pyx_tuple__36);
  Py_VISIT(traverse_module_state->__pyx_tuple__38);
  Py_VISIT(traverse_module_state->__pyx_tuple__40);
  Py_VISIT(traverse_module_state->__pyx_tuple__42);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__45);
  Py_VISIT(traverse_module_state->__pyx_tuple__47);
  Py_VISIT(traverse_module_state->__pyx_tuple__50);
  Py_VISIT(traverse_module_state->__pyx_tuple__52);
  Py_VISIT(traverse_module_state->__pyx_tuple__54);
  Py_VISIT(traverse_module_state->__pyx_tuple__56);
  Py_VISIT(traverse_module_state->__pyx_tuple__60);
  Py_VISIT(traverse_module_state->__pyx_tuple__62);
  Py_VISIT(traverse_module_state->__pyx_tuple__64);
  Py_VISIT(traverse_module_state->__pyx_tuple__67);
  Py_VISIT(traverse_module_state->__pyx_tuple__69);
  Py_VISIT(traverse_module_state->__pyx_tuple__71);
  Py_VISIT(traverse_module_state->__pyx_tuple__74);
  Py_VISIT(traverse_module_state->__pyx_tuple__76);
  Py_VISIT(traverse_module_state->__pyx_tuple__78);
  Py_VISIT(traverse_module_state->__pyx_tuple__80);
  Py_VISIT(traverse_module_state->__pyx_tuple__82);
  Py_VISIT(traverse_module_state->__pyx_tuple__84);
  Py_VISIT(traverse_module_state->__pyx_tuple__87);
  Py_VISIT(traverse_module_state->__pyx_tuple__91);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_tuple__95);
  Py_VISIT(traverse_module_state->__pyx_tuple__99);
  Py_VISIT(traverse_module_state->__pyx_codeobj__6);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__107);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_tuple__110);
  Py_VISIT(traverse_module_state->__pyx_tuple__112);
  Py_VISIT(traverse_module_state->__pyx_tuple__113);
  Py_VISIT(traverse_module_state->__pyx_codeobj__19);
  Py_VISIT(traverse_module_state->__pyx_codeobj__21);
  Py_VISIT(traverse_module_state->__pyx_codeobj__25);
  Py_VISIT(traverse_module_state->__pyx_codeobj__27);
  Py_VISIT(traverse_module_state->__pyx_codeobj__29);
  Py_VISIT(traverse_module_state->__pyx_codeobj__31);
  Py_VISIT(traverse_module_state->__pyx_codeobj__33);
  Py_VISIT(traverse_module_state->__pyx_codeobj__35);
  Py_VISIT(traverse_module_state->__pyx_codeobj__37);
  Py_VISIT(traverse_module_state->__pyx_codeobj__39);
  Py_VISIT(traverse_module_state->__pyx_codeobj__41);
  Py_VISIT(traverse_module_state->__pyx_codeobj__44);
  Py_VISIT(traverse_module_state->__pyx_codeobj__46);
  Py_VISIT(traverse_module_state->__pyx_codeobj__48);
  Py_VISIT(traverse_module_state->__pyx_codeobj__49);
  Py_VISIT(traverse_module_state->__pyx_codeobj__51);
  Py_VISIT(traverse_module_state->__pyx_codeobj__53);
  Py_VISIT(traverse_module_state->__pyx_codeobj__55);
  Py_VISIT(traverse_module_state->__pyx_codeobj__57);
  Py_VISIT(traverse_module_state->__pyx_codeobj__58);
  Py_VISIT(traverse_module_state->__pyx_codeobj__59);
  Py_VISIT(traverse_module_state->__pyx_codeobj__61);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__65);
  Py_VISIT(traverse_module_state->__pyx_codeobj__66);
  Py_VISIT(traverse_module_state->__pyx_codeobj__68);
  Py_VISIT(traverse_module_state->__pyx_codeobj__70);
  Py_VISIT(traverse_module_state->__pyx_codeobj__72);
  Py_VISIT(traverse_module_state->__pyx_codeobj__73);
  Py_VISIT(traverse_module_state->__pyx_codeobj__75);
  Py_VISIT(traverse_module_state->__pyx_codeobj__77);
  Py_VISIT(traverse_module_state->__pyx_codeobj__79);
  Py_VISIT(traverse_module_state->__pyx_codeobj__81);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__85);
  Py_VISIT(traverse_module_state->__pyx_codeobj__86);
  Py_VISIT(traverse_module_state->__pyx_codeobj__88);
  Py_VISIT(traverse_module_state->__pyx_codeobj__89);
  Py_VISIT(traverse_module_state->__pyx_codeobj__90);
  Py_VISIT(traverse_module_state->__pyx_codeobj__92);
  Py_VISIT(traverse_module_state->__pyx_codeobj__94);
  Py_VISIT(traverse_module_state->__pyx_codeobj__96);
  Py_VISIT(traverse_module_state->__pyx_codeobj__97);
  Py_VISIT(traverse_module_state->__pyx_codeobj__98);
  Py_VISIT(traverse_module_state->__pyx_codeobj__100);
  Py_VISIT(traverse_module_state->__pyx_codeobj__102);
  Py_VISIT(traverse_module_state->__pyx_codeobj__103);
  Py_VISIT(traverse_module_state->__pyx_codeobj__104);
  Py_VISIT(traverse_module_state->__pyx_codeobj__105);
  Py_VISIT(traverse_module_state->__pyx_codeobj__106);
  Py_VISIT(traverse_module_state->__pyx_codeobj__108);
  Py_VISIT(traverse_module_state->__pyx_codeobj__111);
  Py_VISIT(traverse_module_state->__pyx_codeobj__114);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_4type_type __pyx_mstate_global->__pyx_ptype_7cpython_4type_type
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_4bool_bool __pyx_mstate_global->__pyx_ptype_7cpython_4bool_bool
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_7complex_complex __pyx_mstate_global->__pyx_ptype_7cpython_7complex_complex
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_8datetime_date __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_date
#define __pyx_ptype_7cpython_8datetime_time __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_time
#define __pyx_ptype_7cpython_8datetime_datetime __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_datetime
#define __pyx_ptype_7cpython_8datetime_timedelta __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_timedelta
#define __pyx_ptype_7cpython_8datetime_tzinfo __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_tzinfo
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl __pyx_mstate_global->__pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl
#define __pyx_type_9playhouse_11_sqlite_ext_BloomFilter __pyx_mstate_global->__pyx_type_9playhouse_11_sqlite_ext_BloomFilter
#define __pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate __pyx_mstate_global->__pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate
#define __pyx_type_9playhouse_11_sqlite_ext_Blob __pyx_mstate_global->__pyx_type_9playhouse_11_sqlite_ext_Blob
#define __pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper __pyx_mstate_global->__pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper
#define __pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash __pyx_mstate_global->__pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash
#endif
#define __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl __pyx_mstate_global->__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl
#define __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter __pyx_mstate_global->__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter
#define __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate __pyx_mstate_global->__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate
#define __pyx_ptype_9playhouse_11_sqlite_ext_Blob __pyx_mstate_global->__pyx_ptype_9playhouse_11_sqlite_ext_Blob
#define __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper __pyx_mstate_global->__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper
#define __pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash __pyx_mstate_global->__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash
#define __pyx_kp_b_3_26 __pyx_mstate_global->__pyx_kp_b_3_26
#define __pyx_n_s_A_O __pyx_mstate_global->__pyx_n_s_A_O
#define __pyx_n_s_B __pyx_mstate_global->__pyx_n_s_B
#define __pyx_n_s_Binary __pyx_mstate_global->__pyx_n_s_Binary
#define __pyx_n_s_Blob __pyx_mstate_global->__pyx_n_s_Blob
#define __pyx_n_s_Blob___reduce_cython __pyx_mstate_global->__pyx_n_s_Blob___reduce_cython
#define __pyx_n_s_Blob___setstate_cython __pyx_mstate_global->__pyx_n_s_Blob___setstate_cython
#define __pyx_n_s_Blob_close __pyx_mstate_global->__pyx_n_s_Blob_close
#define __pyx_kp_u_Blob_index_out_of_range __pyx_mstate_global->__pyx_kp_u_Blob_index_out_of_range
#define __pyx_n_s_Blob_read __pyx_mstate_global->__pyx_n_s_Blob_read
#define __pyx_n_s_Blob_reopen __pyx_mstate_global->__pyx_n_s_Blob_reopen
#define __pyx_n_s_Blob_seek __pyx_mstate_global->__pyx_n_s_Blob_seek
#define __pyx_n_s_Blob_tell __pyx_mstate_global->__pyx_n_s_Blob_tell
#define __pyx_n_s_Blob_write __pyx_mstate_global->__pyx_n_s_Blob_write
#define __pyx_n_s_BloomFilter __pyx_mstate_global->__pyx_n_s_BloomFilter
#define __pyx_n_s_BloomFilterAggregate __pyx_mstate_global->__pyx_n_s_BloomFilterAggregate
#define __pyx_n_s_BloomFilterAggregate___reduce_cy __pyx_mstate_global->__pyx_n_s_BloomFilterAggregate___reduce_cy
#define __pyx_n_s_BloomFilterAggregate___setstate __pyx_mstate_global->__pyx_n_s_BloomFilterAggregate___setstate
#define __pyx_n_s_BloomFilterAggregate_finalize __pyx_mstate_global->__pyx_n_s_BloomFilterAggregate_finalize
#define __pyx_n_s_BloomFilterAggregate_step __pyx_mstate_global->__pyx_n_s_BloomFilterAggregate_step
#define __pyx_n_s_BloomFilter___reduce_cython __pyx_mstate_global->__pyx_n_s_BloomFilter___reduce_cython
#define __pyx_n_s_BloomFilter___setstate_cython __pyx_mstate_global->__pyx_n_s_BloomFilter___setstate_cython
#define __pyx_n_s_BloomFilter_add __pyx_mstate_global->__pyx_n_s_BloomFilter_add
#define __pyx_n_s_BloomFilter_calculate_size __pyx_mstate_global->__pyx_n_s_BloomFilter_calculate_size
#define __pyx_n_s_BloomFilter_from_buffer __pyx_mstate_global->__pyx_n_s_BloomFilter_from_buffer
#define __pyx_n_s_BloomFilter_to_buffer __pyx_mstate_global->__pyx_n_s_BloomFilter_to_buffer
#define __pyx_kp_u_CREATE_TABLE_x_s __pyx_mstate_global->__pyx_kp_u_CREATE_TABLE_x_s
#define __pyx_n_s_C_O __pyx_mstate_global->__pyx_n_s_C_O
#define __pyx_kp_u_Cannot_operate_on_closed_blob __pyx_mstate_global->__pyx_kp_u_Cannot_operate_on_closed_blob
#define __pyx_kp_u_Cannot_operate_on_closed_databas __pyx_mstate_global->__pyx_kp_u_Cannot_operate_on_closed_databas
#define __pyx_kp_u_Column_must_be_either_a_string_o __pyx_mstate_global->__pyx_kp_u_Column_must_be_either_a_string_o
#define __pyx_n_s_ConnectionHelper __pyx_mstate_global->__pyx_n_s_ConnectionHelper
#define __pyx_n_s_ConnectionHelper___reduce_cython __pyx_mstate_global->__pyx_n_s_ConnectionHelper___reduce_cython
#define __pyx_n_s_ConnectionHelper___setstate_cyth __pyx_mstate_global->__pyx_n_s_ConnectionHelper___setstate_cyth
#define __pyx_n_s_ConnectionHelper_autocommit __pyx_mstate_global->__pyx_n_s_ConnectionHelper_autocommit
#define __pyx_n_s_ConnectionHelper_changes __pyx_mstate_global->__pyx_n_s_ConnectionHelper_changes
#define __pyx_n_s_ConnectionHelper_last_insert_row __pyx_mstate_global->__pyx_n_s_ConnectionHelper_last_insert_row
#define __pyx_n_s_ConnectionHelper_set_busy_handle __pyx_mstate_global->__pyx_n_s_ConnectionHelper_set_busy_handle
#define __pyx_n_s_ConnectionHelper_set_commit_hook __pyx_mstate_global->__pyx_n_s_ConnectionHelper_set_commit_hook
#define __pyx_n_s_ConnectionHelper_set_rollback_ho __pyx_mstate_global->__pyx_n_s_ConnectionHelper_set_rollback_ho
#define __pyx_n_s_ConnectionHelper_set_update_hook __pyx_mstate_global->__pyx_n_s_ConnectionHelper_set_update_hook
#define __pyx_n_u_DELETE __pyx_mstate_global->__pyx_n_u_DELETE
#define __pyx_kp_u_Data_would_go_beyond_end_of_blob __pyx_mstate_global->__pyx_kp_u_Data_would_go_beyond_end_of_blob
#define __pyx_kp_u_Error_backuping_up_database_s __pyx_mstate_global->__pyx_kp_u_Error_backuping_up_database_s
#define __pyx_kp_u_Error_reading_from_blob __pyx_mstate_global->__pyx_kp_u_Error_reading_from_blob
#define __pyx_kp_u_Error_requesting_db_status_s __pyx_mstate_global->__pyx_kp_u_Error_requesting_db_status_s
#define __pyx_kp_u_Error_requesting_status_s __pyx_mstate_global->__pyx_kp_u_Error_requesting_status_s
#define __pyx_kp_u_Error_writing_to_blob __pyx_mstate_global->__pyx_kp_u_Error_writing_to_blob
#define __pyx_n_u_INSERT __pyx_mstate_global->__pyx_n_u_INSERT
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_n_s_IndexError __pyx_mstate_global->__pyx_n_s_IndexError
#define __pyx_n_s_InterfaceError __pyx_mstate_global->__pyx_n_s_InterfaceError
#define __pyx_n_s_K __pyx_mstate_global->__pyx_n_s_K
#define __pyx_n_s_L_O __pyx_mstate_global->__pyx_n_s_L_O
#define __pyx_kp_u_Length_must_be_a_positive_intege __pyx_mstate_global->__pyx_kp_u_Length_must_be_a_positive_intege
#define __pyx_n_s_MemoryError __pyx_mstate_global->__pyx_n_s_MemoryError
#define __pyx_n_s_N_O __pyx_mstate_global->__pyx_n_s_N_O
#define __pyx_n_s_Node __pyx_mstate_global->__pyx_n_s_Node
#define __pyx_n_s_NotImplementedError __pyx_mstate_global->__pyx_n_s_NotImplementedError
#define __pyx_n_s_OperationalError __pyx_mstate_global->__pyx_n_s_OperationalError
#define __pyx_n_s_P_O __pyx_mstate_global->__pyx_n_s_P_O
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_n_s_RuntimeError __pyx_mstate_global->__pyx_n_s_RuntimeError
#define __pyx_n_s_StopIteration __pyx_mstate_global->__pyx_n_s_StopIteration
#define __pyx_n_s_TableFunction __pyx_mstate_global->__pyx_n_s_TableFunction
#define __pyx_n_s_TableFunctionImpl __pyx_mstate_global->__pyx_n_s_TableFunctionImpl
#define __pyx_n_s_TableFunctionImpl___reduce_cyth __pyx_mstate_global->__pyx_n_s_TableFunctionImpl___reduce_cyth
#define __pyx_n_s_TableFunctionImpl___setstate_cy __pyx_mstate_global->__pyx_n_s_TableFunctionImpl___setstate_cy
#define __pyx_n_s_TableFunction_get_table_columns __pyx_mstate_global->__pyx_n_s_TableFunction_get_table_columns
#define __pyx_n_s_TableFunction_initialize __pyx_mstate_global->__pyx_n_s_TableFunction_initialize
#define __pyx_n_s_TableFunction_iterate __pyx_mstate_global->__pyx_n_s_TableFunction_iterate
#define __pyx_n_s_TableFunction_register __pyx_mstate_global->__pyx_n_s_TableFunction_register
#define __pyx_kp_u_Time_zones_are_not_available_fro __pyx_mstate_global->__pyx_kp_u_Time_zones_are_not_available_fro
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_n_u_UPDATE __pyx_mstate_global->__pyx_n_u_UPDATE
#define __pyx_n_s_USE_SQLITE_CONSTRAINT __pyx_mstate_global->__pyx_n_s_USE_SQLITE_CONSTRAINT
#define __pyx_kp_u_Unable_to_allocate_blob __pyx_mstate_global->__pyx_kp_u_Unable_to_allocate_blob
#define __pyx_kp_u_Unable_to_initialize_backup __pyx_mstate_global->__pyx_kp_u_Unable_to_initialize_backup
#define __pyx_kp_u_Unable_to_open_blob __pyx_mstate_global->__pyx_kp_u_Unable_to_open_blob
#define __pyx_kp_u_Unable_to_re_open_blob __pyx_mstate_global->__pyx_kp_u_Unable_to_re_open_blob
#define __pyx_kp_u_Unsupported_type_s __pyx_mstate_global->__pyx_kp_u_Unsupported_type_s
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s_X_O __pyx_mstate_global->__pyx_n_s_X_O
#define __pyx_n_s_ZeroBlob __pyx_mstate_global->__pyx_n_s_ZeroBlob
#define __pyx_n_s_ZeroBlob___init __pyx_mstate_global->__pyx_n_s_ZeroBlob___init
#define __pyx_n_s_ZeroBlob___sql __pyx_mstate_global->__pyx_n_s_ZeroBlob___sql
#define __pyx_kp_b__10 __pyx_mstate_global->__pyx_kp_b__10
#define __pyx_kp_u__10 __pyx_mstate_global->__pyx_kp_u__10
#define __pyx_n_s__115 __pyx_mstate_global->__pyx_n_s__115
#define __pyx_kp_u__16 __pyx_mstate_global->__pyx_kp_u__16
#define __pyx_n_s__17 __pyx_mstate_global->__pyx_n_s__17
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_kp_u__4 __pyx_mstate_global->__pyx_kp_u__4
#define __pyx_kp_u__9 __pyx_mstate_global->__pyx_kp_u__9
#define __pyx_n_s_accum __pyx_mstate_global->__pyx_n_s_accum
#define __pyx_n_s_add __pyx_mstate_global->__pyx_n_s_add
#define __pyx_n_s_adler32 __pyx_mstate_global->__pyx_n_s_adler32
#define __pyx_n_u_adler32 __pyx_mstate_global->__pyx_n_u_adler32
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_autocommit __pyx_mstate_global->__pyx_n_s_autocommit
#define __pyx_n_s_avg_length __pyx_mstate_global->__pyx_n_s_avg_length
#define __pyx_n_s_b_part __pyx_mstate_global->__pyx_n_s_b_part
#define __pyx_n_s_backup __pyx_mstate_global->__pyx_n_s_backup
#define __pyx_n_s_backup_to_file __pyx_mstate_global->__pyx_n_s_backup_to_file
#define __pyx_n_s_bdata __pyx_mstate_global->__pyx_n_s_bdata
#define __pyx_n_s_bf __pyx_mstate_global->__pyx_n_s_bf
#define __pyx_n_s_bkey __pyx_mstate_global->__pyx_n_s_bkey
#define __pyx_n_s_bloom __pyx_mstate_global->__pyx_n_s_bloom
#define __pyx_n_u_bloomfilter __pyx_mstate_global->__pyx_n_u_bloomfilter
#define __pyx_n_u_bloomfilter_add __pyx_mstate_global->__pyx_n_u_bloomfilter_add
#define __pyx_n_u_bloomfilter_calculate_size __pyx_mstate_global->__pyx_n_u_bloomfilter_calculate_size
#define __pyx_n_u_bloomfilter_contains __pyx_mstate_global->__pyx_n_u_bloomfilter_contains
#define __pyx_n_s_bname __pyx_mstate_global->__pyx_n_s_bname
#define __pyx_n_s_buf __pyx_mstate_global->__pyx_n_s_buf
#define __pyx_n_s_buflen __pyx_mstate_global->__pyx_n_s_buflen
#define __pyx_n_s_c_conn __pyx_mstate_global->__pyx_n_s_c_conn
#define __pyx_n_s_calculate_size __pyx_mstate_global->__pyx_n_s_calculate_size
#define __pyx_kp_u_cannot_backup_to_or_from_a_close __pyx_mstate_global->__pyx_kp_u_cannot_backup_to_or_from_a_close
#define __pyx_n_s_cdata __pyx_mstate_global->__pyx_n_s_cdata
#define __pyx_n_s_changes __pyx_mstate_global->__pyx_n_s_changes
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_cls __pyx_mstate_global->__pyx_n_s_cls
#define __pyx_n_s_column __pyx_mstate_global->__pyx_n_s_column
#define __pyx_n_s_columns __pyx_mstate_global->__pyx_n_s_columns
#define __pyx_n_s_conn __pyx_mstate_global->__pyx_n_s_conn
#define __pyx_n_s_connect __pyx_mstate_global->__pyx_n_s_connect
#define __pyx_n_s_connection __pyx_mstate_global->__pyx_n_s_connection
#define __pyx_n_s_crc32 __pyx_mstate_global->__pyx_n_s_crc32
#define __pyx_n_u_crc32 __pyx_mstate_global->__pyx_n_u_crc32
#define __pyx_n_s_ctx __pyx_mstate_global->__pyx_n_s_ctx
#define __pyx_n_s_current __pyx_mstate_global->__pyx_n_s_current
#define __pyx_n_s_data __pyx_mstate_global->__pyx_n_s_data
#define __pyx_n_s_database __pyx_mstate_global->__pyx_n_s_database
#define __pyx_n_s_decode __pyx_mstate_global->__pyx_n_s_decode
#define __pyx_n_s_denom __pyx_mstate_global->__pyx_n_s_denom
#define __pyx_n_s_dest __pyx_mstate_global->__pyx_n_s_dest
#define __pyx_n_s_dest_conn __pyx_mstate_global->__pyx_n_s_dest_conn
#define __pyx_n_s_dest_db __pyx_mstate_global->__pyx_n_s_dest_db
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_doc __pyx_mstate_global->__pyx_n_s_doc
#define __pyx_n_s_doc_length __pyx_mstate_global->__pyx_n_s_doc_length
#define __pyx_n_s_docs_with_term __pyx_mstate_global->__pyx_n_s_docs_with_term
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_enumerate __pyx_mstate_global->__pyx_n_s_enumerate
#define __pyx_n_s_epsilon __pyx_mstate_global->__pyx_n_s_epsilon
#define __pyx_n_s_error_p __pyx_mstate_global->__pyx_n_s_error_p
#define __pyx_n_s_fieldNorms __pyx_mstate_global->__pyx_n_s_fieldNorms
#define __pyx_n_s_filename __pyx_mstate_global->__pyx_n_s_filename
#define __pyx_n_s_filters __pyx_mstate_global->__pyx_n_s_filters
#define __pyx_n_s_finalize __pyx_mstate_global->__pyx_n_s_finalize
#define __pyx_n_s_flag __pyx_mstate_global->__pyx_n_s_flag
#define __pyx_n_s_fn __pyx_mstate_global->__pyx_n_s_fn
#define __pyx_n_s_frame_of_reference __pyx_mstate_global->__pyx_n_s_frame_of_reference
#define __pyx_n_s_from_buffer __pyx_mstate_global->__pyx_n_s_from_buffer
#define __pyx_n_u_fts_bm25 __pyx_mstate_global->__pyx_n_u_fts_bm25
#define __pyx_n_u_fts_bm25f __pyx_mstate_global->__pyx_n_u_fts_bm25f
#define __pyx_n_u_fts_lucene __pyx_mstate_global->__pyx_n_u_fts_lucene
#define __pyx_n_u_fts_rank __pyx_mstate_global->__pyx_n_u_fts_rank
#define __pyx_n_s_func __pyx_mstate_global->__pyx_n_s_func
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_get_table_columns_declaration __pyx_mstate_global->__pyx_n_s_get_table_columns_declaration
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_n_s_global_hits __pyx_mstate_global->__pyx_n_s_global_hits
#define __pyx_n_s_hash_impl __pyx_mstate_global->__pyx_n_s_hash_impl
#define __pyx_n_s_hashlib __pyx_mstate_global->__pyx_n_s_hashlib
#define __pyx_n_s_hexdigest __pyx_mstate_global->__pyx_n_s_hexdigest
#define __pyx_n_s_highwater __pyx_mstate_global->__pyx_n_s_highwater
#define __pyx_n_s_hits __pyx_mstate_global->__pyx_n_s_hits
#define __pyx_n_s_icol __pyx_mstate_global->__pyx_n_s_icol
#define __pyx_n_s_idf __pyx_mstate_global->__pyx_n_s_idf
#define __pyx_n_s_idx __pyx_mstate_global->__pyx_n_s_idx
#define __pyx_n_s_impl __pyx_mstate_global->__pyx_n_s_impl
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initialize __pyx_mstate_global->__pyx_n_s_initialize
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_inner __pyx_mstate_global->__pyx_n_s_inner
#define __pyx_n_s_iphrase __pyx_mstate_global->__pyx_n_s_iphrase
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_item __pyx_mstate_global->__pyx_n_s_item
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_iterate __pyx_mstate_global->__pyx_n_s_iterate
#define __pyx_n_s_key __pyx_mstate_global->__pyx_n_s_key
#define __pyx_n_s_keys __pyx_mstate_global->__pyx_n_s_keys
#define __pyx_n_s_last_insert_rowid __pyx_mstate_global->__pyx_n_s_last_insert_rowid
#define __pyx_n_s_length __pyx_mstate_global->__pyx_n_s_length
#define __pyx_n_s_literal __pyx_mstate_global->__pyx_n_s_literal
#define __pyx_n_s_m __pyx_mstate_global->__pyx_n_s_m
#define __pyx_n_u_main __pyx_mstate_global->__pyx_n_u_main
#define __pyx_n_s_main_2 __pyx_mstate_global->__pyx_n_s_main_2
#define __pyx_n_s_make_hash __pyx_mstate_global->__pyx_n_s_make_hash
#define __pyx_n_s_make_hash_locals_inner __pyx_mstate_global->__pyx_n_s_make_hash_locals_inner
#define __pyx_n_s_match_info __pyx_mstate_global->__pyx_n_s_match_info
#define __pyx_n_s_match_info_buf __pyx_mstate_global->__pyx_n_s_match_info_buf
#define __pyx_n_s_match_info_buf_2 __pyx_mstate_global->__pyx_n_s_match_info_buf_2
#define __pyx_n_s_max_length __pyx_mstate_global->__pyx_n_s_max_length
#define __pyx_n_s_md5 __pyx_mstate_global->__pyx_n_s_md5
#define __pyx_n_u_md5 __pyx_mstate_global->__pyx_n_u_md5
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_n_s_mro_entries __pyx_mstate_global->__pyx_n_s_mro_entries
#define __pyx_n_u_murmurhash __pyx_mstate_global->__pyx_n_u_murmurhash
#define __pyx_n_s_n __pyx_mstate_global->__pyx_n_s_n
#define __pyx_n_s_n_items __pyx_mstate_global->__pyx_n_s_n_items
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_ncol __pyx_mstate_global->__pyx_n_s_ncol
#define __pyx_n_s_ncols __pyx_mstate_global->__pyx_n_s_ncols
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_kp_s_no_default___reduce___due_to_non __pyx_mstate_global->__pyx_kp_s_no_default___reduce___due_to_non
#define __pyx_kp_u_no_row_data __pyx_mstate_global->__pyx_kp_u_no_row_data
#define __pyx_n_s_nphrase __pyx_mstate_global->__pyx_n_s_nphrase
#define __pyx_n_s_nseed __pyx_mstate_global->__pyx_n_s_nseed
#define __pyx_n_s_num __pyx_mstate_global->__pyx_n_s_num
#define __pyx_n_s_object __pyx_mstate_global->__pyx_n_s_object
#define __pyx_n_s_offset __pyx_mstate_global->__pyx_n_s_offset
#define __pyx_n_s_p __pyx_mstate_global->__pyx_n_s_p
#define __pyx_n_s_page_count __pyx_mstate_global->__pyx_n_s_page_count
#define __pyx_n_s_page_step __pyx_mstate_global->__pyx_n_s_page_step
#define __pyx_n_s_pages __pyx_mstate_global->__pyx_n_s_pages
#define __pyx_n_s_pairs __pyx_mstate_global->__pyx_n_s_pairs
#define __pyx_n_s_param __pyx_mstate_global->__pyx_n_s_param
#define __pyx_n_s_params __pyx_mstate_global->__pyx_n_s_params
#define __pyx_n_s_pc_score __pyx_mstate_global->__pyx_n_s_pc_score
#define __pyx_n_s_peewee __pyx_mstate_global->__pyx_n_s_peewee
#define __pyx_n_s_peewee_bloomfilter_add __pyx_mstate_global->__pyx_n_s_peewee_bloomfilter_add
#define __pyx_n_s_peewee_bloomfilter_calculate_siz __pyx_mstate_global->__pyx_n_s_peewee_bloomfilter_calculate_siz
#define __pyx_n_s_peewee_bloomfilter_contains __pyx_mstate_global->__pyx_n_s_peewee_bloomfilter_contains
#define __pyx_n_s_peewee_bm25 __pyx_mstate_global->__pyx_n_s_peewee_bm25
#define __pyx_n_s_peewee_bm25f __pyx_mstate_global->__pyx_n_s_peewee_bm25f
#define __pyx_n_s_peewee_lucene __pyx_mstate_global->__pyx_n_s_peewee_lucene
#define __pyx_n_s_peewee_md5 __pyx_mstate_global->__pyx_n_s_peewee_md5
#define __pyx_n_s_peewee_murmurhash __pyx_mstate_global->__pyx_n_s_peewee_murmurhash
#define __pyx_n_s_peewee_rank __pyx_mstate_global->__pyx_n_s_peewee_rank
#define __pyx_n_s_peewee_sha1 __pyx_mstate_global->__pyx_n_s_peewee_sha1
#define __pyx_n_s_peewee_sha256 __pyx_mstate_global->__pyx_n_s_peewee_sha256
#define __pyx_n_s_phrase_info __pyx_mstate_global->__pyx_n_s_phrase_info
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_playhouse__sqlite_ext __pyx_mstate_global->__pyx_n_s_playhouse__sqlite_ext
#define __pyx_kp_s_playhouse__sqlite_ext_pyx __pyx_mstate_global->__pyx_kp_s_playhouse__sqlite_ext_pyx
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_s_print_exc __pyx_mstate_global->__pyx_n_s_print_exc
#define __pyx_n_s_print_tracebacks __pyx_mstate_global->__pyx_n_s_print_tracebacks
#define __pyx_n_s_progress __pyx_mstate_global->__pyx_n_s_progress
#define __pyx_n_s_py_match_info __pyx_mstate_global->__pyx_n_s_py_match_info
#define __pyx_n_s_pybuf __pyx_mstate_global->__pyx_n_s_pybuf
#define __pyx_n_s_pysqlite __pyx_mstate_global->__pyx_n_s_pysqlite
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_BloomFilterAggreg __pyx_mstate_global->__pyx_n_s_pyx_unpickle_BloomFilterAggreg
#define __pyx_n_s_pyx_vtable __pyx_mstate_global->__pyx_n_s_pyx_vtable
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_ratio __pyx_mstate_global->__pyx_n_s_ratio
#define __pyx_n_s_raw_weights __pyx_mstate_global->__pyx_n_s_raw_weights
#define __pyx_n_s_rc __pyx_mstate_global->__pyx_n_s_rc
#define __pyx_n_s_read __pyx_mstate_global->__pyx_n_s_read
#define __pyx_n_s_read_only __pyx_mstate_global->__pyx_n_s_read_only
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_register __pyx_mstate_global->__pyx_n_s_register
#define __pyx_n_s_register_aggregate __pyx_mstate_global->__pyx_n_s_register_aggregate
#define __pyx_n_s_register_bloomfilter __pyx_mstate_global->__pyx_n_s_register_bloomfilter
#define __pyx_n_s_register_function __pyx_mstate_global->__pyx_n_s_register_function
#define __pyx_n_s_register_functions __pyx_mstate_global->__pyx_n_s_register_functions
#define __pyx_n_s_register_hash_functions __pyx_mstate_global->__pyx_n_s_register_hash_functions
#define __pyx_n_s_register_rank_functions __pyx_mstate_global->__pyx_n_s_register_rank_functions
#define __pyx_n_s_remaining __pyx_mstate_global->__pyx_n_s_remaining
#define __pyx_n_s_reopen __pyx_mstate_global->__pyx_n_s_reopen
#define __pyx_n_s_rhs __pyx_mstate_global->__pyx_n_s_rhs
#define __pyx_n_s_rowid __pyx_mstate_global->__pyx_n_s_rowid
#define __pyx_kp_u_s_HIDDEN __pyx_mstate_global->__pyx_kp_u_s_HIDDEN
#define __pyx_kp_u_s_s __pyx_mstate_global->__pyx_kp_u_s_s
#define __pyx_n_s_score __pyx_mstate_global->__pyx_n_s_score
#define __pyx_n_s_seed __pyx_mstate_global->__pyx_n_s_seed
#define __pyx_n_s_seek __pyx_mstate_global->__pyx_n_s_seek
#define __pyx_kp_u_seek_frame_of_reference_must_be __pyx_mstate_global->__pyx_kp_u_seek_frame_of_reference_must_be
#define __pyx_kp_u_seek_offset_outside_of_valid_ran __pyx_mstate_global->__pyx_kp_u_seek_offset_outside_of_valid_ran
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_kp_s_self_bf_cannot_be_converted_to_a __pyx_mstate_global->__pyx_kp_s_self_bf_cannot_be_converted_to_a
#define __pyx_kp_s_self_conn_cannot_be_converted_to __pyx_mstate_global->__pyx_kp_s_self_conn_cannot_be_converted_to
#define __pyx_kp_s_self_conn_self_pBlob_cannot_be_c __pyx_mstate_global->__pyx_kp_s_self_conn_self_pBlob_cannot_be_c
#define __pyx_n_s_set_busy_handler __pyx_mstate_global->__pyx_n_s_set_busy_handler
#define __pyx_n_s_set_commit_hook __pyx_mstate_global->__pyx_n_s_set_commit_hook
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_set_rollback_hook __pyx_mstate_global->__pyx_n_s_set_rollback_hook
#define __pyx_n_s_set_update_hook __pyx_mstate_global->__pyx_n_s_set_update_hook
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_sha1 __pyx_mstate_global->__pyx_n_s_sha1
#define __pyx_n_u_sha1 __pyx_mstate_global->__pyx_n_u_sha1
#define __pyx_n_s_sha256 __pyx_mstate_global->__pyx_n_s_sha256
#define __pyx_n_u_sha256 __pyx_mstate_global->__pyx_n_u_sha256
#define __pyx_n_s_size __pyx_mstate_global->__pyx_n_s_size
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_sql __pyx_mstate_global->__pyx_n_s_sql
#define __pyx_n_s_sqlite3 __pyx_mstate_global->__pyx_n_s_sqlite3
#define __pyx_n_s_sqlite_get_db_status __pyx_mstate_global->__pyx_n_s_sqlite_get_db_status
#define __pyx_n_s_sqlite_get_status __pyx_mstate_global->__pyx_n_s_sqlite_get_status
#define __pyx_n_s_src __pyx_mstate_global->__pyx_n_s_src
#define __pyx_n_s_src_conn __pyx_mstate_global->__pyx_n_s_src_conn
#define __pyx_n_s_src_db __pyx_mstate_global->__pyx_n_s_src_db
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_state_2 __pyx_mstate_global->__pyx_n_s_state_2
#define __pyx_n_s_step __pyx_mstate_global->__pyx_n_s_step
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_table __pyx_mstate_global->__pyx_n_s_table
#define __pyx_n_s_table_function __pyx_mstate_global->__pyx_n_s_table_function
#define __pyx_n_s_tell __pyx_mstate_global->__pyx_n_s_tell
#define __pyx_n_s_term_frequency __pyx_mstate_global->__pyx_n_s_term_frequency
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_tf __pyx_mstate_global->__pyx_n_s_tf
#define __pyx_n_s_timeout __pyx_mstate_global->__pyx_n_s_timeout
#define __pyx_n_s_to_buffer __pyx_mstate_global->__pyx_n_s_to_buffer
#define __pyx_n_s_total_docs __pyx_mstate_global->__pyx_n_s_total_docs
#define __pyx_n_s_traceback __pyx_mstate_global->__pyx_n_s_traceback
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_use_setstate __pyx_mstate_global->__pyx_n_s_use_setstate
#define __pyx_kp_u_utf_8 __pyx_mstate_global->__pyx_kp_u_utf_8
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_n_s_weight __pyx_mstate_global->__pyx_n_s_weight
#define __pyx_n_s_weights __pyx_mstate_global->__pyx_n_s_weights
#define __pyx_n_s_write __pyx_mstate_global->__pyx_n_s_write
#define __pyx_n_s_x __pyx_mstate_global->__pyx_n_s_x
#define __pyx_kp_u_zeroblob_s __pyx_mstate_global->__pyx_kp_u_zeroblob_s
#define __pyx_n_s_zlib __pyx_mstate_global->__pyx_n_s_zlib
#define __pyx_float_1_0 __pyx_mstate_global->__pyx_float_1_0
#define __pyx_float_2_0 __pyx_mstate_global->__pyx_float_2_0
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_5 __pyx_mstate_global->__pyx_int_5
#define __pyx_int_1000 __pyx_mstate_global->__pyx_int_1000
#define __pyx_int_32768 __pyx_mstate_global->__pyx_int_32768
#define __pyx_int_5135835 __pyx_mstate_global->__pyx_int_5135835
#define __pyx_int_211787133 __pyx_mstate_global->__pyx_int_211787133
#define __pyx_int_230328617 __pyx_mstate_global->__pyx_int_230328617
#define __pyx_tuple_ __pyx_mstate_global->__pyx_tuple_
#define __pyx_tuple__3 __pyx_mstate_global->__pyx_tuple__3
#define __pyx_tuple__5 __pyx_mstate_global->__pyx_tuple__5
#define __pyx_tuple__7 __pyx_mstate_global->__pyx_tuple__7
#define __pyx_tuple__8 __pyx_mstate_global->__pyx_tuple__8
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__12 __pyx_mstate_global->__pyx_tuple__12
#define __pyx_tuple__13 __pyx_mstate_global->__pyx_tuple__13
#define __pyx_tuple__14 __pyx_mstate_global->__pyx_tuple__14
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__18 __pyx_mstate_global->__pyx_tuple__18
#define __pyx_tuple__20 __pyx_mstate_global->__pyx_tuple__20
#define __pyx_tuple__22 __pyx_mstate_global->__pyx_tuple__22
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_tuple__26 __pyx_mstate_global->__pyx_tuple__26
#define __pyx_tuple__28 __pyx_mstate_global->__pyx_tuple__28
#define __pyx_tuple__30 __pyx_mstate_global->__pyx_tuple__30
#define __pyx_tuple__32 __pyx_mstate_global->__pyx_tuple__32
#define __pyx_tuple__34 __pyx_mstate_global->__pyx_tuple__34
#define __pyx_tuple__36 __pyx_mstate_global->__pyx_tuple__36
#define __pyx_tuple__38 __pyx_mstate_global->__pyx_tuple__38
#define __pyx_tuple__40 __pyx_mstate_global->__pyx_tuple__40
#define __pyx_tuple__42 __pyx_mstate_global->__pyx_tuple__42
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__45 __pyx_mstate_global->__pyx_tuple__45
#define __pyx_tuple__47 __pyx_mstate_global->__pyx_tuple__47
#define __pyx_tuple__50 __pyx_mstate_global->__pyx_tuple__50
#define __pyx_tuple__52 __pyx_mstate_global->__pyx_tuple__52
#define __pyx_tuple__54 __pyx_mstate_global->__pyx_tuple__54
#define __pyx_tuple__56 __pyx_mstate_global->__pyx_tuple__56
#define __pyx_tuple__60 __pyx_mstate_global->__pyx_tuple__60
#define __pyx_tuple__62 __pyx_mstate_global->__pyx_tuple__62
#define __pyx_tuple__64 __pyx_mstate_global->__pyx_tuple__64
#define __pyx_tuple__67 __pyx_mstate_global->__pyx_tuple__67
#define __pyx_tuple__69 __pyx_mstate_global->__pyx_tuple__69
#define __pyx_tuple__71 __pyx_mstate_global->__pyx_tuple__71
#define __pyx_tuple__74 __pyx_mstate_global->__pyx_tuple__74
#define __pyx_tuple__76 __pyx_mstate_global->__pyx_tuple__76
#define __pyx_tuple__78 __pyx_mstate_global->__pyx_tuple__78
#define __pyx_tuple__80 __pyx_mstate_global->__pyx_tuple__80
#define __pyx_tuple__82 __pyx_mstate_global->__pyx_tuple__82
#define __pyx_tuple__84 __pyx_mstate_global->__pyx_tuple__84
#define __pyx_tuple__87 __pyx_mstate_global->__pyx_tuple__87
#define __pyx_tuple__91 __pyx_mstate_global->__pyx_tuple__91
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_tuple__95 __pyx_mstate_global->__pyx_tuple__95
#define __pyx_tuple__99 __pyx_mstate_global->__pyx_tuple__99
#define __pyx_codeobj__6 __pyx_mstate_global->__pyx_codeobj__6
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__107 __pyx_mstate_global->__pyx_tuple__107
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_tuple__110 __pyx_mstate_global->__pyx_tuple__110
#define __pyx_tuple__112 __pyx_mstate_global->__pyx_tuple__112
#define __pyx_tuple__113 __pyx_mstate_global->__pyx_tuple__113
#define __pyx_codeobj__19 __pyx_mstate_global->__pyx_codeobj__19
#define __pyx_codeobj__21 __pyx_mstate_global->__pyx_codeobj__21
#define __pyx_codeobj__25 __pyx_mstate_global->__pyx_codeobj__25
#define __pyx_codeobj__27 __pyx_mstate_global->__pyx_codeobj__27
#define __pyx_codeobj__29 __pyx_mstate_global->__pyx_codeobj__29
#define __pyx_codeobj__31 __pyx_mstate_global->__pyx_codeobj__31
#define __pyx_codeobj__33 __pyx_mstate_global->__pyx_codeobj__33
#define __pyx_codeobj__35 __pyx_mstate_global->__pyx_codeobj__35
#define __pyx_codeobj__37 __pyx_mstate_global->__pyx_codeobj__37
#define __pyx_codeobj__39 __pyx_mstate_global->__pyx_codeobj__39
#define __pyx_codeobj__41 __pyx_mstate_global->__pyx_codeobj__41
#define __pyx_codeobj__44 __pyx_mstate_global->__pyx_codeobj__44
#define __pyx_codeobj__46 __pyx_mstate_global->__pyx_codeobj__46
#define __pyx_codeobj__48 __pyx_mstate_global->__pyx_codeobj__48
#define __pyx_codeobj__49 __pyx_mstate_global->__pyx_codeobj__49
#define __pyx_codeobj__51 __pyx_mstate_global->__pyx_codeobj__51
#define __pyx_codeobj__53 __pyx_mstate_global->__pyx_codeobj__53
#define __pyx_codeobj__55 __pyx_mstate_global->__pyx_codeobj__55
#define __pyx_codeobj__57 __pyx_mstate_global->__pyx_codeobj__57
#define __pyx_codeobj__58 __pyx_mstate_global->__pyx_codeobj__58
#define __pyx_codeobj__59 __pyx_mstate_global->__pyx_codeobj__59
#define __pyx_codeobj__61 __pyx_mstate_global->__pyx_codeobj__61
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__65 __pyx_mstate_global->__pyx_codeobj__65
#define __pyx_codeobj__66 __pyx_mstate_global->__pyx_codeobj__66
#define __pyx_codeobj__68 __pyx_mstate_global->__pyx_codeobj__68
#define __pyx_codeobj__70 __pyx_mstate_global->__pyx_codeobj__70
#define __pyx_codeobj__72 __pyx_mstate_global->__pyx_codeobj__72
#define __pyx_codeobj__73 __pyx_mstate_global->__pyx_codeobj__73
#define __pyx_codeobj__75 __pyx_mstate_global->__pyx_codeobj__75
#define __pyx_codeobj__77 __pyx_mstate_global->__pyx_codeobj__77
#define __pyx_codeobj__79 __pyx_mstate_global->__pyx_codeobj__79
#define __pyx_codeobj__81 __pyx_mstate_global->__pyx_codeobj__81
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__85 __pyx_mstate_global->__pyx_codeobj__85
#define __pyx_codeobj__86 __pyx_mstate_global->__pyx_codeobj__86
#define __pyx_codeobj__88 __pyx_mstate_global->__pyx_codeobj__88
#define __pyx_codeobj__89 __pyx_mstate_global->__pyx_codeobj__89
#define __pyx_codeobj__90 __pyx_mstate_global->__pyx_codeobj__90
#define __pyx_codeobj__92 __pyx_mstate_global->__pyx_codeobj__92
#define __pyx_codeobj__94 __pyx_mstate_global->__pyx_codeobj__94
#define __pyx_codeobj__96 __pyx_mstate_global->__pyx_codeobj__96
#define __pyx_codeobj__97 __pyx_mstate_global->__pyx_codeobj__97
#define __pyx_codeobj__98 __pyx_mstate_global->__pyx_codeobj__98
#define __pyx_codeobj__100 __pyx_mstate_global->__pyx_codeobj__100
#define __pyx_codeobj__102 __pyx_mstate_global->__pyx_codeobj__102
#define __pyx_codeobj__103 __pyx_mstate_global->__pyx_codeobj__103
#define __pyx_codeobj__104 __pyx_mstate_global->__pyx_codeobj__104
#define __pyx_codeobj__105 __pyx_mstate_global->__pyx_codeobj__105
#define __pyx_codeobj__106 __pyx_mstate_global->__pyx_codeobj__106
#define __pyx_codeobj__108 __pyx_mstate_global->__pyx_codeobj__108
#define __pyx_codeobj__111 __pyx_mstate_global->__pyx_codeobj__111
#define __pyx_codeobj__114 __pyx_mstate_global->__pyx_codeobj__114
/* #### Code section: module_code ### */

/* "cpython/complex.pxd":19
 * 
 *         @property
 *         cdef inline double real(self):             # <<<<<<<<<<<<<<
 *             return self.cval.real
 * 
 */

static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self) {
  double __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("real", 0);

  /* "cpython/complex.pxd":20
 *         @property
 *         cdef inline double real(self):
 *             return self.cval.real             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = __pyx_v_self->cval.real;
  goto __pyx_L0;

  /* "cpython/complex.pxd":19
 * 
 *         @property
 *         cdef inline double real(self):             # <<<<<<<<<<<<<<
 *             return self.cval.real
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/complex.pxd":23
 * 
 *         @property
 *         cdef inline double imag(self):             # <<<<<<<<<<<<<<
 *             return self.cval.imag
 * 
 */

static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self) {
  double __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("imag", 0);

  /* "cpython/complex.pxd":24
 *         @property
 *         cdef inline double imag(self):
 *             return self.cval.imag             # <<<<<<<<<<<<<<
 * 
 *     # PyTypeObject PyComplex_Type
 */
  __pyx_r = __pyx_v_self->cval.imag;
  goto __pyx_L0;

  /* "cpython/complex.pxd":23
 * 
 *         @property
 *         cdef inline double imag(self):             # <<<<<<<<<<<<<<
 *             return self.cval.imag
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/contextvars.pxd":112
 * 
 * 
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value *__pyx_optional_args) {
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value;
  PyObject *__pyx_v_pyvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_value", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_default_value = __pyx_optional_args->default_value;
    }
  }

  /* "cpython/contextvars.pxd":117
 *     or None if no such value or default was found.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:
 */
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":118
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)             # <<<<<<<<<<<<<<
 *     if value is NULL:
 *         # context variable does not have a default
 */
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, NULL, (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 118, __pyx_L1_error)

  /* "cpython/contextvars.pxd":119
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
 */
  __pyx_t_2 = (__pyx_v_value == NULL);
  if (__pyx_t_2) {

    /* "cpython/contextvars.pxd":121
 *     if value is NULL:
 *         # context variable does not have a default
 *         pyvalue = default_value             # <<<<<<<<<<<<<<
 *     else:
 *         # value or default value of context variable
 */
    __Pyx_INCREF(__pyx_v_default_value);
    __pyx_v_pyvalue = __pyx_v_default_value;

    /* "cpython/contextvars.pxd":119
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
 */
    goto __pyx_L3;
  }

  /* "cpython/contextvars.pxd":124
 *     else:
 *         # value or default value of context variable
 *         pyvalue = <object>value             # <<<<<<<<<<<<<<
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
 */
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_value);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_pyvalue = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cpython/contextvars.pxd":125
 *         # value or default value of context variable
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
 * 
 */
    Py_XDECREF(__pyx_v_value);
  }
  __pyx_L3:;

  /* "cpython/contextvars.pxd":126
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyvalue);
  __pyx_r = __pyx_v_pyvalue;
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":112
 * 
 * 
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cpython.contextvars.get_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/contextvars.pxd":129
 * 
 * 
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value_no_default(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default *__pyx_optional_args) {
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value;
  PyObject *__pyx_v_pyvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_value_no_default", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_default_value = __pyx_optional_args->default_value;
    }
  }

  /* "cpython/contextvars.pxd":135
 *     Ignores the default value of the context variable, if any.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
 */
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":136
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)             # <<<<<<<<<<<<<<
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
 */
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, ((PyObject *)__pyx_v_default_value), (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 136, __pyx_L1_error)

  /* "cpython/contextvars.pxd":138
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value             # <<<<<<<<<<<<<<
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_value);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_pyvalue = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cpython/contextvars.pxd":139
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
 */
  Py_XDECREF(__pyx_v_value);

  /* "cpython/contextvars.pxd":140
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyvalue);
  __pyx_r = __pyx_v_pyvalue;
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":129
 * 
 * 
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.contextvars.get_value_no_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":72
 *     ctypedef extern class datetime.date[object PyDateTime_Date]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_4year_year(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("year", 0);

  /* "datetime.pxd":73
 *         @property
 *         cdef inline int year(self):
 *             return PyDateTime_GET_YEAR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_YEAR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":72
 *     ctypedef extern class datetime.date[object PyDateTime_Date]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":76
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_5month_month(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("month", 0);

  /* "datetime.pxd":77
 *         @property
 *         cdef inline int month(self):
 *             return PyDateTime_GET_MONTH(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_MONTH(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":76
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":80
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_3day_day(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("day", 0);

  /* "datetime.pxd":81
 *         @property
 *         cdef inline int day(self):
 *             return PyDateTime_GET_DAY(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 */
  __pyx_r = PyDateTime_GET_DAY(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":80
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":85
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_HOUR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4hour_hour(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hour", 0);

  /* "datetime.pxd":86
 *         @property
 *         cdef inline int hour(self):
 *             return PyDateTime_TIME_GET_HOUR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_HOUR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":85
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_HOUR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":89
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MINUTE(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6minute_minute(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minute", 0);

  /* "datetime.pxd":90
 *         @property
 *         cdef inline int minute(self):
 *             return PyDateTime_TIME_GET_MINUTE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_MINUTE(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":89
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MINUTE(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":93
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_SECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6second_second(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("second", 0);

  /* "datetime.pxd":94
 *         @property
 *         cdef inline int second(self):
 *             return PyDateTime_TIME_GET_SECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_SECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":93
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_SECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":97
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_11microsecond_microsecond(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("microsecond", 0);

  /* "datetime.pxd":98
 *         @property
 *         cdef inline int microsecond(self):
 *             return PyDateTime_TIME_GET_MICROSECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":97
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":101
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_4time_6tzinfo_tzinfo(PyDateTime_Time *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("tzinfo", 0);

  /* "datetime.pxd":102
 *         @property
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_TIME_GET_TZINFO(((PyObject *)__pyx_v_self));
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":101
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":105
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_TIME_GET_FOLD(self)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4fold_fold(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fold", 0);

  /* "datetime.pxd":107
 *         cdef inline int fold(self):
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_TIME_GET_FOLD(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 */
  __pyx_r = PyDateTime_TIME_GET_FOLD(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":105
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_TIME_GET_FOLD(self)
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":111
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4year_year(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("year", 0);

  /* "datetime.pxd":112
 *         @property
 *         cdef inline int year(self):
 *             return PyDateTime_GET_YEAR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_YEAR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":111
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":115
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_5month_month(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("month", 0);

  /* "datetime.pxd":116
 *         @property
 *         cdef inline int month(self):
 *             return PyDateTime_GET_MONTH(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_MONTH(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":115
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":119
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_3day_day(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("day", 0);

  /* "datetime.pxd":120
 *         @property
 *         cdef inline int day(self):
 *             return PyDateTime_GET_DAY(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_DAY(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":119
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":123
 * 
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_HOUR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4hour_hour(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hour", 0);

  /* "datetime.pxd":124
 *         @property
 *         cdef inline int hour(self):
 *             return PyDateTime_DATE_GET_HOUR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_HOUR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":123
 * 
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_HOUR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":127
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MINUTE(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6minute_minute(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minute", 0);

  /* "datetime.pxd":128
 *         @property
 *         cdef inline int minute(self):
 *             return PyDateTime_DATE_GET_MINUTE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_MINUTE(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":127
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MINUTE(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":131
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_SECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6second_second(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("second", 0);

  /* "datetime.pxd":132
 *         @property
 *         cdef inline int second(self):
 *             return PyDateTime_DATE_GET_SECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_SECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":131
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_SECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":135
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("microsecond", 0);

  /* "datetime.pxd":136
 *         @property
 *         cdef inline int microsecond(self):
 *             return PyDateTime_DATE_GET_MICROSECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":135
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":139
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(PyDateTime_DateTime *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("tzinfo", 0);

  /* "datetime.pxd":140
 *         @property
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_DATE_GET_TZINFO(((PyObject *)__pyx_v_self));
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":139
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":143
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_DATE_GET_FOLD(self)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4fold_fold(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fold", 0);

  /* "datetime.pxd":145
 *         cdef inline int fold(self):
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_DATE_GET_FOLD(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 */
  __pyx_r = PyDateTime_DATE_GET_FOLD(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":143
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_DATE_GET_FOLD(self)
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":149
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_DAYS(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_3day_day(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("day", 0);

  /* "datetime.pxd":150
 *         @property
 *         cdef inline int day(self):
 *             return PyDateTime_DELTA_GET_DAYS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DELTA_GET_DAYS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":149
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_DAYS(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":153
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_SECONDS(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_6second_second(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("second", 0);

  /* "datetime.pxd":154
 *         @property
 *         cdef inline int second(self):
 *             return PyDateTime_DELTA_GET_SECONDS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DELTA_GET_SECONDS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":153
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_SECONDS(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":157
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_11microsecond_microsecond(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("microsecond", 0);

  /* "datetime.pxd":158
 *         @property
 *         cdef inline int microsecond(self):
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.tzinfo[object PyDateTime_TZInfo]:
 */
  __pyx_r = PyDateTime_DELTA_GET_MICROSECONDS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":157
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":282
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("import_datetime", 0);

  /* "datetime.pxd":283
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():
 *     PyDateTime_IMPORT             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DateTime CAPI factory function.
 */
  (void)(PyDateTime_IMPORT);

  /* "datetime.pxd":282
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "datetime.pxd":287
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

static CYTHON_INLINE PyDateTime_Date *__pyx_f_7cpython_8datetime_date_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day) {
  PyDateTime_Date *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_new", 0);

  /* "datetime.pxd":288
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)             # <<<<<<<<<<<<<<
 * 
 * # Create time object using DateTime CAPI factory function
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyDateTimeAPI->Date_FromDate(__pyx_v_year, __pyx_v_month, __pyx_v_day, PyDateTimeAPI->DateType)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_Date *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":287
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.date_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":292
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
 */

static CYTHON_INLINE PyDateTime_Time *__pyx_f_7cpython_8datetime_time_new(int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz, struct __pyx_opt_args_7cpython_8datetime_time_new *__pyx_optional_args) {
  int __pyx_v_fold = ((int)0);
  PyDateTime_Time *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("time_new", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_fold = __pyx_optional_args->fold;
    }
  }

  /* "datetime.pxd":293
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)__Pyx_DateTime_TimeWithFold(__pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, __pyx_v_fold)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_time))))) __PYX_ERR(3, 293, __pyx_L1_error)
  __pyx_r = ((PyDateTime_Time *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":292
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.time_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":297
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
 */

static CYTHON_INLINE PyDateTime_DateTime *__pyx_f_7cpython_8datetime_datetime_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day, int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz, struct __pyx_opt_args_7cpython_8datetime_datetime_new *__pyx_optional_args) {
  int __pyx_v_fold = ((int)0);
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_new", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_fold = __pyx_optional_args->fold;
    }
  }

  /* "datetime.pxd":298
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)__Pyx_DateTime_DateTimeWithFold(__pyx_v_year, __pyx_v_month, __pyx_v_day, __pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, __pyx_v_fold)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":297
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.datetime_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":302
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

static CYTHON_INLINE PyDateTime_Delta *__pyx_f_7cpython_8datetime_timedelta_new(int __pyx_v_days, int __pyx_v_seconds, int __pyx_v_useconds) {
  PyDateTime_Delta *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timedelta_new", 0);

  /* "datetime.pxd":303
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyDateTimeAPI->Delta_FromDelta(__pyx_v_days, __pyx_v_seconds, __pyx_v_useconds, 1, PyDateTimeAPI->DeltaType)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_Delta *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":302
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.timedelta_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":306
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timezone_new(PyObject *__pyx_v_offset, struct __pyx_opt_args_7cpython_8datetime_timezone_new *__pyx_optional_args) {
  PyObject *__pyx_v_name = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timezone_new", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_name = __pyx_optional_args->name;
    }
  }

  /* "datetime.pxd":307
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 */
  __pyx_t_1 = (PY_VERSION_HEX < 0x030700b1);
  if (unlikely(__pyx_t_1)) {

    /* "datetime.pxd":308
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')             # <<<<<<<<<<<<<<
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(3, 308, __pyx_L1_error)

    /* "datetime.pxd":307
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 */
  }

  /* "datetime.pxd":309
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DB API constructor.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (__pyx_v_name != Py_None);
  if (__pyx_t_1) {
    __pyx_t_3 = ((PyObject *)__pyx_v_name);
  } else {
    __pyx_t_3 = NULL;
  }
  __pyx_t_2 = __Pyx_TimeZone_FromOffsetAndName(__pyx_v_offset, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":306
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.datetime.timezone_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":312
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 */

static CYTHON_INLINE PyDateTime_DateTime *__pyx_f_7cpython_8datetime_datetime_from_timestamp(PyObject *__pyx_v_timestamp, struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp *__pyx_optional_args) {
  PyObject *__pyx_v_tz = ((PyObject *)Py_None);
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_from_timestamp", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_tz = __pyx_optional_args->tz;
    }
  }

  /* "datetime.pxd":313
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(             # <<<<<<<<<<<<<<
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);

  /* "datetime.pxd":314
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DB API constructor.
 */
  __pyx_t_2 = (__pyx_v_tz != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timestamp);
    __Pyx_GIVEREF(__pyx_v_timestamp);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timestamp);
    __Pyx_INCREF(__pyx_v_tz);
    __Pyx_GIVEREF(__pyx_v_tz);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_tz);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timestamp);
    __Pyx_GIVEREF(__pyx_v_timestamp);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timestamp);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }

  /* "datetime.pxd":313
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(             # <<<<<<<<<<<<<<
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 * 
 */
  __pyx_t_3 = ((PyObject *)PyDateTimeAPI->DateTime_FromTimestamp(((PyObject *)PyDateTimeAPI->DateTimeType), __pyx_t_1, NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":312
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cpython.datetime.datetime_from_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":317
 * 
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))
 * 
 */

static CYTHON_INLINE PyDateTime_Date *__pyx_f_7cpython_8datetime_date_from_timestamp(PyObject *__pyx_v_timestamp) {
  PyDateTime_Date *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_from_timestamp", 0);

  /* "datetime.pxd":318
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))             # <<<<<<<<<<<<<<
 * 
 * # More recognizable getters for date/time/datetime/timedelta.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_timestamp);
  __Pyx_GIVEREF(__pyx_v_timestamp);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_timestamp);
  __pyx_t_2 = ((PyObject *)PyDateTimeAPI->Date_FromTimestamp(((PyObject *)PyDateTimeAPI->DateType), __pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyDateTime_Date *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":317
 * 
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.datetime.date_from_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":326
 * 
 * # Get UTC singleton
 * cdef inline object get_utc():             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_get_utc(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_utc", 0);

  /* "datetime.pxd":327
 * # Get UTC singleton
 * cdef inline object get_utc():
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return <object>__Pyx_TimeZone_UTC
 */
  __pyx_t_1 = (PY_VERSION_HEX < 0x030700b1);
  if (unlikely(__pyx_t_1)) {

    /* "datetime.pxd":328
 * cdef inline object get_utc():
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')             # <<<<<<<<<<<<<<
 *     return <object>__Pyx_TimeZone_UTC
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(3, 328, __pyx_L1_error)

    /* "datetime.pxd":327
 * # Get UTC singleton
 * cdef inline object get_utc():
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return <object>__Pyx_TimeZone_UTC
 */
  }

  /* "datetime.pxd":329
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return <object>__Pyx_TimeZone_UTC             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of time
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__Pyx_TimeZone_UTC));
  __pyx_r = ((PyObject *)__Pyx_TimeZone_UTC);
  goto __pyx_L0;

  /* "datetime.pxd":326
 * 
 * # Get UTC singleton
 * cdef inline object get_utc():             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.datetime.get_utc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":332
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("time_tzinfo", 0);

  /* "datetime.pxd":333
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of datetime
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_TIME_GET_TZINFO(__pyx_v_o);
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":332
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":336
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("datetime_tzinfo", 0);

  /* "datetime.pxd":337
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of date
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_DATE_GET_TZINFO(__pyx_v_o);
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":336
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":340
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_year", 0);

  /* "datetime.pxd":341
 * # Get year of date
 * cdef inline int date_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of date
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":340
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":344
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_month", 0);

  /* "datetime.pxd":345
 * # Get month of date
 * cdef inline int date_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of date
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":344
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":348
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_day", 0);

  /* "datetime.pxd":349
 * # Get day of date
 * cdef inline int date_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of datetime
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":348
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":352
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_year", 0);

  /* "datetime.pxd":353
 * # Get year of datetime
 * cdef inline int datetime_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of datetime
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":352
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":356
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_month", 0);

  /* "datetime.pxd":357
 * # Get month of datetime
 * cdef inline int datetime_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of datetime
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":356
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":360
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_day", 0);

  /* "datetime.pxd":361
 * # Get day of datetime
 * cdef inline int datetime_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of time
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":360
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":364
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_hour", 0);

  /* "datetime.pxd":365
 * # Get hour of time
 * cdef inline int time_hour(object o):
 *     return PyDateTime_TIME_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of time
 */
  __pyx_r = PyDateTime_TIME_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":364
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":368
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_minute", 0);

  /* "datetime.pxd":369
 * # Get minute of time
 * cdef inline int time_minute(object o):
 *     return PyDateTime_TIME_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of time
 */
  __pyx_r = PyDateTime_TIME_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":368
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":372
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_second", 0);

  /* "datetime.pxd":373
 * # Get second of time
 * cdef inline int time_second(object o):
 *     return PyDateTime_TIME_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of time
 */
  __pyx_r = PyDateTime_TIME_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":372
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":376
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_microsecond", 0);

  /* "datetime.pxd":377
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):
 *     return PyDateTime_TIME_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get fold of time
 */
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":376
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":380
 * 
 * # Get fold of time
 * cdef inline int time_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_fold(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_fold", 0);

  /* "datetime.pxd":382
 * cdef inline int time_fold(object o):
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of datetime
 */
  __pyx_r = PyDateTime_TIME_GET_FOLD(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":380
 * 
 * # Get fold of time
 * cdef inline int time_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":385
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_hour", 0);

  /* "datetime.pxd":386
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):
 *     return PyDateTime_DATE_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":385
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":389
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_minute", 0);

  /* "datetime.pxd":390
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):
 *     return PyDateTime_DATE_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":389
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":393
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_second", 0);

  /* "datetime.pxd":394
 * # Get second of datetime
 * cdef inline int datetime_second(object o):
 *     return PyDateTime_DATE_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":393
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":397
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_microsecond", 0);

  /* "datetime.pxd":398
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):
 *     return PyDateTime_DATE_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get fold of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":397
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":401
 * 
 * # Get fold of datetime
 * cdef inline int datetime_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_fold(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_fold", 0);

  /* "datetime.pxd":403
 * cdef inline int datetime_fold(object o):
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)             # <<<<<<<<<<<<<<
 * 
 * # Get days of timedelta
 */
  __pyx_r = PyDateTime_DATE_GET_FOLD(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":401
 * 
 * # Get fold of datetime
 * cdef inline int datetime_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":406
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_days(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_days", 0);

  /* "datetime.pxd":407
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):
 *     return (<PyDateTime_Delta*>o).days             # <<<<<<<<<<<<<<
 * 
 * # Get seconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->days;
  goto __pyx_L0;

  /* "datetime.pxd":406
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":410
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_seconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_seconds", 0);

  /* "datetime.pxd":411
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):
 *     return (<PyDateTime_Delta*>o).seconds             # <<<<<<<<<<<<<<
 * 
 * # Get microseconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->seconds;
  goto __pyx_L0;

  /* "datetime.pxd":410
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":414
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_microseconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_microseconds", 0);

  /* "datetime.pxd":415
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):
 *     return (<PyDateTime_Delta*>o).microseconds             # <<<<<<<<<<<<<<
 * 
 * cdef inline double total_seconds(timedelta obj):
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->microseconds;
  goto __pyx_L0;

  /* "datetime.pxd":414
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":417
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 * cdef inline double total_seconds(timedelta obj):             # <<<<<<<<<<<<<<
 *     # Mirrors the "timedelta.total_seconds()" method.
 *     # Note that this implementation is not guaranteed to give *exactly* the same
 */

static CYTHON_INLINE double __pyx_f_7cpython_8datetime_total_seconds(PyDateTime_Delta *__pyx_v_obj) {
  double __pyx_v_days;
  double __pyx_v_seconds;
  double __pyx_v_micros;
  double __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("total_seconds", 0);

  /* "datetime.pxd":423
 *     cdef:
 *         double days, seconds, micros
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)             # <<<<<<<<<<<<<<
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 */
  __pyx_v_days = ((double)PyDateTime_DELTA_GET_DAYS(((PyObject *)__pyx_v_obj)));

  /* "datetime.pxd":424
 *         double days, seconds, micros
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)             # <<<<<<<<<<<<<<
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 *     return days * 24 * 3600 + seconds + micros / 1_000_000
 */
  __pyx_v_seconds = ((double)PyDateTime_DELTA_GET_SECONDS(((PyObject *)__pyx_v_obj)));

  /* "datetime.pxd":425
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)             # <<<<<<<<<<<<<<
 *     return days * 24 * 3600 + seconds + micros / 1_000_000
 */
  __pyx_v_micros = ((double)PyDateTime_DELTA_GET_MICROSECONDS(((PyObject *)__pyx_v_obj)));

  /* "datetime.pxd":426
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 *     return days * 24 * 3600 + seconds + micros / 1_000_000             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((((__pyx_v_days * 24.0) * 3600.0) + __pyx_v_seconds) + (__pyx_v_micros / 1000000.0));
  goto __pyx_L0;

  /* "datetime.pxd":417
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 * cdef inline double total_seconds(timedelta obj):             # <<<<<<<<<<<<<<
 *     # Mirrors the "timedelta.total_seconds()" method.
 *     # Note that this implementation is not guaranteed to give *exactly* the same
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":296
 * 
 * 
 * cdef sqlite_to_python(int argc, sqlite3_value **params):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int i
 */

static PyObject *__pyx_f_9playhouse_11_sqlite_ext_sqlite_to_python(int __pyx_v_argc, sqlite3_value **__pyx_v_params) {
  int __pyx_v_i;
  int __pyx_v_vtype;
  PyObject *__pyx_v_pyargs = 0;
  PyObject *__pyx_v_pyval = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sqlite_to_python", 0);

  /* "playhouse/_sqlite_ext.pyx":300
 *         int i
 *         int vtype
 *         list pyargs = []             # <<<<<<<<<<<<<<
 * 
 *     for i in range(argc):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pyargs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":302
 *         list pyargs = []
 * 
 *     for i in range(argc):             # <<<<<<<<<<<<<<
 *         vtype = sqlite3_value_type(params[i])
 *         if vtype == SQLITE_INTEGER:
 */
  __pyx_t_2 = __pyx_v_argc;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "playhouse/_sqlite_ext.pyx":303
 * 
 *     for i in range(argc):
 *         vtype = sqlite3_value_type(params[i])             # <<<<<<<<<<<<<<
 *         if vtype == SQLITE_INTEGER:
 *             pyval = sqlite3_value_int(params[i])
 */
    __pyx_v_vtype = sqlite3_value_type((__pyx_v_params[__pyx_v_i]));

    /* "playhouse/_sqlite_ext.pyx":304
 *     for i in range(argc):
 *         vtype = sqlite3_value_type(params[i])
 *         if vtype == SQLITE_INTEGER:             # <<<<<<<<<<<<<<
 *             pyval = sqlite3_value_int(params[i])
 *         elif vtype == SQLITE_FLOAT:
 */
    __pyx_t_5 = (__pyx_v_vtype == SQLITE_INTEGER);
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":305
 *         vtype = sqlite3_value_type(params[i])
 *         if vtype == SQLITE_INTEGER:
 *             pyval = sqlite3_value_int(params[i])             # <<<<<<<<<<<<<<
 *         elif vtype == SQLITE_FLOAT:
 *             pyval = sqlite3_value_double(params[i])
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(sqlite3_value_int((__pyx_v_params[__pyx_v_i]))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "playhouse/_sqlite_ext.pyx":304
 *     for i in range(argc):
 *         vtype = sqlite3_value_type(params[i])
 *         if vtype == SQLITE_INTEGER:             # <<<<<<<<<<<<<<
 *             pyval = sqlite3_value_int(params[i])
 *         elif vtype == SQLITE_FLOAT:
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":306
 *         if vtype == SQLITE_INTEGER:
 *             pyval = sqlite3_value_int(params[i])
 *         elif vtype == SQLITE_FLOAT:             # <<<<<<<<<<<<<<
 *             pyval = sqlite3_value_double(params[i])
 *         elif vtype == SQLITE_TEXT:
 */
    __pyx_t_5 = (__pyx_v_vtype == SQLITE_FLOAT);
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":307
 *             pyval = sqlite3_value_int(params[i])
 *         elif vtype == SQLITE_FLOAT:
 *             pyval = sqlite3_value_double(params[i])             # <<<<<<<<<<<<<<
 *         elif vtype == SQLITE_TEXT:
 *             pyval = PyUnicode_DecodeUTF8(
 */
      __pyx_t_1 = PyFloat_FromDouble(sqlite3_value_double((__pyx_v_params[__pyx_v_i]))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 307, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "playhouse/_sqlite_ext.pyx":306
 *         if vtype == SQLITE_INTEGER:
 *             pyval = sqlite3_value_int(params[i])
 *         elif vtype == SQLITE_FLOAT:             # <<<<<<<<<<<<<<
 *             pyval = sqlite3_value_double(params[i])
 *         elif vtype == SQLITE_TEXT:
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":308
 *         elif vtype == SQLITE_FLOAT:
 *             pyval = sqlite3_value_double(params[i])
 *         elif vtype == SQLITE_TEXT:             # <<<<<<<<<<<<<<
 *             pyval = PyUnicode_DecodeUTF8(
 *                 <const char *>sqlite3_value_text(params[i]),
 */
    __pyx_t_5 = (__pyx_v_vtype == SQLITE_TEXT);
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":309
 *             pyval = sqlite3_value_double(params[i])
 *         elif vtype == SQLITE_TEXT:
 *             pyval = PyUnicode_DecodeUTF8(             # <<<<<<<<<<<<<<
 *                 <const char *>sqlite3_value_text(params[i]),
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]), NULL)
 */
      __pyx_t_1 = PyUnicode_DecodeUTF8(((char const *)sqlite3_value_text((__pyx_v_params[__pyx_v_i]))), ((Py_ssize_t)sqlite3_value_bytes((__pyx_v_params[__pyx_v_i]))), NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "playhouse/_sqlite_ext.pyx":308
 *         elif vtype == SQLITE_FLOAT:
 *             pyval = sqlite3_value_double(params[i])
 *         elif vtype == SQLITE_TEXT:             # <<<<<<<<<<<<<<
 *             pyval = PyUnicode_DecodeUTF8(
 *                 <const char *>sqlite3_value_text(params[i]),
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":312
 *                 <const char *>sqlite3_value_text(params[i]),
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]), NULL)
 *         elif vtype == SQLITE_BLOB:             # <<<<<<<<<<<<<<
 *             pyval = PyBytes_FromStringAndSize(
 *                 <const char *>sqlite3_value_blob(params[i]),
 */
    __pyx_t_5 = (__pyx_v_vtype == SQLITE_BLOB);
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":313
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]), NULL)
 *         elif vtype == SQLITE_BLOB:
 *             pyval = PyBytes_FromStringAndSize(             # <<<<<<<<<<<<<<
 *                 <const char *>sqlite3_value_blob(params[i]),
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]))
 */
      __pyx_t_1 = PyBytes_FromStringAndSize(((char const *)sqlite3_value_blob((__pyx_v_params[__pyx_v_i]))), ((Py_ssize_t)sqlite3_value_bytes((__pyx_v_params[__pyx_v_i])))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "playhouse/_sqlite_ext.pyx":312
 *                 <const char *>sqlite3_value_text(params[i]),
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]), NULL)
 *         elif vtype == SQLITE_BLOB:             # <<<<<<<<<<<<<<
 *             pyval = PyBytes_FromStringAndSize(
 *                 <const char *>sqlite3_value_blob(params[i]),
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":316
 *                 <const char *>sqlite3_value_blob(params[i]),
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]))
 *         elif vtype == SQLITE_NULL:             # <<<<<<<<<<<<<<
 *             pyval = None
 *         else:
 */
    __pyx_t_5 = (__pyx_v_vtype == SQLITE_NULL);
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":317
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]))
 *         elif vtype == SQLITE_NULL:
 *             pyval = None             # <<<<<<<<<<<<<<
 *         else:
 *             pyval = None
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_pyval, Py_None);

      /* "playhouse/_sqlite_ext.pyx":316
 *                 <const char *>sqlite3_value_blob(params[i]),
 *                 <Py_ssize_t>sqlite3_value_bytes(params[i]))
 *         elif vtype == SQLITE_NULL:             # <<<<<<<<<<<<<<
 *             pyval = None
 *         else:
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":319
 *             pyval = None
 *         else:
 *             pyval = None             # <<<<<<<<<<<<<<
 * 
 *         pyargs.append(pyval)
 */
    /*else*/ {
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_pyval, Py_None);
    }
    __pyx_L5:;

    /* "playhouse/_sqlite_ext.pyx":321
 *             pyval = None
 * 
 *         pyargs.append(pyval)             # <<<<<<<<<<<<<<
 * 
 *     return pyargs
 */
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_pyargs, __pyx_v_pyval); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 321, __pyx_L1_error)
  }

  /* "playhouse/_sqlite_ext.pyx":323
 *         pyargs.append(pyval)
 * 
 *     return pyargs             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyargs);
  __pyx_r = __pyx_v_pyargs;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":296
 * 
 * 
 * cdef sqlite_to_python(int argc, sqlite3_value **params):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.sqlite_to_python", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyargs);
  __Pyx_XDECREF(__pyx_v_pyval);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":326
 * 
 * 
 * cdef python_to_sqlite(sqlite3_context *context, value):             # <<<<<<<<<<<<<<
 *     if value is None:
 *         sqlite3_result_null(context)
 */

static PyObject *__pyx_f_9playhouse_11_sqlite_ext_python_to_sqlite(sqlite3_context *__pyx_v_context, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_bval = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  sqlite3_int64 __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  char const *__pyx_t_6;
  Py_ssize_t __pyx_t_7;
  char *__pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  char const *__pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("python_to_sqlite", 0);

  /* "playhouse/_sqlite_ext.pyx":327
 * 
 * cdef python_to_sqlite(sqlite3_context *context, value):
 *     if value is None:             # <<<<<<<<<<<<<<
 *         sqlite3_result_null(context)
 *     elif isinstance(value, (int, long)):
 */
  __pyx_t_1 = (__pyx_v_value == Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":328
 * cdef python_to_sqlite(sqlite3_context *context, value):
 *     if value is None:
 *         sqlite3_result_null(context)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, (int, long)):
 *         sqlite3_result_int64(context, <sqlite3_int64>value)
 */
    sqlite3_result_null(__pyx_v_context);

    /* "playhouse/_sqlite_ext.pyx":327
 * 
 * cdef python_to_sqlite(sqlite3_context *context, value):
 *     if value is None:             # <<<<<<<<<<<<<<
 *         sqlite3_result_null(context)
 *     elif isinstance(value, (int, long)):
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":329
 *     if value is None:
 *         sqlite3_result_null(context)
 *     elif isinstance(value, (int, long)):             # <<<<<<<<<<<<<<
 *         sqlite3_result_int64(context, <sqlite3_int64>value)
 *     elif isinstance(value, float):
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_value); 
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = PyLong_Check(__pyx_v_value); 
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":330
 *         sqlite3_result_null(context)
 *     elif isinstance(value, (int, long)):
 *         sqlite3_result_int64(context, <sqlite3_int64>value)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, float):
 *         sqlite3_result_double(context, <double>value)
 */
    __pyx_t_3 = __Pyx_PyInt_As_sqlite3_int64(__pyx_v_value); if (unlikely((__pyx_t_3 == ((sqlite3_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 330, __pyx_L1_error)
    sqlite3_result_int64(__pyx_v_context, ((sqlite3_int64)__pyx_t_3));

    /* "playhouse/_sqlite_ext.pyx":329
 *     if value is None:
 *         sqlite3_result_null(context)
 *     elif isinstance(value, (int, long)):             # <<<<<<<<<<<<<<
 *         sqlite3_result_int64(context, <sqlite3_int64>value)
 *     elif isinstance(value, float):
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":331
 *     elif isinstance(value, (int, long)):
 *         sqlite3_result_int64(context, <sqlite3_int64>value)
 *     elif isinstance(value, float):             # <<<<<<<<<<<<<<
 *         sqlite3_result_double(context, <double>value)
 *     elif isinstance(value, unicode):
 */
  __pyx_t_1 = PyFloat_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":332
 *         sqlite3_result_int64(context, <sqlite3_int64>value)
 *     elif isinstance(value, float):
 *         sqlite3_result_double(context, <double>value)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, unicode):
 *         bval = PyUnicode_AsUTF8String(value)
 */
    __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_value); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 332, __pyx_L1_error)
    sqlite3_result_double(__pyx_v_context, ((double)__pyx_t_4));

    /* "playhouse/_sqlite_ext.pyx":331
 *     elif isinstance(value, (int, long)):
 *         sqlite3_result_int64(context, <sqlite3_int64>value)
 *     elif isinstance(value, float):             # <<<<<<<<<<<<<<
 *         sqlite3_result_double(context, <double>value)
 *     elif isinstance(value, unicode):
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":333
 *     elif isinstance(value, float):
 *         sqlite3_result_double(context, <double>value)
 *     elif isinstance(value, unicode):             # <<<<<<<<<<<<<<
 *         bval = PyUnicode_AsUTF8String(value)
 *         sqlite3_result_text(
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":334
 *         sqlite3_result_double(context, <double>value)
 *     elif isinstance(value, unicode):
 *         bval = PyUnicode_AsUTF8String(value)             # <<<<<<<<<<<<<<
 *         sqlite3_result_text(
 *             context,
 */
    __pyx_t_5 = PyUnicode_AsUTF8String(__pyx_v_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_bval = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "playhouse/_sqlite_ext.pyx":337
 *         sqlite3_result_text(
 *             context,
 *             <const char *>bval,             # <<<<<<<<<<<<<<
 *             len(bval),
 *             <sqlite3_destructor_type>-1)
 */
    if (unlikely(__pyx_v_bval == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 337, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_PyBytes_AsString(__pyx_v_bval); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 337, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":338
 *             context,
 *             <const char *>bval,
 *             len(bval),             # <<<<<<<<<<<<<<
 *             <sqlite3_destructor_type>-1)
 *     elif isinstance(value, bytes):
 */
    if (unlikely(__pyx_v_bval == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 338, __pyx_L1_error)
    }
    __pyx_t_7 = PyBytes_GET_SIZE(__pyx_v_bval); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 338, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":335
 *     elif isinstance(value, unicode):
 *         bval = PyUnicode_AsUTF8String(value)
 *         sqlite3_result_text(             # <<<<<<<<<<<<<<
 *             context,
 *             <const char *>bval,
 */
    sqlite3_result_text(__pyx_v_context, ((char const *)__pyx_t_6), __pyx_t_7, ((sqlite3_destructor_type)-1L));

    /* "playhouse/_sqlite_ext.pyx":333
 *     elif isinstance(value, float):
 *         sqlite3_result_double(context, <double>value)
 *     elif isinstance(value, unicode):             # <<<<<<<<<<<<<<
 *         bval = PyUnicode_AsUTF8String(value)
 *         sqlite3_result_text(
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":340
 *             len(bval),
 *             <sqlite3_destructor_type>-1)
 *     elif isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *         if PY_MAJOR_VERSION > 2:
 *             sqlite3_result_blob(
 */
  __pyx_t_1 = PyBytes_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":341
 *             <sqlite3_destructor_type>-1)
 *     elif isinstance(value, bytes):
 *         if PY_MAJOR_VERSION > 2:             # <<<<<<<<<<<<<<
 *             sqlite3_result_blob(
 *                 context,
 */
    __pyx_t_1 = (PY_MAJOR_VERSION > 2);
    if (__pyx_t_1) {

      /* "playhouse/_sqlite_ext.pyx":344
 *             sqlite3_result_blob(
 *                 context,
 *                 <void *>(<char *>value),             # <<<<<<<<<<<<<<
 *                 len(value),
 *                 <sqlite3_destructor_type>-1)
 */
      __pyx_t_8 = __Pyx_PyObject_AsWritableString(__pyx_v_value); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) __PYX_ERR(0, 344, __pyx_L1_error)

      /* "playhouse/_sqlite_ext.pyx":345
 *                 context,
 *                 <void *>(<char *>value),
 *                 len(value),             # <<<<<<<<<<<<<<
 *                 <sqlite3_destructor_type>-1)
 *         else:
 */
      __pyx_t_7 = PyObject_Length(__pyx_v_value); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 345, __pyx_L1_error)

      /* "playhouse/_sqlite_ext.pyx":342
 *     elif isinstance(value, bytes):
 *         if PY_MAJOR_VERSION > 2:
 *             sqlite3_result_blob(             # <<<<<<<<<<<<<<
 *                 context,
 *                 <void *>(<char *>value),
 */
      sqlite3_result_blob(__pyx_v_context, ((void *)((char *)__pyx_t_8)), __pyx_t_7, ((sqlite3_destructor_type)-1L));

      /* "playhouse/_sqlite_ext.pyx":341
 *             <sqlite3_destructor_type>-1)
 *     elif isinstance(value, bytes):
 *         if PY_MAJOR_VERSION > 2:             # <<<<<<<<<<<<<<
 *             sqlite3_result_blob(
 *                 context,
 */
      goto __pyx_L6;
    }

    /* "playhouse/_sqlite_ext.pyx":348
 *                 <sqlite3_destructor_type>-1)
 *         else:
 *             sqlite3_result_text(             # <<<<<<<<<<<<<<
 *                 context,
 *                 <const char *>value,
 */
    /*else*/ {

      /* "playhouse/_sqlite_ext.pyx":350
 *             sqlite3_result_text(
 *                 context,
 *                 <const char *>value,             # <<<<<<<<<<<<<<
 *                 len(value),
 *                 <sqlite3_destructor_type>-1)
 */
      __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_value); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) __PYX_ERR(0, 350, __pyx_L1_error)

      /* "playhouse/_sqlite_ext.pyx":351
 *                 context,
 *                 <const char *>value,
 *                 len(value),             # <<<<<<<<<<<<<<
 *                 <sqlite3_destructor_type>-1)
 *     else:
 */
      __pyx_t_7 = PyObject_Length(__pyx_v_value); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 351, __pyx_L1_error)

      /* "playhouse/_sqlite_ext.pyx":348
 *                 <sqlite3_destructor_type>-1)
 *         else:
 *             sqlite3_result_text(             # <<<<<<<<<<<<<<
 *                 context,
 *                 <const char *>value,
 */
      sqlite3_result_text(__pyx_v_context, ((char const *)__pyx_t_9), __pyx_t_7, ((sqlite3_destructor_type)-1L));
    }
    __pyx_L6:;

    /* "playhouse/_sqlite_ext.pyx":340
 *             len(bval),
 *             <sqlite3_destructor_type>-1)
 *     elif isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *         if PY_MAJOR_VERSION > 2:
 *             sqlite3_result_blob(
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":354
 *                 <sqlite3_destructor_type>-1)
 *     else:
 *         sqlite3_result_error(             # <<<<<<<<<<<<<<
 *             context,
 *             encode('Unsupported type %s' % type(value)),
 */
  /*else*/ {

    /* "playhouse/_sqlite_ext.pyx":356
 *         sqlite3_result_error(
 *             context,
 *             encode('Unsupported type %s' % type(value)),             # <<<<<<<<<<<<<<
 *             -1)
 *         return SQLITE_ERROR
 */
    __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Unsupported_type_s, ((PyObject *)Py_TYPE(__pyx_v_value))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_t_10 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 356, __pyx_L1_error)
    }
    __pyx_t_11 = __Pyx_PyBytes_AsString(__pyx_t_10); if (unlikely((!__pyx_t_11) && PyErr_Occurred())) __PYX_ERR(0, 356, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":354
 *                 <sqlite3_destructor_type>-1)
 *     else:
 *         sqlite3_result_error(             # <<<<<<<<<<<<<<
 *             context,
 *             encode('Unsupported type %s' % type(value)),
 */
    sqlite3_result_error(__pyx_v_context, __pyx_t_11, -1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "playhouse/_sqlite_ext.pyx":358
 *             encode('Unsupported type %s' % type(value)),
 *             -1)
 *         return SQLITE_ERROR             # <<<<<<<<<<<<<<
 * 
 *     return SQLITE_OK
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_10 = __Pyx_PyInt_From_int(SQLITE_ERROR); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "playhouse/_sqlite_ext.pyx":360
 *         return SQLITE_ERROR
 * 
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_10 = __Pyx_PyInt_From_int(SQLITE_OK); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_r = __pyx_t_10;
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":326
 * 
 * 
 * cdef python_to_sqlite(sqlite3_context *context, value):             # <<<<<<<<<<<<<<
 *     if value is None:
 *         sqlite3_result_null(context)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("playhouse._sqlite_ext.python_to_sqlite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bval);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":388
 * # We define an xConnect function, but leave xCreate NULL so that the
 * # table-function can be called eponymously.
 * cdef int pwConnect(sqlite3 *db, void *pAux, int argc, const char *const*argv,             # <<<<<<<<<<<<<<
 *                    sqlite3_vtab **ppVtab, char **pzErr) noexcept with gil:
 *     cdef:
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwConnect(sqlite3 *__pyx_v_db, void *__pyx_v_pAux, CYTHON_UNUSED int __pyx_v_argc, CYTHON_UNUSED char const *const *__pyx_v_argv, sqlite3_vtab **__pyx_v_ppVtab, CYTHON_UNUSED char **__pyx_v_pzErr) {
  int __pyx_v_rc;
  PyObject *__pyx_v_table_func_cls = 0;
  __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *__pyx_v_pNew;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  char const *__pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwConnect", 0);

  /* "playhouse/_sqlite_ext.pyx":392
 *     cdef:
 *         int rc
 *         object table_func_cls = <object>pAux             # <<<<<<<<<<<<<<
 *         peewee_vtab *pNew = <peewee_vtab *>0
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_pAux);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_table_func_cls = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":393
 *         int rc
 *         object table_func_cls = <object>pAux
 *         peewee_vtab *pNew = <peewee_vtab *>0             # <<<<<<<<<<<<<<
 * 
 *     rc = sqlite3_declare_vtab(
 */
  __pyx_v_pNew = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *)0);

  /* "playhouse/_sqlite_ext.pyx":398
 *         db,
 *         encode('CREATE TABLE x(%s);' %
 *                table_func_cls.get_table_columns_declaration()))             # <<<<<<<<<<<<<<
 *     if rc == SQLITE_OK:
 *         pNew = <peewee_vtab *>sqlite3_malloc(sizeof(pNew[0]))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func_cls, __pyx_n_s_get_table_columns_declaration); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_3, };
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "playhouse/_sqlite_ext.pyx":397
 *     rc = sqlite3_declare_vtab(
 *         db,
 *         encode('CREATE TABLE x(%s);' %             # <<<<<<<<<<<<<<
 *                table_func_cls.get_table_columns_declaration()))
 *     if rc == SQLITE_OK:
 */
  __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_CREATE_TABLE_x_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 397, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyBytes_AsString(__pyx_t_1); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) __PYX_ERR(0, 397, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":395
 *         peewee_vtab *pNew = <peewee_vtab *>0
 * 
 *     rc = sqlite3_declare_vtab(             # <<<<<<<<<<<<<<
 *         db,
 *         encode('CREATE TABLE x(%s);' %
 */
  __pyx_v_rc = sqlite3_declare_vtab(__pyx_v_db, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":399
 *         encode('CREATE TABLE x(%s);' %
 *                table_func_cls.get_table_columns_declaration()))
 *     if rc == SQLITE_OK:             # <<<<<<<<<<<<<<
 *         pNew = <peewee_vtab *>sqlite3_malloc(sizeof(pNew[0]))
 *         memset(<char *>pNew, 0, sizeof(pNew[0]))
 */
  __pyx_t_6 = (__pyx_v_rc == SQLITE_OK);
  if (__pyx_t_6) {

    /* "playhouse/_sqlite_ext.pyx":400
 *                table_func_cls.get_table_columns_declaration()))
 *     if rc == SQLITE_OK:
 *         pNew = <peewee_vtab *>sqlite3_malloc(sizeof(pNew[0]))             # <<<<<<<<<<<<<<
 *         memset(<char *>pNew, 0, sizeof(pNew[0]))
 *         ppVtab[0] = &(pNew.base)
 */
    __pyx_v_pNew = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *)sqlite3_malloc((sizeof((__pyx_v_pNew[0])))));

    /* "playhouse/_sqlite_ext.pyx":401
 *     if rc == SQLITE_OK:
 *         pNew = <peewee_vtab *>sqlite3_malloc(sizeof(pNew[0]))
 *         memset(<char *>pNew, 0, sizeof(pNew[0]))             # <<<<<<<<<<<<<<
 *         ppVtab[0] = &(pNew.base)
 * 
 */
    (void)(memset(((char *)__pyx_v_pNew), 0, (sizeof((__pyx_v_pNew[0])))));

    /* "playhouse/_sqlite_ext.pyx":402
 *         pNew = <peewee_vtab *>sqlite3_malloc(sizeof(pNew[0]))
 *         memset(<char *>pNew, 0, sizeof(pNew[0]))
 *         ppVtab[0] = &(pNew.base)             # <<<<<<<<<<<<<<
 * 
 *         pNew.table_func_cls = <void *>table_func_cls
 */
    (__pyx_v_ppVtab[0]) = (&__pyx_v_pNew->base);

    /* "playhouse/_sqlite_ext.pyx":404
 *         ppVtab[0] = &(pNew.base)
 * 
 *         pNew.table_func_cls = <void *>table_func_cls             # <<<<<<<<<<<<<<
 *         Py_INCREF(table_func_cls)
 * 
 */
    __pyx_v_pNew->table_func_cls = ((void *)__pyx_v_table_func_cls);

    /* "playhouse/_sqlite_ext.pyx":405
 * 
 *         pNew.table_func_cls = <void *>table_func_cls
 *         Py_INCREF(table_func_cls)             # <<<<<<<<<<<<<<
 * 
 *     return rc
 */
    Py_INCREF(__pyx_v_table_func_cls);

    /* "playhouse/_sqlite_ext.pyx":399
 *         encode('CREATE TABLE x(%s);' %
 *                table_func_cls.get_table_columns_declaration()))
 *     if rc == SQLITE_OK:             # <<<<<<<<<<<<<<
 *         pNew = <peewee_vtab *>sqlite3_malloc(sizeof(pNew[0]))
 *         memset(<char *>pNew, 0, sizeof(pNew[0]))
 */
  }

  /* "playhouse/_sqlite_ext.pyx":407
 *         Py_INCREF(table_func_cls)
 * 
 *     return rc             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_rc;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":388
 * # We define an xConnect function, but leave xCreate NULL so that the
 * # table-function can be called eponymously.
 * cdef int pwConnect(sqlite3 *db, void *pAux, int argc, const char *const*argv,             # <<<<<<<<<<<<<<
 *                    sqlite3_vtab **ppVtab, char **pzErr) noexcept with gil:
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.pwConnect", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_table_func_cls);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":410
 * 
 * 
 * cdef int pwDisconnect(sqlite3_vtab *pBase) noexcept with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwDisconnect(sqlite3_vtab *__pyx_v_pBase) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *__pyx_v_pVtab;
  PyObject *__pyx_v_table_func_cls = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwDisconnect", 0);

  /* "playhouse/_sqlite_ext.pyx":412
 * cdef int pwDisconnect(sqlite3_vtab *pBase) noexcept with gil:
 *     cdef:
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase             # <<<<<<<<<<<<<<
 *         object table_func_cls = <object>(pVtab.table_func_cls)
 * 
 */
  __pyx_v_pVtab = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":413
 *     cdef:
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 *         object table_func_cls = <object>(pVtab.table_func_cls)             # <<<<<<<<<<<<<<
 * 
 *     Py_DECREF(table_func_cls)
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_pVtab->table_func_cls);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_table_func_cls = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":415
 *         object table_func_cls = <object>(pVtab.table_func_cls)
 * 
 *     Py_DECREF(table_func_cls)             # <<<<<<<<<<<<<<
 *     sqlite3_free(pVtab)
 *     return SQLITE_OK
 */
  Py_DECREF(__pyx_v_table_func_cls);

  /* "playhouse/_sqlite_ext.pyx":416
 * 
 *     Py_DECREF(table_func_cls)
 *     sqlite3_free(pVtab)             # <<<<<<<<<<<<<<
 *     return SQLITE_OK
 * 
 */
  sqlite3_free(__pyx_v_pVtab);

  /* "playhouse/_sqlite_ext.pyx":417
 *     Py_DECREF(table_func_cls)
 *     sqlite3_free(pVtab)
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = SQLITE_OK;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":410
 * 
 * 
 * cdef int pwDisconnect(sqlite3_vtab *pBase) noexcept with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_table_func_cls);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":422
 * # The xOpen method is used to initialize a cursor. In this method we
 * # instantiate the TableFunction class and zero out a new cursor for iteration.
 * cdef int pwOpen(sqlite3_vtab *pBase, sqlite3_vtab_cursor **ppCursor) \             # <<<<<<<<<<<<<<
 *                 noexcept with gil:
 *     cdef:
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwOpen(sqlite3_vtab *__pyx_v_pBase, sqlite3_vtab_cursor **__pyx_v_ppCursor) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *__pyx_v_pVtab;
  __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *__pyx_v_pCur;
  PyObject *__pyx_v_table_func_cls = 0;
  PyObject *__pyx_v_table_func = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwOpen", 0);

  /* "playhouse/_sqlite_ext.pyx":425
 *                 noexcept with gil:
 *     cdef:
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase             # <<<<<<<<<<<<<<
 *         peewee_cursor *pCur = <peewee_cursor *>0
 *         object table_func_cls = <object>pVtab.table_func_cls
 */
  __pyx_v_pVtab = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":426
 *     cdef:
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 *         peewee_cursor *pCur = <peewee_cursor *>0             # <<<<<<<<<<<<<<
 *         object table_func_cls = <object>pVtab.table_func_cls
 * 
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)0);

  /* "playhouse/_sqlite_ext.pyx":427
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 *         peewee_cursor *pCur = <peewee_cursor *>0
 *         object table_func_cls = <object>pVtab.table_func_cls             # <<<<<<<<<<<<<<
 * 
 *     pCur = <peewee_cursor *>sqlite3_malloc(sizeof(pCur[0]))
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_pVtab->table_func_cls);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_table_func_cls = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":429
 *         object table_func_cls = <object>pVtab.table_func_cls
 * 
 *     pCur = <peewee_cursor *>sqlite3_malloc(sizeof(pCur[0]))             # <<<<<<<<<<<<<<
 *     memset(<char *>pCur, 0, sizeof(pCur[0]))
 *     ppCursor[0] = &(pCur.base)
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)sqlite3_malloc((sizeof((__pyx_v_pCur[0])))));

  /* "playhouse/_sqlite_ext.pyx":430
 * 
 *     pCur = <peewee_cursor *>sqlite3_malloc(sizeof(pCur[0]))
 *     memset(<char *>pCur, 0, sizeof(pCur[0]))             # <<<<<<<<<<<<<<
 *     ppCursor[0] = &(pCur.base)
 *     pCur.idx = 0
 */
  (void)(memset(((char *)__pyx_v_pCur), 0, (sizeof((__pyx_v_pCur[0])))));

  /* "playhouse/_sqlite_ext.pyx":431
 *     pCur = <peewee_cursor *>sqlite3_malloc(sizeof(pCur[0]))
 *     memset(<char *>pCur, 0, sizeof(pCur[0]))
 *     ppCursor[0] = &(pCur.base)             # <<<<<<<<<<<<<<
 *     pCur.idx = 0
 *     try:
 */
  (__pyx_v_ppCursor[0]) = (&__pyx_v_pCur->base);

  /* "playhouse/_sqlite_ext.pyx":432
 *     memset(<char *>pCur, 0, sizeof(pCur[0]))
 *     ppCursor[0] = &(pCur.base)
 *     pCur.idx = 0             # <<<<<<<<<<<<<<
 *     try:
 *         table_func = table_func_cls()
 */
  __pyx_v_pCur->idx = 0;

  /* "playhouse/_sqlite_ext.pyx":433
 *     ppCursor[0] = &(pCur.base)
 *     pCur.idx = 0
 *     try:             # <<<<<<<<<<<<<<
 *         table_func = table_func_cls()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "playhouse/_sqlite_ext.pyx":434
 *     pCur.idx = 0
 *     try:
 *         table_func = table_func_cls()             # <<<<<<<<<<<<<<
 *     except:
 *         if table_func_cls.print_tracebacks:
 */
      __Pyx_INCREF(__pyx_v_table_func_cls);
      __pyx_t_5 = __pyx_v_table_func_cls; __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      {
        PyObject *__pyx_callargs[1] = {__pyx_t_6, };
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_v_table_func = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "playhouse/_sqlite_ext.pyx":433
 *     ppCursor[0] = &(pCur.base)
 *     pCur.idx = 0
 *     try:             # <<<<<<<<<<<<<<
 *         table_func = table_func_cls()
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "playhouse/_sqlite_ext.pyx":435
 *     try:
 *         table_func = table_func_cls()
 *     except:             # <<<<<<<<<<<<<<
 *         if table_func_cls.print_tracebacks:
 *             traceback.print_exc()
 */
    /*except:*/ {
      __Pyx_AddTraceback("playhouse._sqlite_ext.pwOpen", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 435, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "playhouse/_sqlite_ext.pyx":436
 *         table_func = table_func_cls()
 *     except:
 *         if table_func_cls.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         sqlite3_free(pCur)
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func_cls, __pyx_n_s_print_tracebacks); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 436, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 436, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__pyx_t_9) {

        /* "playhouse/_sqlite_ext.pyx":437
 *     except:
 *         if table_func_cls.print_tracebacks:
 *             traceback.print_exc()             # <<<<<<<<<<<<<<
 *         sqlite3_free(pCur)
 *         return SQLITE_ERROR
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_traceback); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 437, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 437, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = NULL;
        __pyx_t_7 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
            __pyx_t_7 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[1] = {__pyx_t_10, };
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 437, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "playhouse/_sqlite_ext.pyx":436
 *         table_func = table_func_cls()
 *     except:
 *         if table_func_cls.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         sqlite3_free(pCur)
 */
      }

      /* "playhouse/_sqlite_ext.pyx":438
 *         if table_func_cls.print_tracebacks:
 *             traceback.print_exc()
 *         sqlite3_free(pCur)             # <<<<<<<<<<<<<<
 *         return SQLITE_ERROR
 * 
 */
      sqlite3_free(__pyx_v_pCur);

      /* "playhouse/_sqlite_ext.pyx":439
 *             traceback.print_exc()
 *         sqlite3_free(pCur)
 *         return SQLITE_ERROR             # <<<<<<<<<<<<<<
 * 
 *     Py_INCREF(table_func)
 */
      __pyx_r = SQLITE_ERROR;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }

    /* "playhouse/_sqlite_ext.pyx":433
 *     ppCursor[0] = &(pCur.base)
 *     pCur.idx = 0
 *     try:             # <<<<<<<<<<<<<<
 *         table_func = table_func_cls()
 *     except:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "playhouse/_sqlite_ext.pyx":441
 *         return SQLITE_ERROR
 * 
 *     Py_INCREF(table_func)             # <<<<<<<<<<<<<<
 *     pCur.table_func = <void *>table_func
 *     pCur.stopped = False
 */
  Py_INCREF(__pyx_v_table_func);

  /* "playhouse/_sqlite_ext.pyx":442
 * 
 *     Py_INCREF(table_func)
 *     pCur.table_func = <void *>table_func             # <<<<<<<<<<<<<<
 *     pCur.stopped = False
 *     return SQLITE_OK
 */
  __pyx_v_pCur->table_func = ((void *)__pyx_v_table_func);

  /* "playhouse/_sqlite_ext.pyx":443
 *     Py_INCREF(table_func)
 *     pCur.table_func = <void *>table_func
 *     pCur.stopped = False             # <<<<<<<<<<<<<<
 *     return SQLITE_OK
 * 
 */
  __pyx_v_pCur->stopped = 0;

  /* "playhouse/_sqlite_ext.pyx":444
 *     pCur.table_func = <void *>table_func
 *     pCur.stopped = False
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = SQLITE_OK;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":422
 * # The xOpen method is used to initialize a cursor. In this method we
 * # instantiate the TableFunction class and zero out a new cursor for iteration.
 * cdef int pwOpen(sqlite3_vtab *pBase, sqlite3_vtab_cursor **ppCursor) \             # <<<<<<<<<<<<<<
 *                 noexcept with gil:
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.pwOpen", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_table_func_cls);
  __Pyx_XDECREF(__pyx_v_table_func);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":447
 * 
 * 
 * cdef int pwClose(sqlite3_vtab_cursor *pBase) noexcept with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwClose(sqlite3_vtab_cursor *__pyx_v_pBase) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *__pyx_v_pCur;
  PyObject *__pyx_v_table_func = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwClose", 0);

  /* "playhouse/_sqlite_ext.pyx":449
 * cdef int pwClose(sqlite3_vtab_cursor *pBase) noexcept with gil:
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase             # <<<<<<<<<<<<<<
 *         object table_func = <object>pCur.table_func
 *     Py_DECREF(table_func)
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":450
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *         object table_func = <object>pCur.table_func             # <<<<<<<<<<<<<<
 *     Py_DECREF(table_func)
 *     sqlite3_free(pCur)
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_pCur->table_func);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_table_func = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":451
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *         object table_func = <object>pCur.table_func
 *     Py_DECREF(table_func)             # <<<<<<<<<<<<<<
 *     sqlite3_free(pCur)
 *     return SQLITE_OK
 */
  Py_DECREF(__pyx_v_table_func);

  /* "playhouse/_sqlite_ext.pyx":452
 *         object table_func = <object>pCur.table_func
 *     Py_DECREF(table_func)
 *     sqlite3_free(pCur)             # <<<<<<<<<<<<<<
 *     return SQLITE_OK
 * 
 */
  sqlite3_free(__pyx_v_pCur);

  /* "playhouse/_sqlite_ext.pyx":453
 *     Py_DECREF(table_func)
 *     sqlite3_free(pCur)
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = SQLITE_OK;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":447
 * 
 * 
 * cdef int pwClose(sqlite3_vtab_cursor *pBase) noexcept with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_table_func);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":458
 * # Iterate once, advancing the cursor's index and assigning the row data to the
 * # `row_data` field on the peewee_cursor struct.
 * cdef int pwNext(sqlite3_vtab_cursor *pBase) noexcept with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwNext(sqlite3_vtab_cursor *__pyx_v_pBase) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *__pyx_v_pCur;
  PyObject *__pyx_v_table_func = 0;
  PyObject *__pyx_v_result = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwNext", 0);

  /* "playhouse/_sqlite_ext.pyx":460
 * cdef int pwNext(sqlite3_vtab_cursor *pBase) noexcept with gil:
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase             # <<<<<<<<<<<<<<
 *         object table_func = <object>pCur.table_func
 *         tuple result
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":461
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *         object table_func = <object>pCur.table_func             # <<<<<<<<<<<<<<
 *         tuple result
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_pCur->table_func);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_table_func = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":464
 *         tuple result
 * 
 *     if pCur.row_data:             # <<<<<<<<<<<<<<
 *         Py_DECREF(<tuple>pCur.row_data)
 * 
 */
  __pyx_t_2 = (__pyx_v_pCur->row_data != 0);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":465
 * 
 *     if pCur.row_data:
 *         Py_DECREF(<tuple>pCur.row_data)             # <<<<<<<<<<<<<<
 * 
 *     pCur.row_data = NULL
 */
    __pyx_t_1 = ((PyObject *)__pyx_v_pCur->row_data);
    __Pyx_INCREF(__pyx_t_1);
    Py_DECREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "playhouse/_sqlite_ext.pyx":464
 *         tuple result
 * 
 *     if pCur.row_data:             # <<<<<<<<<<<<<<
 *         Py_DECREF(<tuple>pCur.row_data)
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":467
 *         Py_DECREF(<tuple>pCur.row_data)
 * 
 *     pCur.row_data = NULL             # <<<<<<<<<<<<<<
 *     try:
 *         result = tuple(table_func.iterate(pCur.idx))
 */
  __pyx_v_pCur->row_data = NULL;

  /* "playhouse/_sqlite_ext.pyx":468
 * 
 *     pCur.row_data = NULL
 *     try:             # <<<<<<<<<<<<<<
 *         result = tuple(table_func.iterate(pCur.idx))
 *     except StopIteration:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "playhouse/_sqlite_ext.pyx":469
 *     pCur.row_data = NULL
 *     try:
 *         result = tuple(table_func.iterate(pCur.idx))             # <<<<<<<<<<<<<<
 *     except StopIteration:
 *         pCur.stopped = True
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func, __pyx_n_s_iterate); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 469, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyInt_From_PY_LONG_LONG(__pyx_v_pCur->idx); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 469, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_t_6 = __Pyx_PySequence_Tuple(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 469, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_result = ((PyObject*)__pyx_t_6);
      __pyx_t_6 = 0;

      /* "playhouse/_sqlite_ext.pyx":468
 * 
 *     pCur.row_data = NULL
 *     try:             # <<<<<<<<<<<<<<
 *         result = tuple(table_func.iterate(pCur.idx))
 *     except StopIteration:
 */
    }

    /* "playhouse/_sqlite_ext.pyx":477
 *         return SQLITE_ERROR
 *     else:
 *         Py_INCREF(result)             # <<<<<<<<<<<<<<
 *         pCur.row_data = <void *>result
 *         pCur.idx += 1
 */
    /*else:*/ {
      Py_INCREF(__pyx_v_result);

      /* "playhouse/_sqlite_ext.pyx":478
 *     else:
 *         Py_INCREF(result)
 *         pCur.row_data = <void *>result             # <<<<<<<<<<<<<<
 *         pCur.idx += 1
 *         pCur.stopped = False
 */
      __pyx_v_pCur->row_data = ((void *)__pyx_v_result);

      /* "playhouse/_sqlite_ext.pyx":479
 *         Py_INCREF(result)
 *         pCur.row_data = <void *>result
 *         pCur.idx += 1             # <<<<<<<<<<<<<<
 *         pCur.stopped = False
 * 
 */
      __pyx_v_pCur->idx = (__pyx_v_pCur->idx + 1);

      /* "playhouse/_sqlite_ext.pyx":480
 *         pCur.row_data = <void *>result
 *         pCur.idx += 1
 *         pCur.stopped = False             # <<<<<<<<<<<<<<
 * 
 *     return SQLITE_OK
 */
      __pyx_v_pCur->stopped = 0;
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "playhouse/_sqlite_ext.pyx":470
 *     try:
 *         result = tuple(table_func.iterate(pCur.idx))
 *     except StopIteration:             # <<<<<<<<<<<<<<
 *         pCur.stopped = True
 *     except:
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_StopIteration);
    if (__pyx_t_9) {
      __Pyx_AddTraceback("playhouse._sqlite_ext.pwNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(0, 470, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "playhouse/_sqlite_ext.pyx":471
 *         result = tuple(table_func.iterate(pCur.idx))
 *     except StopIteration:
 *         pCur.stopped = True             # <<<<<<<<<<<<<<
 *     except:
 *         if table_func.print_tracebacks:
 */
      __pyx_v_pCur->stopped = 1;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L5_exception_handled;
    }

    /* "playhouse/_sqlite_ext.pyx":472
 *     except StopIteration:
 *         pCur.stopped = True
 *     except:             # <<<<<<<<<<<<<<
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()
 */
    /*except:*/ {
      __Pyx_AddTraceback("playhouse._sqlite_ext.pwNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_1, &__pyx_t_6) < 0) __PYX_ERR(0, 472, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "playhouse/_sqlite_ext.pyx":473
 *         pCur.stopped = True
 *     except:
 *         if table_func.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         return SQLITE_ERROR
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func, __pyx_n_s_print_tracebacks); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 473, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 473, __pyx_L6_except_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__pyx_t_2) {

        /* "playhouse/_sqlite_ext.pyx":474
 *     except:
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()             # <<<<<<<<<<<<<<
 *         return SQLITE_ERROR
 *     else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_traceback); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 474, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 474, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = NULL;
        __pyx_t_9 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
            __pyx_t_9 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[1] = {__pyx_t_10, };
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 474, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "playhouse/_sqlite_ext.pyx":473
 *         pCur.stopped = True
 *     except:
 *         if table_func.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         return SQLITE_ERROR
 */
      }

      /* "playhouse/_sqlite_ext.pyx":475
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()
 *         return SQLITE_ERROR             # <<<<<<<<<<<<<<
 *     else:
 *         Py_INCREF(result)
 */
      __pyx_r = SQLITE_ERROR;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_except_return;
    }

    /* "playhouse/_sqlite_ext.pyx":468
 * 
 *     pCur.row_data = NULL
 *     try:             # <<<<<<<<<<<<<<
 *         result = tuple(table_func.iterate(pCur.idx))
 *     except StopIteration:
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L7_except_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L0;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L9_try_end:;
  }

  /* "playhouse/_sqlite_ext.pyx":482
 *         pCur.stopped = False
 * 
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = SQLITE_OK;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":458
 * # Iterate once, advancing the cursor's index and assigning the row data to the
 * # `row_data` field on the peewee_cursor struct.
 * cdef int pwNext(sqlite3_vtab_cursor *pBase) noexcept with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.pwNext", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_table_func);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":486
 * 
 * # Return the requested column from the current row.
 * cdef int pwColumn(sqlite3_vtab_cursor *pBase, sqlite3_context *ctx,             # <<<<<<<<<<<<<<
 *                   int iCol) noexcept with gil:
 *     cdef:
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwColumn(sqlite3_vtab_cursor *__pyx_v_pBase, sqlite3_context *__pyx_v_ctx, int __pyx_v_iCol) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *__pyx_v_pCur;
  CYTHON_UNUSED sqlite3_int64 __pyx_v_x;
  PyObject *__pyx_v_row_data = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwColumn", 0);

  /* "playhouse/_sqlite_ext.pyx":490
 *     cdef:
 *         bytes bval
 *         peewee_cursor *pCur = <peewee_cursor *>pBase             # <<<<<<<<<<<<<<
 *         sqlite3_int64 x = 0
 *         tuple row_data
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":491
 *         bytes bval
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *         sqlite3_int64 x = 0             # <<<<<<<<<<<<<<
 *         tuple row_data
 * 
 */
  __pyx_v_x = 0;

  /* "playhouse/_sqlite_ext.pyx":494
 *         tuple row_data
 * 
 *     if iCol == -1:             # <<<<<<<<<<<<<<
 *         sqlite3_result_int64(ctx, <sqlite3_int64>pCur.idx)
 *         return SQLITE_OK
 */
  __pyx_t_1 = (__pyx_v_iCol == -1L);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":495
 * 
 *     if iCol == -1:
 *         sqlite3_result_int64(ctx, <sqlite3_int64>pCur.idx)             # <<<<<<<<<<<<<<
 *         return SQLITE_OK
 * 
 */
    sqlite3_result_int64(__pyx_v_ctx, ((sqlite3_int64)__pyx_v_pCur->idx));

    /* "playhouse/_sqlite_ext.pyx":496
 *     if iCol == -1:
 *         sqlite3_result_int64(ctx, <sqlite3_int64>pCur.idx)
 *         return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 *     if not pCur.row_data:
 */
    __pyx_r = SQLITE_OK;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":494
 *         tuple row_data
 * 
 *     if iCol == -1:             # <<<<<<<<<<<<<<
 *         sqlite3_result_int64(ctx, <sqlite3_int64>pCur.idx)
 *         return SQLITE_OK
 */
  }

  /* "playhouse/_sqlite_ext.pyx":498
 *         return SQLITE_OK
 * 
 *     if not pCur.row_data:             # <<<<<<<<<<<<<<
 *         sqlite3_result_error(ctx, encode('no row data'), -1)
 *         return SQLITE_ERROR
 */
  __pyx_t_1 = (!(__pyx_v_pCur->row_data != 0));
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":499
 * 
 *     if not pCur.row_data:
 *         sqlite3_result_error(ctx, encode('no row data'), -1)             # <<<<<<<<<<<<<<
 *         return SQLITE_ERROR
 * 
 */
    __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_kp_u_no_row_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 499, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 499, __pyx_L1_error)
    sqlite3_result_error(__pyx_v_ctx, __pyx_t_3, -1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":500
 *     if not pCur.row_data:
 *         sqlite3_result_error(ctx, encode('no row data'), -1)
 *         return SQLITE_ERROR             # <<<<<<<<<<<<<<
 * 
 *     row_data = <tuple>pCur.row_data
 */
    __pyx_r = SQLITE_ERROR;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":498
 *         return SQLITE_OK
 * 
 *     if not pCur.row_data:             # <<<<<<<<<<<<<<
 *         sqlite3_result_error(ctx, encode('no row data'), -1)
 *         return SQLITE_ERROR
 */
  }

  /* "playhouse/_sqlite_ext.pyx":502
 *         return SQLITE_ERROR
 * 
 *     row_data = <tuple>pCur.row_data             # <<<<<<<<<<<<<<
 *     return python_to_sqlite(ctx, row_data[iCol])
 * 
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_pCur->row_data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_row_data = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":503
 * 
 *     row_data = <tuple>pCur.row_data
 *     return python_to_sqlite(ctx, row_data[iCol])             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_row_data == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 503, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_v_row_data, __pyx_v_iCol, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __pyx_f_9playhouse_11_sqlite_ext_python_to_sqlite(__pyx_v_ctx, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":486
 * 
 * # Return the requested column from the current row.
 * cdef int pwColumn(sqlite3_vtab_cursor *pBase, sqlite3_context *ctx,             # <<<<<<<<<<<<<<
 *                   int iCol) noexcept with gil:
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.pwColumn", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_row_data);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":506
 * 
 * 
 * cdef int pwRowid(sqlite3_vtab_cursor *pBase, sqlite3_int64 *pRowid) noexcept:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwRowid(sqlite3_vtab_cursor *__pyx_v_pBase, sqlite3_int64 *__pyx_v_pRowid) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *__pyx_v_pCur;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pwRowid", 0);

  /* "playhouse/_sqlite_ext.pyx":508
 * cdef int pwRowid(sqlite3_vtab_cursor *pBase, sqlite3_int64 *pRowid) noexcept:
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase             # <<<<<<<<<<<<<<
 *     pRowid[0] = <sqlite3_int64>pCur.idx
 *     return SQLITE_OK
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":509
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *     pRowid[0] = <sqlite3_int64>pCur.idx             # <<<<<<<<<<<<<<
 *     return SQLITE_OK
 * 
 */
  (__pyx_v_pRowid[0]) = ((sqlite3_int64)__pyx_v_pCur->idx);

  /* "playhouse/_sqlite_ext.pyx":510
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *     pRowid[0] = <sqlite3_int64>pCur.idx
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = SQLITE_OK;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":506
 * 
 * 
 * cdef int pwRowid(sqlite3_vtab_cursor *pBase, sqlite3_int64 *pRowid) noexcept:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":514
 * 
 * # Return a boolean indicating whether the cursor has been consumed.
 * cdef int pwEof(sqlite3_vtab_cursor *pBase) noexcept:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwEof(sqlite3_vtab_cursor *__pyx_v_pBase) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *__pyx_v_pCur;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("pwEof", 0);

  /* "playhouse/_sqlite_ext.pyx":516
 * cdef int pwEof(sqlite3_vtab_cursor *pBase) noexcept:
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase             # <<<<<<<<<<<<<<
 *     return 1 if pCur.stopped else 0
 * 
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":517
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *     return 1 if pCur.stopped else 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__pyx_v_pCur->stopped) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":514
 * 
 * # Return a boolean indicating whether the cursor has been consumed.
 * cdef int pwEof(sqlite3_vtab_cursor *pBase) noexcept:             # <<<<<<<<<<<<<<
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":523
 * # get access to the parameters that the function was called with, and call the
 * # TableFunction's `initialize()` function.
 * cdef int pwFilter(sqlite3_vtab_cursor *pBase, int idxNum,             # <<<<<<<<<<<<<<
 *                   const char *idxStr, int argc, sqlite3_value **argv) \
 *                   noexcept with gil:
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwFilter(sqlite3_vtab_cursor *__pyx_v_pBase, CYTHON_UNUSED int __pyx_v_idxNum, char const *__pyx_v_idxStr, int __pyx_v_argc, sqlite3_value **__pyx_v_argv) {
  __pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *__pyx_v_pCur;
  PyObject *__pyx_v_table_func = 0;
  PyObject *__pyx_v_query = 0;
  int __pyx_v_idx;
  PyObject *__pyx_v_row_data = 0;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_py_values = NULL;
  PyObject *__pyx_v_param = NULL;
  sqlite3_value *__pyx_v_value;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwFilter", 0);

  /* "playhouse/_sqlite_ext.pyx":527
 *                   noexcept with gil:
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase             # <<<<<<<<<<<<<<
 *         object table_func = <object>pCur.table_func
 *         dict query = {}
 */
  __pyx_v_pCur = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_cursor *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":528
 *     cdef:
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *         object table_func = <object>pCur.table_func             # <<<<<<<<<<<<<<
 *         dict query = {}
 *         int idx
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_pCur->table_func);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_table_func = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":529
 *         peewee_cursor *pCur = <peewee_cursor *>pBase
 *         object table_func = <object>pCur.table_func
 *         dict query = {}             # <<<<<<<<<<<<<<
 *         int idx
 *         int value_type
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_query = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":535
 *         void *row_data_raw
 * 
 *     if not idxStr or argc == 0 and len(table_func.params):             # <<<<<<<<<<<<<<
 *         return SQLITE_ERROR
 *     elif len(idxStr):
 */
  __pyx_t_3 = (!(__pyx_v_idxStr != 0));
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_argc == 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func, __pyx_n_s_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":536
 * 
 *     if not idxStr or argc == 0 and len(table_func.params):
 *         return SQLITE_ERROR             # <<<<<<<<<<<<<<
 *     elif len(idxStr):
 *         params = decode(idxStr).split(',')
 */
    __pyx_r = SQLITE_ERROR;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":535
 *         void *row_data_raw
 * 
 *     if not idxStr or argc == 0 and len(table_func.params):             # <<<<<<<<<<<<<<
 *         return SQLITE_ERROR
 *     elif len(idxStr):
 */
  }

  /* "playhouse/_sqlite_ext.pyx":537
 *     if not idxStr or argc == 0 and len(table_func.params):
 *         return SQLITE_ERROR
 *     elif len(idxStr):             # <<<<<<<<<<<<<<
 *         params = decode(idxStr).split(',')
 *     else:
 */
  __pyx_t_4 = __Pyx_ssize_strlen(__pyx_v_idxStr); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 537, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_4 != 0);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":538
 *         return SQLITE_ERROR
 *     elif len(idxStr):
 *         params = decode(idxStr).split(',')             # <<<<<<<<<<<<<<
 *     else:
 *         params = []
 */
    __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_idxStr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __pyx_f_9playhouse_11_sqlite_ext_decode(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__pyx_t_5 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "split");
      __PYX_ERR(0, 538, __pyx_L1_error)
    }
    __pyx_t_1 = PyUnicode_Split(((PyObject*)__pyx_t_5), __Pyx_NoneAsNull(__pyx_kp_u__2), -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_params = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "playhouse/_sqlite_ext.pyx":537
 *     if not idxStr or argc == 0 and len(table_func.params):
 *         return SQLITE_ERROR
 *     elif len(idxStr):             # <<<<<<<<<<<<<<
 *         params = decode(idxStr).split(',')
 *     else:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":540
 *         params = decode(idxStr).split(',')
 *     else:
 *         params = []             # <<<<<<<<<<<<<<
 * 
 *     py_values = sqlite_to_python(argc, argv)
 */
  /*else*/ {
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_params = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "playhouse/_sqlite_ext.pyx":542
 *         params = []
 * 
 *     py_values = sqlite_to_python(argc, argv)             # <<<<<<<<<<<<<<
 * 
 *     for idx, param in enumerate(params):
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext_sqlite_to_python(__pyx_v_argc, __pyx_v_argv); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_py_values = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":544
 *     py_values = sqlite_to_python(argc, argv)
 * 
 *     for idx, param in enumerate(params):             # <<<<<<<<<<<<<<
 *         value = argv[idx]
 *         if not value:
 */
  __pyx_t_6 = 0;
  if (likely(PyList_CheckExact(__pyx_v_params)) || PyTuple_CheckExact(__pyx_v_params)) {
    __pyx_t_1 = __pyx_v_params; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 544, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_5); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 544, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 544, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_5); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 544, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 544, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_7(__pyx_t_1);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 544, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_param, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_v_idx = __pyx_t_6;
    __pyx_t_6 = (__pyx_t_6 + 1);

    /* "playhouse/_sqlite_ext.pyx":545
 * 
 *     for idx, param in enumerate(params):
 *         value = argv[idx]             # <<<<<<<<<<<<<<
 *         if not value:
 *             query[param] = None
 */
    __pyx_v_value = (__pyx_v_argv[__pyx_v_idx]);

    /* "playhouse/_sqlite_ext.pyx":546
 *     for idx, param in enumerate(params):
 *         value = argv[idx]
 *         if not value:             # <<<<<<<<<<<<<<
 *             query[param] = None
 *         else:
 */
    __pyx_t_2 = (!(__pyx_v_value != 0));
    if (__pyx_t_2) {

      /* "playhouse/_sqlite_ext.pyx":547
 *         value = argv[idx]
 *         if not value:
 *             query[param] = None             # <<<<<<<<<<<<<<
 *         else:
 *             query[param] = py_values[idx]
 */
      if (unlikely((PyDict_SetItem(__pyx_v_query, __pyx_v_param, Py_None) < 0))) __PYX_ERR(0, 547, __pyx_L1_error)

      /* "playhouse/_sqlite_ext.pyx":546
 *     for idx, param in enumerate(params):
 *         value = argv[idx]
 *         if not value:             # <<<<<<<<<<<<<<
 *             query[param] = None
 *         else:
 */
      goto __pyx_L9;
    }

    /* "playhouse/_sqlite_ext.pyx":549
 *             query[param] = None
 *         else:
 *             query[param] = py_values[idx]             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_py_values, __pyx_v_idx, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely((PyDict_SetItem(__pyx_v_query, __pyx_v_param, __pyx_t_5) < 0))) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_L9:;

    /* "playhouse/_sqlite_ext.pyx":544
 *     py_values = sqlite_to_python(argc, argv)
 * 
 *     for idx, param in enumerate(params):             # <<<<<<<<<<<<<<
 *         value = argv[idx]
 *         if not value:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":551
 *             query[param] = py_values[idx]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         table_func.initialize(**query)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "playhouse/_sqlite_ext.pyx":552
 * 
 *     try:
 *         table_func.initialize(**query)             # <<<<<<<<<<<<<<
 *     except:
 *         if table_func.print_tracebacks:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func, __pyx_n_s_initialize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 552, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = PyDict_Copy(__pyx_v_query); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 552, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 552, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "playhouse/_sqlite_ext.pyx":551
 *             query[param] = py_values[idx]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         table_func.initialize(**query)
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "playhouse/_sqlite_ext.pyx":553
 *     try:
 *         table_func.initialize(**query)
 *     except:             # <<<<<<<<<<<<<<
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()
 */
    /*except:*/ {
      __Pyx_AddTraceback("playhouse._sqlite_ext.pwFilter", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(0, 553, __pyx_L13_except_error)
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "playhouse/_sqlite_ext.pyx":554
 *         table_func.initialize(**query)
 *     except:
 *         if table_func.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         return SQLITE_ERROR
 */
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func, __pyx_n_s_print_tracebacks); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 554, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 554, __pyx_L13_except_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (__pyx_t_2) {

        /* "playhouse/_sqlite_ext.pyx":555
 *     except:
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()             # <<<<<<<<<<<<<<
 *         return SQLITE_ERROR
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_traceback); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 555, __pyx_L13_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 555, __pyx_L13_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_13 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_14, function);
            __pyx_t_6 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[1] = {__pyx_t_13, };
          __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 555, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "playhouse/_sqlite_ext.pyx":554
 *         table_func.initialize(**query)
 *     except:
 *         if table_func.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         return SQLITE_ERROR
 */
      }

      /* "playhouse/_sqlite_ext.pyx":556
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()
 *         return SQLITE_ERROR             # <<<<<<<<<<<<<<
 * 
 *     pCur.stopped = False
 */
      __pyx_r = SQLITE_ERROR;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L14_except_return;
    }

    /* "playhouse/_sqlite_ext.pyx":551
 *             query[param] = py_values[idx]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         table_func.initialize(**query)
 *     except:
 */
    __pyx_L13_except_error:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L14_except_return:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L0;
    __pyx_L16_try_end:;
  }

  /* "playhouse/_sqlite_ext.pyx":558
 *         return SQLITE_ERROR
 * 
 *     pCur.stopped = False             # <<<<<<<<<<<<<<
 *     try:
 *         row_data = tuple(table_func.iterate(0))
 */
  __pyx_v_pCur->stopped = 0;

  /* "playhouse/_sqlite_ext.pyx":559
 * 
 *     pCur.stopped = False
 *     try:             # <<<<<<<<<<<<<<
 *         row_data = tuple(table_func.iterate(0))
 *     except StopIteration:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "playhouse/_sqlite_ext.pyx":560
 *     pCur.stopped = False
 *     try:
 *         row_data = tuple(table_func.iterate(0))             # <<<<<<<<<<<<<<
 *     except StopIteration:
 *         pCur.stopped = True
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func, __pyx_n_s_iterate); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 560, __pyx_L20_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_int_0};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 560, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_5 = __Pyx_PySequence_Tuple(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 560, __pyx_L20_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_row_data = ((PyObject*)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "playhouse/_sqlite_ext.pyx":559
 * 
 *     pCur.stopped = False
 *     try:             # <<<<<<<<<<<<<<
 *         row_data = tuple(table_func.iterate(0))
 *     except StopIteration:
 */
    }

    /* "playhouse/_sqlite_ext.pyx":568
 *         return SQLITE_ERROR
 *     else:
 *         Py_INCREF(row_data)             # <<<<<<<<<<<<<<
 *         pCur.row_data = <void *>row_data
 *         pCur.idx += 1
 */
    /*else:*/ {
      Py_INCREF(__pyx_v_row_data);

      /* "playhouse/_sqlite_ext.pyx":569
 *     else:
 *         Py_INCREF(row_data)
 *         pCur.row_data = <void *>row_data             # <<<<<<<<<<<<<<
 *         pCur.idx += 1
 *     return SQLITE_OK
 */
      __pyx_v_pCur->row_data = ((void *)__pyx_v_row_data);

      /* "playhouse/_sqlite_ext.pyx":570
 *         Py_INCREF(row_data)
 *         pCur.row_data = <void *>row_data
 *         pCur.idx += 1             # <<<<<<<<<<<<<<
 *     return SQLITE_OK
 * 
 */
      __pyx_v_pCur->idx = (__pyx_v_pCur->idx + 1);
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L25_try_end;
    __pyx_L20_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "playhouse/_sqlite_ext.pyx":561
 *     try:
 *         row_data = tuple(table_func.iterate(0))
 *     except StopIteration:             # <<<<<<<<<<<<<<
 *         pCur.stopped = True
 *     except:
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_StopIteration);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("playhouse._sqlite_ext.pwFilter", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_1, &__pyx_t_11) < 0) __PYX_ERR(0, 561, __pyx_L22_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_11);

      /* "playhouse/_sqlite_ext.pyx":562
 *         row_data = tuple(table_func.iterate(0))
 *     except StopIteration:
 *         pCur.stopped = True             # <<<<<<<<<<<<<<
 *     except:
 *         if table_func.print_tracebacks:
 */
      __pyx_v_pCur->stopped = 1;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L21_exception_handled;
    }

    /* "playhouse/_sqlite_ext.pyx":563
 *     except StopIteration:
 *         pCur.stopped = True
 *     except:             # <<<<<<<<<<<<<<
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()
 */
    /*except:*/ {
      __Pyx_AddTraceback("playhouse._sqlite_ext.pwFilter", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_1, &__pyx_t_5) < 0) __PYX_ERR(0, 563, __pyx_L22_except_error)
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_5);

      /* "playhouse/_sqlite_ext.pyx":564
 *         pCur.stopped = True
 *     except:
 *         if table_func.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         return SQLITE_ERROR
 */
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func, __pyx_n_s_print_tracebacks); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 564, __pyx_L22_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 564, __pyx_L22_except_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (__pyx_t_2) {

        /* "playhouse/_sqlite_ext.pyx":565
 *     except:
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()             # <<<<<<<<<<<<<<
 *         return SQLITE_ERROR
 *     else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_traceback); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 565, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 565, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_13, function);
            __pyx_t_6 = 1;
          }
        }
        {
          PyObject *__pyx_callargs[1] = {__pyx_t_14, };
          __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 565, __pyx_L22_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "playhouse/_sqlite_ext.pyx":564
 *         pCur.stopped = True
 *     except:
 *         if table_func.print_tracebacks:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *         return SQLITE_ERROR
 */
      }

      /* "playhouse/_sqlite_ext.pyx":566
 *         if table_func.print_tracebacks:
 *             traceback.print_exc()
 *         return SQLITE_ERROR             # <<<<<<<<<<<<<<
 *     else:
 *         Py_INCREF(row_data)
 */
      __pyx_r = SQLITE_ERROR;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L23_except_return;
    }

    /* "playhouse/_sqlite_ext.pyx":559
 * 
 *     pCur.stopped = False
 *     try:             # <<<<<<<<<<<<<<
 *         row_data = tuple(table_func.iterate(0))
 *     except StopIteration:
 */
    __pyx_L22_except_error:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L23_except_return:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    goto __pyx_L0;
    __pyx_L21_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    __pyx_L25_try_end:;
  }

  /* "playhouse/_sqlite_ext.pyx":571
 *         pCur.row_data = <void *>row_data
 *         pCur.idx += 1
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = SQLITE_OK;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":523
 * # get access to the parameters that the function was called with, and call the
 * # TableFunction's `initialize()` function.
 * cdef int pwFilter(sqlite3_vtab_cursor *pBase, int idxNum,             # <<<<<<<<<<<<<<
 *                   const char *idxStr, int argc, sqlite3_value **argv) \
 *                   noexcept with gil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.pwFilter", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_table_func);
  __Pyx_XDECREF(__pyx_v_query);
  __Pyx_XDECREF(__pyx_v_row_data);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_py_values);
  __Pyx_XDECREF(__pyx_v_param);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":576
 * # SQLite will (in some cases, repeatedly) call the xBestIndex method to try and
 * # find the best query plan.
 * cdef int pwBestIndex(sqlite3_vtab *pBase, sqlite3_index_info *pIdxInfo) \             # <<<<<<<<<<<<<<
 *                      noexcept with gil:
 *     cdef:
 */

static int __pyx_f_9playhouse_11_sqlite_ext_pwBestIndex(sqlite3_vtab *__pyx_v_pBase, sqlite3_index_info *__pyx_v_pIdxInfo) {
  int __pyx_v_i;
  int __pyx_v_col_idx;
  CYTHON_UNUSED int __pyx_v_idxNum;
  int __pyx_v_nArg;
  __pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *__pyx_v_pVtab;
  PyObject *__pyx_v_table_func_cls = 0;
  struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_constraint *__pyx_v_pConstraint;
  PyObject *__pyx_v_columns = 0;
  int __pyx_v_nParams;
  PyObject *__pyx_v_joinedCols = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  char *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("pwBestIndex", 0);

  /* "playhouse/_sqlite_ext.pyx":581
 *         int i
 *         int col_idx
 *         int idxNum = 0, nArg = 0             # <<<<<<<<<<<<<<
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 *         object table_func_cls = <object>pVtab.table_func_cls
 */
  __pyx_v_idxNum = 0;
  __pyx_v_nArg = 0;

  /* "playhouse/_sqlite_ext.pyx":582
 *         int col_idx
 *         int idxNum = 0, nArg = 0
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase             # <<<<<<<<<<<<<<
 *         object table_func_cls = <object>pVtab.table_func_cls
 *         sqlite3_index_constraint *pConstraint = <sqlite3_index_constraint *>0
 */
  __pyx_v_pVtab = ((__pyx_t_9playhouse_11_sqlite_ext_peewee_vtab *)__pyx_v_pBase);

  /* "playhouse/_sqlite_ext.pyx":583
 *         int idxNum = 0, nArg = 0
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 *         object table_func_cls = <object>pVtab.table_func_cls             # <<<<<<<<<<<<<<
 *         sqlite3_index_constraint *pConstraint = <sqlite3_index_constraint *>0
 *         list columns = []
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_pVtab->table_func_cls);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_table_func_cls = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":584
 *         peewee_vtab *pVtab = <peewee_vtab *>pBase
 *         object table_func_cls = <object>pVtab.table_func_cls
 *         sqlite3_index_constraint *pConstraint = <sqlite3_index_constraint *>0             # <<<<<<<<<<<<<<
 *         list columns = []
 *         char *idxStr
 */
  __pyx_v_pConstraint = ((struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_constraint *)0);

  /* "playhouse/_sqlite_ext.pyx":585
 *         object table_func_cls = <object>pVtab.table_func_cls
 *         sqlite3_index_constraint *pConstraint = <sqlite3_index_constraint *>0
 *         list columns = []             # <<<<<<<<<<<<<<
 *         char *idxStr
 *         int nParams = len(table_func_cls.params)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_columns = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":587
 *         list columns = []
 *         char *idxStr
 *         int nParams = len(table_func_cls.params)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(pIdxInfo.nConstraint):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func_cls, __pyx_n_s_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_nParams = __pyx_t_2;

  /* "playhouse/_sqlite_ext.pyx":589
 *         int nParams = len(table_func_cls.params)
 * 
 *     for i in range(pIdxInfo.nConstraint):             # <<<<<<<<<<<<<<
 *         pConstraint = <sqlite3_index_constraint *>pIdxInfo.aConstraint + i
 *         if not pConstraint.usable:
 */
  __pyx_t_3 = __pyx_v_pIdxInfo->nConstraint;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "playhouse/_sqlite_ext.pyx":590
 * 
 *     for i in range(pIdxInfo.nConstraint):
 *         pConstraint = <sqlite3_index_constraint *>pIdxInfo.aConstraint + i             # <<<<<<<<<<<<<<
 *         if not pConstraint.usable:
 *             continue
 */
    __pyx_v_pConstraint = (((struct __pyx_t_9playhouse_11_sqlite_ext_sqlite3_index_constraint *)__pyx_v_pIdxInfo->aConstraint) + __pyx_v_i);

    /* "playhouse/_sqlite_ext.pyx":591
 *     for i in range(pIdxInfo.nConstraint):
 *         pConstraint = <sqlite3_index_constraint *>pIdxInfo.aConstraint + i
 *         if not pConstraint.usable:             # <<<<<<<<<<<<<<
 *             continue
 *         if pConstraint.op != SQLITE_INDEX_CONSTRAINT_EQ:
 */
    __pyx_t_6 = (!(__pyx_v_pConstraint->usable != 0));
    if (__pyx_t_6) {

      /* "playhouse/_sqlite_ext.pyx":592
 *         pConstraint = <sqlite3_index_constraint *>pIdxInfo.aConstraint + i
 *         if not pConstraint.usable:
 *             continue             # <<<<<<<<<<<<<<
 *         if pConstraint.op != SQLITE_INDEX_CONSTRAINT_EQ:
 *             continue
 */
      goto __pyx_L3_continue;

      /* "playhouse/_sqlite_ext.pyx":591
 *     for i in range(pIdxInfo.nConstraint):
 *         pConstraint = <sqlite3_index_constraint *>pIdxInfo.aConstraint + i
 *         if not pConstraint.usable:             # <<<<<<<<<<<<<<
 *             continue
 *         if pConstraint.op != SQLITE_INDEX_CONSTRAINT_EQ:
 */
    }

    /* "playhouse/_sqlite_ext.pyx":593
 *         if not pConstraint.usable:
 *             continue
 *         if pConstraint.op != SQLITE_INDEX_CONSTRAINT_EQ:             # <<<<<<<<<<<<<<
 *             continue
 * 
 */
    __pyx_t_6 = (__pyx_v_pConstraint->op != SQLITE_INDEX_CONSTRAINT_EQ);
    if (__pyx_t_6) {

      /* "playhouse/_sqlite_ext.pyx":594
 *             continue
 *         if pConstraint.op != SQLITE_INDEX_CONSTRAINT_EQ:
 *             continue             # <<<<<<<<<<<<<<
 * 
 *         col_idx = pConstraint.iColumn - table_func_cls._ncols
 */
      goto __pyx_L3_continue;

      /* "playhouse/_sqlite_ext.pyx":593
 *         if not pConstraint.usable:
 *             continue
 *         if pConstraint.op != SQLITE_INDEX_CONSTRAINT_EQ:             # <<<<<<<<<<<<<<
 *             continue
 * 
 */
    }

    /* "playhouse/_sqlite_ext.pyx":596
 *             continue
 * 
 *         col_idx = pConstraint.iColumn - table_func_cls._ncols             # <<<<<<<<<<<<<<
 *         if col_idx >= 0:
 *             columns.append(table_func_cls.params[col_idx])
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_pConstraint->iColumn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func_cls, __pyx_n_s_ncols); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyNumber_Subtract(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_8); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_col_idx = __pyx_t_9;

    /* "playhouse/_sqlite_ext.pyx":597
 * 
 *         col_idx = pConstraint.iColumn - table_func_cls._ncols
 *         if col_idx >= 0:             # <<<<<<<<<<<<<<
 *             columns.append(table_func_cls.params[col_idx])
 *             nArg += 1
 */
    __pyx_t_6 = (__pyx_v_col_idx >= 0);
    if (__pyx_t_6) {

      /* "playhouse/_sqlite_ext.pyx":598
 *         col_idx = pConstraint.iColumn - table_func_cls._ncols
 *         if col_idx >= 0:
 *             columns.append(table_func_cls.params[col_idx])             # <<<<<<<<<<<<<<
 *             nArg += 1
 *             pIdxInfo.aConstraintUsage[i].argvIndex = nArg
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_table_func_cls, __pyx_n_s_params); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_8, __pyx_v_col_idx, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_columns, __pyx_t_7); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "playhouse/_sqlite_ext.pyx":599
 *         if col_idx >= 0:
 *             columns.append(table_func_cls.params[col_idx])
 *             nArg += 1             # <<<<<<<<<<<<<<
 *             pIdxInfo.aConstraintUsage[i].argvIndex = nArg
 *             pIdxInfo.aConstraintUsage[i].omit = 1
 */
      __pyx_v_nArg = (__pyx_v_nArg + 1);

      /* "playhouse/_sqlite_ext.pyx":600
 *             columns.append(table_func_cls.params[col_idx])
 *             nArg += 1
 *             pIdxInfo.aConstraintUsage[i].argvIndex = nArg             # <<<<<<<<<<<<<<
 *             pIdxInfo.aConstraintUsage[i].omit = 1
 * 
 */
      (__pyx_v_pIdxInfo->aConstraintUsage[__pyx_v_i]).argvIndex = __pyx_v_nArg;

      /* "playhouse/_sqlite_ext.pyx":601
 *             nArg += 1
 *             pIdxInfo.aConstraintUsage[i].argvIndex = nArg
 *             pIdxInfo.aConstraintUsage[i].omit = 1             # <<<<<<<<<<<<<<
 * 
 *     if nArg > 0 or nParams == 0:
 */
      (__pyx_v_pIdxInfo->aConstraintUsage[__pyx_v_i]).omit = 1;

      /* "playhouse/_sqlite_ext.pyx":597
 * 
 *         col_idx = pConstraint.iColumn - table_func_cls._ncols
 *         if col_idx >= 0:             # <<<<<<<<<<<<<<
 *             columns.append(table_func_cls.params[col_idx])
 *             nArg += 1
 */
    }
    __pyx_L3_continue:;
  }

  /* "playhouse/_sqlite_ext.pyx":603
 *             pIdxInfo.aConstraintUsage[i].omit = 1
 * 
 *     if nArg > 0 or nParams == 0:             # <<<<<<<<<<<<<<
 *         if nArg == nParams:
 *             # All parameters are present, this is ideal.
 */
  __pyx_t_11 = (__pyx_v_nArg > 0);
  if (!__pyx_t_11) {
  } else {
    __pyx_t_6 = __pyx_t_11;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_11 = (__pyx_v_nParams == 0);
  __pyx_t_6 = __pyx_t_11;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_6) {

    /* "playhouse/_sqlite_ext.pyx":604
 * 
 *     if nArg > 0 or nParams == 0:
 *         if nArg == nParams:             # <<<<<<<<<<<<<<
 *             # All parameters are present, this is ideal.
 *             pIdxInfo.estimatedCost = <double>1
 */
    __pyx_t_6 = (__pyx_v_nArg == __pyx_v_nParams);
    if (__pyx_t_6) {

      /* "playhouse/_sqlite_ext.pyx":606
 *         if nArg == nParams:
 *             # All parameters are present, this is ideal.
 *             pIdxInfo.estimatedCost = <double>1             # <<<<<<<<<<<<<<
 *             pIdxInfo.estimatedRows = 10
 *         else:
 */
      __pyx_v_pIdxInfo->estimatedCost = ((double)1);

      /* "playhouse/_sqlite_ext.pyx":607
 *             # All parameters are present, this is ideal.
 *             pIdxInfo.estimatedCost = <double>1
 *             pIdxInfo.estimatedRows = 10             # <<<<<<<<<<<<<<
 *         else:
 *             # Penalize score based on number of missing params.
 */
      __pyx_v_pIdxInfo->estimatedRows = 10;

      /* "playhouse/_sqlite_ext.pyx":604
 * 
 *     if nArg > 0 or nParams == 0:
 *         if nArg == nParams:             # <<<<<<<<<<<<<<
 *             # All parameters are present, this is ideal.
 *             pIdxInfo.estimatedCost = <double>1
 */
      goto __pyx_L11;
    }

    /* "playhouse/_sqlite_ext.pyx":610
 *         else:
 *             # Penalize score based on number of missing params.
 *             pIdxInfo.estimatedCost = <double>10000000000000 * <double>(nParams - nArg)             # <<<<<<<<<<<<<<
 *             pIdxInfo.estimatedRows = 10 * (nParams - nArg)
 * 
 */
    /*else*/ {
      __pyx_v_pIdxInfo->estimatedCost = (((double)10000000000000.0) * ((double)(__pyx_v_nParams - __pyx_v_nArg)));

      /* "playhouse/_sqlite_ext.pyx":611
 *             # Penalize score based on number of missing params.
 *             pIdxInfo.estimatedCost = <double>10000000000000 * <double>(nParams - nArg)
 *             pIdxInfo.estimatedRows = 10 * (nParams - nArg)             # <<<<<<<<<<<<<<
 * 
 *         # Store a reference to the columns in the index info structure.
 */
      __pyx_v_pIdxInfo->estimatedRows = (10 * (__pyx_v_nParams - __pyx_v_nArg));
    }
    __pyx_L11:;

    /* "playhouse/_sqlite_ext.pyx":614
 * 
 *         # Store a reference to the columns in the index info structure.
 *         joinedCols = encode(','.join(columns))             # <<<<<<<<<<<<<<
 *         pIdxInfo.idxStr = sqlite3_mprintf("%s", <char *>joinedCols)
 *         pIdxInfo.needToFreeIdxStr = 1
 */
    __pyx_t_7 = PyUnicode_Join(__pyx_kp_u__2, __pyx_v_columns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_joinedCols = ((PyObject*)__pyx_t_8);
    __pyx_t_8 = 0;

    /* "playhouse/_sqlite_ext.pyx":615
 *         # Store a reference to the columns in the index info structure.
 *         joinedCols = encode(','.join(columns))
 *         pIdxInfo.idxStr = sqlite3_mprintf("%s", <char *>joinedCols)             # <<<<<<<<<<<<<<
 *         pIdxInfo.needToFreeIdxStr = 1
 *     elif USE_SQLITE_CONSTRAINT:
 */
    if (unlikely(__pyx_v_joinedCols == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 615, __pyx_L1_error)
    }
    __pyx_t_12 = __Pyx_PyBytes_AsWritableString(__pyx_v_joinedCols); if (unlikely((!__pyx_t_12) && PyErr_Occurred())) __PYX_ERR(0, 615, __pyx_L1_error)
    __pyx_v_pIdxInfo->idxStr = sqlite3_mprintf(((char const *)"%s"), ((char *)__pyx_t_12));

    /* "playhouse/_sqlite_ext.pyx":616
 *         joinedCols = encode(','.join(columns))
 *         pIdxInfo.idxStr = sqlite3_mprintf("%s", <char *>joinedCols)
 *         pIdxInfo.needToFreeIdxStr = 1             # <<<<<<<<<<<<<<
 *     elif USE_SQLITE_CONSTRAINT:
 *         return SQLITE_CONSTRAINT
 */
    __pyx_v_pIdxInfo->needToFreeIdxStr = 1;

    /* "playhouse/_sqlite_ext.pyx":603
 *             pIdxInfo.aConstraintUsage[i].omit = 1
 * 
 *     if nArg > 0 or nParams == 0:             # <<<<<<<<<<<<<<
 *         if nArg == nParams:
 *             # All parameters are present, this is ideal.
 */
    goto __pyx_L8;
  }

  /* "playhouse/_sqlite_ext.pyx":617
 *         pIdxInfo.idxStr = sqlite3_mprintf("%s", <char *>joinedCols)
 *         pIdxInfo.needToFreeIdxStr = 1
 *     elif USE_SQLITE_CONSTRAINT:             # <<<<<<<<<<<<<<
 *         return SQLITE_CONSTRAINT
 *     else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_USE_SQLITE_CONSTRAINT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__pyx_t_6) {

    /* "playhouse/_sqlite_ext.pyx":618
 *         pIdxInfo.needToFreeIdxStr = 1
 *     elif USE_SQLITE_CONSTRAINT:
 *         return SQLITE_CONSTRAINT             # <<<<<<<<<<<<<<
 *     else:
 *         pIdxInfo.estimatedCost = DBL_MAX
 */
    __pyx_r = __pyx_v_9playhouse_11_sqlite_ext_SQLITE_CONSTRAINT;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":617
 *         pIdxInfo.idxStr = sqlite3_mprintf("%s", <char *>joinedCols)
 *         pIdxInfo.needToFreeIdxStr = 1
 *     elif USE_SQLITE_CONSTRAINT:             # <<<<<<<<<<<<<<
 *         return SQLITE_CONSTRAINT
 *     else:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":620
 *         return SQLITE_CONSTRAINT
 *     else:
 *         pIdxInfo.estimatedCost = DBL_MAX             # <<<<<<<<<<<<<<
 *         pIdxInfo.estimatedRows = 100000
 *     return SQLITE_OK
 */
  /*else*/ {
    __pyx_v_pIdxInfo->estimatedCost = DBL_MAX;

    /* "playhouse/_sqlite_ext.pyx":621
 *     else:
 *         pIdxInfo.estimatedCost = DBL_MAX
 *         pIdxInfo.estimatedRows = 100000             # <<<<<<<<<<<<<<
 *     return SQLITE_OK
 * 
 */
    __pyx_v_pIdxInfo->estimatedRows = 0x186A0;
  }
  __pyx_L8:;

  /* "playhouse/_sqlite_ext.pyx":622
 *         pIdxInfo.estimatedCost = DBL_MAX
 *         pIdxInfo.estimatedRows = 100000
 *     return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = SQLITE_OK;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":576
 * # SQLite will (in some cases, repeatedly) call the xBestIndex method to try and
 * # find the best query plan.
 * cdef int pwBestIndex(sqlite3_vtab *pBase, sqlite3_index_info *pIdxInfo) \             # <<<<<<<<<<<<<<
 *                      noexcept with gil:
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.pwBestIndex", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_table_func_cls);
  __Pyx_XDECREF(__pyx_v_columns);
  __Pyx_XDECREF(__pyx_v_joinedCols);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":630
 *         object table_function
 * 
 *     def __cinit__(self, table_function):             # <<<<<<<<<<<<<<
 *         self.table_function = table_function
 * 
 */

/* Python wrapper */
static int __pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_table_function = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_table_function,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_table_function)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 630, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 630, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_table_function = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 630, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext._TableFunctionImpl.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl___cinit__(((struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)__pyx_v_self), __pyx_v_table_function);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl___cinit__(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self, PyObject *__pyx_v_table_function) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "playhouse/_sqlite_ext.pyx":631
 * 
 *     def __cinit__(self, table_function):
 *         self.table_function = table_function             # <<<<<<<<<<<<<<
 * 
 *     cdef create_module(self, pysqlite_Connection* sqlite_conn):
 */
  __Pyx_INCREF(__pyx_v_table_function);
  __Pyx_GIVEREF(__pyx_v_table_function);
  __Pyx_GOTREF(__pyx_v_self->table_function);
  __Pyx_DECREF(__pyx_v_self->table_function);
  __pyx_v_self->table_function = __pyx_v_table_function;

  /* "playhouse/_sqlite_ext.pyx":630
 *         object table_function
 * 
 *     def __cinit__(self, table_function):             # <<<<<<<<<<<<<<
 *         self.table_function = table_function
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":633
 *         self.table_function = table_function
 * 
 *     cdef create_module(self, pysqlite_Connection* sqlite_conn):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes name = encode(self.table_function.name)
 */

static PyObject *__pyx_f_9playhouse_11_sqlite_ext_18_TableFunctionImpl_create_module(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self, pysqlite_Connection *__pyx_v_sqlite_conn) {
  PyObject *__pyx_v_name = 0;
  sqlite3 *__pyx_v_db;
  int __pyx_v_rc;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  sqlite3 *__pyx_t_3;
  char const *__pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_module", 0);

  /* "playhouse/_sqlite_ext.pyx":635
 *     cdef create_module(self, pysqlite_Connection* sqlite_conn):
 *         cdef:
 *             bytes name = encode(self.table_function.name)             # <<<<<<<<<<<<<<
 *             sqlite3 *db = sqlite_conn.db
 *             int rc
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->table_function, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_name = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":636
 *         cdef:
 *             bytes name = encode(self.table_function.name)
 *             sqlite3 *db = sqlite_conn.db             # <<<<<<<<<<<<<<
 *             int rc
 * 
 */
  __pyx_t_3 = __pyx_v_sqlite_conn->db;
  __pyx_v_db = __pyx_t_3;

  /* "playhouse/_sqlite_ext.pyx":640
 * 
 *         # Populate the SQLite module struct members.
 *         self.module.iVersion = 0             # <<<<<<<<<<<<<<
 *         self.module.xCreate = NULL
 *         self.module.xConnect = pwConnect
 */
  __pyx_v_self->module.iVersion = 0;

  /* "playhouse/_sqlite_ext.pyx":641
 *         # Populate the SQLite module struct members.
 *         self.module.iVersion = 0
 *         self.module.xCreate = NULL             # <<<<<<<<<<<<<<
 *         self.module.xConnect = pwConnect
 *         self.module.xBestIndex = pwBestIndex
 */
  __pyx_v_self->module.xCreate = NULL;

  /* "playhouse/_sqlite_ext.pyx":642
 *         self.module.iVersion = 0
 *         self.module.xCreate = NULL
 *         self.module.xConnect = pwConnect             # <<<<<<<<<<<<<<
 *         self.module.xBestIndex = pwBestIndex
 *         self.module.xDisconnect = pwDisconnect
 */
  __pyx_v_self->module.xConnect = __pyx_f_9playhouse_11_sqlite_ext_pwConnect;

  /* "playhouse/_sqlite_ext.pyx":643
 *         self.module.xCreate = NULL
 *         self.module.xConnect = pwConnect
 *         self.module.xBestIndex = pwBestIndex             # <<<<<<<<<<<<<<
 *         self.module.xDisconnect = pwDisconnect
 *         self.module.xDestroy = NULL
 */
  __pyx_v_self->module.xBestIndex = __pyx_f_9playhouse_11_sqlite_ext_pwBestIndex;

  /* "playhouse/_sqlite_ext.pyx":644
 *         self.module.xConnect = pwConnect
 *         self.module.xBestIndex = pwBestIndex
 *         self.module.xDisconnect = pwDisconnect             # <<<<<<<<<<<<<<
 *         self.module.xDestroy = NULL
 *         self.module.xOpen = pwOpen
 */
  __pyx_v_self->module.xDisconnect = __pyx_f_9playhouse_11_sqlite_ext_pwDisconnect;

  /* "playhouse/_sqlite_ext.pyx":645
 *         self.module.xBestIndex = pwBestIndex
 *         self.module.xDisconnect = pwDisconnect
 *         self.module.xDestroy = NULL             # <<<<<<<<<<<<<<
 *         self.module.xOpen = pwOpen
 *         self.module.xClose = pwClose
 */
  __pyx_v_self->module.xDestroy = NULL;

  /* "playhouse/_sqlite_ext.pyx":646
 *         self.module.xDisconnect = pwDisconnect
 *         self.module.xDestroy = NULL
 *         self.module.xOpen = pwOpen             # <<<<<<<<<<<<<<
 *         self.module.xClose = pwClose
 *         self.module.xFilter = pwFilter
 */
  __pyx_v_self->module.xOpen = __pyx_f_9playhouse_11_sqlite_ext_pwOpen;

  /* "playhouse/_sqlite_ext.pyx":647
 *         self.module.xDestroy = NULL
 *         self.module.xOpen = pwOpen
 *         self.module.xClose = pwClose             # <<<<<<<<<<<<<<
 *         self.module.xFilter = pwFilter
 *         self.module.xNext = pwNext
 */
  __pyx_v_self->module.xClose = __pyx_f_9playhouse_11_sqlite_ext_pwClose;

  /* "playhouse/_sqlite_ext.pyx":648
 *         self.module.xOpen = pwOpen
 *         self.module.xClose = pwClose
 *         self.module.xFilter = pwFilter             # <<<<<<<<<<<<<<
 *         self.module.xNext = pwNext
 *         self.module.xEof = pwEof
 */
  __pyx_v_self->module.xFilter = __pyx_f_9playhouse_11_sqlite_ext_pwFilter;

  /* "playhouse/_sqlite_ext.pyx":649
 *         self.module.xClose = pwClose
 *         self.module.xFilter = pwFilter
 *         self.module.xNext = pwNext             # <<<<<<<<<<<<<<
 *         self.module.xEof = pwEof
 *         self.module.xColumn = pwColumn
 */
  __pyx_v_self->module.xNext = __pyx_f_9playhouse_11_sqlite_ext_pwNext;

  /* "playhouse/_sqlite_ext.pyx":650
 *         self.module.xFilter = pwFilter
 *         self.module.xNext = pwNext
 *         self.module.xEof = pwEof             # <<<<<<<<<<<<<<
 *         self.module.xColumn = pwColumn
 *         self.module.xRowid = pwRowid
 */
  __pyx_v_self->module.xEof = __pyx_f_9playhouse_11_sqlite_ext_pwEof;

  /* "playhouse/_sqlite_ext.pyx":651
 *         self.module.xNext = pwNext
 *         self.module.xEof = pwEof
 *         self.module.xColumn = pwColumn             # <<<<<<<<<<<<<<
 *         self.module.xRowid = pwRowid
 *         self.module.xUpdate = NULL
 */
  __pyx_v_self->module.xColumn = __pyx_f_9playhouse_11_sqlite_ext_pwColumn;

  /* "playhouse/_sqlite_ext.pyx":652
 *         self.module.xEof = pwEof
 *         self.module.xColumn = pwColumn
 *         self.module.xRowid = pwRowid             # <<<<<<<<<<<<<<
 *         self.module.xUpdate = NULL
 *         self.module.xBegin = NULL
 */
  __pyx_v_self->module.xRowid = __pyx_f_9playhouse_11_sqlite_ext_pwRowid;

  /* "playhouse/_sqlite_ext.pyx":653
 *         self.module.xColumn = pwColumn
 *         self.module.xRowid = pwRowid
 *         self.module.xUpdate = NULL             # <<<<<<<<<<<<<<
 *         self.module.xBegin = NULL
 *         self.module.xSync = NULL
 */
  __pyx_v_self->module.xUpdate = NULL;

  /* "playhouse/_sqlite_ext.pyx":654
 *         self.module.xRowid = pwRowid
 *         self.module.xUpdate = NULL
 *         self.module.xBegin = NULL             # <<<<<<<<<<<<<<
 *         self.module.xSync = NULL
 *         self.module.xCommit = NULL
 */
  __pyx_v_self->module.xBegin = NULL;

  /* "playhouse/_sqlite_ext.pyx":655
 *         self.module.xUpdate = NULL
 *         self.module.xBegin = NULL
 *         self.module.xSync = NULL             # <<<<<<<<<<<<<<
 *         self.module.xCommit = NULL
 *         self.module.xRollback = NULL
 */
  __pyx_v_self->module.xSync = NULL;

  /* "playhouse/_sqlite_ext.pyx":656
 *         self.module.xBegin = NULL
 *         self.module.xSync = NULL
 *         self.module.xCommit = NULL             # <<<<<<<<<<<<<<
 *         self.module.xRollback = NULL
 *         self.module.xFindFunction = NULL
 */
  __pyx_v_self->module.xCommit = NULL;

  /* "playhouse/_sqlite_ext.pyx":657
 *         self.module.xSync = NULL
 *         self.module.xCommit = NULL
 *         self.module.xRollback = NULL             # <<<<<<<<<<<<<<
 *         self.module.xFindFunction = NULL
 *         self.module.xRename = NULL
 */
  __pyx_v_self->module.xRollback = NULL;

  /* "playhouse/_sqlite_ext.pyx":658
 *         self.module.xCommit = NULL
 *         self.module.xRollback = NULL
 *         self.module.xFindFunction = NULL             # <<<<<<<<<<<<<<
 *         self.module.xRename = NULL
 * 
 */
  __pyx_v_self->module.xFindFunction = NULL;

  /* "playhouse/_sqlite_ext.pyx":659
 *         self.module.xRollback = NULL
 *         self.module.xFindFunction = NULL
 *         self.module.xRename = NULL             # <<<<<<<<<<<<<<
 * 
 *         # Create the SQLite virtual table.
 */
  __pyx_v_self->module.xRename = NULL;

  /* "playhouse/_sqlite_ext.pyx":664
 *         rc = sqlite3_create_module(
 *             db,
 *             <const char *>name,             # <<<<<<<<<<<<<<
 *             &self.module,
 *             <void *>(self.table_function))
 */
  if (unlikely(__pyx_v_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 664, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_AsString(__pyx_v_name); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 664, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":662
 * 
 *         # Create the SQLite virtual table.
 *         rc = sqlite3_create_module(             # <<<<<<<<<<<<<<
 *             db,
 *             <const char *>name,
 */
  __pyx_v_rc = sqlite3_create_module(__pyx_v_db, ((char const *)__pyx_t_4), (&__pyx_v_self->module), ((void *)__pyx_v_self->table_function));

  /* "playhouse/_sqlite_ext.pyx":668
 *             <void *>(self.table_function))
 * 
 *         Py_INCREF(self)             # <<<<<<<<<<<<<<
 * 
 *         return rc == SQLITE_OK
 */
  Py_INCREF(((PyObject *)__pyx_v_self));

  /* "playhouse/_sqlite_ext.pyx":670
 *         Py_INCREF(self)
 * 
 *         return rc == SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong((__pyx_v_rc == SQLITE_OK)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":633
 *         self.table_function = table_function
 * 
 *     cdef create_module(self, pysqlite_Connection* sqlite_conn):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes name = encode(self.table_function.name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("playhouse._sqlite_ext._TableFunctionImpl.create_module", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_18_TableFunctionImpl_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl_2__reduce_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext._TableFunctionImpl.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_18_TableFunctionImpl_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext._TableFunctionImpl.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl_4__setstate_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_18_TableFunctionImpl_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext._TableFunctionImpl.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":680
 *     _ncols = None
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register(cls, conn):
 *         cdef _TableFunctionImpl impl = _TableFunctionImpl(cls)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_1register(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_1register = {"register", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_1register, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_1register(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_conn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("register (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_conn,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 680, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_conn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 680, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("register", 1, 2, 2, 1); __PYX_ERR(0, 680, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "register") < 0)) __PYX_ERR(0, 680, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_cls = values[0];
    __pyx_v_conn = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("register", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 680, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.register", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_register(__pyx_self, __pyx_v_cls, __pyx_v_conn);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_register(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_conn) {
  struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *__pyx_v_impl = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("register", 0);

  /* "playhouse/_sqlite_ext.pyx":682
 *     @classmethod
 *     def register(cls, conn):
 *         cdef _TableFunctionImpl impl = _TableFunctionImpl(cls)             # <<<<<<<<<<<<<<
 *         impl.create_module(<pysqlite_Connection *>conn)
 *         cls._ncols = len(cls.columns)
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl), __pyx_v_cls); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_impl = ((struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":683
 *     def register(cls, conn):
 *         cdef _TableFunctionImpl impl = _TableFunctionImpl(cls)
 *         impl.create_module(<pysqlite_Connection *>conn)             # <<<<<<<<<<<<<<
 *         cls._ncols = len(cls.columns)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_9playhouse_11_sqlite_ext__TableFunctionImpl *)__pyx_v_impl->__pyx_vtab)->create_module(__pyx_v_impl, ((pysqlite_Connection *)__pyx_v_conn)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":684
 *         cdef _TableFunctionImpl impl = _TableFunctionImpl(cls)
 *         impl.create_module(<pysqlite_Connection *>conn)
 *         cls._ncols = len(cls.columns)             # <<<<<<<<<<<<<<
 * 
 *     def initialize(self, **filters):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cls, __pyx_n_s_ncols, __pyx_t_1) < 0) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":680
 *     _ncols = None
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register(cls, conn):
 *         cdef _TableFunctionImpl impl = _TableFunctionImpl(cls)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.register", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_impl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":686
 *         cls._ncols = len(cls.columns)
 * 
 *     def initialize(self, **filters):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_3initialize(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_3initialize = {"initialize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_3initialize, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_3initialize(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_filters = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("initialize (wrapper)", 0);
  __pyx_v_filters = PyDict_New(); if (unlikely(!__pyx_v_filters)) return NULL;
  __Pyx_GOTREF(__pyx_v_filters);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 686, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_filters, values + 0, kwd_pos_args, "initialize") < 0)) __PYX_ERR(0, 686, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("initialize", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 686, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_filters); __pyx_v_filters = 0;
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.initialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_2initialize(__pyx_self, __pyx_v_self, __pyx_v_filters);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_filters);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_2initialize(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_filters) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initialize", 0);

  /* "playhouse/_sqlite_ext.pyx":687
 * 
 *     def initialize(self, **filters):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def iterate(self, idx):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(0, 687, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":686
 *         cls._ncols = len(cls.columns)
 * 
 *     def initialize(self, **filters):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.initialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":689
 *         raise NotImplementedError
 * 
 *     def iterate(self, idx):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_5iterate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_5iterate = {"iterate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_5iterate, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_5iterate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_idx = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iterate (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_idx,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 689, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_idx)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 689, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("iterate", 1, 2, 2, 1); __PYX_ERR(0, 689, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "iterate") < 0)) __PYX_ERR(0, 689, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_idx = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("iterate", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 689, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.iterate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_4iterate(__pyx_self, __pyx_v_self, __pyx_v_idx);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_4iterate(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_idx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iterate", 0);

  /* "playhouse/_sqlite_ext.pyx":690
 * 
 *     def iterate(self, idx):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(0, 690, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":689
 *         raise NotImplementedError
 * 
 *     def iterate(self, idx):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.iterate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":692
 *         raise NotImplementedError
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def get_table_columns_declaration(cls):
 *         cdef list accum = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_7get_table_columns_declaration(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_7get_table_columns_declaration = {"get_table_columns_declaration", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_7get_table_columns_declaration, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13TableFunction_7get_table_columns_declaration(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_table_columns_declaration (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 692, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_table_columns_declaration") < 0)) __PYX_ERR(0, 692, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_table_columns_declaration", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 692, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.get_table_columns_declaration", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_6get_table_columns_declaration(__pyx_self, __pyx_v_cls);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_13TableFunction_6get_table_columns_declaration(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_v_accum = 0;
  PyObject *__pyx_v_column = NULL;
  PyObject *__pyx_v_param = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_table_columns_declaration", 0);

  /* "playhouse/_sqlite_ext.pyx":694
 *     @classmethod
 *     def get_table_columns_declaration(cls):
 *         cdef list accum = []             # <<<<<<<<<<<<<<
 * 
 *         for column in cls.columns:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_accum = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":696
 *         cdef list accum = []
 * 
 *         for column in cls.columns:             # <<<<<<<<<<<<<<
 *             if isinstance(column, tuple):
 *                 if len(column) != 2:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 696, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 696, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 696, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 696, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_column, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "playhouse/_sqlite_ext.pyx":697
 * 
 *         for column in cls.columns:
 *             if isinstance(column, tuple):             # <<<<<<<<<<<<<<
 *                 if len(column) != 2:
 *                     raise ValueError('Column must be either a string or a '
 */
    __pyx_t_5 = PyTuple_Check(__pyx_v_column); 
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":698
 *         for column in cls.columns:
 *             if isinstance(column, tuple):
 *                 if len(column) != 2:             # <<<<<<<<<<<<<<
 *                     raise ValueError('Column must be either a string or a '
 *                                      '2-tuple of name, type')
 */
      __pyx_t_6 = PyObject_Length(__pyx_v_column); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 698, __pyx_L1_error)
      __pyx_t_5 = (__pyx_t_6 != 2);
      if (unlikely(__pyx_t_5)) {

        /* "playhouse/_sqlite_ext.pyx":699
 *             if isinstance(column, tuple):
 *                 if len(column) != 2:
 *                     raise ValueError('Column must be either a string or a '             # <<<<<<<<<<<<<<
 *                                      '2-tuple of name, type')
 *                 accum.append('%s %s' % column)
 */
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 699, __pyx_L1_error)

        /* "playhouse/_sqlite_ext.pyx":698
 *         for column in cls.columns:
 *             if isinstance(column, tuple):
 *                 if len(column) != 2:             # <<<<<<<<<<<<<<
 *                     raise ValueError('Column must be either a string or a '
 *                                      '2-tuple of name, type')
 */
      }

      /* "playhouse/_sqlite_ext.pyx":701
 *                     raise ValueError('Column must be either a string or a '
 *                                      '2-tuple of name, type')
 *                 accum.append('%s %s' % column)             # <<<<<<<<<<<<<<
 *             else:
 *                 accum.append(column)
 */
      __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_s, __pyx_v_column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_accum, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 701, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "playhouse/_sqlite_ext.pyx":697
 * 
 *         for column in cls.columns:
 *             if isinstance(column, tuple):             # <<<<<<<<<<<<<<
 *                 if len(column) != 2:
 *                     raise ValueError('Column must be either a string or a '
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":703
 *                 accum.append('%s %s' % column)
 *             else:
 *                 accum.append(column)             # <<<<<<<<<<<<<<
 * 
 *         for param in cls.params:
 */
    /*else*/ {
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_accum, __pyx_v_column); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 703, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "playhouse/_sqlite_ext.pyx":696
 *         cdef list accum = []
 * 
 *         for column in cls.columns:             # <<<<<<<<<<<<<<
 *             if isinstance(column, tuple):
 *                 if len(column) != 2:
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":705
 *                 accum.append(column)
 * 
 *         for param in cls.params:             # <<<<<<<<<<<<<<
 *             accum.append('%s HIDDEN' % param)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_params); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 705, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 705, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 705, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 705, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 705, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 705, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_param, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":706
 * 
 *         for param in cls.params:
 *             accum.append('%s HIDDEN' % param)             # <<<<<<<<<<<<<<
 * 
 *         return ', '.join(accum)
 */
    __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_HIDDEN, __pyx_v_param); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_accum, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 706, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":705
 *                 accum.append(column)
 * 
 *         for param in cls.params:             # <<<<<<<<<<<<<<
 *             accum.append('%s HIDDEN' % param)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":708
 *             accum.append('%s HIDDEN' % param)
 * 
 *         return ', '.join(accum)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__4, __pyx_v_accum); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":692
 *         raise NotImplementedError
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def get_table_columns_declaration(cls):
 *         cdef list accum = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("playhouse._sqlite_ext.TableFunction.get_table_columns_declaration", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_accum);
  __Pyx_XDECREF(__pyx_v_column);
  __Pyx_XDECREF(__pyx_v_param);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":711
 * 
 * 
 * cdef inline bytes encode(key):             # <<<<<<<<<<<<<<
 *     cdef bytes bkey
 *     if PyUnicode_Check(key):
 */

static CYTHON_INLINE PyObject *__pyx_f_9playhouse_11_sqlite_ext_encode(PyObject *__pyx_v_key) {
  PyObject *__pyx_v_bkey = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("encode", 0);

  /* "playhouse/_sqlite_ext.pyx":713
 * cdef inline bytes encode(key):
 *     cdef bytes bkey
 *     if PyUnicode_Check(key):             # <<<<<<<<<<<<<<
 *         bkey = PyUnicode_AsUTF8String(key)
 *     elif PyBytes_Check(key):
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_key);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":714
 *     cdef bytes bkey
 *     if PyUnicode_Check(key):
 *         bkey = PyUnicode_AsUTF8String(key)             # <<<<<<<<<<<<<<
 *     elif PyBytes_Check(key):
 *         bkey = <bytes>key
 */
    __pyx_t_2 = PyUnicode_AsUTF8String(__pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 714, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_bkey = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":713
 * cdef inline bytes encode(key):
 *     cdef bytes bkey
 *     if PyUnicode_Check(key):             # <<<<<<<<<<<<<<
 *         bkey = PyUnicode_AsUTF8String(key)
 *     elif PyBytes_Check(key):
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":715
 *     if PyUnicode_Check(key):
 *         bkey = PyUnicode_AsUTF8String(key)
 *     elif PyBytes_Check(key):             # <<<<<<<<<<<<<<
 *         bkey = <bytes>key
 *     elif key is None:
 */
  __pyx_t_1 = PyBytes_Check(__pyx_v_key);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":716
 *         bkey = PyUnicode_AsUTF8String(key)
 *     elif PyBytes_Check(key):
 *         bkey = <bytes>key             # <<<<<<<<<<<<<<
 *     elif key is None:
 *         return None
 */
    __pyx_t_2 = __pyx_v_key;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_bkey = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":715
 *     if PyUnicode_Check(key):
 *         bkey = PyUnicode_AsUTF8String(key)
 *     elif PyBytes_Check(key):             # <<<<<<<<<<<<<<
 *         bkey = <bytes>key
 *     elif key is None:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":717
 *     elif PyBytes_Check(key):
 *         bkey = <bytes>key
 *     elif key is None:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = (__pyx_v_key == Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":718
 *         bkey = <bytes>key
 *     elif key is None:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         bkey = PyUnicode_AsUTF8String(str(key))
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":717
 *     elif PyBytes_Check(key):
 *         bkey = <bytes>key
 *     elif key is None:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":720
 *         return None
 *     else:
 *         bkey = PyUnicode_AsUTF8String(str(key))             # <<<<<<<<<<<<<<
 *     return bkey
 * 
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Str(__pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyUnicode_AsUTF8String(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_bkey = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "playhouse/_sqlite_ext.pyx":721
 *     else:
 *         bkey = PyUnicode_AsUTF8String(str(key))
 *     return bkey             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_bkey);
  __pyx_r = __pyx_v_bkey;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":711
 * 
 * 
 * cdef inline bytes encode(key):             # <<<<<<<<<<<<<<
 *     cdef bytes bkey
 *     if PyUnicode_Check(key):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.encode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bkey);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":724
 * 
 * 
 * cdef inline unicode decode(key):             # <<<<<<<<<<<<<<
 *     cdef unicode ukey
 *     if PyBytes_Check(key):
 */

static CYTHON_INLINE PyObject *__pyx_f_9playhouse_11_sqlite_ext_decode(PyObject *__pyx_v_key) {
  PyObject *__pyx_v_ukey = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("decode", 0);

  /* "playhouse/_sqlite_ext.pyx":726
 * cdef inline unicode decode(key):
 *     cdef unicode ukey
 *     if PyBytes_Check(key):             # <<<<<<<<<<<<<<
 *         ukey = key.decode('utf-8')
 *     elif PyUnicode_Check(key):
 */
  __pyx_t_1 = PyBytes_Check(__pyx_v_key);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":727
 *     cdef unicode ukey
 *     if PyBytes_Check(key):
 *         ukey = key.decode('utf-8')             # <<<<<<<<<<<<<<
 *     elif PyUnicode_Check(key):
 *         ukey = <unicode>key
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_n_s_decode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 727, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_utf_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 727, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_2))) __PYX_ERR(0, 727, __pyx_L1_error)
    __pyx_v_ukey = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":726
 * cdef inline unicode decode(key):
 *     cdef unicode ukey
 *     if PyBytes_Check(key):             # <<<<<<<<<<<<<<
 *         ukey = key.decode('utf-8')
 *     elif PyUnicode_Check(key):
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":728
 *     if PyBytes_Check(key):
 *         ukey = key.decode('utf-8')
 *     elif PyUnicode_Check(key):             # <<<<<<<<<<<<<<
 *         ukey = <unicode>key
 *     elif key is None:
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_key);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":729
 *         ukey = key.decode('utf-8')
 *     elif PyUnicode_Check(key):
 *         ukey = <unicode>key             # <<<<<<<<<<<<<<
 *     elif key is None:
 *         return None
 */
    __pyx_t_2 = __pyx_v_key;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_ukey = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":728
 *     if PyBytes_Check(key):
 *         ukey = key.decode('utf-8')
 *     elif PyUnicode_Check(key):             # <<<<<<<<<<<<<<
 *         ukey = <unicode>key
 *     elif key is None:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":730
 *     elif PyUnicode_Check(key):
 *         ukey = <unicode>key
 *     elif key is None:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = (__pyx_v_key == Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":731
 *         ukey = <unicode>key
 *     elif key is None:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         ukey = unicode(key)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":730
 *     elif PyUnicode_Check(key):
 *         ukey = <unicode>key
 *     elif key is None:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":733
 *         return None
 *     else:
 *         ukey = unicode(key)             # <<<<<<<<<<<<<<
 *     return ukey
 * 
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_ukey = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "playhouse/_sqlite_ext.pyx":734
 *     else:
 *         ukey = unicode(key)
 *     return ukey             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ukey);
  __pyx_r = __pyx_v_ukey;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":724
 * 
 * 
 * cdef inline unicode decode(key):             # <<<<<<<<<<<<<<
 *     cdef unicode ukey
 *     if PyBytes_Check(key):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("playhouse._sqlite_ext.decode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ukey);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":737
 * 
 * 
 * cdef double *get_weights(int ncol, tuple raw_weights):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int argc = len(raw_weights)
 */

static double *__pyx_f_9playhouse_11_sqlite_ext_get_weights(int __pyx_v_ncol, PyObject *__pyx_v_raw_weights) {
  int __pyx_v_argc;
  int __pyx_v_icol;
  double *__pyx_v_weights;
  double *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  double __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_weights", 0);

  /* "playhouse/_sqlite_ext.pyx":739
 * cdef double *get_weights(int ncol, tuple raw_weights):
 *     cdef:
 *         int argc = len(raw_weights)             # <<<<<<<<<<<<<<
 *         int icol
 *         double *weights = <double *>malloc(sizeof(double) * ncol)
 */
  if (unlikely(__pyx_v_raw_weights == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 739, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_GET_SIZE(__pyx_v_raw_weights); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 739, __pyx_L1_error)
  __pyx_v_argc = __pyx_t_1;

  /* "playhouse/_sqlite_ext.pyx":741
 *         int argc = len(raw_weights)
 *         int icol
 *         double *weights = <double *>malloc(sizeof(double) * ncol)             # <<<<<<<<<<<<<<
 * 
 *     for icol in range(ncol):
 */
  __pyx_v_weights = ((double *)malloc(((sizeof(double)) * __pyx_v_ncol)));

  /* "playhouse/_sqlite_ext.pyx":743
 *         double *weights = <double *>malloc(sizeof(double) * ncol)
 * 
 *     for icol in range(ncol):             # <<<<<<<<<<<<<<
 *         if argc == 0:
 *             weights[icol] = 1.0
 */
  __pyx_t_2 = __pyx_v_ncol;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_icol = __pyx_t_4;

    /* "playhouse/_sqlite_ext.pyx":744
 * 
 *     for icol in range(ncol):
 *         if argc == 0:             # <<<<<<<<<<<<<<
 *             weights[icol] = 1.0
 *         elif icol < argc:
 */
    __pyx_t_5 = (__pyx_v_argc == 0);
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":745
 *     for icol in range(ncol):
 *         if argc == 0:
 *             weights[icol] = 1.0             # <<<<<<<<<<<<<<
 *         elif icol < argc:
 *             weights[icol] = <double>raw_weights[icol]
 */
      (__pyx_v_weights[__pyx_v_icol]) = 1.0;

      /* "playhouse/_sqlite_ext.pyx":744
 * 
 *     for icol in range(ncol):
 *         if argc == 0:             # <<<<<<<<<<<<<<
 *             weights[icol] = 1.0
 *         elif icol < argc:
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":746
 *         if argc == 0:
 *             weights[icol] = 1.0
 *         elif icol < argc:             # <<<<<<<<<<<<<<
 *             weights[icol] = <double>raw_weights[icol]
 *         else:
 */
    __pyx_t_5 = (__pyx_v_icol < __pyx_v_argc);
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":747
 *             weights[icol] = 1.0
 *         elif icol < argc:
 *             weights[icol] = <double>raw_weights[icol]             # <<<<<<<<<<<<<<
 *         else:
 *             weights[icol] = 0.0
 */
      if (unlikely(__pyx_v_raw_weights == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 747, __pyx_L1_error)
      }
      __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v_raw_weights, __pyx_v_icol, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 747, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 747, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      (__pyx_v_weights[__pyx_v_icol]) = ((double)__pyx_t_7);

      /* "playhouse/_sqlite_ext.pyx":746
 *         if argc == 0:
 *             weights[icol] = 1.0
 *         elif icol < argc:             # <<<<<<<<<<<<<<
 *             weights[icol] = <double>raw_weights[icol]
 *         else:
 */
      goto __pyx_L5;
    }

    /* "playhouse/_sqlite_ext.pyx":749
 *             weights[icol] = <double>raw_weights[icol]
 *         else:
 *             weights[icol] = 0.0             # <<<<<<<<<<<<<<
 *     return weights
 * 
 */
    /*else*/ {
      (__pyx_v_weights[__pyx_v_icol]) = 0.0;
    }
    __pyx_L5:;
  }

  /* "playhouse/_sqlite_ext.pyx":750
 *         else:
 *             weights[icol] = 0.0
 *     return weights             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_weights;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":737
 * 
 * 
 * cdef double *get_weights(int ncol, tuple raw_weights):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int argc = len(raw_weights)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("playhouse._sqlite_ext.get_weights", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":753
 * 
 * 
 * def peewee_rank(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     cdef:
 *         unsigned int *match_info
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_1peewee_rank(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_1peewee_rank = {"peewee_rank", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_1peewee_rank, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_1peewee_rank(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_py_match_info = 0;
  PyObject *__pyx_v_raw_weights = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_rank (wrapper)", 0);
  __pyx_v_raw_weights = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_raw_weights)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_raw_weights);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_py_match_info,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_py_match_info)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 753, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "peewee_rank") < 0)) __PYX_ERR(0, 753, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_py_match_info = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_rank", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 753, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_raw_weights); __pyx_v_raw_weights = 0;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_rank", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_peewee_rank(__pyx_self, __pyx_v_py_match_info, __pyx_v_raw_weights);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_raw_weights);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_peewee_rank(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights) {
  unsigned int *__pyx_v_match_info;
  unsigned int *__pyx_v_phrase_info;
  PyObject *__pyx_v__match_info_buf = 0;
  char *__pyx_v_match_info_buf;
  int __pyx_v_nphrase;
  int __pyx_v_ncol;
  int __pyx_v_icol;
  int __pyx_v_iphrase;
  int __pyx_v_hits;
  int __pyx_v_global_hits;
  int __pyx_v_P_O;
  int __pyx_v_C_O;
  int __pyx_v_X_O;
  double __pyx_v_score;
  double __pyx_v_weight;
  double *__pyx_v_weights;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  double *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_rank", 0);

  /* "playhouse/_sqlite_ext.pyx":757
 *         unsigned int *match_info
 *         unsigned int *phrase_info
 *         bytes _match_info_buf = bytes(py_match_info)             # <<<<<<<<<<<<<<
 *         char *match_info_buf = _match_info_buf
 *         int nphrase, ncol, icol, iphrase, hits, global_hits
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_v_py_match_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__match_info_buf = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":758
 *         unsigned int *phrase_info
 *         bytes _match_info_buf = bytes(py_match_info)
 *         char *match_info_buf = _match_info_buf             # <<<<<<<<<<<<<<
 *         int nphrase, ncol, icol, iphrase, hits, global_hits
 *         int P_O = 0, C_O = 1, X_O = 2
 */
  __pyx_t_2 = __Pyx_PyBytes_AsWritableString(__pyx_v__match_info_buf); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 758, __pyx_L1_error)
  __pyx_v_match_info_buf = __pyx_t_2;

  /* "playhouse/_sqlite_ext.pyx":760
 *         char *match_info_buf = _match_info_buf
 *         int nphrase, ncol, icol, iphrase, hits, global_hits
 *         int P_O = 0, C_O = 1, X_O = 2             # <<<<<<<<<<<<<<
 *         double score = 0.0, weight
 *         double *weights
 */
  __pyx_v_P_O = 0;
  __pyx_v_C_O = 1;
  __pyx_v_X_O = 2;

  /* "playhouse/_sqlite_ext.pyx":761
 *         int nphrase, ncol, icol, iphrase, hits, global_hits
 *         int P_O = 0, C_O = 1, X_O = 2
 *         double score = 0.0, weight             # <<<<<<<<<<<<<<
 *         double *weights
 * 
 */
  __pyx_v_score = 0.0;

  /* "playhouse/_sqlite_ext.pyx":764
 *         double *weights
 * 
 *     match_info = <unsigned int *>match_info_buf             # <<<<<<<<<<<<<<
 *     nphrase = match_info[P_O]
 *     ncol = match_info[C_O]
 */
  __pyx_v_match_info = ((unsigned int *)__pyx_v_match_info_buf);

  /* "playhouse/_sqlite_ext.pyx":765
 * 
 *     match_info = <unsigned int *>match_info_buf
 *     nphrase = match_info[P_O]             # <<<<<<<<<<<<<<
 *     ncol = match_info[C_O]
 *     weights = get_weights(ncol, raw_weights)
 */
  __pyx_v_nphrase = (__pyx_v_match_info[__pyx_v_P_O]);

  /* "playhouse/_sqlite_ext.pyx":766
 *     match_info = <unsigned int *>match_info_buf
 *     nphrase = match_info[P_O]
 *     ncol = match_info[C_O]             # <<<<<<<<<<<<<<
 *     weights = get_weights(ncol, raw_weights)
 * 
 */
  __pyx_v_ncol = (__pyx_v_match_info[__pyx_v_C_O]);

  /* "playhouse/_sqlite_ext.pyx":767
 *     nphrase = match_info[P_O]
 *     ncol = match_info[C_O]
 *     weights = get_weights(ncol, raw_weights)             # <<<<<<<<<<<<<<
 * 
 *     # matchinfo X value corresponds to, for each phrase in the search query, a
 */
  __pyx_t_3 = __pyx_f_9playhouse_11_sqlite_ext_get_weights(__pyx_v_ncol, __pyx_v_raw_weights); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 767, __pyx_L1_error)
  __pyx_v_weights = __pyx_t_3;

  /* "playhouse/_sqlite_ext.pyx":775
 *     # p0 : c0=[0, 1, 2],   c1=[3, 4, 5],    c2=[6, 7, 8]
 *     # p1 : c0=[9, 10, 11], c1=[12, 13, 14], c2=[15, 16, 17]
 *     for iphrase in range(nphrase):             # <<<<<<<<<<<<<<
 *         phrase_info = &match_info[X_O + iphrase * ncol * 3]
 *         for icol in range(ncol):
 */
  __pyx_t_4 = __pyx_v_nphrase;
  __pyx_t_5 = __pyx_t_4;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_iphrase = __pyx_t_6;

    /* "playhouse/_sqlite_ext.pyx":776
 *     # p1 : c0=[9, 10, 11], c1=[12, 13, 14], c2=[15, 16, 17]
 *     for iphrase in range(nphrase):
 *         phrase_info = &match_info[X_O + iphrase * ncol * 3]             # <<<<<<<<<<<<<<
 *         for icol in range(ncol):
 *             weight = weights[icol]
 */
    __pyx_v_phrase_info = (&(__pyx_v_match_info[(__pyx_v_X_O + ((__pyx_v_iphrase * __pyx_v_ncol) * 3))]));

    /* "playhouse/_sqlite_ext.pyx":777
 *     for iphrase in range(nphrase):
 *         phrase_info = &match_info[X_O + iphrase * ncol * 3]
 *         for icol in range(ncol):             # <<<<<<<<<<<<<<
 *             weight = weights[icol]
 *             if weight == 0:
 */
    __pyx_t_7 = __pyx_v_ncol;
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_icol = __pyx_t_9;

      /* "playhouse/_sqlite_ext.pyx":778
 *         phrase_info = &match_info[X_O + iphrase * ncol * 3]
 *         for icol in range(ncol):
 *             weight = weights[icol]             # <<<<<<<<<<<<<<
 *             if weight == 0:
 *                 continue
 */
      __pyx_v_weight = (__pyx_v_weights[__pyx_v_icol]);

      /* "playhouse/_sqlite_ext.pyx":779
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      __pyx_t_10 = (__pyx_v_weight == 0.0);
      if (__pyx_t_10) {

        /* "playhouse/_sqlite_ext.pyx":780
 *             weight = weights[icol]
 *             if weight == 0:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             # The idea is that we count the number of times the phrase appears
 */
        goto __pyx_L5_continue;

        /* "playhouse/_sqlite_ext.pyx":779
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      }

      /* "playhouse/_sqlite_ext.pyx":786
 *             # appears in this column across all rows. The ratio of these values
 *             # provides a rough way to score based on "high value" terms.
 *             hits = phrase_info[3 * icol]             # <<<<<<<<<<<<<<
 *             global_hits = phrase_info[3 * icol + 1]
 *             if hits > 0:
 */
      __pyx_v_hits = (__pyx_v_phrase_info[(3 * __pyx_v_icol)]);

      /* "playhouse/_sqlite_ext.pyx":787
 *             # provides a rough way to score based on "high value" terms.
 *             hits = phrase_info[3 * icol]
 *             global_hits = phrase_info[3 * icol + 1]             # <<<<<<<<<<<<<<
 *             if hits > 0:
 *                 score += weight * (<double>hits / <double>global_hits)
 */
      __pyx_v_global_hits = (__pyx_v_phrase_info[((3 * __pyx_v_icol) + 1)]);

      /* "playhouse/_sqlite_ext.pyx":788
 *             hits = phrase_info[3 * icol]
 *             global_hits = phrase_info[3 * icol + 1]
 *             if hits > 0:             # <<<<<<<<<<<<<<
 *                 score += weight * (<double>hits / <double>global_hits)
 * 
 */
      __pyx_t_10 = (__pyx_v_hits > 0);
      if (__pyx_t_10) {

        /* "playhouse/_sqlite_ext.pyx":789
 *             global_hits = phrase_info[3 * icol + 1]
 *             if hits > 0:
 *                 score += weight * (<double>hits / <double>global_hits)             # <<<<<<<<<<<<<<
 * 
 *     free(weights)
 */
        if (unlikely(((double)__pyx_v_global_hits) == 0)) {
          PyErr_SetString(PyExc_ZeroDivisionError, "float division");
          __PYX_ERR(0, 789, __pyx_L1_error)
        }
        __pyx_v_score = (__pyx_v_score + (__pyx_v_weight * (((double)__pyx_v_hits) / ((double)__pyx_v_global_hits))));

        /* "playhouse/_sqlite_ext.pyx":788
 *             hits = phrase_info[3 * icol]
 *             global_hits = phrase_info[3 * icol + 1]
 *             if hits > 0:             # <<<<<<<<<<<<<<
 *                 score += weight * (<double>hits / <double>global_hits)
 * 
 */
      }
      __pyx_L5_continue:;
    }
  }

  /* "playhouse/_sqlite_ext.pyx":791
 *                 score += weight * (<double>hits / <double>global_hits)
 * 
 *     free(weights)             # <<<<<<<<<<<<<<
 *     return -1 * score
 * 
 */
  free(__pyx_v_weights);

  /* "playhouse/_sqlite_ext.pyx":792
 * 
 *     free(weights)
 *     return -1 * score             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((-1.0 * __pyx_v_score)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":753
 * 
 * 
 * def peewee_rank(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     cdef:
 *         unsigned int *match_info
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_rank", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__match_info_buf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":795
 * 
 * 
 * def peewee_lucene(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_lucene(matchinfo(table, 'pcnalx'), 1)
 *     cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_3peewee_lucene(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_3peewee_lucene = {"peewee_lucene", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_3peewee_lucene, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_3peewee_lucene(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_py_match_info = 0;
  PyObject *__pyx_v_raw_weights = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_lucene (wrapper)", 0);
  __pyx_v_raw_weights = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_raw_weights)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_raw_weights);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_py_match_info,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_py_match_info)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 795, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "peewee_lucene") < 0)) __PYX_ERR(0, 795, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_py_match_info = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_lucene", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 795, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_raw_weights); __pyx_v_raw_weights = 0;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_lucene", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_2peewee_lucene(__pyx_self, __pyx_v_py_match_info, __pyx_v_raw_weights);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_raw_weights);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_2peewee_lucene(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights) {
  unsigned int *__pyx_v_match_info;
  PyObject *__pyx_v__match_info_buf = 0;
  char *__pyx_v_match_info_buf;
  int __pyx_v_nphrase;
  int __pyx_v_ncol;
  double __pyx_v_total_docs;
  double __pyx_v_term_frequency;
  double __pyx_v_doc_length;
  double __pyx_v_docs_with_term;
  double __pyx_v_idf;
  double __pyx_v_weight;
  double *__pyx_v_weights;
  int __pyx_v_P_O;
  int __pyx_v_C_O;
  int __pyx_v_N_O;
  int __pyx_v_L_O;
  int __pyx_v_X_O;
  int __pyx_v_iphrase;
  int __pyx_v_icol;
  int __pyx_v_x;
  double __pyx_v_score;
  double __pyx_v_tf;
  double __pyx_v_fieldNorms;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  double *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  double __pyx_t_11;
  unsigned int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_lucene", 0);

  /* "playhouse/_sqlite_ext.pyx":799
 *     cdef:
 *         unsigned int *match_info
 *         bytes _match_info_buf = bytes(py_match_info)             # <<<<<<<<<<<<<<
 *         char *match_info_buf = _match_info_buf
 *         int nphrase, ncol
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_v_py_match_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__match_info_buf = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":800
 *         unsigned int *match_info
 *         bytes _match_info_buf = bytes(py_match_info)
 *         char *match_info_buf = _match_info_buf             # <<<<<<<<<<<<<<
 *         int nphrase, ncol
 *         double total_docs, term_frequency
 */
  __pyx_t_2 = __Pyx_PyBytes_AsWritableString(__pyx_v__match_info_buf); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 800, __pyx_L1_error)
  __pyx_v_match_info_buf = __pyx_t_2;

  /* "playhouse/_sqlite_ext.pyx":806
 *         double idf, weight, rhs, denom
 *         double *weights
 *         int P_O = 0, C_O = 1, N_O = 2, L_O, X_O             # <<<<<<<<<<<<<<
 *         int iphrase, icol, x
 *         double score = 0.0
 */
  __pyx_v_P_O = 0;
  __pyx_v_C_O = 1;
  __pyx_v_N_O = 2;

  /* "playhouse/_sqlite_ext.pyx":808
 *         int P_O = 0, C_O = 1, N_O = 2, L_O, X_O
 *         int iphrase, icol, x
 *         double score = 0.0             # <<<<<<<<<<<<<<
 * 
 *     match_info = <unsigned int *>match_info_buf
 */
  __pyx_v_score = 0.0;

  /* "playhouse/_sqlite_ext.pyx":810
 *         double score = 0.0
 * 
 *     match_info = <unsigned int *>match_info_buf             # <<<<<<<<<<<<<<
 *     nphrase = match_info[P_O]
 *     ncol = match_info[C_O]
 */
  __pyx_v_match_info = ((unsigned int *)__pyx_v_match_info_buf);

  /* "playhouse/_sqlite_ext.pyx":811
 * 
 *     match_info = <unsigned int *>match_info_buf
 *     nphrase = match_info[P_O]             # <<<<<<<<<<<<<<
 *     ncol = match_info[C_O]
 *     total_docs = match_info[N_O]
 */
  __pyx_v_nphrase = (__pyx_v_match_info[__pyx_v_P_O]);

  /* "playhouse/_sqlite_ext.pyx":812
 *     match_info = <unsigned int *>match_info_buf
 *     nphrase = match_info[P_O]
 *     ncol = match_info[C_O]             # <<<<<<<<<<<<<<
 *     total_docs = match_info[N_O]
 * 
 */
  __pyx_v_ncol = (__pyx_v_match_info[__pyx_v_C_O]);

  /* "playhouse/_sqlite_ext.pyx":813
 *     nphrase = match_info[P_O]
 *     ncol = match_info[C_O]
 *     total_docs = match_info[N_O]             # <<<<<<<<<<<<<<
 * 
 *     L_O = 3 + ncol
 */
  __pyx_v_total_docs = (__pyx_v_match_info[__pyx_v_N_O]);

  /* "playhouse/_sqlite_ext.pyx":815
 *     total_docs = match_info[N_O]
 * 
 *     L_O = 3 + ncol             # <<<<<<<<<<<<<<
 *     X_O = L_O + ncol
 *     weights = get_weights(ncol, raw_weights)
 */
  __pyx_v_L_O = (3 + __pyx_v_ncol);

  /* "playhouse/_sqlite_ext.pyx":816
 * 
 *     L_O = 3 + ncol
 *     X_O = L_O + ncol             # <<<<<<<<<<<<<<
 *     weights = get_weights(ncol, raw_weights)
 * 
 */
  __pyx_v_X_O = (__pyx_v_L_O + __pyx_v_ncol);

  /* "playhouse/_sqlite_ext.pyx":817
 *     L_O = 3 + ncol
 *     X_O = L_O + ncol
 *     weights = get_weights(ncol, raw_weights)             # <<<<<<<<<<<<<<
 * 
 *     for iphrase in range(nphrase):
 */
  __pyx_t_3 = __pyx_f_9playhouse_11_sqlite_ext_get_weights(__pyx_v_ncol, __pyx_v_raw_weights); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 817, __pyx_L1_error)
  __pyx_v_weights = __pyx_t_3;

  /* "playhouse/_sqlite_ext.pyx":819
 *     weights = get_weights(ncol, raw_weights)
 * 
 *     for iphrase in range(nphrase):             # <<<<<<<<<<<<<<
 *         for icol in range(ncol):
 *             weight = weights[icol]
 */
  __pyx_t_4 = __pyx_v_nphrase;
  __pyx_t_5 = __pyx_t_4;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_iphrase = __pyx_t_6;

    /* "playhouse/_sqlite_ext.pyx":820
 * 
 *     for iphrase in range(nphrase):
 *         for icol in range(ncol):             # <<<<<<<<<<<<<<
 *             weight = weights[icol]
 *             if weight == 0:
 */
    __pyx_t_7 = __pyx_v_ncol;
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_icol = __pyx_t_9;

      /* "playhouse/_sqlite_ext.pyx":821
 *     for iphrase in range(nphrase):
 *         for icol in range(ncol):
 *             weight = weights[icol]             # <<<<<<<<<<<<<<
 *             if weight == 0:
 *                 continue
 */
      __pyx_v_weight = (__pyx_v_weights[__pyx_v_icol]);

      /* "playhouse/_sqlite_ext.pyx":822
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             doc_length = match_info[L_O + icol]
 */
      __pyx_t_10 = (__pyx_v_weight == 0.0);
      if (__pyx_t_10) {

        /* "playhouse/_sqlite_ext.pyx":823
 *             weight = weights[icol]
 *             if weight == 0:
 *                 continue             # <<<<<<<<<<<<<<
 *             doc_length = match_info[L_O + icol]
 *             x = X_O + (3 * (icol + iphrase * ncol))
 */
        goto __pyx_L5_continue;

        /* "playhouse/_sqlite_ext.pyx":822
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             doc_length = match_info[L_O + icol]
 */
      }

      /* "playhouse/_sqlite_ext.pyx":824
 *             if weight == 0:
 *                 continue
 *             doc_length = match_info[L_O + icol]             # <<<<<<<<<<<<<<
 *             x = X_O + (3 * (icol + iphrase * ncol))
 *             term_frequency = match_info[x]  # f(qi)
 */
      __pyx_v_doc_length = (__pyx_v_match_info[(__pyx_v_L_O + __pyx_v_icol)]);

      /* "playhouse/_sqlite_ext.pyx":825
 *                 continue
 *             doc_length = match_info[L_O + icol]
 *             x = X_O + (3 * (icol + iphrase * ncol))             # <<<<<<<<<<<<<<
 *             term_frequency = match_info[x]  # f(qi)
 *             docs_with_term = match_info[x + 2] or 1. # n(qi)
 */
      __pyx_v_x = (__pyx_v_X_O + (3 * (__pyx_v_icol + (__pyx_v_iphrase * __pyx_v_ncol))));

      /* "playhouse/_sqlite_ext.pyx":826
 *             doc_length = match_info[L_O + icol]
 *             x = X_O + (3 * (icol + iphrase * ncol))
 *             term_frequency = match_info[x]  # f(qi)             # <<<<<<<<<<<<<<
 *             docs_with_term = match_info[x + 2] or 1. # n(qi)
 *             idf = log(total_docs / (docs_with_term + 1.))
 */
      __pyx_v_term_frequency = (__pyx_v_match_info[__pyx_v_x]);

      /* "playhouse/_sqlite_ext.pyx":827
 *             x = X_O + (3 * (icol + iphrase * ncol))
 *             term_frequency = match_info[x]  # f(qi)
 *             docs_with_term = match_info[x + 2] or 1. # n(qi)             # <<<<<<<<<<<<<<
 *             idf = log(total_docs / (docs_with_term + 1.))
 *             tf = sqrt(term_frequency)
 */
      __pyx_t_12 = (__pyx_v_match_info[(__pyx_v_x + 2)]);
      if (!__pyx_t_12) {
      } else {
        __pyx_t_11 = __pyx_t_12;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_11 = 1.;
      __pyx_L8_bool_binop_done:;
      __pyx_v_docs_with_term = __pyx_t_11;

      /* "playhouse/_sqlite_ext.pyx":828
 *             term_frequency = match_info[x]  # f(qi)
 *             docs_with_term = match_info[x + 2] or 1. # n(qi)
 *             idf = log(total_docs / (docs_with_term + 1.))             # <<<<<<<<<<<<<<
 *             tf = sqrt(term_frequency)
 *             fieldNorms = 1.0 / sqrt(doc_length)
 */
      __pyx_t_11 = (__pyx_v_docs_with_term + 1.);
      if (unlikely(__pyx_t_11 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 828, __pyx_L1_error)
      }
      __pyx_v_idf = log((__pyx_v_total_docs / __pyx_t_11));

      /* "playhouse/_sqlite_ext.pyx":829
 *             docs_with_term = match_info[x + 2] or 1. # n(qi)
 *             idf = log(total_docs / (docs_with_term + 1.))
 *             tf = sqrt(term_frequency)             # <<<<<<<<<<<<<<
 *             fieldNorms = 1.0 / sqrt(doc_length)
 *             score += (idf * tf * fieldNorms)
 */
      __pyx_v_tf = sqrt(__pyx_v_term_frequency);

      /* "playhouse/_sqlite_ext.pyx":830
 *             idf = log(total_docs / (docs_with_term + 1.))
 *             tf = sqrt(term_frequency)
 *             fieldNorms = 1.0 / sqrt(doc_length)             # <<<<<<<<<<<<<<
 *             score += (idf * tf * fieldNorms)
 * 
 */
      __pyx_t_11 = sqrt(__pyx_v_doc_length);
      if (unlikely(__pyx_t_11 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 830, __pyx_L1_error)
      }
      __pyx_v_fieldNorms = (1.0 / __pyx_t_11);

      /* "playhouse/_sqlite_ext.pyx":831
 *             tf = sqrt(term_frequency)
 *             fieldNorms = 1.0 / sqrt(doc_length)
 *             score += (idf * tf * fieldNorms)             # <<<<<<<<<<<<<<
 * 
 *     free(weights)
 */
      __pyx_v_score = (__pyx_v_score + ((__pyx_v_idf * __pyx_v_tf) * __pyx_v_fieldNorms));
      __pyx_L5_continue:;
    }
  }

  /* "playhouse/_sqlite_ext.pyx":833
 *             score += (idf * tf * fieldNorms)
 * 
 *     free(weights)             # <<<<<<<<<<<<<<
 *     return -1 * score
 * 
 */
  free(__pyx_v_weights);

  /* "playhouse/_sqlite_ext.pyx":834
 * 
 *     free(weights)
 *     return -1 * score             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((-1.0 * __pyx_v_score)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":795
 * 
 * 
 * def peewee_lucene(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_lucene(matchinfo(table, 'pcnalx'), 1)
 *     cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_lucene", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__match_info_buf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":837
 * 
 * 
 * def peewee_bm25(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_5peewee_bm25(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_5peewee_bm25 = {"peewee_bm25", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_5peewee_bm25, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_5peewee_bm25(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_py_match_info = 0;
  PyObject *__pyx_v_raw_weights = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_bm25 (wrapper)", 0);
  __pyx_v_raw_weights = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_raw_weights)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_raw_weights);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_py_match_info,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_py_match_info)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 837, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "peewee_bm25") < 0)) __PYX_ERR(0, 837, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_py_match_info = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_bm25", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 837, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_raw_weights); __pyx_v_raw_weights = 0;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bm25", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4peewee_bm25(__pyx_self, __pyx_v_py_match_info, __pyx_v_raw_weights);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_raw_weights);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4peewee_bm25(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights) {
  unsigned int *__pyx_v_match_info;
  PyObject *__pyx_v__match_info_buf = 0;
  char *__pyx_v_match_info_buf;
  int __pyx_v_nphrase;
  int __pyx_v_ncol;
  double __pyx_v_B;
  double __pyx_v_K;
  double __pyx_v_total_docs;
  double __pyx_v_term_frequency;
  double __pyx_v_doc_length;
  double __pyx_v_docs_with_term;
  double __pyx_v_avg_length;
  double __pyx_v_idf;
  double __pyx_v_weight;
  double __pyx_v_ratio;
  double __pyx_v_num;
  double __pyx_v_b_part;
  double __pyx_v_denom;
  double __pyx_v_pc_score;
  double *__pyx_v_weights;
  int __pyx_v_P_O;
  int __pyx_v_C_O;
  int __pyx_v_N_O;
  int __pyx_v_A_O;
  int __pyx_v_L_O;
  int __pyx_v_X_O;
  int __pyx_v_iphrase;
  int __pyx_v_icol;
  int __pyx_v_x;
  double __pyx_v_score;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  double *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  double __pyx_t_11;
  double __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_bm25", 0);

  /* "playhouse/_sqlite_ext.pyx":843
 *     cdef:
 *         unsigned int *match_info
 *         bytes _match_info_buf = bytes(py_match_info)             # <<<<<<<<<<<<<<
 *         char *match_info_buf = _match_info_buf
 *         int nphrase, ncol
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_v_py_match_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__match_info_buf = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":844
 *         unsigned int *match_info
 *         bytes _match_info_buf = bytes(py_match_info)
 *         char *match_info_buf = _match_info_buf             # <<<<<<<<<<<<<<
 *         int nphrase, ncol
 *         double B = 0.75, K = 1.2
 */
  __pyx_t_2 = __Pyx_PyBytes_AsWritableString(__pyx_v__match_info_buf); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 844, __pyx_L1_error)
  __pyx_v_match_info_buf = __pyx_t_2;

  /* "playhouse/_sqlite_ext.pyx":846
 *         char *match_info_buf = _match_info_buf
 *         int nphrase, ncol
 *         double B = 0.75, K = 1.2             # <<<<<<<<<<<<<<
 *         double total_docs, term_frequency
 *         double doc_length, docs_with_term, avg_length
 */
  __pyx_v_B = 0.75;
  __pyx_v_K = 1.2;

  /* "playhouse/_sqlite_ext.pyx":851
 *         double idf, weight, ratio, num, b_part, denom, pc_score
 *         double *weights
 *         int P_O = 0, C_O = 1, N_O = 2, A_O = 3, L_O, X_O             # <<<<<<<<<<<<<<
 *         int iphrase, icol, x
 *         double score = 0.0
 */
  __pyx_v_P_O = 0;
  __pyx_v_C_O = 1;
  __pyx_v_N_O = 2;
  __pyx_v_A_O = 3;

  /* "playhouse/_sqlite_ext.pyx":853
 *         int P_O = 0, C_O = 1, N_O = 2, A_O = 3, L_O, X_O
 *         int iphrase, icol, x
 *         double score = 0.0             # <<<<<<<<<<<<<<
 * 
 *     match_info = <unsigned int *>match_info_buf
 */
  __pyx_v_score = 0.0;

  /* "playhouse/_sqlite_ext.pyx":855
 *         double score = 0.0
 * 
 *     match_info = <unsigned int *>match_info_buf             # <<<<<<<<<<<<<<
 *     # PCNALX = matchinfo format.
 *     # P = 1 = phrase count within query.
 */
  __pyx_v_match_info = ((unsigned int *)__pyx_v_match_info_buf);

  /* "playhouse/_sqlite_ext.pyx":866
 *     # * phrase count within column for all rows.
 *     # * total rows for which column contains phrase.
 *     nphrase = match_info[P_O]  # n             # <<<<<<<<<<<<<<
 *     ncol = match_info[C_O]
 *     total_docs = match_info[N_O]  # N
 */
  __pyx_v_nphrase = (__pyx_v_match_info[__pyx_v_P_O]);

  /* "playhouse/_sqlite_ext.pyx":867
 *     # * total rows for which column contains phrase.
 *     nphrase = match_info[P_O]  # n
 *     ncol = match_info[C_O]             # <<<<<<<<<<<<<<
 *     total_docs = match_info[N_O]  # N
 * 
 */
  __pyx_v_ncol = (__pyx_v_match_info[__pyx_v_C_O]);

  /* "playhouse/_sqlite_ext.pyx":868
 *     nphrase = match_info[P_O]  # n
 *     ncol = match_info[C_O]
 *     total_docs = match_info[N_O]  # N             # <<<<<<<<<<<<<<
 * 
 *     L_O = A_O + ncol
 */
  __pyx_v_total_docs = (__pyx_v_match_info[__pyx_v_N_O]);

  /* "playhouse/_sqlite_ext.pyx":870
 *     total_docs = match_info[N_O]  # N
 * 
 *     L_O = A_O + ncol             # <<<<<<<<<<<<<<
 *     X_O = L_O + ncol
 *     weights = get_weights(ncol, raw_weights)
 */
  __pyx_v_L_O = (__pyx_v_A_O + __pyx_v_ncol);

  /* "playhouse/_sqlite_ext.pyx":871
 * 
 *     L_O = A_O + ncol
 *     X_O = L_O + ncol             # <<<<<<<<<<<<<<
 *     weights = get_weights(ncol, raw_weights)
 * 
 */
  __pyx_v_X_O = (__pyx_v_L_O + __pyx_v_ncol);

  /* "playhouse/_sqlite_ext.pyx":872
 *     L_O = A_O + ncol
 *     X_O = L_O + ncol
 *     weights = get_weights(ncol, raw_weights)             # <<<<<<<<<<<<<<
 * 
 *     for iphrase in range(nphrase):
 */
  __pyx_t_3 = __pyx_f_9playhouse_11_sqlite_ext_get_weights(__pyx_v_ncol, __pyx_v_raw_weights); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 872, __pyx_L1_error)
  __pyx_v_weights = __pyx_t_3;

  /* "playhouse/_sqlite_ext.pyx":874
 *     weights = get_weights(ncol, raw_weights)
 * 
 *     for iphrase in range(nphrase):             # <<<<<<<<<<<<<<
 *         for icol in range(ncol):
 *             weight = weights[icol]
 */
  __pyx_t_4 = __pyx_v_nphrase;
  __pyx_t_5 = __pyx_t_4;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_iphrase = __pyx_t_6;

    /* "playhouse/_sqlite_ext.pyx":875
 * 
 *     for iphrase in range(nphrase):
 *         for icol in range(ncol):             # <<<<<<<<<<<<<<
 *             weight = weights[icol]
 *             if weight == 0:
 */
    __pyx_t_7 = __pyx_v_ncol;
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_icol = __pyx_t_9;

      /* "playhouse/_sqlite_ext.pyx":876
 *     for iphrase in range(nphrase):
 *         for icol in range(ncol):
 *             weight = weights[icol]             # <<<<<<<<<<<<<<
 *             if weight == 0:
 *                 continue
 */
      __pyx_v_weight = (__pyx_v_weights[__pyx_v_icol]);

      /* "playhouse/_sqlite_ext.pyx":877
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      __pyx_t_10 = (__pyx_v_weight == 0.0);
      if (__pyx_t_10) {

        /* "playhouse/_sqlite_ext.pyx":878
 *             weight = weights[icol]
 *             if weight == 0:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             x = X_O + (3 * (icol + iphrase * ncol))
 */
        goto __pyx_L5_continue;

        /* "playhouse/_sqlite_ext.pyx":877
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      }

      /* "playhouse/_sqlite_ext.pyx":880
 *                 continue
 * 
 *             x = X_O + (3 * (icol + iphrase * ncol))             # <<<<<<<<<<<<<<
 *             term_frequency = match_info[x]  # f(qi, D)
 *             docs_with_term = match_info[x + 2]  # n(qi)
 */
      __pyx_v_x = (__pyx_v_X_O + (3 * (__pyx_v_icol + (__pyx_v_iphrase * __pyx_v_ncol))));

      /* "playhouse/_sqlite_ext.pyx":881
 * 
 *             x = X_O + (3 * (icol + iphrase * ncol))
 *             term_frequency = match_info[x]  # f(qi, D)             # <<<<<<<<<<<<<<
 *             docs_with_term = match_info[x + 2]  # n(qi)
 * 
 */
      __pyx_v_term_frequency = (__pyx_v_match_info[__pyx_v_x]);

      /* "playhouse/_sqlite_ext.pyx":882
 *             x = X_O + (3 * (icol + iphrase * ncol))
 *             term_frequency = match_info[x]  # f(qi, D)
 *             docs_with_term = match_info[x + 2]  # n(qi)             # <<<<<<<<<<<<<<
 * 
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 */
      __pyx_v_docs_with_term = (__pyx_v_match_info[(__pyx_v_x + 2)]);

      /* "playhouse/_sqlite_ext.pyx":886
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 *             idf = log(
 *                     (total_docs - docs_with_term + 0.5) /             # <<<<<<<<<<<<<<
 *                     (docs_with_term + 0.5))
 *             if idf <= 0.0:
 */
      __pyx_t_11 = ((__pyx_v_total_docs - __pyx_v_docs_with_term) + 0.5);

      /* "playhouse/_sqlite_ext.pyx":887
 *             idf = log(
 *                     (total_docs - docs_with_term + 0.5) /
 *                     (docs_with_term + 0.5))             # <<<<<<<<<<<<<<
 *             if idf <= 0.0:
 *                 idf = 1e-6
 */
      __pyx_t_12 = (__pyx_v_docs_with_term + 0.5);

      /* "playhouse/_sqlite_ext.pyx":886
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 *             idf = log(
 *                     (total_docs - docs_with_term + 0.5) /             # <<<<<<<<<<<<<<
 *                     (docs_with_term + 0.5))
 *             if idf <= 0.0:
 */
      if (unlikely(__pyx_t_12 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 886, __pyx_L1_error)
      }

      /* "playhouse/_sqlite_ext.pyx":885
 * 
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 *             idf = log(             # <<<<<<<<<<<<<<
 *                     (total_docs - docs_with_term + 0.5) /
 *                     (docs_with_term + 0.5))
 */
      __pyx_v_idf = log((__pyx_t_11 / __pyx_t_12));

      /* "playhouse/_sqlite_ext.pyx":888
 *                     (total_docs - docs_with_term + 0.5) /
 *                     (docs_with_term + 0.5))
 *             if idf <= 0.0:             # <<<<<<<<<<<<<<
 *                 idf = 1e-6
 * 
 */
      __pyx_t_10 = (__pyx_v_idf <= 0.0);
      if (__pyx_t_10) {

        /* "playhouse/_sqlite_ext.pyx":889
 *                     (docs_with_term + 0.5))
 *             if idf <= 0.0:
 *                 idf = 1e-6             # <<<<<<<<<<<<<<
 * 
 *             doc_length = match_info[L_O + icol]  # |D|
 */
        __pyx_v_idf = 1e-6;

        /* "playhouse/_sqlite_ext.pyx":888
 *                     (total_docs - docs_with_term + 0.5) /
 *                     (docs_with_term + 0.5))
 *             if idf <= 0.0:             # <<<<<<<<<<<<<<
 *                 idf = 1e-6
 * 
 */
      }

      /* "playhouse/_sqlite_ext.pyx":891
 *                 idf = 1e-6
 * 
 *             doc_length = match_info[L_O + icol]  # |D|             # <<<<<<<<<<<<<<
 *             avg_length = match_info[A_O + icol]  # avgdl
 *             if avg_length == 0:
 */
      __pyx_v_doc_length = (__pyx_v_match_info[(__pyx_v_L_O + __pyx_v_icol)]);

      /* "playhouse/_sqlite_ext.pyx":892
 * 
 *             doc_length = match_info[L_O + icol]  # |D|
 *             avg_length = match_info[A_O + icol]  # avgdl             # <<<<<<<<<<<<<<
 *             if avg_length == 0:
 *                 avg_length = 1
 */
      __pyx_v_avg_length = (__pyx_v_match_info[(__pyx_v_A_O + __pyx_v_icol)]);

      /* "playhouse/_sqlite_ext.pyx":893
 *             doc_length = match_info[L_O + icol]  # |D|
 *             avg_length = match_info[A_O + icol]  # avgdl
 *             if avg_length == 0:             # <<<<<<<<<<<<<<
 *                 avg_length = 1
 *             ratio = doc_length / avg_length
 */
      __pyx_t_10 = (__pyx_v_avg_length == 0.0);
      if (__pyx_t_10) {

        /* "playhouse/_sqlite_ext.pyx":894
 *             avg_length = match_info[A_O + icol]  # avgdl
 *             if avg_length == 0:
 *                 avg_length = 1             # <<<<<<<<<<<<<<
 *             ratio = doc_length / avg_length
 * 
 */
        __pyx_v_avg_length = 1.0;

        /* "playhouse/_sqlite_ext.pyx":893
 *             doc_length = match_info[L_O + icol]  # |D|
 *             avg_length = match_info[A_O + icol]  # avgdl
 *             if avg_length == 0:             # <<<<<<<<<<<<<<
 *                 avg_length = 1
 *             ratio = doc_length / avg_length
 */
      }

      /* "playhouse/_sqlite_ext.pyx":895
 *             if avg_length == 0:
 *                 avg_length = 1
 *             ratio = doc_length / avg_length             # <<<<<<<<<<<<<<
 * 
 *             num = term_frequency * (K + 1)
 */
      if (unlikely(__pyx_v_avg_length == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 895, __pyx_L1_error)
      }
      __pyx_v_ratio = (__pyx_v_doc_length / __pyx_v_avg_length);

      /* "playhouse/_sqlite_ext.pyx":897
 *             ratio = doc_length / avg_length
 * 
 *             num = term_frequency * (K + 1)             # <<<<<<<<<<<<<<
 *             b_part = 1 - B + (B * ratio)
 *             denom = term_frequency + (K * b_part)
 */
      __pyx_v_num = (__pyx_v_term_frequency * (__pyx_v_K + 1.0));

      /* "playhouse/_sqlite_ext.pyx":898
 * 
 *             num = term_frequency * (K + 1)
 *             b_part = 1 - B + (B * ratio)             # <<<<<<<<<<<<<<
 *             denom = term_frequency + (K * b_part)
 * 
 */
      __pyx_v_b_part = ((1.0 - __pyx_v_B) + (__pyx_v_B * __pyx_v_ratio));

      /* "playhouse/_sqlite_ext.pyx":899
 *             num = term_frequency * (K + 1)
 *             b_part = 1 - B + (B * ratio)
 *             denom = term_frequency + (K * b_part)             # <<<<<<<<<<<<<<
 * 
 *             pc_score = idf * (num / denom)
 */
      __pyx_v_denom = (__pyx_v_term_frequency + (__pyx_v_K * __pyx_v_b_part));

      /* "playhouse/_sqlite_ext.pyx":901
 *             denom = term_frequency + (K * b_part)
 * 
 *             pc_score = idf * (num / denom)             # <<<<<<<<<<<<<<
 *             score += (pc_score * weight)
 * 
 */
      if (unlikely(__pyx_v_denom == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 901, __pyx_L1_error)
      }
      __pyx_v_pc_score = (__pyx_v_idf * (__pyx_v_num / __pyx_v_denom));

      /* "playhouse/_sqlite_ext.pyx":902
 * 
 *             pc_score = idf * (num / denom)
 *             score += (pc_score * weight)             # <<<<<<<<<<<<<<
 * 
 *     free(weights)
 */
      __pyx_v_score = (__pyx_v_score + (__pyx_v_pc_score * __pyx_v_weight));
      __pyx_L5_continue:;
    }
  }

  /* "playhouse/_sqlite_ext.pyx":904
 *             score += (pc_score * weight)
 * 
 *     free(weights)             # <<<<<<<<<<<<<<
 *     return -1 * score
 * 
 */
  free(__pyx_v_weights);

  /* "playhouse/_sqlite_ext.pyx":905
 * 
 *     free(weights)
 *     return -1 * score             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((-1.0 * __pyx_v_score)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":837
 * 
 * 
 * def peewee_bm25(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bm25", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__match_info_buf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":908
 * 
 * 
 * def peewee_bm25f(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25f(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_7peewee_bm25f(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_7peewee_bm25f = {"peewee_bm25f", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_7peewee_bm25f, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_7peewee_bm25f(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_py_match_info = 0;
  PyObject *__pyx_v_raw_weights = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_bm25f (wrapper)", 0);
  __pyx_v_raw_weights = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_raw_weights)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_raw_weights);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_py_match_info,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_py_match_info)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 908, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "peewee_bm25f") < 0)) __PYX_ERR(0, 908, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_py_match_info = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_bm25f", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 908, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_raw_weights); __pyx_v_raw_weights = 0;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bm25f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_6peewee_bm25f(__pyx_self, __pyx_v_py_match_info, __pyx_v_raw_weights);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_raw_weights);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_6peewee_bm25f(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_py_match_info, PyObject *__pyx_v_raw_weights) {
  unsigned int *__pyx_v_match_info;
  PyObject *__pyx_v__match_info_buf = 0;
  char *__pyx_v_match_info_buf;
  int __pyx_v_nphrase;
  int __pyx_v_ncol;
  double __pyx_v_B;
  double __pyx_v_K;
  double __pyx_v_epsilon;
  double __pyx_v_total_docs;
  double __pyx_v_term_frequency;
  double __pyx_v_docs_with_term;
  double __pyx_v_doc_length;
  double __pyx_v_avg_length;
  double __pyx_v_idf;
  double __pyx_v_weight;
  double __pyx_v_ratio;
  double __pyx_v_num;
  double __pyx_v_b_part;
  double __pyx_v_denom;
  double __pyx_v_pc_score;
  double *__pyx_v_weights;
  int __pyx_v_P_O;
  int __pyx_v_C_O;
  int __pyx_v_N_O;
  int __pyx_v_A_O;
  int __pyx_v_L_O;
  int __pyx_v_X_O;
  int __pyx_v_iphrase;
  int __pyx_v_icol;
  int __pyx_v_x;
  double __pyx_v_score;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  double __pyx_t_6;
  int __pyx_t_7;
  double *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  double __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_bm25f", 0);

  /* "playhouse/_sqlite_ext.pyx":914
 *     cdef:
 *         unsigned int *match_info
 *         bytes _match_info_buf = bytes(py_match_info)             # <<<<<<<<<<<<<<
 *         char *match_info_buf = _match_info_buf
 *         int nphrase, ncol
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_v_py_match_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__match_info_buf = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":915
 *         unsigned int *match_info
 *         bytes _match_info_buf = bytes(py_match_info)
 *         char *match_info_buf = _match_info_buf             # <<<<<<<<<<<<<<
 *         int nphrase, ncol
 *         double B = 0.75, K = 1.2, epsilon
 */
  __pyx_t_2 = __Pyx_PyBytes_AsWritableString(__pyx_v__match_info_buf); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 915, __pyx_L1_error)
  __pyx_v_match_info_buf = __pyx_t_2;

  /* "playhouse/_sqlite_ext.pyx":917
 *         char *match_info_buf = _match_info_buf
 *         int nphrase, ncol
 *         double B = 0.75, K = 1.2, epsilon             # <<<<<<<<<<<<<<
 *         double total_docs, term_frequency, docs_with_term
 *         double doc_length = 0.0, avg_length = 0.0
 */
  __pyx_v_B = 0.75;
  __pyx_v_K = 1.2;

  /* "playhouse/_sqlite_ext.pyx":919
 *         double B = 0.75, K = 1.2, epsilon
 *         double total_docs, term_frequency, docs_with_term
 *         double doc_length = 0.0, avg_length = 0.0             # <<<<<<<<<<<<<<
 *         double idf, weight, ratio, num, b_part, denom, pc_score
 *         double *weights
 */
  __pyx_v_doc_length = 0.0;
  __pyx_v_avg_length = 0.0;

  /* "playhouse/_sqlite_ext.pyx":922
 *         double idf, weight, ratio, num, b_part, denom, pc_score
 *         double *weights
 *         int P_O = 0, C_O = 1, N_O = 2, A_O = 3, L_O, X_O             # <<<<<<<<<<<<<<
 *         int iphrase, icol, x
 *         double score = 0.0
 */
  __pyx_v_P_O = 0;
  __pyx_v_C_O = 1;
  __pyx_v_N_O = 2;
  __pyx_v_A_O = 3;

  /* "playhouse/_sqlite_ext.pyx":924
 *         int P_O = 0, C_O = 1, N_O = 2, A_O = 3, L_O, X_O
 *         int iphrase, icol, x
 *         double score = 0.0             # <<<<<<<<<<<<<<
 * 
 *     match_info = <unsigned int *>match_info_buf
 */
  __pyx_v_score = 0.0;

  /* "playhouse/_sqlite_ext.pyx":926
 *         double score = 0.0
 * 
 *     match_info = <unsigned int *>match_info_buf             # <<<<<<<<<<<<<<
 *     nphrase = match_info[P_O]  # n
 *     ncol = match_info[C_O]
 */
  __pyx_v_match_info = ((unsigned int *)__pyx_v_match_info_buf);

  /* "playhouse/_sqlite_ext.pyx":927
 * 
 *     match_info = <unsigned int *>match_info_buf
 *     nphrase = match_info[P_O]  # n             # <<<<<<<<<<<<<<
 *     ncol = match_info[C_O]
 *     total_docs = match_info[N_O]  # N
 */
  __pyx_v_nphrase = (__pyx_v_match_info[__pyx_v_P_O]);

  /* "playhouse/_sqlite_ext.pyx":928
 *     match_info = <unsigned int *>match_info_buf
 *     nphrase = match_info[P_O]  # n
 *     ncol = match_info[C_O]             # <<<<<<<<<<<<<<
 *     total_docs = match_info[N_O]  # N
 * 
 */
  __pyx_v_ncol = (__pyx_v_match_info[__pyx_v_C_O]);

  /* "playhouse/_sqlite_ext.pyx":929
 *     nphrase = match_info[P_O]  # n
 *     ncol = match_info[C_O]
 *     total_docs = match_info[N_O]  # N             # <<<<<<<<<<<<<<
 * 
 *     L_O = A_O + ncol
 */
  __pyx_v_total_docs = (__pyx_v_match_info[__pyx_v_N_O]);

  /* "playhouse/_sqlite_ext.pyx":931
 *     total_docs = match_info[N_O]  # N
 * 
 *     L_O = A_O + ncol             # <<<<<<<<<<<<<<
 *     X_O = L_O + ncol
 * 
 */
  __pyx_v_L_O = (__pyx_v_A_O + __pyx_v_ncol);

  /* "playhouse/_sqlite_ext.pyx":932
 * 
 *     L_O = A_O + ncol
 *     X_O = L_O + ncol             # <<<<<<<<<<<<<<
 * 
 *     for icol in range(ncol):
 */
  __pyx_v_X_O = (__pyx_v_L_O + __pyx_v_ncol);

  /* "playhouse/_sqlite_ext.pyx":934
 *     X_O = L_O + ncol
 * 
 *     for icol in range(ncol):             # <<<<<<<<<<<<<<
 *         avg_length += match_info[A_O + icol]
 *         doc_length += match_info[L_O + icol]
 */
  __pyx_t_3 = __pyx_v_ncol;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_icol = __pyx_t_5;

    /* "playhouse/_sqlite_ext.pyx":935
 * 
 *     for icol in range(ncol):
 *         avg_length += match_info[A_O + icol]             # <<<<<<<<<<<<<<
 *         doc_length += match_info[L_O + icol]
 * 
 */
    __pyx_v_avg_length = (__pyx_v_avg_length + (__pyx_v_match_info[(__pyx_v_A_O + __pyx_v_icol)]));

    /* "playhouse/_sqlite_ext.pyx":936
 *     for icol in range(ncol):
 *         avg_length += match_info[A_O + icol]
 *         doc_length += match_info[L_O + icol]             # <<<<<<<<<<<<<<
 * 
 *     epsilon = 1.0 / (total_docs * avg_length)
 */
    __pyx_v_doc_length = (__pyx_v_doc_length + (__pyx_v_match_info[(__pyx_v_L_O + __pyx_v_icol)]));
  }

  /* "playhouse/_sqlite_ext.pyx":938
 *         doc_length += match_info[L_O + icol]
 * 
 *     epsilon = 1.0 / (total_docs * avg_length)             # <<<<<<<<<<<<<<
 *     if avg_length == 0:
 *         avg_length = 1
 */
  __pyx_t_6 = (__pyx_v_total_docs * __pyx_v_avg_length);
  if (unlikely(__pyx_t_6 == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 938, __pyx_L1_error)
  }
  __pyx_v_epsilon = (1.0 / __pyx_t_6);

  /* "playhouse/_sqlite_ext.pyx":939
 * 
 *     epsilon = 1.0 / (total_docs * avg_length)
 *     if avg_length == 0:             # <<<<<<<<<<<<<<
 *         avg_length = 1
 *     ratio = doc_length / avg_length
 */
  __pyx_t_7 = (__pyx_v_avg_length == 0.0);
  if (__pyx_t_7) {

    /* "playhouse/_sqlite_ext.pyx":940
 *     epsilon = 1.0 / (total_docs * avg_length)
 *     if avg_length == 0:
 *         avg_length = 1             # <<<<<<<<<<<<<<
 *     ratio = doc_length / avg_length
 *     weights = get_weights(ncol, raw_weights)
 */
    __pyx_v_avg_length = 1.0;

    /* "playhouse/_sqlite_ext.pyx":939
 * 
 *     epsilon = 1.0 / (total_docs * avg_length)
 *     if avg_length == 0:             # <<<<<<<<<<<<<<
 *         avg_length = 1
 *     ratio = doc_length / avg_length
 */
  }

  /* "playhouse/_sqlite_ext.pyx":941
 *     if avg_length == 0:
 *         avg_length = 1
 *     ratio = doc_length / avg_length             # <<<<<<<<<<<<<<
 *     weights = get_weights(ncol, raw_weights)
 * 
 */
  if (unlikely(__pyx_v_avg_length == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 941, __pyx_L1_error)
  }
  __pyx_v_ratio = (__pyx_v_doc_length / __pyx_v_avg_length);

  /* "playhouse/_sqlite_ext.pyx":942
 *         avg_length = 1
 *     ratio = doc_length / avg_length
 *     weights = get_weights(ncol, raw_weights)             # <<<<<<<<<<<<<<
 * 
 *     for iphrase in range(nphrase):
 */
  __pyx_t_8 = __pyx_f_9playhouse_11_sqlite_ext_get_weights(__pyx_v_ncol, __pyx_v_raw_weights); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 942, __pyx_L1_error)
  __pyx_v_weights = __pyx_t_8;

  /* "playhouse/_sqlite_ext.pyx":944
 *     weights = get_weights(ncol, raw_weights)
 * 
 *     for iphrase in range(nphrase):             # <<<<<<<<<<<<<<
 *         for icol in range(ncol):
 *             weight = weights[icol]
 */
  __pyx_t_3 = __pyx_v_nphrase;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_iphrase = __pyx_t_5;

    /* "playhouse/_sqlite_ext.pyx":945
 * 
 *     for iphrase in range(nphrase):
 *         for icol in range(ncol):             # <<<<<<<<<<<<<<
 *             weight = weights[icol]
 *             if weight == 0:
 */
    __pyx_t_9 = __pyx_v_ncol;
    __pyx_t_10 = __pyx_t_9;
    for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
      __pyx_v_icol = __pyx_t_11;

      /* "playhouse/_sqlite_ext.pyx":946
 *     for iphrase in range(nphrase):
 *         for icol in range(ncol):
 *             weight = weights[icol]             # <<<<<<<<<<<<<<
 *             if weight == 0:
 *                 continue
 */
      __pyx_v_weight = (__pyx_v_weights[__pyx_v_icol]);

      /* "playhouse/_sqlite_ext.pyx":947
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      __pyx_t_7 = (__pyx_v_weight == 0.0);
      if (__pyx_t_7) {

        /* "playhouse/_sqlite_ext.pyx":948
 *             weight = weights[icol]
 *             if weight == 0:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             x = X_O + (3 * (icol + iphrase * ncol))
 */
        goto __pyx_L8_continue;

        /* "playhouse/_sqlite_ext.pyx":947
 *         for icol in range(ncol):
 *             weight = weights[icol]
 *             if weight == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      }

      /* "playhouse/_sqlite_ext.pyx":950
 *                 continue
 * 
 *             x = X_O + (3 * (icol + iphrase * ncol))             # <<<<<<<<<<<<<<
 *             term_frequency = match_info[x]  # f(qi, D)
 *             docs_with_term = match_info[x + 2]  # n(qi)
 */
      __pyx_v_x = (__pyx_v_X_O + (3 * (__pyx_v_icol + (__pyx_v_iphrase * __pyx_v_ncol))));

      /* "playhouse/_sqlite_ext.pyx":951
 * 
 *             x = X_O + (3 * (icol + iphrase * ncol))
 *             term_frequency = match_info[x]  # f(qi, D)             # <<<<<<<<<<<<<<
 *             docs_with_term = match_info[x + 2]  # n(qi)
 * 
 */
      __pyx_v_term_frequency = (__pyx_v_match_info[__pyx_v_x]);

      /* "playhouse/_sqlite_ext.pyx":952
 *             x = X_O + (3 * (icol + iphrase * ncol))
 *             term_frequency = match_info[x]  # f(qi, D)
 *             docs_with_term = match_info[x + 2]  # n(qi)             # <<<<<<<<<<<<<<
 * 
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 */
      __pyx_v_docs_with_term = (__pyx_v_match_info[(__pyx_v_x + 2)]);

      /* "playhouse/_sqlite_ext.pyx":956
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 *             idf = log(
 *                 (total_docs - docs_with_term + 0.5) /             # <<<<<<<<<<<<<<
 *                 (docs_with_term + 0.5))
 *             idf = epsilon if idf <= 0 else idf
 */
      __pyx_t_6 = ((__pyx_v_total_docs - __pyx_v_docs_with_term) + 0.5);

      /* "playhouse/_sqlite_ext.pyx":957
 *             idf = log(
 *                 (total_docs - docs_with_term + 0.5) /
 *                 (docs_with_term + 0.5))             # <<<<<<<<<<<<<<
 *             idf = epsilon if idf <= 0 else idf
 * 
 */
      __pyx_t_12 = (__pyx_v_docs_with_term + 0.5);

      /* "playhouse/_sqlite_ext.pyx":956
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 *             idf = log(
 *                 (total_docs - docs_with_term + 0.5) /             # <<<<<<<<<<<<<<
 *                 (docs_with_term + 0.5))
 *             idf = epsilon if idf <= 0 else idf
 */
      if (unlikely(__pyx_t_12 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 956, __pyx_L1_error)
      }

      /* "playhouse/_sqlite_ext.pyx":955
 * 
 *             # log( (N - n(qi) + 0.5) / (n(qi) + 0.5) )
 *             idf = log(             # <<<<<<<<<<<<<<
 *                 (total_docs - docs_with_term + 0.5) /
 *                 (docs_with_term + 0.5))
 */
      __pyx_v_idf = log((__pyx_t_6 / __pyx_t_12));

      /* "playhouse/_sqlite_ext.pyx":958
 *                 (total_docs - docs_with_term + 0.5) /
 *                 (docs_with_term + 0.5))
 *             idf = epsilon if idf <= 0 else idf             # <<<<<<<<<<<<<<
 * 
 *             num = term_frequency * (K + 1)
 */
      if ((__pyx_v_idf <= 0.0)) {
        __pyx_t_12 = __pyx_v_epsilon;
      } else {
        __pyx_t_12 = __pyx_v_idf;
      }
      __pyx_v_idf = __pyx_t_12;

      /* "playhouse/_sqlite_ext.pyx":960
 *             idf = epsilon if idf <= 0 else idf
 * 
 *             num = term_frequency * (K + 1)             # <<<<<<<<<<<<<<
 *             b_part = 1 - B + (B * ratio)
 *             denom = term_frequency + (K * b_part)
 */
      __pyx_v_num = (__pyx_v_term_frequency * (__pyx_v_K + 1.0));

      /* "playhouse/_sqlite_ext.pyx":961
 * 
 *             num = term_frequency * (K + 1)
 *             b_part = 1 - B + (B * ratio)             # <<<<<<<<<<<<<<
 *             denom = term_frequency + (K * b_part)
 * 
 */
      __pyx_v_b_part = ((1.0 - __pyx_v_B) + (__pyx_v_B * __pyx_v_ratio));

      /* "playhouse/_sqlite_ext.pyx":962
 *             num = term_frequency * (K + 1)
 *             b_part = 1 - B + (B * ratio)
 *             denom = term_frequency + (K * b_part)             # <<<<<<<<<<<<<<
 * 
 *             pc_score = idf * ((num / denom) + 1.)
 */
      __pyx_v_denom = (__pyx_v_term_frequency + (__pyx_v_K * __pyx_v_b_part));

      /* "playhouse/_sqlite_ext.pyx":964
 *             denom = term_frequency + (K * b_part)
 * 
 *             pc_score = idf * ((num / denom) + 1.)             # <<<<<<<<<<<<<<
 *             score += (pc_score * weight)
 * 
 */
      if (unlikely(__pyx_v_denom == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 964, __pyx_L1_error)
      }
      __pyx_v_pc_score = (__pyx_v_idf * ((__pyx_v_num / __pyx_v_denom) + 1.));

      /* "playhouse/_sqlite_ext.pyx":965
 * 
 *             pc_score = idf * ((num / denom) + 1.)
 *             score += (pc_score * weight)             # <<<<<<<<<<<<<<
 * 
 *     free(weights)
 */
      __pyx_v_score = (__pyx_v_score + (__pyx_v_pc_score * __pyx_v_weight));
      __pyx_L8_continue:;
    }
  }

  /* "playhouse/_sqlite_ext.pyx":967
 *             score += (pc_score * weight)
 * 
 *     free(weights)             # <<<<<<<<<<<<<<
 *     return -1 * score
 * 
 */
  free(__pyx_v_weights);

  /* "playhouse/_sqlite_ext.pyx":968
 * 
 *     free(weights)
 *     return -1 * score             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((-1.0 * __pyx_v_score)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":908
 * 
 * 
 * def peewee_bm25f(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25f(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bm25f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__match_info_buf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":971
 * 
 * 
 * cdef uint32_t murmurhash2(const unsigned char *key, ssize_t nlen,             # <<<<<<<<<<<<<<
 *                           uint32_t seed):
 *     cdef:
 */

static uint32_t __pyx_f_9playhouse_11_sqlite_ext_murmurhash2(unsigned char const *__pyx_v_key, Py_ssize_t __pyx_v_nlen, uint32_t __pyx_v_seed) {
  uint32_t __pyx_v_m;
  int __pyx_v_r;
  unsigned char const *__pyx_v_data;
  uint32_t __pyx_v_h;
  uint32_t __pyx_v_k;
  uint32_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("murmurhash2", 0);

  /* "playhouse/_sqlite_ext.pyx":974
 *                           uint32_t seed):
 *     cdef:
 *         uint32_t m = 0x5bd1e995             # <<<<<<<<<<<<<<
 *         int r = 24
 *         const unsigned char *data = key
 */
  __pyx_v_m = 0x5bd1e995;

  /* "playhouse/_sqlite_ext.pyx":975
 *     cdef:
 *         uint32_t m = 0x5bd1e995
 *         int r = 24             # <<<<<<<<<<<<<<
 *         const unsigned char *data = key
 *         uint32_t h = seed ^ nlen
 */
  __pyx_v_r = 24;

  /* "playhouse/_sqlite_ext.pyx":976
 *         uint32_t m = 0x5bd1e995
 *         int r = 24
 *         const unsigned char *data = key             # <<<<<<<<<<<<<<
 *         uint32_t h = seed ^ nlen
 *         uint32_t k
 */
  __pyx_v_data = __pyx_v_key;

  /* "playhouse/_sqlite_ext.pyx":977
 *         int r = 24
 *         const unsigned char *data = key
 *         uint32_t h = seed ^ nlen             # <<<<<<<<<<<<<<
 *         uint32_t k
 * 
 */
  __pyx_v_h = (__pyx_v_seed ^ __pyx_v_nlen);

  /* "playhouse/_sqlite_ext.pyx":980
 *         uint32_t k
 * 
 *     while nlen >= 4:             # <<<<<<<<<<<<<<
 *         k = <uint32_t>((<uint32_t *>data)[0])
 * 
 */
  while (1) {
    __pyx_t_1 = (__pyx_v_nlen >= 4);
    if (!__pyx_t_1) break;

    /* "playhouse/_sqlite_ext.pyx":981
 * 
 *     while nlen >= 4:
 *         k = <uint32_t>((<uint32_t *>data)[0])             # <<<<<<<<<<<<<<
 * 
 *         k *= m
 */
    __pyx_v_k = ((uint32_t)(((uint32_t *)__pyx_v_data)[0]));

    /* "playhouse/_sqlite_ext.pyx":983
 *         k = <uint32_t>((<uint32_t *>data)[0])
 * 
 *         k *= m             # <<<<<<<<<<<<<<
 *         k = k ^ (k >> r)
 *         k *= m
 */
    __pyx_v_k = (__pyx_v_k * __pyx_v_m);

    /* "playhouse/_sqlite_ext.pyx":984
 * 
 *         k *= m
 *         k = k ^ (k >> r)             # <<<<<<<<<<<<<<
 *         k *= m
 * 
 */
    __pyx_v_k = (__pyx_v_k ^ (__pyx_v_k >> __pyx_v_r));

    /* "playhouse/_sqlite_ext.pyx":985
 *         k *= m
 *         k = k ^ (k >> r)
 *         k *= m             # <<<<<<<<<<<<<<
 * 
 *         h *= m
 */
    __pyx_v_k = (__pyx_v_k * __pyx_v_m);

    /* "playhouse/_sqlite_ext.pyx":987
 *         k *= m
 * 
 *         h *= m             # <<<<<<<<<<<<<<
 *         h = h ^ k
 * 
 */
    __pyx_v_h = (__pyx_v_h * __pyx_v_m);

    /* "playhouse/_sqlite_ext.pyx":988
 * 
 *         h *= m
 *         h = h ^ k             # <<<<<<<<<<<<<<
 * 
 *         data += 4
 */
    __pyx_v_h = (__pyx_v_h ^ __pyx_v_k);

    /* "playhouse/_sqlite_ext.pyx":990
 *         h = h ^ k
 * 
 *         data += 4             # <<<<<<<<<<<<<<
 *         nlen -= 4
 * 
 */
    __pyx_v_data = (__pyx_v_data + 4);

    /* "playhouse/_sqlite_ext.pyx":991
 * 
 *         data += 4
 *         nlen -= 4             # <<<<<<<<<<<<<<
 * 
 *     if nlen == 3:
 */
    __pyx_v_nlen = (__pyx_v_nlen - 4);
  }

  /* "playhouse/_sqlite_ext.pyx":993
 *         nlen -= 4
 * 
 *     if nlen == 3:             # <<<<<<<<<<<<<<
 *         h = h ^ (data[2] << 16)
 *     if nlen >= 2:
 */
  __pyx_t_1 = (__pyx_v_nlen == 3);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":994
 * 
 *     if nlen == 3:
 *         h = h ^ (data[2] << 16)             # <<<<<<<<<<<<<<
 *     if nlen >= 2:
 *         h = h ^ (data[1] << 8)
 */
    __pyx_v_h = (__pyx_v_h ^ ((__pyx_v_data[2]) << 16));

    /* "playhouse/_sqlite_ext.pyx":993
 *         nlen -= 4
 * 
 *     if nlen == 3:             # <<<<<<<<<<<<<<
 *         h = h ^ (data[2] << 16)
 *     if nlen >= 2:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":995
 *     if nlen == 3:
 *         h = h ^ (data[2] << 16)
 *     if nlen >= 2:             # <<<<<<<<<<<<<<
 *         h = h ^ (data[1] << 8)
 *     if nlen >= 1:
 */
  __pyx_t_1 = (__pyx_v_nlen >= 2);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":996
 *         h = h ^ (data[2] << 16)
 *     if nlen >= 2:
 *         h = h ^ (data[1] << 8)             # <<<<<<<<<<<<<<
 *     if nlen >= 1:
 *         h = h ^ (data[0])
 */
    __pyx_v_h = (__pyx_v_h ^ ((__pyx_v_data[1]) << 8));

    /* "playhouse/_sqlite_ext.pyx":995
 *     if nlen == 3:
 *         h = h ^ (data[2] << 16)
 *     if nlen >= 2:             # <<<<<<<<<<<<<<
 *         h = h ^ (data[1] << 8)
 *     if nlen >= 1:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":997
 *     if nlen >= 2:
 *         h = h ^ (data[1] << 8)
 *     if nlen >= 1:             # <<<<<<<<<<<<<<
 *         h = h ^ (data[0])
 *         h *= m
 */
  __pyx_t_1 = (__pyx_v_nlen >= 1);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":998
 *         h = h ^ (data[1] << 8)
 *     if nlen >= 1:
 *         h = h ^ (data[0])             # <<<<<<<<<<<<<<
 *         h *= m
 * 
 */
    __pyx_v_h = (__pyx_v_h ^ (__pyx_v_data[0]));

    /* "playhouse/_sqlite_ext.pyx":999
 *     if nlen >= 1:
 *         h = h ^ (data[0])
 *         h *= m             # <<<<<<<<<<<<<<
 * 
 *     h = h ^ (h >> 13)
 */
    __pyx_v_h = (__pyx_v_h * __pyx_v_m);

    /* "playhouse/_sqlite_ext.pyx":997
 *     if nlen >= 2:
 *         h = h ^ (data[1] << 8)
 *     if nlen >= 1:             # <<<<<<<<<<<<<<
 *         h = h ^ (data[0])
 *         h *= m
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1001
 *         h *= m
 * 
 *     h = h ^ (h >> 13)             # <<<<<<<<<<<<<<
 *     h *= m
 *     h = h ^ (h >> 15)
 */
  __pyx_v_h = (__pyx_v_h ^ (__pyx_v_h >> 13));

  /* "playhouse/_sqlite_ext.pyx":1002
 * 
 *     h = h ^ (h >> 13)
 *     h *= m             # <<<<<<<<<<<<<<
 *     h = h ^ (h >> 15)
 *     return h
 */
  __pyx_v_h = (__pyx_v_h * __pyx_v_m);

  /* "playhouse/_sqlite_ext.pyx":1003
 *     h = h ^ (h >> 13)
 *     h *= m
 *     h = h ^ (h >> 15)             # <<<<<<<<<<<<<<
 *     return h
 * 
 */
  __pyx_v_h = (__pyx_v_h ^ (__pyx_v_h >> 15));

  /* "playhouse/_sqlite_ext.pyx":1004
 *     h *= m
 *     h = h ^ (h >> 15)
 *     return h             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_h;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":971
 * 
 * 
 * cdef uint32_t murmurhash2(const unsigned char *key, ssize_t nlen,             # <<<<<<<<<<<<<<
 *                           uint32_t seed):
 *     cdef:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1007
 * 
 * 
 * def peewee_murmurhash(key, seed=None):             # <<<<<<<<<<<<<<
 *     if key is None:
 *         return
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_9peewee_murmurhash(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_9peewee_murmurhash = {"peewee_murmurhash", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_9peewee_murmurhash, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_9peewee_murmurhash(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_seed = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_murmurhash (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_seed,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1007, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_seed);
          if (value) { values[1] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1007, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "peewee_murmurhash") < 0)) __PYX_ERR(0, 1007, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_key = values[0];
    __pyx_v_seed = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_murmurhash", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1007, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_murmurhash", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_8peewee_murmurhash(__pyx_self, __pyx_v_key, __pyx_v_seed);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_8peewee_murmurhash(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_seed) {
  PyObject *__pyx_v_bkey = 0;
  int __pyx_v_nseed;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  unsigned char *__pyx_t_5;
  Py_ssize_t __pyx_t_6;
  uint32_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_murmurhash", 0);

  /* "playhouse/_sqlite_ext.pyx":1008
 * 
 * def peewee_murmurhash(key, seed=None):
 *     if key is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = (__pyx_v_key == Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1009
 * def peewee_murmurhash(key, seed=None):
 *     if key is None:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1008
 * 
 * def peewee_murmurhash(key, seed=None):
 *     if key is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1012
 * 
 *     cdef:
 *         bytes bkey = encode(key)             # <<<<<<<<<<<<<<
 *         int nseed = seed or 0
 * 
 */
  __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_bkey = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1013
 *     cdef:
 *         bytes bkey = encode(key)
 *         int nseed = seed or 0             # <<<<<<<<<<<<<<
 * 
 *     if key:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_seed); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1013, __pyx_L1_error)
  if (!__pyx_t_1) {
  } else {
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_seed); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1013, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = 0;
  __pyx_L4_bool_binop_done:;
  __pyx_v_nseed = __pyx_t_3;

  /* "playhouse/_sqlite_ext.pyx":1015
 *         int nseed = seed or 0
 * 
 *     if key:             # <<<<<<<<<<<<<<
 *         return murmurhash2(<unsigned char *>bkey, len(bkey), nseed)
 *     return 0
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_key); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1015, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1016
 * 
 *     if key:
 *         return murmurhash2(<unsigned char *>bkey, len(bkey), nseed)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_bkey == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 1016, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyBytes_AsWritableUString(__pyx_v_bkey); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) __PYX_ERR(0, 1016, __pyx_L1_error)
    if (unlikely(__pyx_v_bkey == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 1016, __pyx_L1_error)
    }
    __pyx_t_6 = PyBytes_GET_SIZE(__pyx_v_bkey); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1016, __pyx_L1_error)
    __pyx_t_7 = __pyx_f_9playhouse_11_sqlite_ext_murmurhash2(((unsigned char *)__pyx_t_5), __pyx_t_6, __pyx_v_nseed); if (unlikely(__pyx_t_7 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1016, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyInt_From_uint32_t(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1015
 *         int nseed = seed or 0
 * 
 *     if key:             # <<<<<<<<<<<<<<
 *         return murmurhash2(<unsigned char *>bkey, len(bkey), nseed)
 *     return 0
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1017
 *     if key:
 *         return murmurhash2(<unsigned char *>bkey, len(bkey), nseed)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_int_0);
  __pyx_r = __pyx_int_0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1007
 * 
 * 
 * def peewee_murmurhash(key, seed=None):             # <<<<<<<<<<<<<<
 *     if key is None:
 *         return
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_murmurhash", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bkey);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1020
 * 
 * 
 * def make_hash(hash_impl):             # <<<<<<<<<<<<<<
 *     def inner(*items):
 *         state = hash_impl()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11make_hash(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_11make_hash = {"make_hash", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11make_hash, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11make_hash(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_hash_impl = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_hash (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_hash_impl,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_hash_impl)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1020, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "make_hash") < 0)) __PYX_ERR(0, 1020, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_hash_impl = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_hash", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1020, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.make_hash", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_10make_hash(__pyx_self, __pyx_v_hash_impl);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1021
 * 
 * def make_hash(hash_impl):
 *     def inner(*items):             # <<<<<<<<<<<<<<
 *         state = hash_impl()
 *         for item in items:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_9make_hash_1inner(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_9make_hash_1inner = {"inner", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_9make_hash_1inner, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_9make_hash_1inner(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_items = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inner (wrapper)", 0);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inner", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_items = __pyx_args;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_9make_hash_inner(__pyx_self, __pyx_v_items);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_items);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_9make_hash_inner(PyObject *__pyx_self, PyObject *__pyx_v_items) {
  struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *__pyx_cur_scope;
  struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *__pyx_outer_scope;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inner", 0);
  __pyx_outer_scope = (struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "playhouse/_sqlite_ext.pyx":1022
 * def make_hash(hash_impl):
 *     def inner(*items):
 *         state = hash_impl()             # <<<<<<<<<<<<<<
 *         for item in items:
 *             state.update(encode(item))
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_hash_impl)) { __Pyx_RaiseClosureNameError("hash_impl"); __PYX_ERR(0, 1022, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_hash_impl);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_hash_impl; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_3, };
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1022, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_state = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1023
 *     def inner(*items):
 *         state = hash_impl()
 *         for item in items:             # <<<<<<<<<<<<<<
 *             state.update(encode(item))
 *         return state.hexdigest()
 */
  __pyx_t_1 = __pyx_v_items; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
  for (;;) {
    if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 1023, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1023, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":1024
 *         state = hash_impl()
 *         for item in items:
 *             state.update(encode(item))             # <<<<<<<<<<<<<<
 *         return state.hexdigest()
 *     return inner
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_update); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_item); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1024, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":1023
 *     def inner(*items):
 *         state = hash_impl()
 *         for item in items:             # <<<<<<<<<<<<<<
 *             state.update(encode(item))
 *         return state.hexdigest()
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1025
 *         for item in items:
 *             state.update(encode(item))
 *         return state.hexdigest()             # <<<<<<<<<<<<<<
 *     return inner
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_hexdigest); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_3, };
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1025, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1021
 * 
 * def make_hash(hash_impl):
 *     def inner(*items):             # <<<<<<<<<<<<<<
 *         state = hash_impl()
 *         for item in items:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("playhouse._sqlite_ext.make_hash.inner", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1020
 * 
 * 
 * def make_hash(hash_impl):             # <<<<<<<<<<<<<<
 *     def inner(*items):
 *         state = hash_impl()
 */

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_10make_hash(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_hash_impl) {
  struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *__pyx_cur_scope;
  PyObject *__pyx_v_inner = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_hash", 0);
  __pyx_cur_scope = (struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *)__pyx_tp_new_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash(__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1020, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_hash_impl = __pyx_v_hash_impl;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_hash_impl);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_hash_impl);

  /* "playhouse/_sqlite_ext.pyx":1021
 * 
 * def make_hash(hash_impl):
 *     def inner(*items):             # <<<<<<<<<<<<<<
 *         state = hash_impl()
 *         for item in items:
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_9make_hash_1inner, 0, __pyx_n_s_make_hash_locals_inner, ((PyObject*)__pyx_cur_scope), __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__6)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_inner = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1026
 *             state.update(encode(item))
 *         return state.hexdigest()
 *     return inner             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_inner);
  __pyx_r = __pyx_v_inner;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1020
 * 
 * 
 * def make_hash(hash_impl):             # <<<<<<<<<<<<<<
 *     def inner(*items):
 *         state = hash_impl()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.make_hash", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_inner);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1034
 * 
 * 
 * def _register_functions(database, pairs):             # <<<<<<<<<<<<<<
 *     for func, name in pairs:
 *         database.register_function(func, name)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13_register_functions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_13_register_functions = {"_register_functions", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_13_register_functions, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_13_register_functions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_database = 0;
  PyObject *__pyx_v_pairs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_register_functions (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_database,&__pyx_n_s_pairs,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_database)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1034, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pairs)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1034, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_register_functions", 1, 2, 2, 1); __PYX_ERR(0, 1034, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_register_functions") < 0)) __PYX_ERR(0, 1034, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_database = values[0];
    __pyx_v_pairs = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_register_functions", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1034, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext._register_functions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_12_register_functions(__pyx_self, __pyx_v_database, __pyx_v_pairs);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_12_register_functions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database, PyObject *__pyx_v_pairs) {
  PyObject *__pyx_v_func = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_register_functions", 0);

  /* "playhouse/_sqlite_ext.pyx":1035
 * 
 * def _register_functions(database, pairs):
 *     for func, name in pairs:             # <<<<<<<<<<<<<<
 *         database.register_function(func, name)
 * 
 */
  if (likely(PyList_CheckExact(__pyx_v_pairs)) || PyTuple_CheckExact(__pyx_v_pairs)) {
    __pyx_t_1 = __pyx_v_pairs; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_pairs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1035, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1035, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1035, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1035, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1035, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1035, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 1035, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1035, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_func, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "playhouse/_sqlite_ext.pyx":1036
 * def _register_functions(database, pairs):
 *     for func, name in pairs:
 *         database.register_function(func, name)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_database, __pyx_n_s_register_function); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_9 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_func, __pyx_v_name};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 2+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1036, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "playhouse/_sqlite_ext.pyx":1035
 * 
 * def _register_functions(database, pairs):
 *     for func, name in pairs:             # <<<<<<<<<<<<<<
 *         database.register_function(func, name)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1034
 * 
 * 
 * def _register_functions(database, pairs):             # <<<<<<<<<<<<<<
 *     for func, name in pairs:
 *         database.register_function(func, name)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("playhouse._sqlite_ext._register_functions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_func);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1039
 * 
 * 
 * def register_hash_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_murmurhash, 'murmurhash'),
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_15register_hash_functions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_15register_hash_functions = {"register_hash_functions", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_15register_hash_functions, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_15register_hash_functions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_database = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("register_hash_functions (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_database,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_database)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1039, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "register_hash_functions") < 0)) __PYX_ERR(0, 1039, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_database = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("register_hash_functions", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1039, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.register_hash_functions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_14register_hash_functions(__pyx_self, __pyx_v_database);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_14register_hash_functions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("register_hash_functions", 0);

  /* "playhouse/_sqlite_ext.pyx":1040
 * 
 * def register_hash_functions(database):
 *     _register_functions(database, (             # <<<<<<<<<<<<<<
 *         (peewee_murmurhash, 'murmurhash'),
 *         (peewee_md5, 'md5'),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_register_functions); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "playhouse/_sqlite_ext.pyx":1041
 * def register_hash_functions(database):
 *     _register_functions(database, (
 *         (peewee_murmurhash, 'murmurhash'),             # <<<<<<<<<<<<<<
 *         (peewee_md5, 'md5'),
 *         (peewee_sha1, 'sha1'),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_murmurhash); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_murmurhash);
  __Pyx_GIVEREF(__pyx_n_u_murmurhash);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_n_u_murmurhash);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1042
 *     _register_functions(database, (
 *         (peewee_murmurhash, 'murmurhash'),
 *         (peewee_md5, 'md5'),             # <<<<<<<<<<<<<<
 *         (peewee_sha1, 'sha1'),
 *         (peewee_sha256, 'sha256'),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_md5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_md5);
  __Pyx_GIVEREF(__pyx_n_u_md5);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_n_u_md5);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1043
 *         (peewee_murmurhash, 'murmurhash'),
 *         (peewee_md5, 'md5'),
 *         (peewee_sha1, 'sha1'),             # <<<<<<<<<<<<<<
 *         (peewee_sha256, 'sha256'),
 *         (zlib.adler32, 'adler32'),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_sha1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_sha1);
  __Pyx_GIVEREF(__pyx_n_u_sha1);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_sha1);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1044
 *         (peewee_md5, 'md5'),
 *         (peewee_sha1, 'sha1'),
 *         (peewee_sha256, 'sha256'),             # <<<<<<<<<<<<<<
 *         (zlib.adler32, 'adler32'),
 *         (zlib.crc32, 'crc32')))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_sha256); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_sha256);
  __Pyx_GIVEREF(__pyx_n_u_sha256);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_n_u_sha256);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1045
 *         (peewee_sha1, 'sha1'),
 *         (peewee_sha256, 'sha256'),
 *         (zlib.adler32, 'adler32'),             # <<<<<<<<<<<<<<
 *         (zlib.crc32, 'crc32')))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_zlib); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_adler32); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8);
  __Pyx_INCREF(__pyx_n_u_adler32);
  __Pyx_GIVEREF(__pyx_n_u_adler32);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_adler32);
  __pyx_t_8 = 0;

  /* "playhouse/_sqlite_ext.pyx":1046
 *         (peewee_sha256, 'sha256'),
 *         (zlib.adler32, 'adler32'),
 *         (zlib.crc32, 'crc32')))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_zlib); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_crc32); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9);
  __Pyx_INCREF(__pyx_n_u_crc32);
  __Pyx_GIVEREF(__pyx_n_u_crc32);
  PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_n_u_crc32);
  __pyx_t_9 = 0;

  /* "playhouse/_sqlite_ext.pyx":1041
 * def register_hash_functions(database):
 *     _register_functions(database, (
 *         (peewee_murmurhash, 'murmurhash'),             # <<<<<<<<<<<<<<
 *         (peewee_md5, 'md5'),
 *         (peewee_sha1, 'sha1'),
 */
  __pyx_t_9 = PyTuple_New(6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_9, 5, __pyx_t_8);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_3 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_10 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_10 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_database, __pyx_t_9};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1039
 * 
 * 
 * def register_hash_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_murmurhash, 'murmurhash'),
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("playhouse._sqlite_ext.register_hash_functions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1049
 * 
 * 
 * def register_rank_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_bm25, 'fts_bm25'),
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_17register_rank_functions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_17register_rank_functions = {"register_rank_functions", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_17register_rank_functions, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_17register_rank_functions(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_database = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("register_rank_functions (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_database,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_database)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1049, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "register_rank_functions") < 0)) __PYX_ERR(0, 1049, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_database = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("register_rank_functions", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1049, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.register_rank_functions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16register_rank_functions(__pyx_self, __pyx_v_database);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16register_rank_functions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("register_rank_functions", 0);

  /* "playhouse/_sqlite_ext.pyx":1050
 * 
 * def register_rank_functions(database):
 *     _register_functions(database, (             # <<<<<<<<<<<<<<
 *         (peewee_bm25, 'fts_bm25'),
 *         (peewee_bm25f, 'fts_bm25f'),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_register_functions); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "playhouse/_sqlite_ext.pyx":1051
 * def register_rank_functions(database):
 *     _register_functions(database, (
 *         (peewee_bm25, 'fts_bm25'),             # <<<<<<<<<<<<<<
 *         (peewee_bm25f, 'fts_bm25f'),
 *         (peewee_lucene, 'fts_lucene'),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_bm25); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_fts_bm25);
  __Pyx_GIVEREF(__pyx_n_u_fts_bm25);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_n_u_fts_bm25);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1052
 *     _register_functions(database, (
 *         (peewee_bm25, 'fts_bm25'),
 *         (peewee_bm25f, 'fts_bm25f'),             # <<<<<<<<<<<<<<
 *         (peewee_lucene, 'fts_lucene'),
 *         (peewee_rank, 'fts_rank')))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_bm25f); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_fts_bm25f);
  __Pyx_GIVEREF(__pyx_n_u_fts_bm25f);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_n_u_fts_bm25f);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1053
 *         (peewee_bm25, 'fts_bm25'),
 *         (peewee_bm25f, 'fts_bm25f'),
 *         (peewee_lucene, 'fts_lucene'),             # <<<<<<<<<<<<<<
 *         (peewee_rank, 'fts_rank')))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_lucene); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_fts_lucene);
  __Pyx_GIVEREF(__pyx_n_u_fts_lucene);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_fts_lucene);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1054
 *         (peewee_bm25f, 'fts_bm25f'),
 *         (peewee_lucene, 'fts_lucene'),
 *         (peewee_rank, 'fts_rank')))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_rank); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_fts_rank);
  __Pyx_GIVEREF(__pyx_n_u_fts_rank);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_n_u_fts_rank);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1051
 * def register_rank_functions(database):
 *     _register_functions(database, (
 *         (peewee_bm25, 'fts_bm25'),             # <<<<<<<<<<<<<<
 *         (peewee_bm25f, 'fts_bm25f'),
 *         (peewee_lucene, 'fts_lucene'),
 */
  __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_7);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_8 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_database, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1050, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1049
 * 
 * 
 * def register_rank_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_bm25, 'fts_bm25'),
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("playhouse._sqlite_ext.register_rank_functions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1065
 * 
 * 
 * cdef bf_t *bf_create(size_t size):             # <<<<<<<<<<<<<<
 *     cdef bf_t *bf = <bf_t *>calloc(1, sizeof(bf_t))
 *     bf.size = size
 */

static __pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_f_9playhouse_11_sqlite_ext_bf_create(size_t __pyx_v_size) {
  __pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_v_bf;
  __pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bf_create", 0);

  /* "playhouse/_sqlite_ext.pyx":1066
 * 
 * cdef bf_t *bf_create(size_t size):
 *     cdef bf_t *bf = <bf_t *>calloc(1, sizeof(bf_t))             # <<<<<<<<<<<<<<
 *     bf.size = size
 *     bf.bits = calloc(1, size)
 */
  __pyx_v_bf = ((__pyx_t_9playhouse_11_sqlite_ext_bf_t *)calloc(1, (sizeof(__pyx_t_9playhouse_11_sqlite_ext_bf_t))));

  /* "playhouse/_sqlite_ext.pyx":1067
 * cdef bf_t *bf_create(size_t size):
 *     cdef bf_t *bf = <bf_t *>calloc(1, sizeof(bf_t))
 *     bf.size = size             # <<<<<<<<<<<<<<
 *     bf.bits = calloc(1, size)
 *     return bf
 */
  __pyx_v_bf->size = __pyx_v_size;

  /* "playhouse/_sqlite_ext.pyx":1068
 *     cdef bf_t *bf = <bf_t *>calloc(1, sizeof(bf_t))
 *     bf.size = size
 *     bf.bits = calloc(1, size)             # <<<<<<<<<<<<<<
 *     return bf
 * 
 */
  __pyx_v_bf->bits = calloc(1, __pyx_v_size);

  /* "playhouse/_sqlite_ext.pyx":1069
 *     bf.size = size
 *     bf.bits = calloc(1, size)
 *     return bf             # <<<<<<<<<<<<<<
 * 
 * @cython.cdivision(True)
 */
  __pyx_r = __pyx_v_bf;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1065
 * 
 * 
 * cdef bf_t *bf_create(size_t size):             # <<<<<<<<<<<<<<
 *     cdef bf_t *bf = <bf_t *>calloc(1, sizeof(bf_t))
 *     bf.size = size
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1072
 * 
 * @cython.cdivision(True)
 * cdef uint32_t bf_bitindex(bf_t *bf, unsigned char *key, size_t klen, int seed):             # <<<<<<<<<<<<<<
 *     cdef:
 *         uint32_t h = murmurhash2(key, klen, seed)
 */

static uint32_t __pyx_f_9playhouse_11_sqlite_ext_bf_bitindex(__pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_v_bf, unsigned char *__pyx_v_key, size_t __pyx_v_klen, int __pyx_v_seed) {
  uint32_t __pyx_v_h;
  uint32_t __pyx_r;
  __Pyx_RefNannyDeclarations
  uint32_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bf_bitindex", 0);

  /* "playhouse/_sqlite_ext.pyx":1074
 * cdef uint32_t bf_bitindex(bf_t *bf, unsigned char *key, size_t klen, int seed):
 *     cdef:
 *         uint32_t h = murmurhash2(key, klen, seed)             # <<<<<<<<<<<<<<
 *     return h % (bf.size * 8)
 * 
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext_murmurhash2(__pyx_v_key, __pyx_v_klen, __pyx_v_seed); if (unlikely(__pyx_t_1 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1074, __pyx_L1_error)
  __pyx_v_h = __pyx_t_1;

  /* "playhouse/_sqlite_ext.pyx":1075
 *     cdef:
 *         uint32_t h = murmurhash2(key, klen, seed)
 *     return h % (bf.size * 8)             # <<<<<<<<<<<<<<
 * 
 * @cython.cdivision(True)
 */
  __pyx_r = (__pyx_v_h % (__pyx_v_bf->size * 8));
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1072
 * 
 * @cython.cdivision(True)
 * cdef uint32_t bf_bitindex(bf_t *bf, unsigned char *key, size_t klen, int seed):             # <<<<<<<<<<<<<<
 *     cdef:
 *         uint32_t h = murmurhash2(key, klen, seed)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.bf_bitindex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1078
 * 
 * @cython.cdivision(True)
 * cdef bf_add(bf_t *bf, unsigned char *key):             # <<<<<<<<<<<<<<
 *     cdef:
 *         uint8_t *bits = <uint8_t *>(bf.bits)
 */

static PyObject *__pyx_f_9playhouse_11_sqlite_ext_bf_add(__pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_v_bf, unsigned char *__pyx_v_key) {
  uint8_t *__pyx_v_bits;
  uint32_t __pyx_v_h;
  int __pyx_v_pos;
  int __pyx_v_seed;
  size_t __pyx_v_keylen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int *__pyx_t_1;
  int *__pyx_t_2;
  int *__pyx_t_3;
  uint32_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bf_add", 0);

  /* "playhouse/_sqlite_ext.pyx":1080
 * cdef bf_add(bf_t *bf, unsigned char *key):
 *     cdef:
 *         uint8_t *bits = <uint8_t *>(bf.bits)             # <<<<<<<<<<<<<<
 *         uint32_t h
 *         int pos, seed
 */
  __pyx_v_bits = ((uint8_t *)__pyx_v_bf->bits);

  /* "playhouse/_sqlite_ext.pyx":1083
 *         uint32_t h
 *         int pos, seed
 *         size_t keylen = strlen(<const char *>key)             # <<<<<<<<<<<<<<
 * 
 *     for seed in seeds:
 */
  __pyx_v_keylen = strlen(((char const *)__pyx_v_key));

  /* "playhouse/_sqlite_ext.pyx":1085
 *         size_t keylen = strlen(<const char *>key)
 * 
 *     for seed in seeds:             # <<<<<<<<<<<<<<
 *         h = bf_bitindex(bf, key, keylen, seed)
 *         pos = h / 8
 */
  __pyx_t_2 = (__pyx_v_9playhouse_11_sqlite_ext_seeds + 10);
  for (__pyx_t_3 = __pyx_v_9playhouse_11_sqlite_ext_seeds; __pyx_t_3 < __pyx_t_2; __pyx_t_3++) {
    __pyx_t_1 = __pyx_t_3;
    __pyx_v_seed = (__pyx_t_1[0]);

    /* "playhouse/_sqlite_ext.pyx":1086
 * 
 *     for seed in seeds:
 *         h = bf_bitindex(bf, key, keylen, seed)             # <<<<<<<<<<<<<<
 *         pos = h / 8
 *         bits[pos] = bits[pos] | (1 << (h % 8))
 */
    __pyx_t_4 = __pyx_f_9playhouse_11_sqlite_ext_bf_bitindex(__pyx_v_bf, __pyx_v_key, __pyx_v_keylen, __pyx_v_seed); if (unlikely(__pyx_t_4 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1086, __pyx_L1_error)
    __pyx_v_h = __pyx_t_4;

    /* "playhouse/_sqlite_ext.pyx":1087
 *     for seed in seeds:
 *         h = bf_bitindex(bf, key, keylen, seed)
 *         pos = h / 8             # <<<<<<<<<<<<<<
 *         bits[pos] = bits[pos] | (1 << (h % 8))
 * 
 */
    __pyx_v_pos = (((long)__pyx_v_h) / 8);

    /* "playhouse/_sqlite_ext.pyx":1088
 *         h = bf_bitindex(bf, key, keylen, seed)
 *         pos = h / 8
 *         bits[pos] = bits[pos] | (1 << (h % 8))             # <<<<<<<<<<<<<<
 * 
 * @cython.cdivision(True)
 */
    (__pyx_v_bits[__pyx_v_pos]) = ((__pyx_v_bits[__pyx_v_pos]) | (1 << (__pyx_v_h % 8)));
  }

  /* "playhouse/_sqlite_ext.pyx":1078
 * 
 * @cython.cdivision(True)
 * cdef bf_add(bf_t *bf, unsigned char *key):             # <<<<<<<<<<<<<<
 *     cdef:
 *         uint8_t *bits = <uint8_t *>(bf.bits)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.bf_add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1091
 * 
 * @cython.cdivision(True)
 * cdef int bf_contains(bf_t *bf, unsigned char *key):             # <<<<<<<<<<<<<<
 *     cdef:
 *         uint8_t *bits = <uint8_t *>(bf.bits)
 */

static int __pyx_f_9playhouse_11_sqlite_ext_bf_contains(__pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_v_bf, unsigned char *__pyx_v_key) {
  uint8_t *__pyx_v_bits;
  uint32_t __pyx_v_h;
  int __pyx_v_pos;
  int __pyx_v_seed;
  size_t __pyx_v_keylen;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int *__pyx_t_1;
  int *__pyx_t_2;
  int *__pyx_t_3;
  uint32_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bf_contains", 0);

  /* "playhouse/_sqlite_ext.pyx":1093
 * cdef int bf_contains(bf_t *bf, unsigned char *key):
 *     cdef:
 *         uint8_t *bits = <uint8_t *>(bf.bits)             # <<<<<<<<<<<<<<
 *         uint32_t h
 *         int pos, seed
 */
  __pyx_v_bits = ((uint8_t *)__pyx_v_bf->bits);

  /* "playhouse/_sqlite_ext.pyx":1096
 *         uint32_t h
 *         int pos, seed
 *         size_t keylen = strlen(<const char *>key)             # <<<<<<<<<<<<<<
 * 
 *     for seed in seeds:
 */
  __pyx_v_keylen = strlen(((char const *)__pyx_v_key));

  /* "playhouse/_sqlite_ext.pyx":1098
 *         size_t keylen = strlen(<const char *>key)
 * 
 *     for seed in seeds:             # <<<<<<<<<<<<<<
 *         h = bf_bitindex(bf, key, keylen, seed)
 *         pos = h / 8
 */
  __pyx_t_2 = (__pyx_v_9playhouse_11_sqlite_ext_seeds + 10);
  for (__pyx_t_3 = __pyx_v_9playhouse_11_sqlite_ext_seeds; __pyx_t_3 < __pyx_t_2; __pyx_t_3++) {
    __pyx_t_1 = __pyx_t_3;
    __pyx_v_seed = (__pyx_t_1[0]);

    /* "playhouse/_sqlite_ext.pyx":1099
 * 
 *     for seed in seeds:
 *         h = bf_bitindex(bf, key, keylen, seed)             # <<<<<<<<<<<<<<
 *         pos = h / 8
 *         if not (bits[pos] & (1 << (h % 8))):
 */
    __pyx_t_4 = __pyx_f_9playhouse_11_sqlite_ext_bf_bitindex(__pyx_v_bf, __pyx_v_key, __pyx_v_keylen, __pyx_v_seed); if (unlikely(__pyx_t_4 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1099, __pyx_L1_error)
    __pyx_v_h = __pyx_t_4;

    /* "playhouse/_sqlite_ext.pyx":1100
 *     for seed in seeds:
 *         h = bf_bitindex(bf, key, keylen, seed)
 *         pos = h / 8             # <<<<<<<<<<<<<<
 *         if not (bits[pos] & (1 << (h % 8))):
 *             return 0
 */
    __pyx_v_pos = (((long)__pyx_v_h) / 8);

    /* "playhouse/_sqlite_ext.pyx":1101
 *         h = bf_bitindex(bf, key, keylen, seed)
 *         pos = h / 8
 *         if not (bits[pos] & (1 << (h % 8))):             # <<<<<<<<<<<<<<
 *             return 0
 *     return 1
 */
    __pyx_t_5 = (!(((__pyx_v_bits[__pyx_v_pos]) & (1 << (__pyx_v_h % 8))) != 0));
    if (__pyx_t_5) {

      /* "playhouse/_sqlite_ext.pyx":1102
 *         pos = h / 8
 *         if not (bits[pos] & (1 << (h % 8))):
 *             return 0             # <<<<<<<<<<<<<<
 *     return 1
 * 
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "playhouse/_sqlite_ext.pyx":1101
 *         h = bf_bitindex(bf, key, keylen, seed)
 *         pos = h / 8
 *         if not (bits[pos] & (1 << (h % 8))):             # <<<<<<<<<<<<<<
 *             return 0
 *     return 1
 */
    }
  }

  /* "playhouse/_sqlite_ext.pyx":1103
 *         if not (bits[pos] & (1 << (h % 8))):
 *             return 0
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * cdef bf_free(bf_t *bf):
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1091
 * 
 * @cython.cdivision(True)
 * cdef int bf_contains(bf_t *bf, unsigned char *key):             # <<<<<<<<<<<<<<
 *     cdef:
 *         uint8_t *bits = <uint8_t *>(bf.bits)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.bf_contains", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1105
 *     return 1
 * 
 * cdef bf_free(bf_t *bf):             # <<<<<<<<<<<<<<
 *     free(bf.bits)
 *     free(bf)
 */

static PyObject *__pyx_f_9playhouse_11_sqlite_ext_bf_free(__pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_v_bf) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bf_free", 0);

  /* "playhouse/_sqlite_ext.pyx":1106
 * 
 * cdef bf_free(bf_t *bf):
 *     free(bf.bits)             # <<<<<<<<<<<<<<
 *     free(bf)
 * 
 */
  free(__pyx_v_bf->bits);

  /* "playhouse/_sqlite_ext.pyx":1107
 * cdef bf_free(bf_t *bf):
 *     free(bf.bits)
 *     free(bf)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  free(__pyx_v_bf);

  /* "playhouse/_sqlite_ext.pyx":1105
 *     return 1
 * 
 * cdef bf_free(bf_t *bf):             # <<<<<<<<<<<<<<
 *     free(bf.bits)
 *     free(bf)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1114
 *         bf_t *bf
 * 
 *     def __init__(self, size=1024 * 32):             # <<<<<<<<<<<<<<
 *         self.bf = bf_create(<size_t>size)
 * 
 */

/* Python wrapper */
static int __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)__pyx_int_32768);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1114, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1114, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_size = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1114, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter___init__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self), __pyx_v_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, PyObject *__pyx_v_size) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  size_t __pyx_t_1;
  __pyx_t_9playhouse_11_sqlite_ext_bf_t *__pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "playhouse/_sqlite_ext.pyx":1115
 * 
 *     def __init__(self, size=1024 * 32):
 *         self.bf = bf_create(<size_t>size)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_1 = __Pyx_PyInt_As_size_t(__pyx_v_size); if (unlikely((__pyx_t_1 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1115, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext_bf_create(((size_t)__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1115, __pyx_L1_error)
  __pyx_v_self->bf = __pyx_t_2;

  /* "playhouse/_sqlite_ext.pyx":1114
 *         bf_t *bf
 * 
 *     def __init__(self, size=1024 * 32):             # <<<<<<<<<<<<<<
 *         self.bf = bf_create(<size_t>size)
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1117
 *         self.bf = bf_create(<size_t>size)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.bf:
 *             bf_free(self.bf)
 */

/* Python wrapper */
static void __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_2__dealloc__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_2__dealloc__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "playhouse/_sqlite_ext.pyx":1118
 * 
 *     def __dealloc__(self):
 *         if self.bf:             # <<<<<<<<<<<<<<
 *             bf_free(self.bf)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->bf != 0);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1119
 *     def __dealloc__(self):
 *         if self.bf:
 *             bf_free(self.bf)             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
    __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext_bf_free(__pyx_v_self->bf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "playhouse/_sqlite_ext.pyx":1118
 * 
 *     def __dealloc__(self):
 *         if self.bf:             # <<<<<<<<<<<<<<
 *             bf_free(self.bf)
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1117
 *         self.bf = bf_create(<size_t>size)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.bf:
 *             bf_free(self.bf)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.BloomFilter.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "playhouse/_sqlite_ext.pyx":1121
 *             bf_free(self.bf)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.bf.size
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_4__len__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_4__len__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "playhouse/_sqlite_ext.pyx":1122
 * 
 *     def __len__(self):
 *         return self.bf.size             # <<<<<<<<<<<<<<
 * 
 *     def add(self, *keys):
 */
  __pyx_r = __pyx_v_self->bf->size;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1121
 *             bf_free(self.bf)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.bf.size
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1124
 *         return self.bf.size
 * 
 *     def add(self, *keys):             # <<<<<<<<<<<<<<
 *         cdef bytes bkey
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_7add(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_7add = {"add", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_7add, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_7add(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_keys = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add (wrapper)", 0);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "add", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_keys = __pyx_args;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_6add(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self), __pyx_v_keys);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_keys);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_6add(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, PyObject *__pyx_v_keys) {
  PyObject *__pyx_v_bkey = 0;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  unsigned char *__pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);

  /* "playhouse/_sqlite_ext.pyx":1127
 *         cdef bytes bkey
 * 
 *         for key in keys:             # <<<<<<<<<<<<<<
 *             bkey = encode(key)
 *             bf_add(self.bf, <unsigned char *>bkey)
 */
  __pyx_t_1 = __pyx_v_keys; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1127, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "playhouse/_sqlite_ext.pyx":1128
 * 
 *         for key in keys:
 *             bkey = encode(key)             # <<<<<<<<<<<<<<
 *             bf_add(self.bf, <unsigned char *>bkey)
 * 
 */
    __pyx_t_3 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_bkey, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "playhouse/_sqlite_ext.pyx":1129
 *         for key in keys:
 *             bkey = encode(key)
 *             bf_add(self.bf, <unsigned char *>bkey)             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, key):
 */
    if (unlikely(__pyx_v_bkey == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 1129, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyBytes_AsWritableUString(__pyx_v_bkey); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 1129, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_9playhouse_11_sqlite_ext_bf_add(__pyx_v_self->bf, ((unsigned char *)__pyx_t_4)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "playhouse/_sqlite_ext.pyx":1127
 *         cdef bytes bkey
 * 
 *         for key in keys:             # <<<<<<<<<<<<<<
 *             bkey = encode(key)
 *             bf_add(self.bf, <unsigned char *>bkey)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1124
 *         return self.bf.size
 * 
 *     def add(self, *keys):             # <<<<<<<<<<<<<<
 *         cdef bytes bkey
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bkey);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1131
 *             bf_add(self.bf, <unsigned char *>bkey)
 * 
 *     def __contains__(self, key):             # <<<<<<<<<<<<<<
 *         cdef bytes bkey = encode(key)
 *         return bf_contains(self.bf, <unsigned char *>bkey)
 */

/* Python wrapper */
static int __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_9__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_9__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_8__contains__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_8__contains__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, PyObject *__pyx_v_key) {
  PyObject *__pyx_v_bkey = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  unsigned char *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__contains__", 0);

  /* "playhouse/_sqlite_ext.pyx":1132
 * 
 *     def __contains__(self, key):
 *         cdef bytes bkey = encode(key)             # <<<<<<<<<<<<<<
 *         return bf_contains(self.bf, <unsigned char *>bkey)
 * 
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bkey = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1133
 *     def __contains__(self, key):
 *         cdef bytes bkey = encode(key)
 *         return bf_contains(self.bf, <unsigned char *>bkey)             # <<<<<<<<<<<<<<
 * 
 *     def to_buffer(self):
 */
  if (unlikely(__pyx_v_bkey == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1133, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyBytes_AsWritableUString(__pyx_v_bkey); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 1133, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_9playhouse_11_sqlite_ext_bf_contains(__pyx_v_self->bf, ((unsigned char *)__pyx_t_2)); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1133, __pyx_L1_error)
  __pyx_r = __pyx_t_3;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1131
 *             bf_add(self.bf, <unsigned char *>bkey)
 * 
 *     def __contains__(self, key):             # <<<<<<<<<<<<<<
 *         cdef bytes bkey = encode(key)
 *         return bf_contains(self.bf, <unsigned char *>bkey)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bkey);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1135
 *         return bf_contains(self.bf, <unsigned char *>bkey)
 * 
 *     def to_buffer(self):             # <<<<<<<<<<<<<<
 *         # We have to do this so that embedded NULL bytes are preserved.
 *         cdef bytes buf = PyBytes_FromStringAndSize(<char *>(self.bf.bits),
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_11to_buffer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_11to_buffer = {"to_buffer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_11to_buffer, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_11to_buffer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_buffer (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_buffer", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_buffer", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_10to_buffer(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_10to_buffer(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self) {
  PyObject *__pyx_v_buf = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_buffer", 0);

  /* "playhouse/_sqlite_ext.pyx":1137
 *     def to_buffer(self):
 *         # We have to do this so that embedded NULL bytes are preserved.
 *         cdef bytes buf = PyBytes_FromStringAndSize(<char *>(self.bf.bits),             # <<<<<<<<<<<<<<
 *                                                    self.bf.size)
 *         # Similarly we wrap in a buffer object so pysqlite preserves the
 */
  __pyx_t_1 = PyBytes_FromStringAndSize(((char *)__pyx_v_self->bf->bits), __pyx_v_self->bf->size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_buf = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1141
 *         # Similarly we wrap in a buffer object so pysqlite preserves the
 *         # embedded NULL bytes.
 *         return buf             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_buf);
  __pyx_r = __pyx_v_buf;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1135
 *         return bf_contains(self.bf, <unsigned char *>bkey)
 * 
 *     def to_buffer(self):             # <<<<<<<<<<<<<<
 *         # We have to do this so that embedded NULL bytes are preserved.
 *         cdef bytes buf = PyBytes_FromStringAndSize(<char *>(self.bf.bits),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.to_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_buf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1143
 *         return buf
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_buffer(cls, data):
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_13from_buffer(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_13from_buffer = {"from_buffer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_13from_buffer, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_13from_buffer(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_buffer (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1143, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "from_buffer") < 0)) __PYX_ERR(0, 1143, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_data = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_buffer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1143, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.from_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_12from_buffer(((PyTypeObject*)__pyx_v_cls), __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_12from_buffer(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_data) {
  char *__pyx_v_buf;
  Py_ssize_t __pyx_v_buflen;
  struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_bloom = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_buffer", 0);

  /* "playhouse/_sqlite_ext.pyx":1150
 *             BloomFilter bloom
 * 
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)             # <<<<<<<<<<<<<<
 * 
 *         bloom = BloomFilter(buflen)
 */
  __pyx_t_1 = PyBytes_AsStringAndSize(__pyx_v_data, (&__pyx_v_buf), (&__pyx_v_buflen)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1150, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1152
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)
 * 
 *         bloom = BloomFilter(buflen)             # <<<<<<<<<<<<<<
 *         memcpy(bloom.bf.bits, <void *>buf, buflen)
 *         return bloom
 */
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_buflen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter), __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_bloom = ((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1153
 * 
 *         bloom = BloomFilter(buflen)
 *         memcpy(bloom.bf.bits, <void *>buf, buflen)             # <<<<<<<<<<<<<<
 *         return bloom
 * 
 */
  (void)(memcpy(__pyx_v_bloom->bf->bits, ((void *)__pyx_v_buf), __pyx_v_buflen));

  /* "playhouse/_sqlite_ext.pyx":1154
 *         bloom = BloomFilter(buflen)
 *         memcpy(bloom.bf.bits, <void *>buf, buflen)
 *         return bloom             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_bloom);
  __pyx_r = ((PyObject *)__pyx_v_bloom);
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1143
 *         return buf
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_buffer(cls, data):
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.from_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_bloom);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1156
 *         return bloom
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def calculate_size(cls, double n, double p):
 *         cdef double m = ceil((n * log(p)) / log(1.0 / (pow(2.0, log(2.0)))))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_15calculate_size(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_15calculate_size = {"calculate_size", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_15calculate_size, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_15calculate_size(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_n;
  double __pyx_v_p;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calculate_size (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_p,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1156, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1156, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("calculate_size", 1, 2, 2, 1); __PYX_ERR(0, 1156, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "calculate_size") < 0)) __PYX_ERR(0, 1156, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_n = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_n == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1157, __pyx_L3_error)
    __pyx_v_p = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_p == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1157, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calculate_size", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1156, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.calculate_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_14calculate_size(((PyTypeObject*)__pyx_v_cls), __pyx_v_n, __pyx_v_p);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_14calculate_size(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, double __pyx_v_n, double __pyx_v_p) {
  double __pyx_v_m;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  double __pyx_t_4;
  double __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calculate_size", 0);

  /* "playhouse/_sqlite_ext.pyx":1158
 *     @classmethod
 *     def calculate_size(cls, double n, double p):
 *         cdef double m = ceil((n * log(p)) / log(1.0 / (pow(2.0, log(2.0)))))             # <<<<<<<<<<<<<<
 *         return m
 * 
 */
  __pyx_t_1 = (__pyx_v_n * log(__pyx_v_p));
  __pyx_t_2 = PyFloat_FromDouble(log(2.0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyNumber_Power2(__pyx_float_2_0, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyFloat_TrueDivideCObj(__pyx_float_1_0, __pyx_t_3, 1.0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = log(__pyx_t_4);
  if (unlikely(__pyx_t_5 == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 1158, __pyx_L1_error)
  }
  __pyx_v_m = ceil((__pyx_t_1 / __pyx_t_5));

  /* "playhouse/_sqlite_ext.pyx":1159
 *     def calculate_size(cls, double n, double p):
 *         cdef double m = ceil((n * log(p)) / log(1.0 / (pow(2.0, log(2.0)))))
 *         return m             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_m); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1156
 *         return bloom
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def calculate_size(cls, double n, double p):
 *         cdef double m = ceil((n * log(p)) / log(1.0 / (pow(2.0, log(2.0)))))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.calculate_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_17__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_17__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_17__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_17__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_16__reduce_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_bf_cannot_be_converted_to_a, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_19__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_19__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_19__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_19__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_18__setstate_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_11BloomFilter_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_bf_cannot_be_converted_to_a, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilter.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1166
 *         BloomFilter bf
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.bf = None
 * 
 */

/* Python wrapper */
static int __pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate___init__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "playhouse/_sqlite_ext.pyx":1167
 * 
 *     def __init__(self):
 *         self.bf = None             # <<<<<<<<<<<<<<
 * 
 *     def step(self, value, size=None):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->bf);
  __Pyx_DECREF((PyObject *)__pyx_v_self->bf);
  __pyx_v_self->bf = ((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)Py_None);

  /* "playhouse/_sqlite_ext.pyx":1166
 *         BloomFilter bf
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.bf = None
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1169
 *         self.bf = None
 * 
 *     def step(self, value, size=None):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             size = size or 1024
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_3step(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_3step = {"step", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_3step, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_3step(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_size = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("step (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,&__pyx_n_s_size,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1169, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size);
          if (value) { values[1] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1169, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "step") < 0)) __PYX_ERR(0, 1169, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_value = values[0];
    __pyx_v_size = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("step", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1169, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilterAggregate.step", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_2step(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)__pyx_v_self), __pyx_v_value, __pyx_v_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_2step(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("step", 0);
  __Pyx_INCREF(__pyx_v_size);

  /* "playhouse/_sqlite_ext.pyx":1170
 * 
 *     def step(self, value, size=None):
 *         if not self.bf:             # <<<<<<<<<<<<<<
 *             size = size or 1024
 *             self.bf = BloomFilter(size)
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->bf)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1170, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":1171
 *     def step(self, value, size=None):
 *         if not self.bf:
 *             size = size or 1024             # <<<<<<<<<<<<<<
 *             self.bf = BloomFilter(size)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_size); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1171, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __Pyx_INCREF(__pyx_v_size);
      __pyx_t_3 = __pyx_v_size;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyInt_From_long(0x400); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_L4_bool_binop_done:;
    __Pyx_DECREF_SET(__pyx_v_size, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "playhouse/_sqlite_ext.pyx":1172
 *         if not self.bf:
 *             size = size or 1024
 *             self.bf = BloomFilter(size)             # <<<<<<<<<<<<<<
 * 
 *         self.bf.add(value)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter), __pyx_v_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->bf);
    __Pyx_DECREF((PyObject *)__pyx_v_self->bf);
    __pyx_v_self->bf = ((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "playhouse/_sqlite_ext.pyx":1170
 * 
 *     def step(self, value, size=None):
 *         if not self.bf:             # <<<<<<<<<<<<<<
 *             size = size or 1024
 *             self.bf = BloomFilter(size)
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1174
 *             self.bf = BloomFilter(size)
 * 
 *         self.bf.add(value)             # <<<<<<<<<<<<<<
 * 
 *     def finalize(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->bf), __pyx_n_s_add); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_value};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1169
 *         self.bf = None
 * 
 *     def step(self, value, size=None):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             size = size or 1024
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilterAggregate.step", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_size);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1176
 *         self.bf.add(value)
 * 
 *     def finalize(self):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             return None
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_5finalize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_5finalize = {"finalize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_5finalize, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_5finalize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("finalize (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("finalize", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "finalize", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_4finalize(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_4finalize(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("finalize", 0);

  /* "playhouse/_sqlite_ext.pyx":1177
 * 
 *     def finalize(self):
 *         if not self.bf:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->bf)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1177, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":1178
 *     def finalize(self):
 *         if not self.bf:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         return pysqlite.Binary(self.bf.to_buffer())
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1177
 * 
 *     def finalize(self):
 *         if not self.bf:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1180
 *             return None
 * 
 *         return pysqlite.Binary(self.bf.to_buffer())             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pysqlite); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_Binary); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->bf), __pyx_n_s_to_buffer); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_7, };
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_8 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1176
 *         self.bf.add(value)
 * 
 *     def finalize(self):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             return None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilterAggregate.finalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_6__reduce_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_6__reduce_cython__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.bf,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self->bf);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->bf);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->bf));
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.bf,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.bf,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.bf is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.bf,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.bf is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, None), state
 */
  /*else*/ {
    __pyx_t_2 = (((PyObject *)__pyx_v_self->bf) != Py_None);
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bf is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.bf is not None
 *     if use_setstate:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_BloomFilterAggreg); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_5135835);
    __Pyx_GIVEREF(__pyx_int_5135835);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_5135835);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.bf is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, None), state
 *     else:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BloomFilterAggregate__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_BloomFilterAggreg); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_5135835);
    __Pyx_GIVEREF(__pyx_int_5135835);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_5135835);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilterAggregate.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BloomFilterAggregate__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilterAggregate.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_8__setstate_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20BloomFilterAggregate_8__setstate_cython__(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BloomFilterAggregate__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext___pyx_unpickle_BloomFilterAggregate__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BloomFilterAggregate__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.BloomFilterAggregate.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1183
 * 
 * 
 * def peewee_bloomfilter_contains(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_19peewee_bloomfilter_contains(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_19peewee_bloomfilter_contains = {"peewee_bloomfilter_contains", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_19peewee_bloomfilter_contains, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_19peewee_bloomfilter_contains(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_data = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_bloomfilter_contains (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_data,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1183, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1183, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("peewee_bloomfilter_contains", 1, 2, 2, 1); __PYX_ERR(0, 1183, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "peewee_bloomfilter_contains") < 0)) __PYX_ERR(0, 1183, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_bloomfilter_contains", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1183, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bloomfilter_contains", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_18peewee_bloomfilter_contains(__pyx_self, __pyx_v_key, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_18peewee_bloomfilter_contains(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_data) {
  __pyx_t_9playhouse_11_sqlite_ext_bf_t __pyx_v_bf;
  PyObject *__pyx_v_bkey = 0;
  PyObject *__pyx_v_bdata = 0;
  unsigned char *__pyx_v_cdata;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  unsigned char *__pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_bloomfilter_contains", 0);

  /* "playhouse/_sqlite_ext.pyx":1187
 *         bf_t bf
 *         bytes bkey
 *         bytes bdata = bytes(data)             # <<<<<<<<<<<<<<
 *         unsigned char *cdata = <unsigned char *>bdata
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_v_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bdata = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1188
 *         bytes bkey
 *         bytes bdata = bytes(data)
 *         unsigned char *cdata = <unsigned char *>bdata             # <<<<<<<<<<<<<<
 * 
 *     bf.size = len(data)
 */
  __pyx_t_2 = __Pyx_PyBytes_AsWritableUString(__pyx_v_bdata); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 1188, __pyx_L1_error)
  __pyx_v_cdata = ((unsigned char *)__pyx_t_2);

  /* "playhouse/_sqlite_ext.pyx":1190
 *         unsigned char *cdata = <unsigned char *>bdata
 * 
 *     bf.size = len(data)             # <<<<<<<<<<<<<<
 *     bf.bits = <void *>cdata
 *     bkey = encode(key)
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1190, __pyx_L1_error)
  __pyx_v_bf.size = __pyx_t_3;

  /* "playhouse/_sqlite_ext.pyx":1191
 * 
 *     bf.size = len(data)
 *     bf.bits = <void *>cdata             # <<<<<<<<<<<<<<
 *     bkey = encode(key)
 * 
 */
  __pyx_v_bf.bits = ((void *)__pyx_v_cdata);

  /* "playhouse/_sqlite_ext.pyx":1192
 *     bf.size = len(data)
 *     bf.bits = <void *>cdata
 *     bkey = encode(key)             # <<<<<<<<<<<<<<
 * 
 *     return bf_contains(&bf, <unsigned char *>bkey)
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bkey = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1194
 *     bkey = encode(key)
 * 
 *     return bf_contains(&bf, <unsigned char *>bkey)             # <<<<<<<<<<<<<<
 * 
 * def peewee_bloomfilter_add(key, data):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_bkey == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1194, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyBytes_AsWritableUString(__pyx_v_bkey); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 1194, __pyx_L1_error)
  __pyx_t_4 = __pyx_f_9playhouse_11_sqlite_ext_bf_contains((&__pyx_v_bf), ((unsigned char *)__pyx_t_2)); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1194, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1183
 * 
 * 
 * def peewee_bloomfilter_contains(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bloomfilter_contains", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bkey);
  __Pyx_XDECREF(__pyx_v_bdata);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1196
 *     return bf_contains(&bf, <unsigned char *>bkey)
 * 
 * def peewee_bloomfilter_add(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_21peewee_bloomfilter_add(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_21peewee_bloomfilter_add = {"peewee_bloomfilter_add", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_21peewee_bloomfilter_add, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_21peewee_bloomfilter_add(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_data = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_bloomfilter_add (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_data,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1196, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1196, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("peewee_bloomfilter_add", 1, 2, 2, 1); __PYX_ERR(0, 1196, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "peewee_bloomfilter_add") < 0)) __PYX_ERR(0, 1196, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_bloomfilter_add", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1196, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bloomfilter_add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_20peewee_bloomfilter_add(__pyx_self, __pyx_v_key, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_20peewee_bloomfilter_add(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_data) {
  __pyx_t_9playhouse_11_sqlite_ext_bf_t __pyx_v_bf;
  PyObject *__pyx_v_bkey = 0;
  char *__pyx_v_buf;
  Py_ssize_t __pyx_v_buflen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  unsigned char *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_bloomfilter_add", 0);

  /* "playhouse/_sqlite_ext.pyx":1203
 *         Py_ssize_t buflen
 * 
 *     PyBytes_AsStringAndSize(data, &buf, &buflen)             # <<<<<<<<<<<<<<
 *     bf.size = buflen
 *     bf.bits = <void *>buf
 */
  __pyx_t_1 = PyBytes_AsStringAndSize(__pyx_v_data, (&__pyx_v_buf), (&__pyx_v_buflen)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1203, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1204
 * 
 *     PyBytes_AsStringAndSize(data, &buf, &buflen)
 *     bf.size = buflen             # <<<<<<<<<<<<<<
 *     bf.bits = <void *>buf
 * 
 */
  __pyx_v_bf.size = __pyx_v_buflen;

  /* "playhouse/_sqlite_ext.pyx":1205
 *     PyBytes_AsStringAndSize(data, &buf, &buflen)
 *     bf.size = buflen
 *     bf.bits = <void *>buf             # <<<<<<<<<<<<<<
 * 
 *     bkey = encode(key)
 */
  __pyx_v_bf.bits = ((void *)__pyx_v_buf);

  /* "playhouse/_sqlite_ext.pyx":1207
 *     bf.bits = <void *>buf
 * 
 *     bkey = encode(key)             # <<<<<<<<<<<<<<
 *     bf_add(&bf, bkey)
 *     return data
 */
  __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_bkey = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1208
 * 
 *     bkey = encode(key)
 *     bf_add(&bf, bkey)             # <<<<<<<<<<<<<<
 *     return data
 * 
 */
  if (unlikely(__pyx_v_bkey == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1208, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsWritableUString(__pyx_v_bkey); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1208, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext_bf_add((&__pyx_v_bf), __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1209
 *     bkey = encode(key)
 *     bf_add(&bf, bkey)
 *     return data             # <<<<<<<<<<<<<<
 * 
 * def peewee_bloomfilter_calculate_size(n_items, error_p):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_data);
  __pyx_r = __pyx_v_data;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1196
 *     return bf_contains(&bf, <unsigned char *>bkey)
 * 
 * def peewee_bloomfilter_add(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bloomfilter_add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bkey);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1211
 *     return data
 * 
 * def peewee_bloomfilter_calculate_size(n_items, error_p):             # <<<<<<<<<<<<<<
 *     return BloomFilter.calculate_size(n_items, error_p)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_23peewee_bloomfilter_calculate_size(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_23peewee_bloomfilter_calculate_size = {"peewee_bloomfilter_calculate_size", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_23peewee_bloomfilter_calculate_size, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_23peewee_bloomfilter_calculate_size(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_n_items = 0;
  PyObject *__pyx_v_error_p = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peewee_bloomfilter_calculate_size (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n_items,&__pyx_n_s_error_p,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n_items)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1211, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_error_p)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1211, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("peewee_bloomfilter_calculate_size", 1, 2, 2, 1); __PYX_ERR(0, 1211, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "peewee_bloomfilter_calculate_size") < 0)) __PYX_ERR(0, 1211, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_n_items = values[0];
    __pyx_v_error_p = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("peewee_bloomfilter_calculate_size", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1211, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bloomfilter_calculate_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_22peewee_bloomfilter_calculate_size(__pyx_self, __pyx_v_n_items, __pyx_v_error_p);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_22peewee_bloomfilter_calculate_size(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_n_items, PyObject *__pyx_v_error_p) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peewee_bloomfilter_calculate_size", 0);

  /* "playhouse/_sqlite_ext.pyx":1212
 * 
 * def peewee_bloomfilter_calculate_size(n_items, error_p):
 *     return BloomFilter.calculate_size(n_items, error_p)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter), __pyx_n_s_calculate_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_n_items, __pyx_v_error_p};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1211
 *     return data
 * 
 * def peewee_bloomfilter_calculate_size(n_items, error_p):             # <<<<<<<<<<<<<<
 *     return BloomFilter.calculate_size(n_items, error_p)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.peewee_bloomfilter_calculate_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1215
 * 
 * 
 * def register_bloomfilter(database):             # <<<<<<<<<<<<<<
 *     database.register_aggregate(BloomFilterAggregate, 'bloomfilter')
 *     database.register_function(peewee_bloomfilter_add,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_25register_bloomfilter(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_25register_bloomfilter = {"register_bloomfilter", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_25register_bloomfilter, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_25register_bloomfilter(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_database = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("register_bloomfilter (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_database,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_database)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1215, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "register_bloomfilter") < 0)) __PYX_ERR(0, 1215, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_database = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("register_bloomfilter", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1215, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.register_bloomfilter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_24register_bloomfilter(__pyx_self, __pyx_v_database);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_24register_bloomfilter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_database) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("register_bloomfilter", 0);

  /* "playhouse/_sqlite_ext.pyx":1216
 * 
 * def register_bloomfilter(database):
 *     database.register_aggregate(BloomFilterAggregate, 'bloomfilter')             # <<<<<<<<<<<<<<
 *     database.register_function(peewee_bloomfilter_add,
 *                                'bloomfilter_add')
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_database, __pyx_n_s_register_aggregate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate), __pyx_n_u_bloomfilter};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1217
 * def register_bloomfilter(database):
 *     database.register_aggregate(BloomFilterAggregate, 'bloomfilter')
 *     database.register_function(peewee_bloomfilter_add,             # <<<<<<<<<<<<<<
 *                                'bloomfilter_add')
 *     database.register_function(peewee_bloomfilter_contains,
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_database, __pyx_n_s_register_function); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_bloomfilter_add); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_3, __pyx_n_u_bloomfilter_add};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1219
 *     database.register_function(peewee_bloomfilter_add,
 *                                'bloomfilter_add')
 *     database.register_function(peewee_bloomfilter_contains,             # <<<<<<<<<<<<<<
 *                                'bloomfilter_contains')
 *     database.register_function(peewee_bloomfilter_calculate_size,
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_database, __pyx_n_s_register_function); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_bloomfilter_contains); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_3, __pyx_n_u_bloomfilter_contains};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1221
 *     database.register_function(peewee_bloomfilter_contains,
 *                                'bloomfilter_contains')
 *     database.register_function(peewee_bloomfilter_calculate_size,             # <<<<<<<<<<<<<<
 *                                'bloomfilter_calculate_size')
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_database, __pyx_n_s_register_function); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_peewee_bloomfilter_calculate_siz); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_3, __pyx_n_u_bloomfilter_calculate_size};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1215
 * 
 * 
 * def register_bloomfilter(database):             # <<<<<<<<<<<<<<
 *     database.register_aggregate(BloomFilterAggregate, 'bloomfilter')
 *     database.register_function(peewee_bloomfilter_add,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("playhouse._sqlite_ext.register_bloomfilter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1225
 * 
 * 
 * cdef inline int _check_connection(pysqlite_Connection *conn) except -1:             # <<<<<<<<<<<<<<
 *     """
 *     Check that the underlying SQLite database connection is usable. Raises an
 */

static CYTHON_INLINE int __pyx_f_9playhouse_11_sqlite_ext__check_connection(pysqlite_Connection *__pyx_v_conn) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_check_connection", 0);

  /* "playhouse/_sqlite_ext.pyx":1230
 *     InterfaceError if the connection is either uninitialized or closed.
 *     """
 *     if not conn.db:             # <<<<<<<<<<<<<<
 *         raise InterfaceError('Cannot operate on closed database.')
 *     return 1
 */
  __pyx_t_1 = (!(__pyx_v_conn->db != 0));
  if (unlikely(__pyx_t_1)) {

    /* "playhouse/_sqlite_ext.pyx":1231
 *     """
 *     if not conn.db:
 *         raise InterfaceError('Cannot operate on closed database.')             # <<<<<<<<<<<<<<
 *     return 1
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_InterfaceError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_Cannot_operate_on_closed_databas};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1231, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1230
 *     InterfaceError if the connection is either uninitialized or closed.
 *     """
 *     if not conn.db:             # <<<<<<<<<<<<<<
 *         raise InterfaceError('Cannot operate on closed database.')
 *     return 1
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1232
 *     if not conn.db:
 *         raise InterfaceError('Cannot operate on closed database.')
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1225
 * 
 * 
 * cdef inline int _check_connection(pysqlite_Connection *conn) except -1:             # <<<<<<<<<<<<<<
 *     """
 *     Check that the underlying SQLite database connection is usable. Raises an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("playhouse._sqlite_ext._check_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1236
 * 
 * class ZeroBlob(Node):
 *     def __init__(self, length):             # <<<<<<<<<<<<<<
 *         if not isinstance(length, int) or length < 0:
 *             raise ValueError('Length must be a positive integer.')
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_8ZeroBlob_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_8ZeroBlob_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_8ZeroBlob_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_8ZeroBlob_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_length = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_length,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1236, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_length)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1236, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 1236, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1236, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_length = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1236, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ZeroBlob.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_8ZeroBlob___init__(__pyx_self, __pyx_v_self, __pyx_v_length);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_8ZeroBlob___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_length) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "playhouse/_sqlite_ext.pyx":1237
 * class ZeroBlob(Node):
 *     def __init__(self, length):
 *         if not isinstance(length, int) or length < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError('Length must be a positive integer.')
 *         self.length = length
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_length); 
  __pyx_t_3 = (!__pyx_t_2);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_length, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1237, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "playhouse/_sqlite_ext.pyx":1238
 *     def __init__(self, length):
 *         if not isinstance(length, int) or length < 0:
 *             raise ValueError('Length must be a positive integer.')             # <<<<<<<<<<<<<<
 *         self.length = length
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1238, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1237
 * class ZeroBlob(Node):
 *     def __init__(self, length):
 *         if not isinstance(length, int) or length < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError('Length must be a positive integer.')
 *         self.length = length
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1239
 *         if not isinstance(length, int) or length < 0:
 *             raise ValueError('Length must be a positive integer.')
 *         self.length = length             # <<<<<<<<<<<<<<
 * 
 *     def __sql__(self, ctx):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_length, __pyx_v_length) < 0) __PYX_ERR(0, 1239, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1236
 * 
 * class ZeroBlob(Node):
 *     def __init__(self, length):             # <<<<<<<<<<<<<<
 *         if not isinstance(length, int) or length < 0:
 *             raise ValueError('Length must be a positive integer.')
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("playhouse._sqlite_ext.ZeroBlob.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1241
 *         self.length = length
 * 
 *     def __sql__(self, ctx):             # <<<<<<<<<<<<<<
 *         return ctx.literal('zeroblob(%s)' % self.length)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_8ZeroBlob_3__sql__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_8ZeroBlob_3__sql__ = {"__sql__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_8ZeroBlob_3__sql__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_8ZeroBlob_3__sql__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_ctx = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__sql__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_ctx,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1241, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ctx)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1241, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__sql__", 1, 2, 2, 1); __PYX_ERR(0, 1241, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__sql__") < 0)) __PYX_ERR(0, 1241, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_ctx = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__sql__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1241, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ZeroBlob.__sql__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_8ZeroBlob_2__sql__(__pyx_self, __pyx_v_self, __pyx_v_ctx);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_8ZeroBlob_2__sql__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__sql__", 0);

  /* "playhouse/_sqlite_ext.pyx":1242
 * 
 *     def __sql__(self, ctx):
 *         return ctx.literal('zeroblob(%s)' % self.length)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_n_s_literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_zeroblob_s, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1241
 *         self.length = length
 * 
 *     def __sql__(self, ctx):             # <<<<<<<<<<<<<<
 *         return ctx.literal('zeroblob(%s)' % self.length)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("playhouse._sqlite_ext.ZeroBlob.__sql__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1248
 * 
 * 
 * cdef inline int _check_blob_closed(Blob blob) except -1:             # <<<<<<<<<<<<<<
 *     _check_connection(blob.conn)
 *     if not blob.pBlob:
 */

static CYTHON_INLINE int __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_blob) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_check_blob_closed", 0);

  /* "playhouse/_sqlite_ext.pyx":1249
 * 
 * cdef inline int _check_blob_closed(Blob blob) except -1:
 *     _check_connection(blob.conn)             # <<<<<<<<<<<<<<
 *     if not blob.pBlob:
 *         raise InterfaceError('Cannot operate on closed blob.')
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_connection(__pyx_v_blob->conn); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1249, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1250
 * cdef inline int _check_blob_closed(Blob blob) except -1:
 *     _check_connection(blob.conn)
 *     if not blob.pBlob:             # <<<<<<<<<<<<<<
 *         raise InterfaceError('Cannot operate on closed blob.')
 *     return 1
 */
  __pyx_t_2 = (!(__pyx_v_blob->pBlob != 0));
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1251
 *     _check_connection(blob.conn)
 *     if not blob.pBlob:
 *         raise InterfaceError('Cannot operate on closed blob.')             # <<<<<<<<<<<<<<
 *     return 1
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_InterfaceError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_1 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_1 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_Cannot_operate_on_closed_blob};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_1, 1+__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1251, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1251, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1250
 * cdef inline int _check_blob_closed(Blob blob) except -1:
 *     _check_connection(blob.conn)
 *     if not blob.pBlob:             # <<<<<<<<<<<<<<
 *         raise InterfaceError('Cannot operate on closed blob.')
 *     return 1
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1252
 *     if not blob.pBlob:
 *         raise InterfaceError('Cannot operate on closed blob.')
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1248
 * 
 * 
 * cdef inline int _check_blob_closed(Blob blob) except -1:             # <<<<<<<<<<<<<<
 *     _check_connection(blob.conn)
 *     if not blob.pBlob:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("playhouse._sqlite_ext._check_blob_closed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1261
 *         sqlite3_blob *pBlob
 * 
 *     def __init__(self, database, table, column, rowid,             # <<<<<<<<<<<<<<
 *                  read_only=False):
 *         cdef:
 */

/* Python wrapper */
static int __pyx_pw_9playhouse_11_sqlite_ext_4Blob_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9playhouse_11_sqlite_ext_4Blob_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_database = 0;
  PyObject *__pyx_v_table = 0;
  PyObject *__pyx_v_column = 0;
  PyObject *__pyx_v_rowid = 0;
  PyObject *__pyx_v_read_only = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_database,&__pyx_n_s_table,&__pyx_n_s_column,&__pyx_n_s_rowid,&__pyx_n_s_read_only,0};
    PyObject* values[5] = {0,0,0,0,0};

    /* "playhouse/_sqlite_ext.pyx":1262
 * 
 *     def __init__(self, database, table, column, rowid,
 *                  read_only=False):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes btable = encode(table)
 */
    values[4] = ((PyObject *)Py_False);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_database)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1261, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_table)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1261, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 5, 1); __PYX_ERR(0, 1261, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_column)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1261, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 5, 2); __PYX_ERR(0, 1261, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_rowid)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1261, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 5, 3); __PYX_ERR(0, 1261, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_read_only);
          if (value) { values[4] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1261, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1261, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_database = values[0];
    __pyx_v_table = values[1];
    __pyx_v_column = values[2];
    __pyx_v_rowid = values[3];
    __pyx_v_read_only = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 5, __pyx_nargs); __PYX_ERR(0, 1261, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob___init__(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self), __pyx_v_database, __pyx_v_table, __pyx_v_column, __pyx_v_rowid, __pyx_v_read_only);

  /* "playhouse/_sqlite_ext.pyx":1261
 *         sqlite3_blob *pBlob
 * 
 *     def __init__(self, database, table, column, rowid,             # <<<<<<<<<<<<<<
 *                  read_only=False):
 *         cdef:
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9playhouse_11_sqlite_ext_4Blob___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_database, PyObject *__pyx_v_table, PyObject *__pyx_v_column, PyObject *__pyx_v_rowid, PyObject *__pyx_v_read_only) {
  PyObject *__pyx_v_btable = 0;
  PyObject *__pyx_v_bcolumn = 0;
  int __pyx_v_flags;
  int __pyx_v_rc;
  sqlite3_blob *__pyx_v_blob;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  char *__pyx_t_5;
  char *__pyx_t_6;
  PY_LONG_LONG __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "playhouse/_sqlite_ext.pyx":1264
 *                  read_only=False):
 *         cdef:
 *             bytes btable = encode(table)             # <<<<<<<<<<<<<<
 *             bytes bcolumn = encode(column)
 *             int flags = 0 if read_only else 1
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_table); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_btable = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1265
 *         cdef:
 *             bytes btable = encode(table)
 *             bytes bcolumn = encode(column)             # <<<<<<<<<<<<<<
 *             int flags = 0 if read_only else 1
 *             int rc
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_v_column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bcolumn = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1266
 *             bytes btable = encode(table)
 *             bytes bcolumn = encode(column)
 *             int flags = 0 if read_only else 1             # <<<<<<<<<<<<<<
 *             int rc
 *             sqlite3_blob *blob
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_read_only); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1266, __pyx_L1_error)
  if (__pyx_t_3) {
    __pyx_t_2 = 0;
  } else {
    __pyx_t_2 = 1;
  }
  __pyx_v_flags = __pyx_t_2;

  /* "playhouse/_sqlite_ext.pyx":1270
 *             sqlite3_blob *blob
 * 
 *         self.conn = <pysqlite_Connection *>(database._state.conn)             # <<<<<<<<<<<<<<
 *         _check_connection(self.conn)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_database, __pyx_n_s_state_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_conn); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->conn = ((pysqlite_Connection *)__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "playhouse/_sqlite_ext.pyx":1271
 * 
 *         self.conn = <pysqlite_Connection *>(database._state.conn)
 *         _check_connection(self.conn)             # <<<<<<<<<<<<<<
 * 
 *         rc = sqlite3_blob_open(
 */
  __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext__check_connection(__pyx_v_self->conn); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1271, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1276
 *             self.conn.db,
 *             'main',
 *             <char *>btable,             # <<<<<<<<<<<<<<
 *             <char *>bcolumn,
 *             <long long>rowid,
 */
  if (unlikely(__pyx_v_btable == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1276, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyBytes_AsWritableString(__pyx_v_btable); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) __PYX_ERR(0, 1276, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1277
 *             'main',
 *             <char *>btable,
 *             <char *>bcolumn,             # <<<<<<<<<<<<<<
 *             <long long>rowid,
 *             flags,
 */
  if (unlikely(__pyx_v_bcolumn == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1277, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsWritableString(__pyx_v_bcolumn); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1277, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1278
 *             <char *>btable,
 *             <char *>bcolumn,
 *             <long long>rowid,             # <<<<<<<<<<<<<<
 *             flags,
 *             &blob)
 */
  __pyx_t_7 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_v_rowid); if (unlikely((__pyx_t_7 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1278, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1273
 *         _check_connection(self.conn)
 * 
 *         rc = sqlite3_blob_open(             # <<<<<<<<<<<<<<
 *             self.conn.db,
 *             'main',
 */
  __pyx_v_rc = sqlite3_blob_open(__pyx_v_self->conn->db, ((char const *)"main"), ((char *)__pyx_t_5), ((char *)__pyx_t_6), ((PY_LONG_LONG)__pyx_t_7), __pyx_v_flags, (&__pyx_v_blob));

  /* "playhouse/_sqlite_ext.pyx":1281
 *             flags,
 *             &blob)
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             raise OperationalError('Unable to open blob.')
 *         if not blob:
 */
  __pyx_t_3 = (__pyx_v_rc != SQLITE_OK);
  if (unlikely(__pyx_t_3)) {

    /* "playhouse/_sqlite_ext.pyx":1282
 *             &blob)
 *         if rc != SQLITE_OK:
 *             raise OperationalError('Unable to open blob.')             # <<<<<<<<<<<<<<
 *         if not blob:
 *             raise MemoryError('Unable to allocate blob.')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    __pyx_t_2 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_2 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_u_Unable_to_open_blob};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1282, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1281
 *             flags,
 *             &blob)
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             raise OperationalError('Unable to open blob.')
 *         if not blob:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1283
 *         if rc != SQLITE_OK:
 *             raise OperationalError('Unable to open blob.')
 *         if not blob:             # <<<<<<<<<<<<<<
 *             raise MemoryError('Unable to allocate blob.')
 * 
 */
  __pyx_t_3 = (!(__pyx_v_blob != 0));
  if (unlikely(__pyx_t_3)) {

    /* "playhouse/_sqlite_ext.pyx":1284
 *             raise OperationalError('Unable to open blob.')
 *         if not blob:
 *             raise MemoryError('Unable to allocate blob.')             # <<<<<<<<<<<<<<
 * 
 *         self.pBlob = blob
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1284, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1283
 *         if rc != SQLITE_OK:
 *             raise OperationalError('Unable to open blob.')
 *         if not blob:             # <<<<<<<<<<<<<<
 *             raise MemoryError('Unable to allocate blob.')
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1286
 *             raise MemoryError('Unable to allocate blob.')
 * 
 *         self.pBlob = blob             # <<<<<<<<<<<<<<
 *         self.offset = 0
 * 
 */
  __pyx_v_self->pBlob = __pyx_v_blob;

  /* "playhouse/_sqlite_ext.pyx":1287
 * 
 *         self.pBlob = blob
 *         self.offset = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef _close(self):
 */
  __pyx_v_self->offset = 0;

  /* "playhouse/_sqlite_ext.pyx":1261
 *         sqlite3_blob *pBlob
 * 
 *     def __init__(self, database, table, column, rowid,             # <<<<<<<<<<<<<<
 *                  read_only=False):
 *         cdef:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_btable);
  __Pyx_XDECREF(__pyx_v_bcolumn);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1289
 *         self.offset = 0
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self.pBlob and self.conn.db:
 *             with nogil:
 */

static PyObject *__pyx_f_9playhouse_11_sqlite_ext_4Blob__close(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "playhouse/_sqlite_ext.pyx":1290
 * 
 *     cdef _close(self):
 *         if self.pBlob and self.conn.db:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sqlite3_blob_close(self.pBlob)
 */
  __pyx_t_2 = (__pyx_v_self->pBlob != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->conn->db != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1291
 *     cdef _close(self):
 *         if self.pBlob and self.conn.db:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sqlite3_blob_close(self.pBlob)
 *         self.pBlob = <sqlite3_blob *>0
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "playhouse/_sqlite_ext.pyx":1292
 *         if self.pBlob and self.conn.db:
 *             with nogil:
 *                 sqlite3_blob_close(self.pBlob)             # <<<<<<<<<<<<<<
 *         self.pBlob = <sqlite3_blob *>0
 * 
 */
          (void)(sqlite3_blob_close(__pyx_v_self->pBlob));
        }

        /* "playhouse/_sqlite_ext.pyx":1291
 *     cdef _close(self):
 *         if self.pBlob and self.conn.db:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sqlite3_blob_close(self.pBlob)
 *         self.pBlob = <sqlite3_blob *>0
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L8;
          }
          __pyx_L8:;
        }
    }

    /* "playhouse/_sqlite_ext.pyx":1290
 * 
 *     cdef _close(self):
 *         if self.pBlob and self.conn.db:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sqlite3_blob_close(self.pBlob)
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1293
 *             with nogil:
 *                 sqlite3_blob_close(self.pBlob)
 *         self.pBlob = <sqlite3_blob *>0             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_v_self->pBlob = ((sqlite3_blob *)0);

  /* "playhouse/_sqlite_ext.pyx":1289
 *         self.offset = 0
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self.pBlob and self.conn.db:
 *             with nogil:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1295
 *         self.pBlob = <sqlite3_blob *>0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self._close()
 * 
 */

/* Python wrapper */
static void __pyx_pw_9playhouse_11_sqlite_ext_4Blob_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_9playhouse_11_sqlite_ext_4Blob_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_9playhouse_11_sqlite_ext_4Blob_2__dealloc__(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_9playhouse_11_sqlite_ext_4Blob_2__dealloc__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "playhouse/_sqlite_ext.pyx":1296
 * 
 *     def __dealloc__(self):
 *         self._close()             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self->__pyx_vtab)->_close(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1295
 *         self.pBlob = <sqlite3_blob *>0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self._close()
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext.Blob.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "playhouse/_sqlite_ext.pyx":1298
 *         self._close()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         return sqlite3_blob_bytes(self.pBlob)
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_9playhouse_11_sqlite_ext_4Blob_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_9playhouse_11_sqlite_ext_4Blob_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_4__len__(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_9playhouse_11_sqlite_ext_4Blob_4__len__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "playhouse/_sqlite_ext.pyx":1299
 * 
 *     def __len__(self):
 *         _check_blob_closed(self)             # <<<<<<<<<<<<<<
 *         return sqlite3_blob_bytes(self.pBlob)
 * 
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1299, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1300
 *     def __len__(self):
 *         _check_blob_closed(self)
 *         return sqlite3_blob_bytes(self.pBlob)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, idx):
 */
  __pyx_r = sqlite3_blob_bytes(__pyx_v_self->pBlob);
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1298
 *         self._close()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         return sqlite3_blob_bytes(self.pBlob)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1302
 *         return sqlite3_blob_bytes(self.pBlob)
 * 
 *     def __getitem__(self, idx):             # <<<<<<<<<<<<<<
 *         cdef:
 *             unsigned char c
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_7__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_idx); /*proto*/
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_7__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_idx) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_6__getitem__(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self), ((PyObject *)__pyx_v_idx));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_6__getitem__(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_idx) {
  unsigned char __pyx_v_c;
  int __pyx_v_i;
  int __pyx_v_rc;
  int __pyx_v_size;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "playhouse/_sqlite_ext.pyx":1305
 *         cdef:
 *             unsigned char c
 *             int i = idx             # <<<<<<<<<<<<<<
 *             int rc
 *             int size
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_idx); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1305, __pyx_L1_error)
  __pyx_v_i = __pyx_t_1;

  /* "playhouse/_sqlite_ext.pyx":1309
 *             int size
 * 
 *         _check_blob_closed(self)             # <<<<<<<<<<<<<<
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         if i < 0: i += size
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1309, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1310
 * 
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)             # <<<<<<<<<<<<<<
 *         if i < 0: i += size
 *         if i < 0 or i >= size:
 */
  __pyx_v_size = sqlite3_blob_bytes(__pyx_v_self->pBlob);

  /* "playhouse/_sqlite_ext.pyx":1311
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         if i < 0: i += size             # <<<<<<<<<<<<<<
 *         if i < 0 or i >= size:
 *             raise IndexError('Blob index out of range (%s, %s)' % (i, size))
 */
  __pyx_t_2 = (__pyx_v_i < 0);
  if (__pyx_t_2) {
    __pyx_v_i = (__pyx_v_i + __pyx_v_size);
  }

  /* "playhouse/_sqlite_ext.pyx":1312
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         if i < 0: i += size
 *         if i < 0 or i >= size:             # <<<<<<<<<<<<<<
 *             raise IndexError('Blob index out of range (%s, %s)' % (i, size))
 * 
 */
  __pyx_t_3 = (__pyx_v_i < 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_i >= __pyx_v_size);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1313
 *         if i < 0: i += size
 *         if i < 0 or i >= size:
 *             raise IndexError('Blob index out of range (%s, %s)' % (i, size))             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    __pyx_t_6 = 127;
    __Pyx_INCREF(__pyx_kp_u_Blob_index_out_of_range);
    __pyx_t_5 += 25;
    __Pyx_GIVEREF(__pyx_kp_u_Blob_index_out_of_range);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u_Blob_index_out_of_range);
    __pyx_t_7 = __Pyx_PyUnicode_From_int(__pyx_v_i, 0, ' ', 'd'); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u__4);
    __pyx_t_5 += 2;
    __Pyx_GIVEREF(__pyx_kp_u__4);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u__4);
    __pyx_t_7 = __Pyx_PyUnicode_From_int(__pyx_v_size, 0, ' ', 'd'); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u__9);
    __pyx_t_5 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__9);
    PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_kp_u__9);
    __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_4, 5, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_IndexError, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1313, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1312
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         if i < 0: i += size
 *         if i < 0 or i >= size:             # <<<<<<<<<<<<<<
 *             raise IndexError('Blob index out of range (%s, %s)' % (i, size))
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1315
 *             raise IndexError('Blob index out of range (%s, %s)' % (i, size))
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_blob_read(self.pBlob, &c, 1, i)
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "playhouse/_sqlite_ext.pyx":1316
 * 
 *         with nogil:
 *             rc = sqlite3_blob_read(self.pBlob, &c, 1, i)             # <<<<<<<<<<<<<<
 * 
 *         if rc != SQLITE_OK:
 */
        __pyx_v_rc = sqlite3_blob_read(__pyx_v_self->pBlob, (&__pyx_v_c), 1, __pyx_v_i);
      }

      /* "playhouse/_sqlite_ext.pyx":1315
 *             raise IndexError('Blob index out of range (%s, %s)' % (i, size))
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_blob_read(self.pBlob, &c, 1, i)
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L9;
        }
        __pyx_L9:;
      }
  }

  /* "playhouse/_sqlite_ext.pyx":1318
 *             rc = sqlite3_blob_read(self.pBlob, &c, 1, i)
 * 
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             self._close()
 *             raise OperationalError('Error reading from blob.')
 */
  __pyx_t_2 = (__pyx_v_rc != SQLITE_OK);
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1319
 * 
 *         if rc != SQLITE_OK:
 *             self._close()             # <<<<<<<<<<<<<<
 *             raise OperationalError('Error reading from blob.')
 * 
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self->__pyx_vtab)->_close(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "playhouse/_sqlite_ext.pyx":1320
 *         if rc != SQLITE_OK:
 *             self._close()
 *             raise OperationalError('Error reading from blob.')             # <<<<<<<<<<<<<<
 * 
 *         return PyBytes_FromStringAndSize(<char *>&c, 1)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    __pyx_t_1 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_1 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_u_Error_reading_from_blob};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_1, 1+__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1320, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1318
 *             rc = sqlite3_blob_read(self.pBlob, &c, 1, i)
 * 
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             self._close()
 *             raise OperationalError('Error reading from blob.')
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1322
 *             raise OperationalError('Error reading from blob.')
 * 
 *         return PyBytes_FromStringAndSize(<char *>&c, 1)             # <<<<<<<<<<<<<<
 * 
 *     def read(self, n=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyBytes_FromStringAndSize(((char *)(&__pyx_v_c)), 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1302
 *         return sqlite3_blob_bytes(self.pBlob)
 * 
 *     def __getitem__(self, idx):             # <<<<<<<<<<<<<<
 *         cdef:
 *             unsigned char c
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1324
 *         return PyBytes_FromStringAndSize(<char *>&c, 1)
 * 
 *     def read(self, n=None):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes pybuf
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_9read(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_9read = {"read", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_9read, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_9read(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_n = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1324, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "read") < 0)) __PYX_ERR(0, 1324, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("read", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1324, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_8read(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self), __pyx_v_n);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_8read(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_n) {
  PyObject *__pyx_v_pybuf = 0;
  int __pyx_v_length;
  int __pyx_v_max_length;
  int __pyx_v_rc;
  int __pyx_v_size;
  char *__pyx_v_buf;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read", 0);

  /* "playhouse/_sqlite_ext.pyx":1327
 *         cdef:
 *             bytes pybuf
 *             int length = -1             # <<<<<<<<<<<<<<
 *             int max_length
 *             int rc
 */
  __pyx_v_length = -1;

  /* "playhouse/_sqlite_ext.pyx":1333
 *             char *buf
 * 
 *         if n is not None:             # <<<<<<<<<<<<<<
 *             length = n
 * 
 */
  __pyx_t_1 = (__pyx_v_n != Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1334
 * 
 *         if n is not None:
 *             length = n             # <<<<<<<<<<<<<<
 * 
 *         _check_blob_closed(self)
 */
    __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_v_n); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1334, __pyx_L1_error)
    __pyx_v_length = __pyx_t_2;

    /* "playhouse/_sqlite_ext.pyx":1333
 *             char *buf
 * 
 *         if n is not None:             # <<<<<<<<<<<<<<
 *             length = n
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1336
 *             length = n
 * 
 *         _check_blob_closed(self)             # <<<<<<<<<<<<<<
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         max_length = size - self.offset
 */
  __pyx_t_2 = __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(__pyx_v_self); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1336, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1337
 * 
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)             # <<<<<<<<<<<<<<
 *         max_length = size - self.offset
 *         if length < 0 or length > max_length:
 */
  __pyx_v_size = sqlite3_blob_bytes(__pyx_v_self->pBlob);

  /* "playhouse/_sqlite_ext.pyx":1338
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         max_length = size - self.offset             # <<<<<<<<<<<<<<
 *         if length < 0 or length > max_length:
 *             length = max_length
 */
  __pyx_v_max_length = (__pyx_v_size - __pyx_v_self->offset);

  /* "playhouse/_sqlite_ext.pyx":1339
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         max_length = size - self.offset
 *         if length < 0 or length > max_length:             # <<<<<<<<<<<<<<
 *             length = max_length
 * 
 */
  __pyx_t_3 = (__pyx_v_length < 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_length > __pyx_v_max_length);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1340
 *         max_length = size - self.offset
 *         if length < 0 or length > max_length:
 *             length = max_length             # <<<<<<<<<<<<<<
 * 
 *         if length == 0:
 */
    __pyx_v_length = __pyx_v_max_length;

    /* "playhouse/_sqlite_ext.pyx":1339
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         max_length = size - self.offset
 *         if length < 0 or length > max_length:             # <<<<<<<<<<<<<<
 *             length = max_length
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1342
 *             length = max_length
 * 
 *         if length == 0:             # <<<<<<<<<<<<<<
 *             return b''
 * 
 */
  __pyx_t_1 = (__pyx_v_length == 0);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1343
 * 
 *         if length == 0:
 *             return b''             # <<<<<<<<<<<<<<
 * 
 *         pybuf = PyBytes_FromStringAndSize(NULL, length)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_b__10);
    __pyx_r = __pyx_kp_b__10;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1342
 *             length = max_length
 * 
 *         if length == 0:             # <<<<<<<<<<<<<<
 *             return b''
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1345
 *             return b''
 * 
 *         pybuf = PyBytes_FromStringAndSize(NULL, length)             # <<<<<<<<<<<<<<
 *         buf = PyBytes_AS_STRING(pybuf)
 *         with nogil:
 */
  __pyx_t_4 = PyBytes_FromStringAndSize(NULL, __pyx_v_length); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_pybuf = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "playhouse/_sqlite_ext.pyx":1346
 * 
 *         pybuf = PyBytes_FromStringAndSize(NULL, length)
 *         buf = PyBytes_AS_STRING(pybuf)             # <<<<<<<<<<<<<<
 *         with nogil:
 *             rc = sqlite3_blob_read(self.pBlob, buf, length, self.offset)
 */
  __pyx_v_buf = PyBytes_AS_STRING(__pyx_v_pybuf);

  /* "playhouse/_sqlite_ext.pyx":1347
 *         pybuf = PyBytes_FromStringAndSize(NULL, length)
 *         buf = PyBytes_AS_STRING(pybuf)
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_blob_read(self.pBlob, buf, length, self.offset)
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "playhouse/_sqlite_ext.pyx":1348
 *         buf = PyBytes_AS_STRING(pybuf)
 *         with nogil:
 *             rc = sqlite3_blob_read(self.pBlob, buf, length, self.offset)             # <<<<<<<<<<<<<<
 * 
 *         if rc != SQLITE_OK:
 */
        __pyx_v_rc = sqlite3_blob_read(__pyx_v_self->pBlob, __pyx_v_buf, __pyx_v_length, __pyx_v_self->offset);
      }

      /* "playhouse/_sqlite_ext.pyx":1347
 *         pybuf = PyBytes_FromStringAndSize(NULL, length)
 *         buf = PyBytes_AS_STRING(pybuf)
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_blob_read(self.pBlob, buf, length, self.offset)
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "playhouse/_sqlite_ext.pyx":1350
 *             rc = sqlite3_blob_read(self.pBlob, buf, length, self.offset)
 * 
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             self._close()
 *             raise OperationalError('Error reading from blob.')
 */
  __pyx_t_1 = (__pyx_v_rc != SQLITE_OK);
  if (unlikely(__pyx_t_1)) {

    /* "playhouse/_sqlite_ext.pyx":1351
 * 
 *         if rc != SQLITE_OK:
 *             self._close()             # <<<<<<<<<<<<<<
 *             raise OperationalError('Error reading from blob.')
 * 
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self->__pyx_vtab)->_close(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "playhouse/_sqlite_ext.pyx":1352
 *         if rc != SQLITE_OK:
 *             self._close()
 *             raise OperationalError('Error reading from blob.')             # <<<<<<<<<<<<<<
 * 
 *         self.offset += length
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_2 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_2 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u_Error_reading_from_blob};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1352, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1350
 *             rc = sqlite3_blob_read(self.pBlob, buf, length, self.offset)
 * 
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             self._close()
 *             raise OperationalError('Error reading from blob.')
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1354
 *             raise OperationalError('Error reading from blob.')
 * 
 *         self.offset += length             # <<<<<<<<<<<<<<
 *         return bytes(pybuf)
 * 
 */
  __pyx_v_self->offset = (__pyx_v_self->offset + __pyx_v_length);

  /* "playhouse/_sqlite_ext.pyx":1355
 * 
 *         self.offset += length
 *         return bytes(pybuf)             # <<<<<<<<<<<<<<
 * 
 *     def seek(self, offset, frame_of_reference=0):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_v_pybuf); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1324
 *         return PyBytes_FromStringAndSize(<char *>&c, 1)
 * 
 *     def read(self, n=None):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes pybuf
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pybuf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1357
 *         return bytes(pybuf)
 * 
 *     def seek(self, offset, frame_of_reference=0):             # <<<<<<<<<<<<<<
 *         cdef int size
 *         _check_blob_closed(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_11seek(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_11seek = {"seek", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_11seek, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_11seek(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_offset = 0;
  PyObject *__pyx_v_frame_of_reference = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seek (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_offset,&__pyx_n_s_frame_of_reference,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)__pyx_int_0);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_offset)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1357, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_frame_of_reference);
          if (value) { values[1] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1357, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "seek") < 0)) __PYX_ERR(0, 1357, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_offset = values[0];
    __pyx_v_frame_of_reference = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("seek", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1357, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.seek", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_10seek(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self), __pyx_v_offset, __pyx_v_frame_of_reference);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_10seek(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_offset, PyObject *__pyx_v_frame_of_reference) {
  int __pyx_v_size;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seek", 0);
  __Pyx_INCREF(__pyx_v_offset);

  /* "playhouse/_sqlite_ext.pyx":1359
 *     def seek(self, offset, frame_of_reference=0):
 *         cdef int size
 *         _check_blob_closed(self)             # <<<<<<<<<<<<<<
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         if frame_of_reference == 0:
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1359, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1360
 *         cdef int size
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)             # <<<<<<<<<<<<<<
 *         if frame_of_reference == 0:
 *             pass
 */
  __pyx_v_size = sqlite3_blob_bytes(__pyx_v_self->pBlob);

  /* "playhouse/_sqlite_ext.pyx":1361
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         if frame_of_reference == 0:             # <<<<<<<<<<<<<<
 *             pass
 *         elif frame_of_reference == 1:
 */
  __pyx_t_2 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_frame_of_reference, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1361, __pyx_L1_error)
  if (__pyx_t_2) {
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1363
 *         if frame_of_reference == 0:
 *             pass
 *         elif frame_of_reference == 1:             # <<<<<<<<<<<<<<
 *             offset += self.offset
 *         elif frame_of_reference == 2:
 */
  __pyx_t_2 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_frame_of_reference, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1363, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":1364
 *             pass
 *         elif frame_of_reference == 1:
 *             offset += self.offset             # <<<<<<<<<<<<<<
 *         elif frame_of_reference == 2:
 *             offset += size
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_offset, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_offset, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "playhouse/_sqlite_ext.pyx":1363
 *         if frame_of_reference == 0:
 *             pass
 *         elif frame_of_reference == 1:             # <<<<<<<<<<<<<<
 *             offset += self.offset
 *         elif frame_of_reference == 2:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1365
 *         elif frame_of_reference == 1:
 *             offset += self.offset
 *         elif frame_of_reference == 2:             # <<<<<<<<<<<<<<
 *             offset += size
 *         else:
 */
  __pyx_t_2 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_frame_of_reference, __pyx_int_2, 2, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1365, __pyx_L1_error)
  if (likely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1366
 *             offset += self.offset
 *         elif frame_of_reference == 2:
 *             offset += size             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError('seek() frame of reference must be 0, 1 or 2.')
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1366, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_offset, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1366, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_offset, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "playhouse/_sqlite_ext.pyx":1365
 *         elif frame_of_reference == 1:
 *             offset += self.offset
 *         elif frame_of_reference == 2:             # <<<<<<<<<<<<<<
 *             offset += size
 *         else:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1368
 *             offset += size
 *         else:
 *             raise ValueError('seek() frame of reference must be 0, 1 or 2.')             # <<<<<<<<<<<<<<
 * 
 *         if offset < 0 or offset > size:
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1368, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "playhouse/_sqlite_ext.pyx":1370
 *             raise ValueError('seek() frame of reference must be 0, 1 or 2.')
 * 
 *         if offset < 0 or offset > size:             # <<<<<<<<<<<<<<
 *             raise ValueError('seek() offset outside of valid range.')
 *         self.offset = offset
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_offset, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1370, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_offset, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_5;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1371
 * 
 *         if offset < 0 or offset > size:
 *             raise ValueError('seek() offset outside of valid range.')             # <<<<<<<<<<<<<<
 *         self.offset = offset
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1371, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1370
 *             raise ValueError('seek() frame of reference must be 0, 1 or 2.')
 * 
 *         if offset < 0 or offset > size:             # <<<<<<<<<<<<<<
 *             raise ValueError('seek() offset outside of valid range.')
 *         self.offset = offset
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1372
 *         if offset < 0 or offset > size:
 *             raise ValueError('seek() offset outside of valid range.')
 *         self.offset = offset             # <<<<<<<<<<<<<<
 * 
 *     def tell(self):
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_offset); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1372, __pyx_L1_error)
  __pyx_v_self->offset = __pyx_t_1;

  /* "playhouse/_sqlite_ext.pyx":1357
 *         return bytes(pybuf)
 * 
 *     def seek(self, offset, frame_of_reference=0):             # <<<<<<<<<<<<<<
 *         cdef int size
 *         _check_blob_closed(self)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.seek", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_offset);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1374
 *         self.offset = offset
 * 
 *     def tell(self):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         return self.offset
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_13tell(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_13tell = {"tell", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_13tell, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_13tell(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tell (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("tell", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tell", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_12tell(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_12tell(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tell", 0);

  /* "playhouse/_sqlite_ext.pyx":1375
 * 
 *     def tell(self):
 *         _check_blob_closed(self)             # <<<<<<<<<<<<<<
 *         return self.offset
 * 
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1375, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1376
 *     def tell(self):
 *         _check_blob_closed(self)
 *         return self.offset             # <<<<<<<<<<<<<<
 * 
 *     def write(self, bytes data):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1374
 *         self.offset = offset
 * 
 *     def tell(self):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         return self.offset
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.tell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1378
 *         return self.offset
 * 
 *     def write(self, bytes data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             char *buf
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_15write(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_15write = {"write", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_15write, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_15write(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1378, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "write") < 0)) __PYX_ERR(0, 1378, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_data = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("write", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1378, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_data), (&PyBytes_Type), 1, "data", 1))) __PYX_ERR(0, 1378, __pyx_L1_error)
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_14write(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self), __pyx_v_data);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_14write(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_data) {
  char *__pyx_v_buf;
  int __pyx_v_rc;
  int __pyx_v_remaining;
  int __pyx_v_size;
  Py_ssize_t __pyx_v_buflen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("write", 0);

  /* "playhouse/_sqlite_ext.pyx":1386
 *             Py_ssize_t buflen
 * 
 *         _check_blob_closed(self)             # <<<<<<<<<<<<<<
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         remaining = size - self.offset
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1386, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1387
 * 
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)             # <<<<<<<<<<<<<<
 *         remaining = size - self.offset
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)
 */
  __pyx_v_size = sqlite3_blob_bytes(__pyx_v_self->pBlob);

  /* "playhouse/_sqlite_ext.pyx":1388
 *         _check_blob_closed(self)
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         remaining = size - self.offset             # <<<<<<<<<<<<<<
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)
 *         if buflen > remaining:
 */
  __pyx_v_remaining = (__pyx_v_size - __pyx_v_self->offset);

  /* "playhouse/_sqlite_ext.pyx":1389
 *         size = sqlite3_blob_bytes(self.pBlob)
 *         remaining = size - self.offset
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)             # <<<<<<<<<<<<<<
 *         if buflen > remaining:
 *             raise ValueError('Data would go beyond end of blob')
 */
  __pyx_t_1 = PyBytes_AsStringAndSize(__pyx_v_data, (&__pyx_v_buf), (&__pyx_v_buflen)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1389, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1390
 *         remaining = size - self.offset
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)
 *         if buflen > remaining:             # <<<<<<<<<<<<<<
 *             raise ValueError('Data would go beyond end of blob')
 * 
 */
  __pyx_t_2 = (__pyx_v_buflen > __pyx_v_remaining);
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1391
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)
 *         if buflen > remaining:
 *             raise ValueError('Data would go beyond end of blob')             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1391, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1390
 *         remaining = size - self.offset
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)
 *         if buflen > remaining:             # <<<<<<<<<<<<<<
 *             raise ValueError('Data would go beyond end of blob')
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1393
 *             raise ValueError('Data would go beyond end of blob')
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_blob_write(self.pBlob, buf, buflen, self.offset)
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "playhouse/_sqlite_ext.pyx":1394
 * 
 *         with nogil:
 *             rc = sqlite3_blob_write(self.pBlob, buf, buflen, self.offset)             # <<<<<<<<<<<<<<
 * 
 *         if rc != SQLITE_OK:
 */
        __pyx_v_rc = sqlite3_blob_write(__pyx_v_self->pBlob, __pyx_v_buf, __pyx_v_buflen, __pyx_v_self->offset);
      }

      /* "playhouse/_sqlite_ext.pyx":1393
 *             raise ValueError('Data would go beyond end of blob')
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_blob_write(self.pBlob, buf, buflen, self.offset)
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L6;
        }
        __pyx_L6:;
      }
  }

  /* "playhouse/_sqlite_ext.pyx":1396
 *             rc = sqlite3_blob_write(self.pBlob, buf, buflen, self.offset)
 * 
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             raise OperationalError('Error writing to blob.')
 *         self.offset += <int>buflen
 */
  __pyx_t_2 = (__pyx_v_rc != SQLITE_OK);
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1397
 * 
 *         if rc != SQLITE_OK:
 *             raise OperationalError('Error writing to blob.')             # <<<<<<<<<<<<<<
 *         self.offset += <int>buflen
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_1 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_1 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_Error_writing_to_blob};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_1, 1+__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1397, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1397, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1396
 *             rc = sqlite3_blob_write(self.pBlob, buf, buflen, self.offset)
 * 
 *         if rc != SQLITE_OK:             # <<<<<<<<<<<<<<
 *             raise OperationalError('Error writing to blob.')
 *         self.offset += <int>buflen
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1398
 *         if rc != SQLITE_OK:
 *             raise OperationalError('Error writing to blob.')
 *         self.offset += <int>buflen             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __pyx_v_self->offset = (__pyx_v_self->offset + ((int)__pyx_v_buflen));

  /* "playhouse/_sqlite_ext.pyx":1378
 *         return self.offset
 * 
 *     def write(self, bytes data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             char *buf
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1400
 *         self.offset += <int>buflen
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         _check_connection(self.conn)
 *         self._close()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_17close(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_17close = {"close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_17close, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_17close(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("close", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "close", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_16close(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_16close(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close", 0);

  /* "playhouse/_sqlite_ext.pyx":1401
 * 
 *     def close(self):
 *         _check_connection(self.conn)             # <<<<<<<<<<<<<<
 *         self._close()
 * 
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_connection(__pyx_v_self->conn); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1401, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1402
 *     def close(self):
 *         _check_connection(self.conn)
 *         self._close()             # <<<<<<<<<<<<<<
 * 
 *     def reopen(self, rowid):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self->__pyx_vtab)->_close(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1400
 *         self.offset += <int>buflen
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         _check_connection(self.conn)
 *         self._close()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1404
 *         self._close()
 * 
 *     def reopen(self, rowid):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         self.offset = 0
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_19reopen(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_19reopen = {"reopen", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_19reopen, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_19reopen(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_rowid = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reopen (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_rowid,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_rowid)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1404, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "reopen") < 0)) __PYX_ERR(0, 1404, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_rowid = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reopen", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1404, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.reopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_18reopen(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self), __pyx_v_rowid);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_18reopen(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, PyObject *__pyx_v_rowid) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PY_LONG_LONG __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reopen", 0);

  /* "playhouse/_sqlite_ext.pyx":1405
 * 
 *     def reopen(self, rowid):
 *         _check_blob_closed(self)             # <<<<<<<<<<<<<<
 *         self.offset = 0
 *         if sqlite3_blob_reopen(self.pBlob, <long long>rowid):
 */
  __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext__check_blob_closed(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1405, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1406
 *     def reopen(self, rowid):
 *         _check_blob_closed(self)
 *         self.offset = 0             # <<<<<<<<<<<<<<
 *         if sqlite3_blob_reopen(self.pBlob, <long long>rowid):
 *             self._close()
 */
  __pyx_v_self->offset = 0;

  /* "playhouse/_sqlite_ext.pyx":1407
 *         _check_blob_closed(self)
 *         self.offset = 0
 *         if sqlite3_blob_reopen(self.pBlob, <long long>rowid):             # <<<<<<<<<<<<<<
 *             self._close()
 *             raise OperationalError('Unable to re-open blob.')
 */
  __pyx_t_2 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_v_rowid); if (unlikely((__pyx_t_2 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1407, __pyx_L1_error)
  __pyx_t_3 = (sqlite3_blob_reopen(__pyx_v_self->pBlob, ((PY_LONG_LONG)__pyx_t_2)) != 0);
  if (unlikely(__pyx_t_3)) {

    /* "playhouse/_sqlite_ext.pyx":1408
 *         self.offset = 0
 *         if sqlite3_blob_reopen(self.pBlob, <long long>rowid):
 *             self._close()             # <<<<<<<<<<<<<<
 *             raise OperationalError('Unable to re-open blob.')
 * 
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self->__pyx_vtab)->_close(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "playhouse/_sqlite_ext.pyx":1409
 *         if sqlite3_blob_reopen(self.pBlob, <long long>rowid):
 *             self._close()
 *             raise OperationalError('Unable to re-open blob.')             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_1 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_1 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u_Unable_to_re_open_blob};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_1, 1+__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1409, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1407
 *         _check_blob_closed(self)
 *         self.offset = 0
 *         if sqlite3_blob_reopen(self.pBlob, <long long>rowid):             # <<<<<<<<<<<<<<
 *             self._close()
 *             raise OperationalError('Unable to re-open blob.')
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1404
 *         self._close()
 * 
 *     def reopen(self, rowid):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         self.offset = 0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.reopen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_21__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_21__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_21__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_21__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_20__reduce_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_20__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_conn_self_pBlob_cannot_be_c, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_23__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_4Blob_23__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_23__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_4Blob_23__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_4Blob_22__setstate_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_4Blob_22__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_conn_self_pBlob_cannot_be_c, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.Blob.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1412
 * 
 * 
 * def sqlite_get_status(flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_27sqlite_get_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_27sqlite_get_status = {"sqlite_get_status", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_27sqlite_get_status, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_27sqlite_get_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_flag = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sqlite_get_status (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_flag,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flag)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1412, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sqlite_get_status") < 0)) __PYX_ERR(0, 1412, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_flag = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sqlite_get_status", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1412, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.sqlite_get_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_26sqlite_get_status(__pyx_self, __pyx_v_flag);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_26sqlite_get_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_flag) {
  int __pyx_v_current;
  int __pyx_v_highwater;
  int __pyx_v_rc;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sqlite_get_status", 0);

  /* "playhouse/_sqlite_ext.pyx":1416
 *         int current, highwater, rc
 * 
 *     rc = sqlite3_status(flag, &current, &highwater, 0)             # <<<<<<<<<<<<<<
 *     if rc == SQLITE_OK:
 *         return (current, highwater)
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_flag); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1416, __pyx_L1_error)
  __pyx_v_rc = sqlite3_status(__pyx_t_1, (&__pyx_v_current), (&__pyx_v_highwater), 0);

  /* "playhouse/_sqlite_ext.pyx":1417
 * 
 *     rc = sqlite3_status(flag, &current, &highwater, 0)
 *     if rc == SQLITE_OK:             # <<<<<<<<<<<<<<
 *         return (current, highwater)
 *     raise Exception('Error requesting status: %s' % rc)
 */
  __pyx_t_2 = (__pyx_v_rc == SQLITE_OK);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":1418
 *     rc = sqlite3_status(flag, &current, &highwater, 0)
 *     if rc == SQLITE_OK:
 *         return (current, highwater)             # <<<<<<<<<<<<<<
 *     raise Exception('Error requesting status: %s' % rc)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_current); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_highwater); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1417
 * 
 *     rc = sqlite3_status(flag, &current, &highwater, 0)
 *     if rc == SQLITE_OK:             # <<<<<<<<<<<<<<
 *         return (current, highwater)
 *     raise Exception('Error requesting status: %s' % rc)
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1419
 *     if rc == SQLITE_OK:
 *         return (current, highwater)
 *     raise Exception('Error requesting status: %s' % rc)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_rc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_Error_requesting_status_s, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __PYX_ERR(0, 1419, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1412
 * 
 * 
 * def sqlite_get_status(flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("playhouse._sqlite_ext.sqlite_get_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1422
 * 
 * 
 * def sqlite_get_db_status(conn, flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_29sqlite_get_db_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_29sqlite_get_db_status = {"sqlite_get_db_status", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_29sqlite_get_db_status, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_29sqlite_get_db_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_conn = 0;
  PyObject *__pyx_v_flag = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sqlite_get_db_status (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_conn,&__pyx_n_s_flag,0};
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_conn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1422, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flag)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1422, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("sqlite_get_db_status", 1, 2, 2, 1); __PYX_ERR(0, 1422, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sqlite_get_db_status") < 0)) __PYX_ERR(0, 1422, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_conn = values[0];
    __pyx_v_flag = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sqlite_get_db_status", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1422, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.sqlite_get_db_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_28sqlite_get_db_status(__pyx_self, __pyx_v_conn, __pyx_v_flag);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_28sqlite_get_db_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_conn, PyObject *__pyx_v_flag) {
  int __pyx_v_current;
  int __pyx_v_highwater;
  int __pyx_v_rc;
  pysqlite_Connection *__pyx_v_c_conn;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sqlite_get_db_status", 0);

  /* "playhouse/_sqlite_ext.pyx":1425
 *     cdef:
 *         int current, highwater, rc
 *         pysqlite_Connection *c_conn = <pysqlite_Connection *>conn             # <<<<<<<<<<<<<<
 * 
 *     if not c_conn.db:
 */
  __pyx_v_c_conn = ((pysqlite_Connection *)__pyx_v_conn);

  /* "playhouse/_sqlite_ext.pyx":1427
 *         pysqlite_Connection *c_conn = <pysqlite_Connection *>conn
 * 
 *     if not c_conn.db:             # <<<<<<<<<<<<<<
 *         return (None, None)
 * 
 */
  __pyx_t_1 = (!(__pyx_v_c_conn->db != 0));
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1428
 * 
 *     if not c_conn.db:
 *         return (None, None)             # <<<<<<<<<<<<<<
 * 
 *     rc = sqlite3_db_status(c_conn.db, flag, &current, &highwater, 0)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_tuple__14);
    __pyx_r = __pyx_tuple__14;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1427
 *         pysqlite_Connection *c_conn = <pysqlite_Connection *>conn
 * 
 *     if not c_conn.db:             # <<<<<<<<<<<<<<
 *         return (None, None)
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1430
 *         return (None, None)
 * 
 *     rc = sqlite3_db_status(c_conn.db, flag, &current, &highwater, 0)             # <<<<<<<<<<<<<<
 *     if rc == SQLITE_OK:
 *         return (current, highwater)
 */
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_v_flag); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1430, __pyx_L1_error)
  __pyx_v_rc = sqlite3_db_status(__pyx_v_c_conn->db, __pyx_t_2, (&__pyx_v_current), (&__pyx_v_highwater), 0);

  /* "playhouse/_sqlite_ext.pyx":1431
 * 
 *     rc = sqlite3_db_status(c_conn.db, flag, &current, &highwater, 0)
 *     if rc == SQLITE_OK:             # <<<<<<<<<<<<<<
 *         return (current, highwater)
 *     raise Exception('Error requesting db status: %s' % rc)
 */
  __pyx_t_1 = (__pyx_v_rc == SQLITE_OK);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1432
 *     rc = sqlite3_db_status(c_conn.db, flag, &current, &highwater, 0)
 *     if rc == SQLITE_OK:
 *         return (current, highwater)             # <<<<<<<<<<<<<<
 *     raise Exception('Error requesting db status: %s' % rc)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_current); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_highwater); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1431
 * 
 *     rc = sqlite3_db_status(c_conn.db, flag, &current, &highwater, 0)
 *     if rc == SQLITE_OK:             # <<<<<<<<<<<<<<
 *         return (current, highwater)
 *     raise Exception('Error requesting db status: %s' % rc)
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1433
 *     if rc == SQLITE_OK:
 *         return (current, highwater)
 *     raise Exception('Error requesting db status: %s' % rc)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_rc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_Error_requesting_db_status_s, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __PYX_ERR(0, 1433, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1422
 * 
 * 
 * def sqlite_get_db_status(conn, flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("playhouse._sqlite_ext.sqlite_get_db_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1441
 *         pysqlite_Connection *conn
 * 
 *     def __init__(self, connection):             # <<<<<<<<<<<<<<
 *         self.conn = <pysqlite_Connection *>connection
 *         self._commit_hook = self._rollback_hook = self._update_hook = None
 */

/* Python wrapper */
static int __pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_connection = 0;
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_connection,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_connection)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1441, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1441, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_connection = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1441, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper___init__(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self), __pyx_v_connection);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper___init__(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_connection) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "playhouse/_sqlite_ext.pyx":1442
 * 
 *     def __init__(self, connection):
 *         self.conn = <pysqlite_Connection *>connection             # <<<<<<<<<<<<<<
 *         self._commit_hook = self._rollback_hook = self._update_hook = None
 * 
 */
  __pyx_v_self->conn = ((pysqlite_Connection *)__pyx_v_connection);

  /* "playhouse/_sqlite_ext.pyx":1443
 *     def __init__(self, connection):
 *         self.conn = <pysqlite_Connection *>connection
 *         self._commit_hook = self._rollback_hook = self._update_hook = None             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_commit_hook);
  __Pyx_DECREF(__pyx_v_self->_commit_hook);
  __pyx_v_self->_commit_hook = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_rollback_hook);
  __Pyx_DECREF(__pyx_v_self->_rollback_hook);
  __pyx_v_self->_rollback_hook = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_update_hook);
  __Pyx_DECREF(__pyx_v_self->_update_hook);
  __pyx_v_self->_update_hook = Py_None;

  /* "playhouse/_sqlite_ext.pyx":1441
 *         pysqlite_Connection *conn
 * 
 *     def __init__(self, connection):             # <<<<<<<<<<<<<<
 *         self.conn = <pysqlite_Connection *>connection
 *         self._commit_hook = self._rollback_hook = self._update_hook = None
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1445
 *         self._commit_hook = self._rollback_hook = self._update_hook = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         # When deallocating a Database object, we need to ensure that we clear
 *         # any commit, rollback or update hooks that may have been applied.
 */

/* Python wrapper */
static void __pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_2__dealloc__(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_2__dealloc__(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "playhouse/_sqlite_ext.pyx":1448
 *         # When deallocating a Database object, we need to ensure that we clear
 *         # any commit, rollback or update hooks that may have been applied.
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->conn->initialized != 0));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_self->conn->db != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1449
 *         # any commit, rollback or update hooks that may have been applied.
 *         if not self.conn.initialized or not self.conn.db:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self._commit_hook is not None:
 */
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1448
 *         # When deallocating a Database object, we need to ensure that we clear
 *         # any commit, rollback or update hooks that may have been applied.
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1451
 *             return
 * 
 *         if self._commit_hook is not None:             # <<<<<<<<<<<<<<
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         if self._rollback_hook is not None:
 */
  __pyx_t_1 = (__pyx_v_self->_commit_hook != Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1452
 * 
 *         if self._commit_hook is not None:
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)             # <<<<<<<<<<<<<<
 *         if self._rollback_hook is not None:
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 */
    (void)(sqlite3_commit_hook(__pyx_v_self->conn->db, NULL, NULL));

    /* "playhouse/_sqlite_ext.pyx":1451
 *             return
 * 
 *         if self._commit_hook is not None:             # <<<<<<<<<<<<<<
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         if self._rollback_hook is not None:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1453
 *         if self._commit_hook is not None:
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         if self._rollback_hook is not None:             # <<<<<<<<<<<<<<
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         if self._update_hook is not None:
 */
  __pyx_t_1 = (__pyx_v_self->_rollback_hook != Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1454
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         if self._rollback_hook is not None:
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)             # <<<<<<<<<<<<<<
 *         if self._update_hook is not None:
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 */
    (void)(sqlite3_rollback_hook(__pyx_v_self->conn->db, NULL, NULL));

    /* "playhouse/_sqlite_ext.pyx":1453
 *         if self._commit_hook is not None:
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         if self._rollback_hook is not None:             # <<<<<<<<<<<<<<
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         if self._update_hook is not None:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1455
 *         if self._rollback_hook is not None:
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         if self._update_hook is not None:             # <<<<<<<<<<<<<<
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_update_hook != Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1456
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         if self._update_hook is not None:
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)             # <<<<<<<<<<<<<<
 * 
 *     def set_commit_hook(self, fn):
 */
    (void)(sqlite3_update_hook(__pyx_v_self->conn->db, NULL, NULL));

    /* "playhouse/_sqlite_ext.pyx":1455
 *         if self._rollback_hook is not None:
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         if self._update_hook is not None:             # <<<<<<<<<<<<<<
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1445
 *         self._commit_hook = self._rollback_hook = self._update_hook = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         # When deallocating a Database object, we need to ensure that we clear
 *         # any commit, rollback or update hooks that may have been applied.
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "playhouse/_sqlite_ext.pyx":1458
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 * 
 *     def set_commit_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_5set_commit_hook(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_5set_commit_hook = {"set_commit_hook", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_5set_commit_hook, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_5set_commit_hook(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_fn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_commit_hook (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fn,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1458, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_commit_hook") < 0)) __PYX_ERR(0, 1458, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_fn = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_commit_hook", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1458, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.set_commit_hook", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_4set_commit_hook(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self), __pyx_v_fn);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_4set_commit_hook(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_fn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_commit_hook", 0);

  /* "playhouse/_sqlite_ext.pyx":1459
 * 
 *     def set_commit_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->conn->initialized != 0));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_self->conn->db != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1460
 *     def set_commit_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._commit_hook = fn
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1459
 * 
 *     def set_commit_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1462
 *             return
 * 
 *         self._commit_hook = fn             # <<<<<<<<<<<<<<
 *         if fn is None:
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 */
  __Pyx_INCREF(__pyx_v_fn);
  __Pyx_GIVEREF(__pyx_v_fn);
  __Pyx_GOTREF(__pyx_v_self->_commit_hook);
  __Pyx_DECREF(__pyx_v_self->_commit_hook);
  __pyx_v_self->_commit_hook = __pyx_v_fn;

  /* "playhouse/_sqlite_ext.pyx":1463
 * 
 *         self._commit_hook = fn
 *         if fn is None:             # <<<<<<<<<<<<<<
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_fn == Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1464
 *         self._commit_hook = fn
 *         if fn is None:
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)             # <<<<<<<<<<<<<<
 *         else:
 *             sqlite3_commit_hook(self.conn.db, _commit_callback, <void *>fn)
 */
    (void)(sqlite3_commit_hook(__pyx_v_self->conn->db, NULL, NULL));

    /* "playhouse/_sqlite_ext.pyx":1463
 * 
 *         self._commit_hook = fn
 *         if fn is None:             # <<<<<<<<<<<<<<
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         else:
 */
    goto __pyx_L6;
  }

  /* "playhouse/_sqlite_ext.pyx":1466
 *             sqlite3_commit_hook(self.conn.db, NULL, NULL)
 *         else:
 *             sqlite3_commit_hook(self.conn.db, _commit_callback, <void *>fn)             # <<<<<<<<<<<<<<
 * 
 *     def set_rollback_hook(self, fn):
 */
  /*else*/ {
    (void)(sqlite3_commit_hook(__pyx_v_self->conn->db, __pyx_f_9playhouse_11_sqlite_ext__commit_callback, ((void *)__pyx_v_fn)));
  }
  __pyx_L6:;

  /* "playhouse/_sqlite_ext.pyx":1458
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 * 
 *     def set_commit_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1468
 *             sqlite3_commit_hook(self.conn.db, _commit_callback, <void *>fn)
 * 
 *     def set_rollback_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_7set_rollback_hook(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_7set_rollback_hook = {"set_rollback_hook", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_7set_rollback_hook, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_7set_rollback_hook(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_fn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_rollback_hook (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fn,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1468, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_rollback_hook") < 0)) __PYX_ERR(0, 1468, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_fn = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_rollback_hook", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1468, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.set_rollback_hook", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_6set_rollback_hook(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self), __pyx_v_fn);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_6set_rollback_hook(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_fn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_rollback_hook", 0);

  /* "playhouse/_sqlite_ext.pyx":1469
 * 
 *     def set_rollback_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->conn->initialized != 0));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_self->conn->db != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1470
 *     def set_rollback_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._rollback_hook = fn
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1469
 * 
 *     def set_rollback_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1472
 *             return
 * 
 *         self._rollback_hook = fn             # <<<<<<<<<<<<<<
 *         if fn is None:
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 */
  __Pyx_INCREF(__pyx_v_fn);
  __Pyx_GIVEREF(__pyx_v_fn);
  __Pyx_GOTREF(__pyx_v_self->_rollback_hook);
  __Pyx_DECREF(__pyx_v_self->_rollback_hook);
  __pyx_v_self->_rollback_hook = __pyx_v_fn;

  /* "playhouse/_sqlite_ext.pyx":1473
 * 
 *         self._rollback_hook = fn
 *         if fn is None:             # <<<<<<<<<<<<<<
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_fn == Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1474
 *         self._rollback_hook = fn
 *         if fn is None:
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)             # <<<<<<<<<<<<<<
 *         else:
 *             sqlite3_rollback_hook(self.conn.db, _rollback_callback, <void *>fn)
 */
    (void)(sqlite3_rollback_hook(__pyx_v_self->conn->db, NULL, NULL));

    /* "playhouse/_sqlite_ext.pyx":1473
 * 
 *         self._rollback_hook = fn
 *         if fn is None:             # <<<<<<<<<<<<<<
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         else:
 */
    goto __pyx_L6;
  }

  /* "playhouse/_sqlite_ext.pyx":1476
 *             sqlite3_rollback_hook(self.conn.db, NULL, NULL)
 *         else:
 *             sqlite3_rollback_hook(self.conn.db, _rollback_callback, <void *>fn)             # <<<<<<<<<<<<<<
 * 
 *     def set_update_hook(self, fn):
 */
  /*else*/ {
    (void)(sqlite3_rollback_hook(__pyx_v_self->conn->db, __pyx_f_9playhouse_11_sqlite_ext__rollback_callback, ((void *)__pyx_v_fn)));
  }
  __pyx_L6:;

  /* "playhouse/_sqlite_ext.pyx":1468
 *             sqlite3_commit_hook(self.conn.db, _commit_callback, <void *>fn)
 * 
 *     def set_rollback_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1478
 *             sqlite3_rollback_hook(self.conn.db, _rollback_callback, <void *>fn)
 * 
 *     def set_update_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_9set_update_hook(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_9set_update_hook = {"set_update_hook", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_9set_update_hook, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_9set_update_hook(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_fn = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_update_hook (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fn,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1478, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_update_hook") < 0)) __PYX_ERR(0, 1478, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_fn = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_update_hook", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1478, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.set_update_hook", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_8set_update_hook(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self), __pyx_v_fn);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_8set_update_hook(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_fn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_update_hook", 0);

  /* "playhouse/_sqlite_ext.pyx":1479
 * 
 *     def set_update_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->conn->initialized != 0));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_self->conn->db != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1480
 *     def set_update_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._update_hook = fn
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1479
 * 
 *     def set_update_hook(self, fn):
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1482
 *             return
 * 
 *         self._update_hook = fn             # <<<<<<<<<<<<<<
 *         if fn is None:
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 */
  __Pyx_INCREF(__pyx_v_fn);
  __Pyx_GIVEREF(__pyx_v_fn);
  __Pyx_GOTREF(__pyx_v_self->_update_hook);
  __Pyx_DECREF(__pyx_v_self->_update_hook);
  __pyx_v_self->_update_hook = __pyx_v_fn;

  /* "playhouse/_sqlite_ext.pyx":1483
 * 
 *         self._update_hook = fn
 *         if fn is None:             # <<<<<<<<<<<<<<
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_fn == Py_None);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1484
 *         self._update_hook = fn
 *         if fn is None:
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)             # <<<<<<<<<<<<<<
 *         else:
 *             sqlite3_update_hook(self.conn.db, _update_callback, <void *>fn)
 */
    (void)(sqlite3_update_hook(__pyx_v_self->conn->db, NULL, NULL));

    /* "playhouse/_sqlite_ext.pyx":1483
 * 
 *         self._update_hook = fn
 *         if fn is None:             # <<<<<<<<<<<<<<
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 *         else:
 */
    goto __pyx_L6;
  }

  /* "playhouse/_sqlite_ext.pyx":1486
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 *         else:
 *             sqlite3_update_hook(self.conn.db, _update_callback, <void *>fn)             # <<<<<<<<<<<<<<
 * 
 *     def set_busy_handler(self, timeout=5):
 */
  /*else*/ {
    (void)(sqlite3_update_hook(__pyx_v_self->conn->db, __pyx_f_9playhouse_11_sqlite_ext__update_callback, ((void *)__pyx_v_fn)));
  }
  __pyx_L6:;

  /* "playhouse/_sqlite_ext.pyx":1478
 *             sqlite3_rollback_hook(self.conn.db, _rollback_callback, <void *>fn)
 * 
 *     def set_update_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1488
 *             sqlite3_update_hook(self.conn.db, _update_callback, <void *>fn)
 * 
 *     def set_busy_handler(self, timeout=5):             # <<<<<<<<<<<<<<
 *         """
 *         Replace the default busy handler with one that introduces some "jitter"
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_11set_busy_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9playhouse_11_sqlite_ext_16ConnectionHelper_10set_busy_handler, "\n        Replace the default busy handler with one that introduces some \"jitter\"\n        into the amount of time delayed between checks.\n        ");
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_11set_busy_handler = {"set_busy_handler", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_11set_busy_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9playhouse_11_sqlite_ext_16ConnectionHelper_10set_busy_handler};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_11set_busy_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_busy_handler (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_timeout,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)__pyx_int_5);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_timeout);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1488, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_busy_handler") < 0)) __PYX_ERR(0, 1488, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_timeout = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_busy_handler", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1488, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.set_busy_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_10set_busy_handler(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self), __pyx_v_timeout);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_10set_busy_handler(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, PyObject *__pyx_v_timeout) {
  sqlite3_int64 __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  sqlite3_int64 __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_busy_handler", 0);

  /* "playhouse/_sqlite_ext.pyx":1493
 *         into the amount of time delayed between checks.
 *         """
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->conn->initialized != 0));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_self->conn->db != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1494
 *         """
 *         if not self.conn.initialized or not self.conn.db:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         cdef sqlite3_int64 n = timeout * 1000
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1493
 *         into the amount of time delayed between checks.
 *         """
 *         if not self.conn.initialized or not self.conn.db:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1496
 *             return False
 * 
 *         cdef sqlite3_int64 n = timeout * 1000             # <<<<<<<<<<<<<<
 *         sqlite3_busy_handler(self.conn.db, _aggressive_busy_handler, <void *>n)
 *         return True
 */
  __pyx_t_3 = __Pyx_PyInt_MultiplyObjC(__pyx_v_timeout, __pyx_int_1000, 0x3E8, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_As_sqlite3_int64(__pyx_t_3); if (unlikely((__pyx_t_4 == ((sqlite3_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1496, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_n = __pyx_t_4;

  /* "playhouse/_sqlite_ext.pyx":1497
 * 
 *         cdef sqlite3_int64 n = timeout * 1000
 *         sqlite3_busy_handler(self.conn.db, _aggressive_busy_handler, <void *>n)             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
  (void)(sqlite3_busy_handler(__pyx_v_self->conn->db, __pyx_f_9playhouse_11_sqlite_ext__aggressive_busy_handler, ((void *)__pyx_v_n)));

  /* "playhouse/_sqlite_ext.pyx":1498
 *         cdef sqlite3_int64 n = timeout * 1000
 *         sqlite3_busy_handler(self.conn.db, _aggressive_busy_handler, <void *>n)
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def changes(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1488
 *             sqlite3_update_hook(self.conn.db, _update_callback, <void *>fn)
 * 
 *     def set_busy_handler(self, timeout=5):             # <<<<<<<<<<<<<<
 *         """
 *         Replace the default busy handler with one that introduces some "jitter"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.set_busy_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1500
 *         return True
 * 
 *     def changes(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_changes(self.conn.db)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_13changes(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_13changes = {"changes", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_13changes, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_13changes(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("changes (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("changes", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "changes", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_12changes(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_12changes(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("changes", 0);

  /* "playhouse/_sqlite_ext.pyx":1501
 * 
 *     def changes(self):
 *         if self.conn.initialized and self.conn.db:             # <<<<<<<<<<<<<<
 *             return sqlite3_changes(self.conn.db)
 * 
 */
  __pyx_t_2 = (__pyx_v_self->conn->initialized != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->conn->db != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1502
 *     def changes(self):
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_changes(self.conn.db)             # <<<<<<<<<<<<<<
 * 
 *     def last_insert_rowid(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_From_int(sqlite3_changes(__pyx_v_self->conn->db)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1501
 * 
 *     def changes(self):
 *         if self.conn.initialized and self.conn.db:             # <<<<<<<<<<<<<<
 *             return sqlite3_changes(self.conn.db)
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1500
 *         return True
 * 
 *     def changes(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_changes(self.conn.db)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.changes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1504
 *             return sqlite3_changes(self.conn.db)
 * 
 *     def last_insert_rowid(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_15last_insert_rowid(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_15last_insert_rowid = {"last_insert_rowid", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_15last_insert_rowid, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_15last_insert_rowid(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("last_insert_rowid (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("last_insert_rowid", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "last_insert_rowid", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_14last_insert_rowid(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_14last_insert_rowid(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("last_insert_rowid", 0);

  /* "playhouse/_sqlite_ext.pyx":1505
 * 
 *     def last_insert_rowid(self):
 *         if self.conn.initialized and self.conn.db:             # <<<<<<<<<<<<<<
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 * 
 */
  __pyx_t_2 = (__pyx_v_self->conn->initialized != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->conn->db != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1506
 *     def last_insert_rowid(self):
 *         if self.conn.initialized and self.conn.db:
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)             # <<<<<<<<<<<<<<
 * 
 *     def autocommit(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_From_int(((int)sqlite3_last_insert_rowid(__pyx_v_self->conn->db))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1505
 * 
 *     def last_insert_rowid(self):
 *         if self.conn.initialized and self.conn.db:             # <<<<<<<<<<<<<<
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1504
 *             return sqlite3_changes(self.conn.db)
 * 
 *     def last_insert_rowid(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.last_insert_rowid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1508
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 * 
 *     def autocommit(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_get_autocommit(self.conn.db) != 0
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_17autocommit(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_17autocommit = {"autocommit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_17autocommit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_17autocommit(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("autocommit (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("autocommit", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "autocommit", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_16autocommit(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_16autocommit(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("autocommit", 0);

  /* "playhouse/_sqlite_ext.pyx":1509
 * 
 *     def autocommit(self):
 *         if self.conn.initialized and self.conn.db:             # <<<<<<<<<<<<<<
 *             return sqlite3_get_autocommit(self.conn.db) != 0
 * 
 */
  __pyx_t_2 = (__pyx_v_self->conn->initialized != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->conn->db != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1510
 *     def autocommit(self):
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_get_autocommit(self.conn.db) != 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyBool_FromLong((sqlite3_get_autocommit(__pyx_v_self->conn->db) != 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1509
 * 
 *     def autocommit(self):
 *         if self.conn.initialized and self.conn.db:             # <<<<<<<<<<<<<<
 *             return sqlite3_get_autocommit(self.conn.db) != 0
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1508
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 * 
 *     def autocommit(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_get_autocommit(self.conn.db) != 0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.autocommit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_19__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_19__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_19__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_19__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_18__reduce_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_18__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_conn_cannot_be_converted_to, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_21__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_21__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_21__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_21__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_20__setstate_cython__(((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_16ConnectionHelper_20__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_conn_cannot_be_converted_to, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.ConnectionHelper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1513
 * 
 * 
 * cdef int _commit_callback(void *userData) noexcept with gil:             # <<<<<<<<<<<<<<
 *     # C-callback that delegates to the Python commit handler. If the Python
 *     # function raises a ValueError, then the commit is aborted and the
 */

static int __pyx_f_9playhouse_11_sqlite_ext__commit_callback(void *__pyx_v_userData) {
  PyObject *__pyx_v_fn = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_commit_callback", 0);

  /* "playhouse/_sqlite_ext.pyx":1518
 *     # transaction rolled back. Otherwise, regardless of the function return
 *     # value, the transaction will commit.
 *     cdef object fn = <object>userData             # <<<<<<<<<<<<<<
 *     try:
 *         fn()
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_userData);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_fn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1519
 *     # value, the transaction will commit.
 *     cdef object fn = <object>userData
 *     try:             # <<<<<<<<<<<<<<
 *         fn()
 *     except ValueError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "playhouse/_sqlite_ext.pyx":1520
 *     cdef object fn = <object>userData
 *     try:
 *         fn()             # <<<<<<<<<<<<<<
 *     except ValueError:
 *         return 1
 */
      __Pyx_INCREF(__pyx_v_fn);
      __pyx_t_5 = __pyx_v_fn; __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      {
        PyObject *__pyx_callargs[1] = {__pyx_t_6, };
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1520, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "playhouse/_sqlite_ext.pyx":1519
 *     # value, the transaction will commit.
 *     cdef object fn = <object>userData
 *     try:             # <<<<<<<<<<<<<<
 *         fn()
 *     except ValueError:
 */
    }

    /* "playhouse/_sqlite_ext.pyx":1524
 *         return 1
 *     else:
 *         return SQLITE_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else:*/ {
      __pyx_r = SQLITE_OK;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "playhouse/_sqlite_ext.pyx":1521
 *     try:
 *         fn()
 *     except ValueError:             # <<<<<<<<<<<<<<
 *         return 1
 *     else:
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("playhouse._sqlite_ext._commit_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 1521, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "playhouse/_sqlite_ext.pyx":1522
 *         fn()
 *     except ValueError:
 *         return 1             # <<<<<<<<<<<<<<
 *     else:
 *         return SQLITE_OK
 */
      __pyx_r = 1;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "playhouse/_sqlite_ext.pyx":1519
 *     # value, the transaction will commit.
 *     cdef object fn = <object>userData
 *     try:             # <<<<<<<<<<<<<<
 *         fn()
 *     except ValueError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "playhouse/_sqlite_ext.pyx":1513
 * 
 * 
 * cdef int _commit_callback(void *userData) noexcept with gil:             # <<<<<<<<<<<<<<
 *     # C-callback that delegates to the Python commit handler. If the Python
 *     # function raises a ValueError, then the commit is aborted and the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext._commit_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1527
 * 
 * 
 * cdef void _rollback_callback(void *userData) noexcept with gil:             # <<<<<<<<<<<<<<
 *     # C-callback that delegates to the Python rollback handler.
 *     cdef object fn = <object>userData
 */

static void __pyx_f_9playhouse_11_sqlite_ext__rollback_callback(void *__pyx_v_userData) {
  PyObject *__pyx_v_fn = 0;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_rollback_callback", 0);

  /* "playhouse/_sqlite_ext.pyx":1529
 * cdef void _rollback_callback(void *userData) noexcept with gil:
 *     # C-callback that delegates to the Python rollback handler.
 *     cdef object fn = <object>userData             # <<<<<<<<<<<<<<
 *     fn()
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_userData);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_fn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1530
 *     # C-callback that delegates to the Python rollback handler.
 *     cdef object fn = <object>userData
 *     fn()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF(__pyx_v_fn);
  __pyx_t_2 = __pyx_v_fn; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_3, };
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1530, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1527
 * 
 * 
 * cdef void _rollback_callback(void *userData) noexcept with gil:             # <<<<<<<<<<<<<<
 *     # C-callback that delegates to the Python rollback handler.
 *     cdef object fn = <object>userData
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext._rollback_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "playhouse/_sqlite_ext.pyx":1533
 * 
 * 
 * cdef void _update_callback(void *userData, int queryType, const char *database,             # <<<<<<<<<<<<<<
 *                            const char *table, sqlite3_int64 rowid) noexcept with gil:
 *     # C-callback that delegates to a Python function that is executed whenever
 */

static void __pyx_f_9playhouse_11_sqlite_ext__update_callback(void *__pyx_v_userData, int __pyx_v_queryType, char const *__pyx_v_database, char const *__pyx_v_table, sqlite3_int64 __pyx_v_rowid) {
  PyObject *__pyx_v_fn = 0;
  PyObject *__pyx_v_query = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_update_callback", 0);

  /* "playhouse/_sqlite_ext.pyx":1540
 *     # database, the name of the table being updated, and the rowid of the row
 *     # being updatd.
 *     cdef object fn = <object>userData             # <<<<<<<<<<<<<<
 *     if queryType == SQLITE_INSERT:
 *         query = 'INSERT'
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_userData);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_fn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1541
 *     # being updatd.
 *     cdef object fn = <object>userData
 *     if queryType == SQLITE_INSERT:             # <<<<<<<<<<<<<<
 *         query = 'INSERT'
 *     elif queryType == SQLITE_UPDATE:
 */
  __pyx_t_2 = (__pyx_v_queryType == SQLITE_INSERT);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":1542
 *     cdef object fn = <object>userData
 *     if queryType == SQLITE_INSERT:
 *         query = 'INSERT'             # <<<<<<<<<<<<<<
 *     elif queryType == SQLITE_UPDATE:
 *         query = 'UPDATE'
 */
    __Pyx_INCREF(__pyx_n_u_INSERT);
    __pyx_v_query = __pyx_n_u_INSERT;

    /* "playhouse/_sqlite_ext.pyx":1541
 *     # being updatd.
 *     cdef object fn = <object>userData
 *     if queryType == SQLITE_INSERT:             # <<<<<<<<<<<<<<
 *         query = 'INSERT'
 *     elif queryType == SQLITE_UPDATE:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1543
 *     if queryType == SQLITE_INSERT:
 *         query = 'INSERT'
 *     elif queryType == SQLITE_UPDATE:             # <<<<<<<<<<<<<<
 *         query = 'UPDATE'
 *     elif queryType == SQLITE_DELETE:
 */
  __pyx_t_2 = (__pyx_v_queryType == SQLITE_UPDATE);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":1544
 *         query = 'INSERT'
 *     elif queryType == SQLITE_UPDATE:
 *         query = 'UPDATE'             # <<<<<<<<<<<<<<
 *     elif queryType == SQLITE_DELETE:
 *         query = 'DELETE'
 */
    __Pyx_INCREF(__pyx_n_u_UPDATE);
    __pyx_v_query = __pyx_n_u_UPDATE;

    /* "playhouse/_sqlite_ext.pyx":1543
 *     if queryType == SQLITE_INSERT:
 *         query = 'INSERT'
 *     elif queryType == SQLITE_UPDATE:             # <<<<<<<<<<<<<<
 *         query = 'UPDATE'
 *     elif queryType == SQLITE_DELETE:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1545
 *     elif queryType == SQLITE_UPDATE:
 *         query = 'UPDATE'
 *     elif queryType == SQLITE_DELETE:             # <<<<<<<<<<<<<<
 *         query = 'DELETE'
 *     else:
 */
  __pyx_t_2 = (__pyx_v_queryType == SQLITE_DELETE);
  if (__pyx_t_2) {

    /* "playhouse/_sqlite_ext.pyx":1546
 *         query = 'UPDATE'
 *     elif queryType == SQLITE_DELETE:
 *         query = 'DELETE'             # <<<<<<<<<<<<<<
 *     else:
 *         query = ''
 */
    __Pyx_INCREF(__pyx_n_u_DELETE);
    __pyx_v_query = __pyx_n_u_DELETE;

    /* "playhouse/_sqlite_ext.pyx":1545
 *     elif queryType == SQLITE_UPDATE:
 *         query = 'UPDATE'
 *     elif queryType == SQLITE_DELETE:             # <<<<<<<<<<<<<<
 *         query = 'DELETE'
 *     else:
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1548
 *         query = 'DELETE'
 *     else:
 *         query = ''             # <<<<<<<<<<<<<<
 *     fn(query, decode(database), decode(table), <int>rowid)
 * 
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_kp_u__10);
    __pyx_v_query = __pyx_kp_u__10;
  }
  __pyx_L3:;

  /* "playhouse/_sqlite_ext.pyx":1549
 *     else:
 *         query = ''
 *     fn(query, decode(database), decode(table), <int>rowid)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_database); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_9playhouse_11_sqlite_ext_decode(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_table); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_f_9playhouse_11_sqlite_ext_decode(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(((int)__pyx_v_rowid)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_fn);
  __pyx_t_6 = __pyx_v_fn; __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_query, __pyx_t_4, __pyx_t_5, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 4+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1533
 * 
 * 
 * cdef void _update_callback(void *userData, int queryType, const char *database,             # <<<<<<<<<<<<<<
 *                            const char *table, sqlite3_int64 rowid) noexcept with gil:
 *     # C-callback that delegates to a Python function that is executed whenever
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_WriteUnraisable("playhouse._sqlite_ext._update_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_XDECREF(__pyx_v_query);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "playhouse/_sqlite_ext.pyx":1552
 * 
 * 
 * def backup(src_conn, dest_conn, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bytes bname = encode(name or 'main')
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_31backup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_31backup = {"backup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_31backup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_31backup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_src_conn = 0;
  PyObject *__pyx_v_dest_conn = 0;
  PyObject *__pyx_v_pages = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_progress = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("backup (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_src_conn,&__pyx_n_s_dest_conn,&__pyx_n_s_pages,&__pyx_n_s_name,&__pyx_n_s_progress,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)Py_None));
    values[4] = ((PyObject *)((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_src_conn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1552, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dest_conn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1552, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("backup", 0, 2, 5, 1); __PYX_ERR(0, 1552, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pages);
          if (value) { values[2] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1552, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name);
          if (value) { values[3] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1552, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_progress);
          if (value) { values[4] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1552, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "backup") < 0)) __PYX_ERR(0, 1552, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_src_conn = values[0];
    __pyx_v_dest_conn = values[1];
    __pyx_v_pages = values[2];
    __pyx_v_name = values[3];
    __pyx_v_progress = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("backup", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 1552, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.backup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_30backup(__pyx_self, __pyx_v_src_conn, __pyx_v_dest_conn, __pyx_v_pages, __pyx_v_name, __pyx_v_progress);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_30backup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_src_conn, PyObject *__pyx_v_dest_conn, PyObject *__pyx_v_pages, PyObject *__pyx_v_name, PyObject *__pyx_v_progress) {
  PyObject *__pyx_v_bname = 0;
  int __pyx_v_page_step;
  int __pyx_v_rc;
  pysqlite_Connection *__pyx_v_src;
  pysqlite_Connection *__pyx_v_dest;
  sqlite3 *__pyx_v_src_db;
  sqlite3 *__pyx_v_dest_db;
  sqlite3_backup *__pyx_v_backup;
  int __pyx_v_remaining;
  int __pyx_v_page_count;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  sqlite3 *__pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("backup", 0);

  /* "playhouse/_sqlite_ext.pyx":1554
 * def backup(src_conn, dest_conn, pages=None, name=None, progress=None):
 *     cdef:
 *         bytes bname = encode(name or 'main')             # <<<<<<<<<<<<<<
 *         int page_step = pages or -1
 *         int rc
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_name); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1554, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_name);
    __pyx_t_1 = __pyx_v_name;
    goto __pyx_L3_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_n_u_main);
  __pyx_t_1 = __pyx_n_u_main;
  __pyx_L3_bool_binop_done:;
  __pyx_t_3 = __pyx_f_9playhouse_11_sqlite_ext_encode(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_bname = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1555
 *     cdef:
 *         bytes bname = encode(name or 'main')
 *         int page_step = pages or -1             # <<<<<<<<<<<<<<
 *         int rc
 *         pysqlite_Connection *src = <pysqlite_Connection *>src_conn
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_pages); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1555, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_pages); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1555, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = -1L;
  __pyx_L5_bool_binop_done:;
  __pyx_v_page_step = __pyx_t_4;

  /* "playhouse/_sqlite_ext.pyx":1557
 *         int page_step = pages or -1
 *         int rc
 *         pysqlite_Connection *src = <pysqlite_Connection *>src_conn             # <<<<<<<<<<<<<<
 *         pysqlite_Connection *dest = <pysqlite_Connection *>dest_conn
 *         sqlite3 *src_db = src.db
 */
  __pyx_v_src = ((pysqlite_Connection *)__pyx_v_src_conn);

  /* "playhouse/_sqlite_ext.pyx":1558
 *         int rc
 *         pysqlite_Connection *src = <pysqlite_Connection *>src_conn
 *         pysqlite_Connection *dest = <pysqlite_Connection *>dest_conn             # <<<<<<<<<<<<<<
 *         sqlite3 *src_db = src.db
 *         sqlite3 *dest_db = dest.db
 */
  __pyx_v_dest = ((pysqlite_Connection *)__pyx_v_dest_conn);

  /* "playhouse/_sqlite_ext.pyx":1559
 *         pysqlite_Connection *src = <pysqlite_Connection *>src_conn
 *         pysqlite_Connection *dest = <pysqlite_Connection *>dest_conn
 *         sqlite3 *src_db = src.db             # <<<<<<<<<<<<<<
 *         sqlite3 *dest_db = dest.db
 *         sqlite3_backup *backup
 */
  __pyx_t_6 = __pyx_v_src->db;
  __pyx_v_src_db = __pyx_t_6;

  /* "playhouse/_sqlite_ext.pyx":1560
 *         pysqlite_Connection *dest = <pysqlite_Connection *>dest_conn
 *         sqlite3 *src_db = src.db
 *         sqlite3 *dest_db = dest.db             # <<<<<<<<<<<<<<
 *         sqlite3_backup *backup
 * 
 */
  __pyx_t_6 = __pyx_v_dest->db;
  __pyx_v_dest_db = __pyx_t_6;

  /* "playhouse/_sqlite_ext.pyx":1563
 *         sqlite3_backup *backup
 * 
 *     if not src_db or not dest_db:             # <<<<<<<<<<<<<<
 *         raise OperationalError('cannot backup to or from a closed database')
 * 
 */
  __pyx_t_7 = (!(__pyx_v_src_db != 0));
  if (!__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_7 = (!(__pyx_v_dest_db != 0));
  __pyx_t_2 = __pyx_t_7;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1564
 * 
 *     if not src_db or not dest_db:
 *         raise OperationalError('cannot backup to or from a closed database')             # <<<<<<<<<<<<<<
 * 
 *     # We always backup to the "main" database in the dest db.
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    __pyx_t_4 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_u_cannot_backup_to_or_from_a_close};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1564, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1563
 *         sqlite3_backup *backup
 * 
 *     if not src_db or not dest_db:             # <<<<<<<<<<<<<<
 *         raise OperationalError('cannot backup to or from a closed database')
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1567
 * 
 *     # We always backup to the "main" database in the dest db.
 *     backup = sqlite3_backup_init(dest_db, b'main', src_db, bname)             # <<<<<<<<<<<<<<
 *     if backup == NULL:
 *         raise OperationalError('Unable to initialize backup.')
 */
  if (unlikely(__pyx_v_bname == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1567, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyBytes_AsString(__pyx_v_bname); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) __PYX_ERR(0, 1567, __pyx_L1_error)
  __pyx_v_backup = sqlite3_backup_init(__pyx_v_dest_db, ((char const *)"main"), __pyx_v_src_db, __pyx_t_9);

  /* "playhouse/_sqlite_ext.pyx":1568
 *     # We always backup to the "main" database in the dest db.
 *     backup = sqlite3_backup_init(dest_db, b'main', src_db, bname)
 *     if backup == NULL:             # <<<<<<<<<<<<<<
 *         raise OperationalError('Unable to initialize backup.')
 * 
 */
  __pyx_t_2 = (__pyx_v_backup == NULL);
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1569
 *     backup = sqlite3_backup_init(dest_db, b'main', src_db, bname)
 *     if backup == NULL:
 *         raise OperationalError('Unable to initialize backup.')             # <<<<<<<<<<<<<<
 * 
 *     while True:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    __pyx_t_4 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_u_Unable_to_initialize_backup};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1569, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1568
 *     # We always backup to the "main" database in the dest db.
 *     backup = sqlite3_backup_init(dest_db, b'main', src_db, bname)
 *     if backup == NULL:             # <<<<<<<<<<<<<<
 *         raise OperationalError('Unable to initialize backup.')
 * 
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1571
 *         raise OperationalError('Unable to initialize backup.')
 * 
 *     while True:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             rc = sqlite3_backup_step(backup, page_step)
 */
  while (1) {

    /* "playhouse/_sqlite_ext.pyx":1572
 * 
 *     while True:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_backup_step(backup, page_step)
 *         if progress is not None:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "playhouse/_sqlite_ext.pyx":1573
 *     while True:
 *         with nogil:
 *             rc = sqlite3_backup_step(backup, page_step)             # <<<<<<<<<<<<<<
 *         if progress is not None:
 *             # Progress-handler is called with (remaining, page count, is done?)
 */
          __pyx_v_rc = sqlite3_backup_step(__pyx_v_backup, __pyx_v_page_step);
        }

        /* "playhouse/_sqlite_ext.pyx":1572
 * 
 *     while True:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             rc = sqlite3_backup_step(backup, page_step)
 *         if progress is not None:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L17;
          }
          __pyx_L17:;
        }
    }

    /* "playhouse/_sqlite_ext.pyx":1574
 *         with nogil:
 *             rc = sqlite3_backup_step(backup, page_step)
 *         if progress is not None:             # <<<<<<<<<<<<<<
 *             # Progress-handler is called with (remaining, page count, is done?)
 *             remaining = sqlite3_backup_remaining(backup)
 */
    __pyx_t_2 = (__pyx_v_progress != Py_None);
    if (__pyx_t_2) {

      /* "playhouse/_sqlite_ext.pyx":1576
 *         if progress is not None:
 *             # Progress-handler is called with (remaining, page count, is done?)
 *             remaining = sqlite3_backup_remaining(backup)             # <<<<<<<<<<<<<<
 *             page_count = sqlite3_backup_pagecount(backup)
 *             try:
 */
      __pyx_v_remaining = sqlite3_backup_remaining(__pyx_v_backup);

      /* "playhouse/_sqlite_ext.pyx":1577
 *             # Progress-handler is called with (remaining, page count, is done?)
 *             remaining = sqlite3_backup_remaining(backup)
 *             page_count = sqlite3_backup_pagecount(backup)             # <<<<<<<<<<<<<<
 *             try:
 *                 progress(remaining, page_count, rc == SQLITE_DONE)
 */
      __pyx_v_page_count = sqlite3_backup_pagecount(__pyx_v_backup);

      /* "playhouse/_sqlite_ext.pyx":1578
 *             remaining = sqlite3_backup_remaining(backup)
 *             page_count = sqlite3_backup_pagecount(backup)
 *             try:             # <<<<<<<<<<<<<<
 *                 progress(remaining, page_count, rc == SQLITE_DONE)
 *             except:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        /*try:*/ {

          /* "playhouse/_sqlite_ext.pyx":1579
 *             page_count = sqlite3_backup_pagecount(backup)
 *             try:
 *                 progress(remaining, page_count, rc == SQLITE_DONE)             # <<<<<<<<<<<<<<
 *             except:
 *                 sqlite3_backup_finish(backup)
 */
          __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_remaining); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1579, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_page_count); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1579, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_13 = __Pyx_PyBool_FromLong((__pyx_v_rc == SQLITE_DONE)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1579, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_INCREF(__pyx_v_progress);
          __pyx_t_14 = __pyx_v_progress; __pyx_t_15 = NULL;
          __pyx_t_4 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_15)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_15);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
              __pyx_t_4 = 1;
            }
          }
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_15, __pyx_t_1, __pyx_t_8, __pyx_t_13};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1579, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "playhouse/_sqlite_ext.pyx":1578
 *             remaining = sqlite3_backup_remaining(backup)
 *             page_count = sqlite3_backup_pagecount(backup)
 *             try:             # <<<<<<<<<<<<<<
 *                 progress(remaining, page_count, rc == SQLITE_DONE)
 *             except:
 */
        }
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L26_try_end;
        __pyx_L19_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "playhouse/_sqlite_ext.pyx":1580
 *             try:
 *                 progress(remaining, page_count, rc == SQLITE_DONE)
 *             except:             # <<<<<<<<<<<<<<
 *                 sqlite3_backup_finish(backup)
 *                 raise
 */
        /*except:*/ {
          __Pyx_AddTraceback("playhouse._sqlite_ext.backup", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_14, &__pyx_t_13) < 0) __PYX_ERR(0, 1580, __pyx_L21_except_error)
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_13);

          /* "playhouse/_sqlite_ext.pyx":1581
 *                 progress(remaining, page_count, rc == SQLITE_DONE)
 *             except:
 *                 sqlite3_backup_finish(backup)             # <<<<<<<<<<<<<<
 *                 raise
 *         if rc == SQLITE_BUSY or rc == SQLITE_LOCKED:
 */
          (void)(sqlite3_backup_finish(__pyx_v_backup));

          /* "playhouse/_sqlite_ext.pyx":1582
 *             except:
 *                 sqlite3_backup_finish(backup)
 *                 raise             # <<<<<<<<<<<<<<
 *         if rc == SQLITE_BUSY or rc == SQLITE_LOCKED:
 *             with nogil:
 */
          __Pyx_GIVEREF(__pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_14, __pyx_t_13);
          __pyx_t_3 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; 
          __PYX_ERR(0, 1582, __pyx_L21_except_error)
        }

        /* "playhouse/_sqlite_ext.pyx":1578
 *             remaining = sqlite3_backup_remaining(backup)
 *             page_count = sqlite3_backup_pagecount(backup)
 *             try:             # <<<<<<<<<<<<<<
 *                 progress(remaining, page_count, rc == SQLITE_DONE)
 *             except:
 */
        __pyx_L21_except_error:;
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
        goto __pyx_L1_error;
        __pyx_L26_try_end:;
      }

      /* "playhouse/_sqlite_ext.pyx":1574
 *         with nogil:
 *             rc = sqlite3_backup_step(backup, page_step)
 *         if progress is not None:             # <<<<<<<<<<<<<<
 *             # Progress-handler is called with (remaining, page count, is done?)
 *             remaining = sqlite3_backup_remaining(backup)
 */
    }

    /* "playhouse/_sqlite_ext.pyx":1583
 *                 sqlite3_backup_finish(backup)
 *                 raise
 *         if rc == SQLITE_BUSY or rc == SQLITE_LOCKED:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sqlite3_sleep(250)
 */
    __pyx_t_7 = (__pyx_v_rc == SQLITE_BUSY);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_2 = __pyx_t_7;
      goto __pyx_L30_bool_binop_done;
    }
    __pyx_t_7 = (__pyx_v_rc == SQLITE_LOCKED);
    __pyx_t_2 = __pyx_t_7;
    __pyx_L30_bool_binop_done:;
    if (__pyx_t_2) {

      /* "playhouse/_sqlite_ext.pyx":1584
 *                 raise
 *         if rc == SQLITE_BUSY or rc == SQLITE_LOCKED:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sqlite3_sleep(250)
 *         elif rc == SQLITE_DONE:
 */
      {
          #ifdef WITH_THREAD
          PyThreadState *_save;
          _save = NULL;
          Py_UNBLOCK_THREADS
          __Pyx_FastGIL_Remember();
          #endif
          /*try:*/ {

            /* "playhouse/_sqlite_ext.pyx":1585
 *         if rc == SQLITE_BUSY or rc == SQLITE_LOCKED:
 *             with nogil:
 *                 sqlite3_sleep(250)             # <<<<<<<<<<<<<<
 *         elif rc == SQLITE_DONE:
 *             break
 */
            (void)(sqlite3_sleep(0xFA));
          }

          /* "playhouse/_sqlite_ext.pyx":1584
 *                 raise
 *         if rc == SQLITE_BUSY or rc == SQLITE_LOCKED:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sqlite3_sleep(250)
 *         elif rc == SQLITE_DONE:
 */
          /*finally:*/ {
            /*normal exit:*/{
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L36;
            }
            __pyx_L36:;
          }
      }

      /* "playhouse/_sqlite_ext.pyx":1583
 *                 sqlite3_backup_finish(backup)
 *                 raise
 *         if rc == SQLITE_BUSY or rc == SQLITE_LOCKED:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sqlite3_sleep(250)
 */
      goto __pyx_L29;
    }

    /* "playhouse/_sqlite_ext.pyx":1586
 *             with nogil:
 *                 sqlite3_sleep(250)
 *         elif rc == SQLITE_DONE:             # <<<<<<<<<<<<<<
 *             break
 * 
 */
    __pyx_t_2 = (__pyx_v_rc == SQLITE_DONE);
    if (__pyx_t_2) {

      /* "playhouse/_sqlite_ext.pyx":1587
 *                 sqlite3_sleep(250)
 *         elif rc == SQLITE_DONE:
 *             break             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
      goto __pyx_L12_break;

      /* "playhouse/_sqlite_ext.pyx":1586
 *             with nogil:
 *                 sqlite3_sleep(250)
 *         elif rc == SQLITE_DONE:             # <<<<<<<<<<<<<<
 *             break
 * 
 */
    }
    __pyx_L29:;
  }
  __pyx_L12_break:;

  /* "playhouse/_sqlite_ext.pyx":1589
 *             break
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sqlite3_backup_finish(backup)
 *     if sqlite3_errcode(dest_db):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "playhouse/_sqlite_ext.pyx":1590
 * 
 *     with nogil:
 *         sqlite3_backup_finish(backup)             # <<<<<<<<<<<<<<
 *     if sqlite3_errcode(dest_db):
 *         raise OperationalError('Error backuping up database: %s' %
 */
        (void)(sqlite3_backup_finish(__pyx_v_backup));
      }

      /* "playhouse/_sqlite_ext.pyx":1589
 *             break
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sqlite3_backup_finish(backup)
 *     if sqlite3_errcode(dest_db):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L39;
        }
        __pyx_L39:;
      }
  }

  /* "playhouse/_sqlite_ext.pyx":1591
 *     with nogil:
 *         sqlite3_backup_finish(backup)
 *     if sqlite3_errcode(dest_db):             # <<<<<<<<<<<<<<
 *         raise OperationalError('Error backuping up database: %s' %
 *                                sqlite3_errmsg(dest_db))
 */
  __pyx_t_2 = (sqlite3_errcode(__pyx_v_dest_db) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "playhouse/_sqlite_ext.pyx":1592
 *         sqlite3_backup_finish(backup)
 *     if sqlite3_errcode(dest_db):
 *         raise OperationalError('Error backuping up database: %s' %             # <<<<<<<<<<<<<<
 *                                sqlite3_errmsg(dest_db))
 *     return True
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);

    /* "playhouse/_sqlite_ext.pyx":1593
 *     if sqlite3_errcode(dest_db):
 *         raise OperationalError('Error backuping up database: %s' %
 *                                sqlite3_errmsg(dest_db))             # <<<<<<<<<<<<<<
 *     return True
 * 
 */
    __pyx_t_3 = __Pyx_PyBytes_FromString(sqlite3_errmsg(__pyx_v_dest_db)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "playhouse/_sqlite_ext.pyx":1592
 *         sqlite3_backup_finish(backup)
 *     if sqlite3_errcode(dest_db):
 *         raise OperationalError('Error backuping up database: %s' %             # <<<<<<<<<<<<<<
 *                                sqlite3_errmsg(dest_db))
 *     return True
 */
    __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_Error_backuping_up_database_s, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
        __pyx_t_4 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
      __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    }
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(0, 1592, __pyx_L1_error)

    /* "playhouse/_sqlite_ext.pyx":1591
 *     with nogil:
 *         sqlite3_backup_finish(backup)
 *     if sqlite3_errcode(dest_db):             # <<<<<<<<<<<<<<
 *         raise OperationalError('Error backuping up database: %s' %
 *                                sqlite3_errmsg(dest_db))
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1594
 *         raise OperationalError('Error backuping up database: %s' %
 *                                sqlite3_errmsg(dest_db))
 *     return True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1552
 * 
 * 
 * def backup(src_conn, dest_conn, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bytes bname = encode(name or 'main')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("playhouse._sqlite_ext.backup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1597
 * 
 * 
 * def backup_to_file(src_conn, filename, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     dest_conn = pysqlite.connect(filename)
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_33backup_to_file(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_33backup_to_file = {"backup_to_file", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_33backup_to_file, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_33backup_to_file(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_src_conn = 0;
  PyObject *__pyx_v_filename = 0;
  PyObject *__pyx_v_pages = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_progress = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("backup_to_file (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_src_conn,&__pyx_n_s_filename,&__pyx_n_s_pages,&__pyx_n_s_name,&__pyx_n_s_progress,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)Py_None));
    values[4] = ((PyObject *)((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_src_conn)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1597, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_filename)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1597, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("backup_to_file", 0, 2, 5, 1); __PYX_ERR(0, 1597, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pages);
          if (value) { values[2] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1597, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name);
          if (value) { values[3] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1597, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_progress);
          if (value) { values[4] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1597, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "backup_to_file") < 0)) __PYX_ERR(0, 1597, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_src_conn = values[0];
    __pyx_v_filename = values[1];
    __pyx_v_pages = values[2];
    __pyx_v_name = values[3];
    __pyx_v_progress = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("backup_to_file", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 1597, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.backup_to_file", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_32backup_to_file(__pyx_self, __pyx_v_src_conn, __pyx_v_filename, __pyx_v_pages, __pyx_v_name, __pyx_v_progress);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_32backup_to_file(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_src_conn, PyObject *__pyx_v_filename, PyObject *__pyx_v_pages, PyObject *__pyx_v_name, PyObject *__pyx_v_progress) {
  PyObject *__pyx_v_dest_conn = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("backup_to_file", 0);

  /* "playhouse/_sqlite_ext.pyx":1598
 * 
 * def backup_to_file(src_conn, filename, pages=None, name=None, progress=None):
 *     dest_conn = pysqlite.connect(filename)             # <<<<<<<<<<<<<<
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)
 *     dest_conn.close()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pysqlite); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_connect); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_filename};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_dest_conn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "playhouse/_sqlite_ext.pyx":1599
 * def backup_to_file(src_conn, filename, pages=None, name=None, progress=None):
 *     dest_conn = pysqlite.connect(filename)
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)             # <<<<<<<<<<<<<<
 *     dest_conn.close()
 *     return True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_backup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_src_conn);
  __Pyx_GIVEREF(__pyx_v_src_conn);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_src_conn);
  __Pyx_INCREF(__pyx_v_dest_conn);
  __Pyx_GIVEREF(__pyx_v_dest_conn);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_dest_conn);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_pages, __pyx_v_pages) < 0) __PYX_ERR(0, 1599, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_name, __pyx_v_name) < 0) __PYX_ERR(0, 1599, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_progress, __pyx_v_progress) < 0) __PYX_ERR(0, 1599, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "playhouse/_sqlite_ext.pyx":1600
 *     dest_conn = pysqlite.connect(filename)
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)
 *     dest_conn.close()             # <<<<<<<<<<<<<<
 *     return True
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_dest_conn, __pyx_n_s_close); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_3, };
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "playhouse/_sqlite_ext.pyx":1601
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)
 *     dest_conn.close()
 *     return True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1597
 * 
 * 
 * def backup_to_file(src_conn, filename, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     dest_conn = pysqlite.connect(filename)
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("playhouse._sqlite_ext.backup_to_file", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dest_conn);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "playhouse/_sqlite_ext.pyx":1604
 * 
 * 
 * cdef int _aggressive_busy_handler(void *ptr, int n) noexcept nogil:             # <<<<<<<<<<<<<<
 *     # In concurrent environments, it often seems that if multiple queries are
 *     # kicked off at around the same time, they proceed in lock-step to check
 */

static int __pyx_f_9playhouse_11_sqlite_ext__aggressive_busy_handler(void *__pyx_v_ptr, int __pyx_v_n) {
  sqlite3_int64 __pyx_v_busyTimeout;
  int __pyx_v_current;
  int __pyx_v_total;
  int __pyx_r;
  int __pyx_t_1;

  /* "playhouse/_sqlite_ext.pyx":1611
 *     # attempts in the same time period than the default handler.
 *     cdef:
 *         sqlite3_int64 busyTimeout = <sqlite3_int64>ptr             # <<<<<<<<<<<<<<
 *         int current, total
 * 
 */
  __pyx_v_busyTimeout = ((sqlite3_int64)__pyx_v_ptr);

  /* "playhouse/_sqlite_ext.pyx":1614
 *         int current, total
 * 
 *     if n < 20:             # <<<<<<<<<<<<<<
 *         current = 25 - (rand() % 10)  # ~20ms
 *         total = n * 20
 */
  __pyx_t_1 = (__pyx_v_n < 20);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1615
 * 
 *     if n < 20:
 *         current = 25 - (rand() % 10)  # ~20ms             # <<<<<<<<<<<<<<
 *         total = n * 20
 *     elif n < 40:
 */
    __pyx_v_current = (25 - __Pyx_mod_long(rand(), 10));

    /* "playhouse/_sqlite_ext.pyx":1616
 *     if n < 20:
 *         current = 25 - (rand() % 10)  # ~20ms
 *         total = n * 20             # <<<<<<<<<<<<<<
 *     elif n < 40:
 *         current = 50 - (rand() % 20)  # ~40ms
 */
    __pyx_v_total = (__pyx_v_n * 20);

    /* "playhouse/_sqlite_ext.pyx":1614
 *         int current, total
 * 
 *     if n < 20:             # <<<<<<<<<<<<<<
 *         current = 25 - (rand() % 10)  # ~20ms
 *         total = n * 20
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1617
 *         current = 25 - (rand() % 10)  # ~20ms
 *         total = n * 20
 *     elif n < 40:             # <<<<<<<<<<<<<<
 *         current = 50 - (rand() % 20)  # ~40ms
 *         total = 400 + ((n - 20) * 40)
 */
  __pyx_t_1 = (__pyx_v_n < 40);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1618
 *         total = n * 20
 *     elif n < 40:
 *         current = 50 - (rand() % 20)  # ~40ms             # <<<<<<<<<<<<<<
 *         total = 400 + ((n - 20) * 40)
 *     else:
 */
    __pyx_v_current = (50 - __Pyx_mod_long(rand(), 20));

    /* "playhouse/_sqlite_ext.pyx":1619
 *     elif n < 40:
 *         current = 50 - (rand() % 20)  # ~40ms
 *         total = 400 + ((n - 20) * 40)             # <<<<<<<<<<<<<<
 *     else:
 *         current = 120 - (rand() % 40)  # ~100ms
 */
    __pyx_v_total = (0x190 + ((__pyx_v_n - 20) * 40));

    /* "playhouse/_sqlite_ext.pyx":1617
 *         current = 25 - (rand() % 10)  # ~20ms
 *         total = n * 20
 *     elif n < 40:             # <<<<<<<<<<<<<<
 *         current = 50 - (rand() % 20)  # ~40ms
 *         total = 400 + ((n - 20) * 40)
 */
    goto __pyx_L3;
  }

  /* "playhouse/_sqlite_ext.pyx":1621
 *         total = 400 + ((n - 20) * 40)
 *     else:
 *         current = 120 - (rand() % 40)  # ~100ms             # <<<<<<<<<<<<<<
 *         total = 1200 + ((n - 40) * 100)  # Estimate the amount of time slept.
 * 
 */
  /*else*/ {
    __pyx_v_current = (0x78 - __Pyx_mod_long(rand(), 40));

    /* "playhouse/_sqlite_ext.pyx":1622
 *     else:
 *         current = 120 - (rand() % 40)  # ~100ms
 *         total = 1200 + ((n - 40) * 100)  # Estimate the amount of time slept.             # <<<<<<<<<<<<<<
 * 
 *     if total + current > busyTimeout:
 */
    __pyx_v_total = (0x4B0 + ((__pyx_v_n - 40) * 0x64));
  }
  __pyx_L3:;

  /* "playhouse/_sqlite_ext.pyx":1624
 *         total = 1200 + ((n - 40) * 100)  # Estimate the amount of time slept.
 * 
 *     if total + current > busyTimeout:             # <<<<<<<<<<<<<<
 *         current = busyTimeout - total
 *     if current > 0:
 */
  __pyx_t_1 = ((__pyx_v_total + __pyx_v_current) > __pyx_v_busyTimeout);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1625
 * 
 *     if total + current > busyTimeout:
 *         current = busyTimeout - total             # <<<<<<<<<<<<<<
 *     if current > 0:
 *         sqlite3_sleep(current)
 */
    __pyx_v_current = (__pyx_v_busyTimeout - __pyx_v_total);

    /* "playhouse/_sqlite_ext.pyx":1624
 *         total = 1200 + ((n - 40) * 100)  # Estimate the amount of time slept.
 * 
 *     if total + current > busyTimeout:             # <<<<<<<<<<<<<<
 *         current = busyTimeout - total
 *     if current > 0:
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1626
 *     if total + current > busyTimeout:
 *         current = busyTimeout - total
 *     if current > 0:             # <<<<<<<<<<<<<<
 *         sqlite3_sleep(current)
 *         return 1
 */
  __pyx_t_1 = (__pyx_v_current > 0);
  if (__pyx_t_1) {

    /* "playhouse/_sqlite_ext.pyx":1627
 *         current = busyTimeout - total
 *     if current > 0:
 *         sqlite3_sleep(current)             # <<<<<<<<<<<<<<
 *         return 1
 *     return 0
 */
    (void)(sqlite3_sleep(__pyx_v_current));

    /* "playhouse/_sqlite_ext.pyx":1628
 *     if current > 0:
 *         sqlite3_sleep(current)
 *         return 1             # <<<<<<<<<<<<<<
 *     return 0
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "playhouse/_sqlite_ext.pyx":1626
 *     if total + current > busyTimeout:
 *         current = busyTimeout - total
 *     if current > 0:             # <<<<<<<<<<<<<<
 *         sqlite3_sleep(current)
 *         return 1
 */
  }

  /* "playhouse/_sqlite_ext.pyx":1629
 *         sqlite3_sleep(current)
 *         return 1
 *     return 0             # <<<<<<<<<<<<<<
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "playhouse/_sqlite_ext.pyx":1604
 * 
 * 
 * cdef int _aggressive_busy_handler(void *ptr, int n) noexcept nogil:             # <<<<<<<<<<<<<<
 *     # In concurrent environments, it often seems that if multiple queries are
 *     # kicked off at around the same time, they proceed in lock-step to check
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_BloomFilterAggregate(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_35__pyx_unpickle_BloomFilterAggregate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9playhouse_11_sqlite_ext_35__pyx_unpickle_BloomFilterAggregate = {"__pyx_unpickle_BloomFilterAggregate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_35__pyx_unpickle_BloomFilterAggregate, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9playhouse_11_sqlite_ext_35__pyx_unpickle_BloomFilterAggregate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_BloomFilterAggregate (wrapper)", 0);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BloomFilterAggregate", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BloomFilterAggregate", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_BloomFilterAggregate") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BloomFilterAggregate", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("playhouse._sqlite_ext.__pyx_unpickle_BloomFilterAggregate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9playhouse_11_sqlite_ext_34__pyx_unpickle_BloomFilterAggregate(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9playhouse_11_sqlite_ext_34__pyx_unpickle_BloomFilterAggregate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BloomFilterAggregate", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x04e5ddb, 0xdba8929, 0xc9f9d7d):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__15, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x04e5ddb, 0xdba8929, 0xc9f9d7d):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum
 *     __pyx_result = BloomFilterAggregate.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0x04e5ddb, 0xdba8929, 0xc9f9d7d):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = BloomFilterAggregate.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x04e5ddb, 0xdba8929, 0xc9f9d7d):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum
 *     __pyx_result = BloomFilterAggregate.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BloomFilterAggregate__set_state(<BloomFilterAggregate> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum
 *     __pyx_result = BloomFilterAggregate.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BloomFilterAggregate__set_state(<BloomFilterAggregate> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = BloomFilterAggregate.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BloomFilterAggregate__set_state(<BloomFilterAggregate> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_BloomFilterAggregate__set_state(BloomFilterAggregate __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_9playhouse_11_sqlite_ext___pyx_unpickle_BloomFilterAggregate__set_state(((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum
 *     __pyx_result = BloomFilterAggregate.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BloomFilterAggregate__set_state(<BloomFilterAggregate> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BloomFilterAggregate__set_state(<BloomFilterAggregate> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_BloomFilterAggregate__set_state(BloomFilterAggregate __pyx_result, tuple __pyx_state):
 *     __pyx_result.bf = __pyx_state[0]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_BloomFilterAggregate(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("playhouse._sqlite_ext.__pyx_unpickle_BloomFilterAggregate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_BloomFilterAggregate__set_state(<BloomFilterAggregate> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BloomFilterAggregate__set_state(BloomFilterAggregate __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.bf = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_9playhouse_11_sqlite_ext___pyx_unpickle_BloomFilterAggregate__set_state(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BloomFilterAggregate__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_BloomFilterAggregate__set_state(BloomFilterAggregate __pyx_result, tuple __pyx_state):
 *     __pyx_result.bf = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->bf);
  __Pyx_DECREF((PyObject *)__pyx_v___pyx_result->bf);
  __pyx_v___pyx_result->bf = ((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_BloomFilterAggregate__set_state(BloomFilterAggregate __pyx_result, tuple __pyx_state):
 *     __pyx_result.bf = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 > 1);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.bf = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_BloomFilterAggregate__set_state(BloomFilterAggregate __pyx_result, tuple __pyx_state):
 *     __pyx_result.bf = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_BloomFilterAggregate__set_state(<BloomFilterAggregate> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BloomFilterAggregate__set_state(BloomFilterAggregate __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.bf = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("playhouse._sqlite_ext.__pyx_unpickle_BloomFilterAggregate__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_9playhouse_11_sqlite_ext__TableFunctionImpl __pyx_vtable_9playhouse_11_sqlite_ext__TableFunctionImpl;

static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext__TableFunctionImpl(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)o);
  p->__pyx_vtab = __pyx_vtabptr_9playhouse_11_sqlite_ext__TableFunctionImpl;
  p->table_function = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9playhouse_11_sqlite_ext__TableFunctionImpl(PyObject *o) {
  struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *p = (struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9playhouse_11_sqlite_ext__TableFunctionImpl) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table_function);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_9playhouse_11_sqlite_ext__TableFunctionImpl(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *p = (struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)o;
  if (p->table_function) {
    e = (*v)(p->table_function, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9playhouse_11_sqlite_ext__TableFunctionImpl(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *p = (struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *)o;
  tmp = ((PyObject*)p->table_function);
  p->table_function = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9playhouse_11_sqlite_ext__TableFunctionImpl[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_18_TableFunctionImpl_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9playhouse_11_sqlite_ext__TableFunctionImpl},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9playhouse_11_sqlite_ext__TableFunctionImpl},
  {Py_tp_clear, (void *)__pyx_tp_clear_9playhouse_11_sqlite_ext__TableFunctionImpl},
  {Py_tp_methods, (void *)__pyx_methods_9playhouse_11_sqlite_ext__TableFunctionImpl},
  {Py_tp_new, (void *)__pyx_tp_new_9playhouse_11_sqlite_ext__TableFunctionImpl},
  {0, 0},
};
static PyType_Spec __pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl_spec = {
  "playhouse._sqlite_ext._TableFunctionImpl",
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl_slots,
};
#else

static PyTypeObject __pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl = {
  PyVarObject_HEAD_INIT(0, 0)
  "playhouse._sqlite_ext.""_TableFunctionImpl", /*tp_name*/
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9playhouse_11_sqlite_ext__TableFunctionImpl, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9playhouse_11_sqlite_ext__TableFunctionImpl, /*tp_traverse*/
  __pyx_tp_clear_9playhouse_11_sqlite_ext__TableFunctionImpl, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9playhouse_11_sqlite_ext__TableFunctionImpl, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9playhouse_11_sqlite_ext__TableFunctionImpl, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilter(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  return o;
}

static void __pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilter(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilter) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_9playhouse_11_sqlite_ext_BloomFilter[] = {
  {"add", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_7add, METH_VARARGS|METH_KEYWORDS, 0},
  {"to_buffer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_11to_buffer, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"from_buffer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_13from_buffer, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"calculate_size", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_15calculate_size, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_17__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_19__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9playhouse_11_sqlite_ext_BloomFilter_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilter},
  {Py_sq_length, (void *)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_5__len__},
  {Py_sq_contains, (void *)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_9__contains__},
  {Py_mp_length, (void *)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_5__len__},
  {Py_tp_methods, (void *)__pyx_methods_9playhouse_11_sqlite_ext_BloomFilter},
  {Py_tp_init, (void *)__pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilter},
  {0, 0},
};
static PyType_Spec __pyx_type_9playhouse_11_sqlite_ext_BloomFilter_spec = {
  "playhouse._sqlite_ext.BloomFilter",
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_9playhouse_11_sqlite_ext_BloomFilter_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_BloomFilter = {
  __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_9__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_BloomFilter = {
  __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_9playhouse_11_sqlite_ext_BloomFilter = {
  PyVarObject_HEAD_INIT(0, 0)
  "playhouse._sqlite_ext.""BloomFilter", /*tp_name*/
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_BloomFilter, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_BloomFilter, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9playhouse_11_sqlite_ext_BloomFilter, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_9playhouse_11_sqlite_ext_11BloomFilter_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilterAggregate(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)o);
  p->bf = ((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilterAggregate(PyObject *o) {
  struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *p = (struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilterAggregate) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->bf);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_9playhouse_11_sqlite_ext_BloomFilterAggregate(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *p = (struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)o;
  if (p->bf) {
    e = (*v)(((PyObject *)p->bf), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9playhouse_11_sqlite_ext_BloomFilterAggregate(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *p = (struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate *)o;
  tmp = ((PyObject*)p->bf);
  p->bf = ((struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilter *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9playhouse_11_sqlite_ext_BloomFilterAggregate[] = {
  {"step", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_3step, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"finalize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_5finalize, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilterAggregate},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9playhouse_11_sqlite_ext_BloomFilterAggregate},
  {Py_tp_clear, (void *)__pyx_tp_clear_9playhouse_11_sqlite_ext_BloomFilterAggregate},
  {Py_tp_methods, (void *)__pyx_methods_9playhouse_11_sqlite_ext_BloomFilterAggregate},
  {Py_tp_init, (void *)__pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilterAggregate},
  {0, 0},
};
static PyType_Spec __pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate_spec = {
  "playhouse._sqlite_ext.BloomFilterAggregate",
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate_slots,
};
#else

static PyTypeObject __pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate = {
  PyVarObject_HEAD_INIT(0, 0)
  "playhouse._sqlite_ext.""BloomFilterAggregate", /*tp_name*/
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_BloomFilterAggregate), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9playhouse_11_sqlite_ext_BloomFilterAggregate, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9playhouse_11_sqlite_ext_BloomFilterAggregate, /*tp_traverse*/
  __pyx_tp_clear_9playhouse_11_sqlite_ext_BloomFilterAggregate, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9playhouse_11_sqlite_ext_BloomFilterAggregate, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_9playhouse_11_sqlite_ext_20BloomFilterAggregate_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9playhouse_11_sqlite_ext_BloomFilterAggregate, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9playhouse_11_sqlite_ext_Blob __pyx_vtable_9playhouse_11_sqlite_ext_Blob;

static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_Blob(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *)o);
  p->__pyx_vtab = __pyx_vtabptr_9playhouse_11_sqlite_ext_Blob;
  return o;
}

static void __pyx_tp_dealloc_9playhouse_11_sqlite_ext_Blob(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9playhouse_11_sqlite_ext_Blob) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9playhouse_11_sqlite_ext_4Blob_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}
static PyObject *__pyx_sq_item_9playhouse_11_sqlite_ext_Blob(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyMethodDef __pyx_methods_9playhouse_11_sqlite_ext_Blob[] = {
  {"read", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_9read, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"seek", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_11seek, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"tell", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_13tell, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"write", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_15write, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_17close, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"reopen", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_19reopen, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_21__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_23__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9playhouse_11_sqlite_ext_Blob_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9playhouse_11_sqlite_ext_Blob},
  {Py_sq_length, (void *)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_5__len__},
  {Py_sq_item, (void *)__pyx_sq_item_9playhouse_11_sqlite_ext_Blob},
  {Py_mp_length, (void *)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_5__len__},
  {Py_mp_subscript, (void *)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_7__getitem__},
  {Py_tp_methods, (void *)__pyx_methods_9playhouse_11_sqlite_ext_Blob},
  {Py_tp_init, (void *)__pyx_pw_9playhouse_11_sqlite_ext_4Blob_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_9playhouse_11_sqlite_ext_Blob},
  {0, 0},
};
static PyType_Spec __pyx_type_9playhouse_11_sqlite_ext_Blob_spec = {
  "playhouse._sqlite_ext.Blob",
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_9playhouse_11_sqlite_ext_Blob_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Blob = {
  __pyx_pw_9playhouse_11_sqlite_ext_4Blob_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_9playhouse_11_sqlite_ext_Blob, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Blob = {
  __pyx_pw_9playhouse_11_sqlite_ext_4Blob_5__len__, /*mp_length*/
  __pyx_pw_9playhouse_11_sqlite_ext_4Blob_7__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_9playhouse_11_sqlite_ext_Blob = {
  PyVarObject_HEAD_INIT(0, 0)
  "playhouse._sqlite_ext.""Blob", /*tp_name*/
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9playhouse_11_sqlite_ext_Blob, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Blob, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Blob, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9playhouse_11_sqlite_ext_Blob, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_9playhouse_11_sqlite_ext_4Blob_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9playhouse_11_sqlite_ext_Blob, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext_ConnectionHelper(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)o);
  p->_commit_hook = Py_None; Py_INCREF(Py_None);
  p->_rollback_hook = Py_None; Py_INCREF(Py_None);
  p->_update_hook = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9playhouse_11_sqlite_ext_ConnectionHelper(PyObject *o) {
  struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *p = (struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9playhouse_11_sqlite_ext_ConnectionHelper) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->_commit_hook);
  Py_CLEAR(p->_rollback_hook);
  Py_CLEAR(p->_update_hook);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_9playhouse_11_sqlite_ext_ConnectionHelper(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *p = (struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)o;
  if (p->_commit_hook) {
    e = (*v)(p->_commit_hook, a); if (e) return e;
  }
  if (p->_rollback_hook) {
    e = (*v)(p->_rollback_hook, a); if (e) return e;
  }
  if (p->_update_hook) {
    e = (*v)(p->_update_hook, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9playhouse_11_sqlite_ext_ConnectionHelper(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *p = (struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper *)o;
  tmp = ((PyObject*)p->_commit_hook);
  p->_commit_hook = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_rollback_hook);
  p->_rollback_hook = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_update_hook);
  p->_update_hook = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9playhouse_11_sqlite_ext_ConnectionHelper[] = {
  {"set_commit_hook", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_5set_commit_hook, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"set_rollback_hook", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_7set_rollback_hook, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"set_update_hook", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_9set_update_hook, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"set_busy_handler", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_11set_busy_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9playhouse_11_sqlite_ext_16ConnectionHelper_10set_busy_handler},
  {"changes", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_13changes, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"last_insert_rowid", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_15last_insert_rowid, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"autocommit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_17autocommit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_19__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_21__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9playhouse_11_sqlite_ext_ConnectionHelper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9playhouse_11_sqlite_ext_ConnectionHelper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9playhouse_11_sqlite_ext_ConnectionHelper},
  {Py_tp_methods, (void *)__pyx_methods_9playhouse_11_sqlite_ext_ConnectionHelper},
  {Py_tp_init, (void *)__pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_9playhouse_11_sqlite_ext_ConnectionHelper},
  {0, 0},
};
static PyType_Spec __pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper_spec = {
  "playhouse._sqlite_ext.ConnectionHelper",
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper_slots,
};
#else

static PyTypeObject __pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper = {
  PyVarObject_HEAD_INIT(0, 0)
  "playhouse._sqlite_ext.""ConnectionHelper", /*tp_name*/
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext_ConnectionHelper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9playhouse_11_sqlite_ext_ConnectionHelper, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9playhouse_11_sqlite_ext_ConnectionHelper, /*tp_traverse*/
  __pyx_tp_clear_9playhouse_11_sqlite_ext_ConnectionHelper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9playhouse_11_sqlite_ext_ConnectionHelper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_9playhouse_11_sqlite_ext_16ConnectionHelper_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9playhouse_11_sqlite_ext_ConnectionHelper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *__pyx_freelist_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash[8];
static int __pyx_freecount_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash = 0;

static PyObject *__pyx_tp_new_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (CYTHON_COMPILING_IN_CPYTHON && likely((int)(__pyx_freecount_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash)))) {
    o = (PyObject*)__pyx_freelist_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash[--__pyx_freecount_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash];
    memset(o, 0, sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash(PyObject *o) {
  struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *p = (struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_hash_impl);
  if (CYTHON_COMPILING_IN_CPYTHON && ((int)(__pyx_freecount_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash)))) {
    __pyx_freelist_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash[__pyx_freecount_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash++] = ((struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *p = (struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *)o;
  if (p->__pyx_v_hash_impl) {
    e = (*v)(p->__pyx_v_hash_impl, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *p = (struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash *)o;
  tmp = ((PyObject*)p->__pyx_v_hash_impl);
  p->__pyx_v_hash_impl = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash},
  {Py_tp_clear, (void *)__pyx_tp_clear_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash},
  {Py_tp_new, (void *)__pyx_tp_new_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash},
  {0, 0},
};
static PyType_Spec __pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash_spec = {
  "playhouse._sqlite_ext.__pyx_scope_struct__make_hash",
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash_slots,
};
#else

static PyTypeObject __pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash = {
  PyVarObject_HEAD_INIT(0, 0)
  "playhouse._sqlite_ext.""__pyx_scope_struct__make_hash", /*tp_name*/
  sizeof(struct __pyx_obj_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash, /*tp_traverse*/
  __pyx_tp_clear_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_b_3_26, __pyx_k_3_26, sizeof(__pyx_k_3_26), 0, 0, 0, 0},
    {&__pyx_n_s_A_O, __pyx_k_A_O, sizeof(__pyx_k_A_O), 0, 0, 1, 1},
    {&__pyx_n_s_B, __pyx_k_B, sizeof(__pyx_k_B), 0, 0, 1, 1},
    {&__pyx_n_s_Binary, __pyx_k_Binary, sizeof(__pyx_k_Binary), 0, 0, 1, 1},
    {&__pyx_n_s_Blob, __pyx_k_Blob, sizeof(__pyx_k_Blob), 0, 0, 1, 1},
    {&__pyx_n_s_Blob___reduce_cython, __pyx_k_Blob___reduce_cython, sizeof(__pyx_k_Blob___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Blob___setstate_cython, __pyx_k_Blob___setstate_cython, sizeof(__pyx_k_Blob___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Blob_close, __pyx_k_Blob_close, sizeof(__pyx_k_Blob_close), 0, 0, 1, 1},
    {&__pyx_kp_u_Blob_index_out_of_range, __pyx_k_Blob_index_out_of_range, sizeof(__pyx_k_Blob_index_out_of_range), 0, 1, 0, 0},
    {&__pyx_n_s_Blob_read, __pyx_k_Blob_read, sizeof(__pyx_k_Blob_read), 0, 0, 1, 1},
    {&__pyx_n_s_Blob_reopen, __pyx_k_Blob_reopen, sizeof(__pyx_k_Blob_reopen), 0, 0, 1, 1},
    {&__pyx_n_s_Blob_seek, __pyx_k_Blob_seek, sizeof(__pyx_k_Blob_seek), 0, 0, 1, 1},
    {&__pyx_n_s_Blob_tell, __pyx_k_Blob_tell, sizeof(__pyx_k_Blob_tell), 0, 0, 1, 1},
    {&__pyx_n_s_Blob_write, __pyx_k_Blob_write, sizeof(__pyx_k_Blob_write), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilter, __pyx_k_BloomFilter, sizeof(__pyx_k_BloomFilter), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilterAggregate, __pyx_k_BloomFilterAggregate, sizeof(__pyx_k_BloomFilterAggregate), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilterAggregate___reduce_cy, __pyx_k_BloomFilterAggregate___reduce_cy, sizeof(__pyx_k_BloomFilterAggregate___reduce_cy), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilterAggregate___setstate, __pyx_k_BloomFilterAggregate___setstate, sizeof(__pyx_k_BloomFilterAggregate___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilterAggregate_finalize, __pyx_k_BloomFilterAggregate_finalize, sizeof(__pyx_k_BloomFilterAggregate_finalize), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilterAggregate_step, __pyx_k_BloomFilterAggregate_step, sizeof(__pyx_k_BloomFilterAggregate_step), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilter___reduce_cython, __pyx_k_BloomFilter___reduce_cython, sizeof(__pyx_k_BloomFilter___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilter___setstate_cython, __pyx_k_BloomFilter___setstate_cython, sizeof(__pyx_k_BloomFilter___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilter_add, __pyx_k_BloomFilter_add, sizeof(__pyx_k_BloomFilter_add), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilter_calculate_size, __pyx_k_BloomFilter_calculate_size, sizeof(__pyx_k_BloomFilter_calculate_size), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilter_from_buffer, __pyx_k_BloomFilter_from_buffer, sizeof(__pyx_k_BloomFilter_from_buffer), 0, 0, 1, 1},
    {&__pyx_n_s_BloomFilter_to_buffer, __pyx_k_BloomFilter_to_buffer, sizeof(__pyx_k_BloomFilter_to_buffer), 0, 0, 1, 1},
    {&__pyx_kp_u_CREATE_TABLE_x_s, __pyx_k_CREATE_TABLE_x_s, sizeof(__pyx_k_CREATE_TABLE_x_s), 0, 1, 0, 0},
    {&__pyx_n_s_C_O, __pyx_k_C_O, sizeof(__pyx_k_C_O), 0, 0, 1, 1},
    {&__pyx_kp_u_Cannot_operate_on_closed_blob, __pyx_k_Cannot_operate_on_closed_blob, sizeof(__pyx_k_Cannot_operate_on_closed_blob), 0, 1, 0, 0},
    {&__pyx_kp_u_Cannot_operate_on_closed_databas, __pyx_k_Cannot_operate_on_closed_databas, sizeof(__pyx_k_Cannot_operate_on_closed_databas), 0, 1, 0, 0},
    {&__pyx_kp_u_Column_must_be_either_a_string_o, __pyx_k_Column_must_be_either_a_string_o, sizeof(__pyx_k_Column_must_be_either_a_string_o), 0, 1, 0, 0},
    {&__pyx_n_s_ConnectionHelper, __pyx_k_ConnectionHelper, sizeof(__pyx_k_ConnectionHelper), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper___reduce_cython, __pyx_k_ConnectionHelper___reduce_cython, sizeof(__pyx_k_ConnectionHelper___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper___setstate_cyth, __pyx_k_ConnectionHelper___setstate_cyth, sizeof(__pyx_k_ConnectionHelper___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper_autocommit, __pyx_k_ConnectionHelper_autocommit, sizeof(__pyx_k_ConnectionHelper_autocommit), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper_changes, __pyx_k_ConnectionHelper_changes, sizeof(__pyx_k_ConnectionHelper_changes), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper_last_insert_row, __pyx_k_ConnectionHelper_last_insert_row, sizeof(__pyx_k_ConnectionHelper_last_insert_row), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper_set_busy_handle, __pyx_k_ConnectionHelper_set_busy_handle, sizeof(__pyx_k_ConnectionHelper_set_busy_handle), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper_set_commit_hook, __pyx_k_ConnectionHelper_set_commit_hook, sizeof(__pyx_k_ConnectionHelper_set_commit_hook), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper_set_rollback_ho, __pyx_k_ConnectionHelper_set_rollback_ho, sizeof(__pyx_k_ConnectionHelper_set_rollback_ho), 0, 0, 1, 1},
    {&__pyx_n_s_ConnectionHelper_set_update_hook, __pyx_k_ConnectionHelper_set_update_hook, sizeof(__pyx_k_ConnectionHelper_set_update_hook), 0, 0, 1, 1},
    {&__pyx_n_u_DELETE, __pyx_k_DELETE, sizeof(__pyx_k_DELETE), 0, 1, 0, 1},
    {&__pyx_kp_u_Data_would_go_beyond_end_of_blob, __pyx_k_Data_would_go_beyond_end_of_blob, sizeof(__pyx_k_Data_would_go_beyond_end_of_blob), 0, 1, 0, 0},
    {&__pyx_kp_u_Error_backuping_up_database_s, __pyx_k_Error_backuping_up_database_s, sizeof(__pyx_k_Error_backuping_up_database_s), 0, 1, 0, 0},
    {&__pyx_kp_u_Error_reading_from_blob, __pyx_k_Error_reading_from_blob, sizeof(__pyx_k_Error_reading_from_blob), 0, 1, 0, 0},
    {&__pyx_kp_u_Error_requesting_db_status_s, __pyx_k_Error_requesting_db_status_s, sizeof(__pyx_k_Error_requesting_db_status_s), 0, 1, 0, 0},
    {&__pyx_kp_u_Error_requesting_status_s, __pyx_k_Error_requesting_status_s, sizeof(__pyx_k_Error_requesting_status_s), 0, 1, 0, 0},
    {&__pyx_kp_u_Error_writing_to_blob, __pyx_k_Error_writing_to_blob, sizeof(__pyx_k_Error_writing_to_blob), 0, 1, 0, 0},
    {&__pyx_n_u_INSERT, __pyx_k_INSERT, sizeof(__pyx_k_INSERT), 0, 1, 0, 1},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
    {&__pyx_n_s_InterfaceError, __pyx_k_InterfaceError, sizeof(__pyx_k_InterfaceError), 0, 0, 1, 1},
    {&__pyx_n_s_K, __pyx_k_K, sizeof(__pyx_k_K), 0, 0, 1, 1},
    {&__pyx_n_s_L_O, __pyx_k_L_O, sizeof(__pyx_k_L_O), 0, 0, 1, 1},
    {&__pyx_kp_u_Length_must_be_a_positive_intege, __pyx_k_Length_must_be_a_positive_intege, sizeof(__pyx_k_Length_must_be_a_positive_intege), 0, 1, 0, 0},
    {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
    {&__pyx_n_s_N_O, __pyx_k_N_O, sizeof(__pyx_k_N_O), 0, 0, 1, 1},
    {&__pyx_n_s_Node, __pyx_k_Node, sizeof(__pyx_k_Node), 0, 0, 1, 1},
    {&__pyx_n_s_NotImplementedError, __pyx_k_NotImplementedError, sizeof(__pyx_k_NotImplementedError), 0, 0, 1, 1},
    {&__pyx_n_s_OperationalError, __pyx_k_OperationalError, sizeof(__pyx_k_OperationalError), 0, 0, 1, 1},
    {&__pyx_n_s_P_O, __pyx_k_P_O, sizeof(__pyx_k_P_O), 0, 0, 1, 1},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
    {&__pyx_n_s_StopIteration, __pyx_k_StopIteration, sizeof(__pyx_k_StopIteration), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunction, __pyx_k_TableFunction, sizeof(__pyx_k_TableFunction), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunctionImpl, __pyx_k_TableFunctionImpl, sizeof(__pyx_k_TableFunctionImpl), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunctionImpl___reduce_cyth, __pyx_k_TableFunctionImpl___reduce_cyth, sizeof(__pyx_k_TableFunctionImpl___reduce_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunctionImpl___setstate_cy, __pyx_k_TableFunctionImpl___setstate_cy, sizeof(__pyx_k_TableFunctionImpl___setstate_cy), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunction_get_table_columns, __pyx_k_TableFunction_get_table_columns, sizeof(__pyx_k_TableFunction_get_table_columns), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunction_initialize, __pyx_k_TableFunction_initialize, sizeof(__pyx_k_TableFunction_initialize), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunction_iterate, __pyx_k_TableFunction_iterate, sizeof(__pyx_k_TableFunction_iterate), 0, 0, 1, 1},
    {&__pyx_n_s_TableFunction_register, __pyx_k_TableFunction_register, sizeof(__pyx_k_TableFunction_register), 0, 0, 1, 1},
    {&__pyx_kp_u_Time_zones_are_not_available_fro, __pyx_k_Time_zones_are_not_available_fro, sizeof(__pyx_k_Time_zones_are_not_available_fro), 0, 1, 0, 0},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_n_u_UPDATE, __pyx_k_UPDATE, sizeof(__pyx_k_UPDATE), 0, 1, 0, 1},
    {&__pyx_n_s_USE_SQLITE_CONSTRAINT, __pyx_k_USE_SQLITE_CONSTRAINT, sizeof(__pyx_k_USE_SQLITE_CONSTRAINT), 0, 0, 1, 1},
    {&__pyx_kp_u_Unable_to_allocate_blob, __pyx_k_Unable_to_allocate_blob, sizeof(__pyx_k_Unable_to_allocate_blob), 0, 1, 0, 0},
    {&__pyx_kp_u_Unable_to_initialize_backup, __pyx_k_Unable_to_initialize_backup, sizeof(__pyx_k_Unable_to_initialize_backup), 0, 1, 0, 0},
    {&__pyx_kp_u_Unable_to_open_blob, __pyx_k_Unable_to_open_blob, sizeof(__pyx_k_Unable_to_open_blob), 0, 1, 0, 0},
    {&__pyx_kp_u_Unable_to_re_open_blob, __pyx_k_Unable_to_re_open_blob, sizeof(__pyx_k_Unable_to_re_open_blob), 0, 1, 0, 0},
    {&__pyx_kp_u_Unsupported_type_s, __pyx_k_Unsupported_type_s, sizeof(__pyx_k_Unsupported_type_s), 0, 1, 0, 0},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_s_X_O, __pyx_k_X_O, sizeof(__pyx_k_X_O), 0, 0, 1, 1},
    {&__pyx_n_s_ZeroBlob, __pyx_k_ZeroBlob, sizeof(__pyx_k_ZeroBlob), 0, 0, 1, 1},
    {&__pyx_n_s_ZeroBlob___init, __pyx_k_ZeroBlob___init, sizeof(__pyx_k_ZeroBlob___init), 0, 0, 1, 1},
    {&__pyx_n_s_ZeroBlob___sql, __pyx_k_ZeroBlob___sql, sizeof(__pyx_k_ZeroBlob___sql), 0, 0, 1, 1},
    {&__pyx_kp_b__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 0, 0, 0},
    {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
    {&__pyx_n_s__115, __pyx_k__115, sizeof(__pyx_k__115), 0, 0, 1, 1},
    {&__pyx_kp_u__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 1, 0, 0},
    {&__pyx_n_s__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 0, 1, 1},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
    {&__pyx_kp_u__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 1, 0, 0},
    {&__pyx_n_s_accum, __pyx_k_accum, sizeof(__pyx_k_accum), 0, 0, 1, 1},
    {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
    {&__pyx_n_s_adler32, __pyx_k_adler32, sizeof(__pyx_k_adler32), 0, 0, 1, 1},
    {&__pyx_n_u_adler32, __pyx_k_adler32, sizeof(__pyx_k_adler32), 0, 1, 0, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_autocommit, __pyx_k_autocommit, sizeof(__pyx_k_autocommit), 0, 0, 1, 1},
    {&__pyx_n_s_avg_length, __pyx_k_avg_length, sizeof(__pyx_k_avg_length), 0, 0, 1, 1},
    {&__pyx_n_s_b_part, __pyx_k_b_part, sizeof(__pyx_k_b_part), 0, 0, 1, 1},
    {&__pyx_n_s_backup, __pyx_k_backup, sizeof(__pyx_k_backup), 0, 0, 1, 1},
    {&__pyx_n_s_backup_to_file, __pyx_k_backup_to_file, sizeof(__pyx_k_backup_to_file), 0, 0, 1, 1},
    {&__pyx_n_s_bdata, __pyx_k_bdata, sizeof(__pyx_k_bdata), 0, 0, 1, 1},
    {&__pyx_n_s_bf, __pyx_k_bf, sizeof(__pyx_k_bf), 0, 0, 1, 1},
    {&__pyx_n_s_bkey, __pyx_k_bkey, sizeof(__pyx_k_bkey), 0, 0, 1, 1},
    {&__pyx_n_s_bloom, __pyx_k_bloom, sizeof(__pyx_k_bloom), 0, 0, 1, 1},
    {&__pyx_n_u_bloomfilter, __pyx_k_bloomfilter, sizeof(__pyx_k_bloomfilter), 0, 1, 0, 1},
    {&__pyx_n_u_bloomfilter_add, __pyx_k_bloomfilter_add, sizeof(__pyx_k_bloomfilter_add), 0, 1, 0, 1},
    {&__pyx_n_u_bloomfilter_calculate_size, __pyx_k_bloomfilter_calculate_size, sizeof(__pyx_k_bloomfilter_calculate_size), 0, 1, 0, 1},
    {&__pyx_n_u_bloomfilter_contains, __pyx_k_bloomfilter_contains, sizeof(__pyx_k_bloomfilter_contains), 0, 1, 0, 1},
    {&__pyx_n_s_bname, __pyx_k_bname, sizeof(__pyx_k_bname), 0, 0, 1, 1},
    {&__pyx_n_s_buf, __pyx_k_buf, sizeof(__pyx_k_buf), 0, 0, 1, 1},
    {&__pyx_n_s_buflen, __pyx_k_buflen, sizeof(__pyx_k_buflen), 0, 0, 1, 1},
    {&__pyx_n_s_c_conn, __pyx_k_c_conn, sizeof(__pyx_k_c_conn), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_size, __pyx_k_calculate_size, sizeof(__pyx_k_calculate_size), 0, 0, 1, 1},
    {&__pyx_kp_u_cannot_backup_to_or_from_a_close, __pyx_k_cannot_backup_to_or_from_a_close, sizeof(__pyx_k_cannot_backup_to_or_from_a_close), 0, 1, 0, 0},
    {&__pyx_n_s_cdata, __pyx_k_cdata, sizeof(__pyx_k_cdata), 0, 0, 1, 1},
    {&__pyx_n_s_changes, __pyx_k_changes, sizeof(__pyx_k_changes), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
    {&__pyx_n_s_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 0, 1, 1},
    {&__pyx_n_s_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 0, 1, 1},
    {&__pyx_n_s_conn, __pyx_k_conn, sizeof(__pyx_k_conn), 0, 0, 1, 1},
    {&__pyx_n_s_connect, __pyx_k_connect, sizeof(__pyx_k_connect), 0, 0, 1, 1},
    {&__pyx_n_s_connection, __pyx_k_connection, sizeof(__pyx_k_connection), 0, 0, 1, 1},
    {&__pyx_n_s_crc32, __pyx_k_crc32, sizeof(__pyx_k_crc32), 0, 0, 1, 1},
    {&__pyx_n_u_crc32, __pyx_k_crc32, sizeof(__pyx_k_crc32), 0, 1, 0, 1},
    {&__pyx_n_s_ctx, __pyx_k_ctx, sizeof(__pyx_k_ctx), 0, 0, 1, 1},
    {&__pyx_n_s_current, __pyx_k_current, sizeof(__pyx_k_current), 0, 0, 1, 1},
    {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
    {&__pyx_n_s_database, __pyx_k_database, sizeof(__pyx_k_database), 0, 0, 1, 1},
    {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
    {&__pyx_n_s_denom, __pyx_k_denom, sizeof(__pyx_k_denom), 0, 0, 1, 1},
    {&__pyx_n_s_dest, __pyx_k_dest, sizeof(__pyx_k_dest), 0, 0, 1, 1},
    {&__pyx_n_s_dest_conn, __pyx_k_dest_conn, sizeof(__pyx_k_dest_conn), 0, 0, 1, 1},
    {&__pyx_n_s_dest_db, __pyx_k_dest_db, sizeof(__pyx_k_dest_db), 0, 0, 1, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
    {&__pyx_n_s_doc_length, __pyx_k_doc_length, sizeof(__pyx_k_doc_length), 0, 0, 1, 1},
    {&__pyx_n_s_docs_with_term, __pyx_k_docs_with_term, sizeof(__pyx_k_docs_with_term), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
    {&__pyx_n_s_epsilon, __pyx_k_epsilon, sizeof(__pyx_k_epsilon), 0, 0, 1, 1},
    {&__pyx_n_s_error_p, __pyx_k_error_p, sizeof(__pyx_k_error_p), 0, 0, 1, 1},
    {&__pyx_n_s_fieldNorms, __pyx_k_fieldNorms, sizeof(__pyx_k_fieldNorms), 0, 0, 1, 1},
    {&__pyx_n_s_filename, __pyx_k_filename, sizeof(__pyx_k_filename), 0, 0, 1, 1},
    {&__pyx_n_s_filters, __pyx_k_filters, sizeof(__pyx_k_filters), 0, 0, 1, 1},
    {&__pyx_n_s_finalize, __pyx_k_finalize, sizeof(__pyx_k_finalize), 0, 0, 1, 1},
    {&__pyx_n_s_flag, __pyx_k_flag, sizeof(__pyx_k_flag), 0, 0, 1, 1},
    {&__pyx_n_s_fn, __pyx_k_fn, sizeof(__pyx_k_fn), 0, 0, 1, 1},
    {&__pyx_n_s_frame_of_reference, __pyx_k_frame_of_reference, sizeof(__pyx_k_frame_of_reference), 0, 0, 1, 1},
    {&__pyx_n_s_from_buffer, __pyx_k_from_buffer, sizeof(__pyx_k_from_buffer), 0, 0, 1, 1},
    {&__pyx_n_u_fts_bm25, __pyx_k_fts_bm25, sizeof(__pyx_k_fts_bm25), 0, 1, 0, 1},
    {&__pyx_n_u_fts_bm25f, __pyx_k_fts_bm25f, sizeof(__pyx_k_fts_bm25f), 0, 1, 0, 1},
    {&__pyx_n_u_fts_lucene, __pyx_k_fts_lucene, sizeof(__pyx_k_fts_lucene), 0, 1, 0, 1},
    {&__pyx_n_u_fts_rank, __pyx_k_fts_rank, sizeof(__pyx_k_fts_rank), 0, 1, 0, 1},
    {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_get_table_columns_declaration, __pyx_k_get_table_columns_declaration, sizeof(__pyx_k_get_table_columns_declaration), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_n_s_global_hits, __pyx_k_global_hits, sizeof(__pyx_k_global_hits), 0, 0, 1, 1},
    {&__pyx_n_s_hash_impl, __pyx_k_hash_impl, sizeof(__pyx_k_hash_impl), 0, 0, 1, 1},
    {&__pyx_n_s_hashlib, __pyx_k_hashlib, sizeof(__pyx_k_hashlib), 0, 0, 1, 1},
    {&__pyx_n_s_hexdigest, __pyx_k_hexdigest, sizeof(__pyx_k_hexdigest), 0, 0, 1, 1},
    {&__pyx_n_s_highwater, __pyx_k_highwater, sizeof(__pyx_k_highwater), 0, 0, 1, 1},
    {&__pyx_n_s_hits, __pyx_k_hits, sizeof(__pyx_k_hits), 0, 0, 1, 1},
    {&__pyx_n_s_icol, __pyx_k_icol, sizeof(__pyx_k_icol), 0, 0, 1, 1},
    {&__pyx_n_s_idf, __pyx_k_idf, sizeof(__pyx_k_idf), 0, 0, 1, 1},
    {&__pyx_n_s_idx, __pyx_k_idx, sizeof(__pyx_k_idx), 0, 0, 1, 1},
    {&__pyx_n_s_impl, __pyx_k_impl, sizeof(__pyx_k_impl), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
    {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
    {&__pyx_n_s_initialize, __pyx_k_initialize, sizeof(__pyx_k_initialize), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_inner, __pyx_k_inner, sizeof(__pyx_k_inner), 0, 0, 1, 1},
    {&__pyx_n_s_iphrase, __pyx_k_iphrase, sizeof(__pyx_k_iphrase), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_item, __pyx_k_item, sizeof(__pyx_k_item), 0, 0, 1, 1},
    {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
    {&__pyx_n_s_iterate, __pyx_k_iterate, sizeof(__pyx_k_iterate), 0, 0, 1, 1},
    {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
    {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
    {&__pyx_n_s_last_insert_rowid, __pyx_k_last_insert_rowid, sizeof(__pyx_k_last_insert_rowid), 0, 0, 1, 1},
    {&__pyx_n_s_length, __pyx_k_length, sizeof(__pyx_k_length), 0, 0, 1, 1},
    {&__pyx_n_s_literal, __pyx_k_literal, sizeof(__pyx_k_literal), 0, 0, 1, 1},
    {&__pyx_n_s_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 0, 1, 1},
    {&__pyx_n_u_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 1, 0, 1},
    {&__pyx_n_s_main_2, __pyx_k_main_2, sizeof(__pyx_k_main_2), 0, 0, 1, 1},
    {&__pyx_n_s_make_hash, __pyx_k_make_hash, sizeof(__pyx_k_make_hash), 0, 0, 1, 1},
    {&__pyx_n_s_make_hash_locals_inner, __pyx_k_make_hash_locals_inner, sizeof(__pyx_k_make_hash_locals_inner), 0, 0, 1, 1},
    {&__pyx_n_s_match_info, __pyx_k_match_info, sizeof(__pyx_k_match_info), 0, 0, 1, 1},
    {&__pyx_n_s_match_info_buf, __pyx_k_match_info_buf, sizeof(__pyx_k_match_info_buf), 0, 0, 1, 1},
    {&__pyx_n_s_match_info_buf_2, __pyx_k_match_info_buf_2, sizeof(__pyx_k_match_info_buf_2), 0, 0, 1, 1},
    {&__pyx_n_s_max_length, __pyx_k_max_length, sizeof(__pyx_k_max_length), 0, 0, 1, 1},
    {&__pyx_n_s_md5, __pyx_k_md5, sizeof(__pyx_k_md5), 0, 0, 1, 1},
    {&__pyx_n_u_md5, __pyx_k_md5, sizeof(__pyx_k_md5), 0, 1, 0, 1},
    {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
    {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
    {&__pyx_n_s_mro_entries, __pyx_k_mro_entries, sizeof(__pyx_k_mro_entries), 0, 0, 1, 1},
    {&__pyx_n_u_murmurhash, __pyx_k_murmurhash, sizeof(__pyx_k_murmurhash), 0, 1, 0, 1},
    {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
    {&__pyx_n_s_n_items, __pyx_k_n_items, sizeof(__pyx_k_n_items), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_ncol, __pyx_k_ncol, sizeof(__pyx_k_ncol), 0, 0, 1, 1},
    {&__pyx_n_s_ncols, __pyx_k_ncols, sizeof(__pyx_k_ncols), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
    {&__pyx_kp_u_no_row_data, __pyx_k_no_row_data, sizeof(__pyx_k_no_row_data), 0, 1, 0, 0},
    {&__pyx_n_s_nphrase, __pyx_k_nphrase, sizeof(__pyx_k_nphrase), 0, 0, 1, 1},
    {&__pyx_n_s_nseed, __pyx_k_nseed, sizeof(__pyx_k_nseed), 0, 0, 1, 1},
    {&__pyx_n_s_num, __pyx_k_num, sizeof(__pyx_k_num), 0, 0, 1, 1},
    {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
    {&__pyx_n_s_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 0, 1, 1},
    {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
    {&__pyx_n_s_page_count, __pyx_k_page_count, sizeof(__pyx_k_page_count), 0, 0, 1, 1},
    {&__pyx_n_s_page_step, __pyx_k_page_step, sizeof(__pyx_k_page_step), 0, 0, 1, 1},
    {&__pyx_n_s_pages, __pyx_k_pages, sizeof(__pyx_k_pages), 0, 0, 1, 1},
    {&__pyx_n_s_pairs, __pyx_k_pairs, sizeof(__pyx_k_pairs), 0, 0, 1, 1},
    {&__pyx_n_s_param, __pyx_k_param, sizeof(__pyx_k_param), 0, 0, 1, 1},
    {&__pyx_n_s_params, __pyx_k_params, sizeof(__pyx_k_params), 0, 0, 1, 1},
    {&__pyx_n_s_pc_score, __pyx_k_pc_score, sizeof(__pyx_k_pc_score), 0, 0, 1, 1},
    {&__pyx_n_s_peewee, __pyx_k_peewee, sizeof(__pyx_k_peewee), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_bloomfilter_add, __pyx_k_peewee_bloomfilter_add, sizeof(__pyx_k_peewee_bloomfilter_add), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_bloomfilter_calculate_siz, __pyx_k_peewee_bloomfilter_calculate_siz, sizeof(__pyx_k_peewee_bloomfilter_calculate_siz), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_bloomfilter_contains, __pyx_k_peewee_bloomfilter_contains, sizeof(__pyx_k_peewee_bloomfilter_contains), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_bm25, __pyx_k_peewee_bm25, sizeof(__pyx_k_peewee_bm25), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_bm25f, __pyx_k_peewee_bm25f, sizeof(__pyx_k_peewee_bm25f), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_lucene, __pyx_k_peewee_lucene, sizeof(__pyx_k_peewee_lucene), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_md5, __pyx_k_peewee_md5, sizeof(__pyx_k_peewee_md5), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_murmurhash, __pyx_k_peewee_murmurhash, sizeof(__pyx_k_peewee_murmurhash), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_rank, __pyx_k_peewee_rank, sizeof(__pyx_k_peewee_rank), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_sha1, __pyx_k_peewee_sha1, sizeof(__pyx_k_peewee_sha1), 0, 0, 1, 1},
    {&__pyx_n_s_peewee_sha256, __pyx_k_peewee_sha256, sizeof(__pyx_k_peewee_sha256), 0, 0, 1, 1},
    {&__pyx_n_s_phrase_info, __pyx_k_phrase_info, sizeof(__pyx_k_phrase_info), 0, 0, 1, 1},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_n_s_playhouse__sqlite_ext, __pyx_k_playhouse__sqlite_ext, sizeof(__pyx_k_playhouse__sqlite_ext), 0, 0, 1, 1},
    {&__pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_k_playhouse__sqlite_ext_pyx, sizeof(__pyx_k_playhouse__sqlite_ext_pyx), 0, 0, 1, 0},
    {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
    {&__pyx_n_s_print_exc, __pyx_k_print_exc, sizeof(__pyx_k_print_exc), 0, 0, 1, 1},
    {&__pyx_n_s_print_tracebacks, __pyx_k_print_tracebacks, sizeof(__pyx_k_print_tracebacks), 0, 0, 1, 1},
    {&__pyx_n_s_progress, __pyx_k_progress, sizeof(__pyx_k_progress), 0, 0, 1, 1},
    {&__pyx_n_s_py_match_info, __pyx_k_py_match_info, sizeof(__pyx_k_py_match_info), 0, 0, 1, 1},
    {&__pyx_n_s_pybuf, __pyx_k_pybuf, sizeof(__pyx_k_pybuf), 0, 0, 1, 1},
    {&__pyx_n_s_pysqlite, __pyx_k_pysqlite, sizeof(__pyx_k_pysqlite), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_BloomFilterAggreg, __pyx_k_pyx_unpickle_BloomFilterAggreg, sizeof(__pyx_k_pyx_unpickle_BloomFilterAggreg), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_ratio, __pyx_k_ratio, sizeof(__pyx_k_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_raw_weights, __pyx_k_raw_weights, sizeof(__pyx_k_raw_weights), 0, 0, 1, 1},
    {&__pyx_n_s_rc, __pyx_k_rc, sizeof(__pyx_k_rc), 0, 0, 1, 1},
    {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
    {&__pyx_n_s_read_only, __pyx_k_read_only, sizeof(__pyx_k_read_only), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_register, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
    {&__pyx_n_s_register_aggregate, __pyx_k_register_aggregate, sizeof(__pyx_k_register_aggregate), 0, 0, 1, 1},
    {&__pyx_n_s_register_bloomfilter, __pyx_k_register_bloomfilter, sizeof(__pyx_k_register_bloomfilter), 0, 0, 1, 1},
    {&__pyx_n_s_register_function, __pyx_k_register_function, sizeof(__pyx_k_register_function), 0, 0, 1, 1},
    {&__pyx_n_s_register_functions, __pyx_k_register_functions, sizeof(__pyx_k_register_functions), 0, 0, 1, 1},
    {&__pyx_n_s_register_hash_functions, __pyx_k_register_hash_functions, sizeof(__pyx_k_register_hash_functions), 0, 0, 1, 1},
    {&__pyx_n_s_register_rank_functions, __pyx_k_register_rank_functions, sizeof(__pyx_k_register_rank_functions), 0, 0, 1, 1},
    {&__pyx_n_s_remaining, __pyx_k_remaining, sizeof(__pyx_k_remaining), 0, 0, 1, 1},
    {&__pyx_n_s_reopen, __pyx_k_reopen, sizeof(__pyx_k_reopen), 0, 0, 1, 1},
    {&__pyx_n_s_rhs, __pyx_k_rhs, sizeof(__pyx_k_rhs), 0, 0, 1, 1},
    {&__pyx_n_s_rowid, __pyx_k_rowid, sizeof(__pyx_k_rowid), 0, 0, 1, 1},
    {&__pyx_kp_u_s_HIDDEN, __pyx_k_s_HIDDEN, sizeof(__pyx_k_s_HIDDEN), 0, 1, 0, 0},
    {&__pyx_kp_u_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 1, 0, 0},
    {&__pyx_n_s_score, __pyx_k_score, sizeof(__pyx_k_score), 0, 0, 1, 1},
    {&__pyx_n_s_seed, __pyx_k_seed, sizeof(__pyx_k_seed), 0, 0, 1, 1},
    {&__pyx_n_s_seek, __pyx_k_seek, sizeof(__pyx_k_seek), 0, 0, 1, 1},
    {&__pyx_kp_u_seek_frame_of_reference_must_be, __pyx_k_seek_frame_of_reference_must_be, sizeof(__pyx_k_seek_frame_of_reference_must_be), 0, 1, 0, 0},
    {&__pyx_kp_u_seek_offset_outside_of_valid_ran, __pyx_k_seek_offset_outside_of_valid_ran, sizeof(__pyx_k_seek_offset_outside_of_valid_ran), 0, 1, 0, 0},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_kp_s_self_bf_cannot_be_converted_to_a, __pyx_k_self_bf_cannot_be_converted_to_a, sizeof(__pyx_k_self_bf_cannot_be_converted_to_a), 0, 0, 1, 0},
    {&__pyx_kp_s_self_conn_cannot_be_converted_to, __pyx_k_self_conn_cannot_be_converted_to, sizeof(__pyx_k_self_conn_cannot_be_converted_to), 0, 0, 1, 0},
    {&__pyx_kp_s_self_conn_self_pBlob_cannot_be_c, __pyx_k_self_conn_self_pBlob_cannot_be_c, sizeof(__pyx_k_self_conn_self_pBlob_cannot_be_c), 0, 0, 1, 0},
    {&__pyx_n_s_set_busy_handler, __pyx_k_set_busy_handler, sizeof(__pyx_k_set_busy_handler), 0, 0, 1, 1},
    {&__pyx_n_s_set_commit_hook, __pyx_k_set_commit_hook, sizeof(__pyx_k_set_commit_hook), 0, 0, 1, 1},
    {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
    {&__pyx_n_s_set_rollback_hook, __pyx_k_set_rollback_hook, sizeof(__pyx_k_set_rollback_hook), 0, 0, 1, 1},
    {&__pyx_n_s_set_update_hook, __pyx_k_set_update_hook, sizeof(__pyx_k_set_update_hook), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_sha1, __pyx_k_sha1, sizeof(__pyx_k_sha1), 0, 0, 1, 1},
    {&__pyx_n_u_sha1, __pyx_k_sha1, sizeof(__pyx_k_sha1), 0, 1, 0, 1},
    {&__pyx_n_s_sha256, __pyx_k_sha256, sizeof(__pyx_k_sha256), 0, 0, 1, 1},
    {&__pyx_n_u_sha256, __pyx_k_sha256, sizeof(__pyx_k_sha256), 0, 1, 0, 1},
    {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_sql, __pyx_k_sql, sizeof(__pyx_k_sql), 0, 0, 1, 1},
    {&__pyx_n_s_sqlite3, __pyx_k_sqlite3, sizeof(__pyx_k_sqlite3), 0, 0, 1, 1},
    {&__pyx_n_s_sqlite_get_db_status, __pyx_k_sqlite_get_db_status, sizeof(__pyx_k_sqlite_get_db_status), 0, 0, 1, 1},
    {&__pyx_n_s_sqlite_get_status, __pyx_k_sqlite_get_status, sizeof(__pyx_k_sqlite_get_status), 0, 0, 1, 1},
    {&__pyx_n_s_src, __pyx_k_src, sizeof(__pyx_k_src), 0, 0, 1, 1},
    {&__pyx_n_s_src_conn, __pyx_k_src_conn, sizeof(__pyx_k_src_conn), 0, 0, 1, 1},
    {&__pyx_n_s_src_db, __pyx_k_src_db, sizeof(__pyx_k_src_db), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_state_2, __pyx_k_state_2, sizeof(__pyx_k_state_2), 0, 0, 1, 1},
    {&__pyx_n_s_step, __pyx_k_step, sizeof(__pyx_k_step), 0, 0, 1, 1},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
    {&__pyx_n_s_table, __pyx_k_table, sizeof(__pyx_k_table), 0, 0, 1, 1},
    {&__pyx_n_s_table_function, __pyx_k_table_function, sizeof(__pyx_k_table_function), 0, 0, 1, 1},
    {&__pyx_n_s_tell, __pyx_k_tell, sizeof(__pyx_k_tell), 0, 0, 1, 1},
    {&__pyx_n_s_term_frequency, __pyx_k_term_frequency, sizeof(__pyx_k_term_frequency), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_tf, __pyx_k_tf, sizeof(__pyx_k_tf), 0, 0, 1, 1},
    {&__pyx_n_s_timeout, __pyx_k_timeout, sizeof(__pyx_k_timeout), 0, 0, 1, 1},
    {&__pyx_n_s_to_buffer, __pyx_k_to_buffer, sizeof(__pyx_k_to_buffer), 0, 0, 1, 1},
    {&__pyx_n_s_total_docs, __pyx_k_total_docs, sizeof(__pyx_k_total_docs), 0, 0, 1, 1},
    {&__pyx_n_s_traceback, __pyx_k_traceback, sizeof(__pyx_k_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
    {&__pyx_kp_u_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 1, 0, 0},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_n_s_weight, __pyx_k_weight, sizeof(__pyx_k_weight), 0, 0, 1, 1},
    {&__pyx_n_s_weights, __pyx_k_weights, sizeof(__pyx_k_weights), 0, 0, 1, 1},
    {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
    {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
    {&__pyx_kp_u_zeroblob_s, __pyx_k_zeroblob_s, sizeof(__pyx_k_zeroblob_s), 0, 1, 0, 0},
    {&__pyx_n_s_zlib, __pyx_k_zlib, sizeof(__pyx_k_zlib), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 673, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 302, __pyx_L1_error)
  __pyx_builtin_StopIteration = __Pyx_GetBuiltinName(__pyx_n_s_StopIteration); if (!__pyx_builtin_StopIteration) __PYX_ERR(0, 470, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 544, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_builtin_NotImplementedError = __Pyx_GetBuiltinName(__pyx_n_s_NotImplementedError); if (!__pyx_builtin_NotImplementedError) __PYX_ERR(0, 687, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 699, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(0, 1284, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 1313, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(3, 308, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "datetime.pxd":308
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')             # <<<<<<<<<<<<<<
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 * 
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_Time_zones_are_not_available_fro); if (unlikely(!__pyx_tuple_)) __PYX_ERR(3, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "playhouse/_sqlite_ext.pyx":699
 *             if isinstance(column, tuple):
 *                 if len(column) != 2:
 *                     raise ValueError('Column must be either a string or a '             # <<<<<<<<<<<<<<
 *                                      '2-tuple of name, type')
 *                 accum.append('%s %s' % column)
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_Column_must_be_either_a_string_o); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "playhouse/_sqlite_ext.pyx":1021
 * 
 * def make_hash(hash_impl):
 *     def inner(*items):             # <<<<<<<<<<<<<<
 *         state = hash_impl()
 *         for item in items:
 */
  __pyx_tuple__5 = PyTuple_Pack(3, __pyx_n_s_items, __pyx_n_s_state, __pyx_n_s_item); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 1021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);
  __pyx_codeobj__6 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__5, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_inner, 1021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__6)) __PYX_ERR(0, 1021, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1238
 *     def __init__(self, length):
 *         if not isinstance(length, int) or length < 0:
 *             raise ValueError('Length must be a positive integer.')             # <<<<<<<<<<<<<<
 *         self.length = length
 * 
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_u_Length_must_be_a_positive_intege); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "playhouse/_sqlite_ext.pyx":1284
 *             raise OperationalError('Unable to open blob.')
 *         if not blob:
 *             raise MemoryError('Unable to allocate blob.')             # <<<<<<<<<<<<<<
 * 
 *         self.pBlob = blob
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_u_Unable_to_allocate_blob); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 1284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "playhouse/_sqlite_ext.pyx":1368
 *             offset += size
 *         else:
 *             raise ValueError('seek() frame of reference must be 0, 1 or 2.')             # <<<<<<<<<<<<<<
 * 
 *         if offset < 0 or offset > size:
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_seek_frame_of_reference_must_be); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 1368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "playhouse/_sqlite_ext.pyx":1371
 * 
 *         if offset < 0 or offset > size:
 *             raise ValueError('seek() offset outside of valid range.')             # <<<<<<<<<<<<<<
 *         self.offset = offset
 * 
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_seek_offset_outside_of_valid_ran); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "playhouse/_sqlite_ext.pyx":1391
 *         PyBytes_AsStringAndSize(data, &buf, &buflen)
 *         if buflen > remaining:
 *             raise ValueError('Data would go beyond end of blob')             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_u_Data_would_go_beyond_end_of_blob); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 1391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "playhouse/_sqlite_ext.pyx":1428
 * 
 *     if not c_conn.db:
 *         return (None, None)             # <<<<<<<<<<<<<<
 * 
 *     rc = sqlite3_db_status(c_conn.db, flag, &current, &highwater, 0)
 */
  __pyx_tuple__14 = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 1428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x04e5ddb, 0xdba8929, 0xc9f9d7d):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x04e5ddb, 0xdba8929, 0xc9f9d7d) = (bf))" % __pyx_checksum
 */
  __pyx_tuple__15 = PyTuple_Pack(3, __pyx_int_5135835, __pyx_int_230328617, __pyx_int_211787133); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);
  __pyx_codeobj__19 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__19)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_tuple__20 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);
  __pyx_codeobj__21 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__21)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":673
 * 
 * 
 * class TableFunction(object):             # <<<<<<<<<<<<<<
 *     columns = None
 *     params = None
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "playhouse/_sqlite_ext.pyx":680
 *     _ncols = None
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register(cls, conn):
 *         cdef _TableFunctionImpl impl = _TableFunctionImpl(cls)
 */
  __pyx_tuple__24 = PyTuple_Pack(3, __pyx_n_s_cls, __pyx_n_s_conn, __pyx_n_s_impl); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);
  __pyx_codeobj__25 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_register, 680, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__25)) __PYX_ERR(0, 680, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":686
 *         cls._ncols = len(cls.columns)
 * 
 *     def initialize(self, **filters):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */
  __pyx_tuple__26 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_filters); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);
  __pyx_codeobj__27 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__26, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_initialize, 686, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__27)) __PYX_ERR(0, 686, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":689
 *         raise NotImplementedError
 * 
 *     def iterate(self, idx):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */
  __pyx_tuple__28 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_idx); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);
  __pyx_codeobj__29 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__28, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_iterate, 689, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__29)) __PYX_ERR(0, 689, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":692
 *         raise NotImplementedError
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def get_table_columns_declaration(cls):
 *         cdef list accum = []
 */
  __pyx_tuple__30 = PyTuple_Pack(4, __pyx_n_s_cls, __pyx_n_s_accum, __pyx_n_s_column, __pyx_n_s_param); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __pyx_codeobj__31 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__30, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_get_table_columns_declaration, 692, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__31)) __PYX_ERR(0, 692, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":753
 * 
 * 
 * def peewee_rank(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     cdef:
 *         unsigned int *match_info
 */
  __pyx_tuple__32 = PyTuple_Pack(18, __pyx_n_s_py_match_info, __pyx_n_s_raw_weights, __pyx_n_s_match_info, __pyx_n_s_phrase_info, __pyx_n_s_match_info_buf, __pyx_n_s_match_info_buf_2, __pyx_n_s_nphrase, __pyx_n_s_ncol, __pyx_n_s_icol, __pyx_n_s_iphrase, __pyx_n_s_hits, __pyx_n_s_global_hits, __pyx_n_s_P_O, __pyx_n_s_C_O, __pyx_n_s_X_O, __pyx_n_s_score, __pyx_n_s_weight, __pyx_n_s_weights); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);
  __pyx_codeobj__33 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 18, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__32, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_rank, 753, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__33)) __PYX_ERR(0, 753, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":795
 * 
 * 
 * def peewee_lucene(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_lucene(matchinfo(table, 'pcnalx'), 1)
 *     cdef:
 */
  __pyx_tuple__34 = PyTuple_Pack(28, __pyx_n_s_py_match_info, __pyx_n_s_raw_weights, __pyx_n_s_match_info, __pyx_n_s_match_info_buf, __pyx_n_s_match_info_buf_2, __pyx_n_s_nphrase, __pyx_n_s_ncol, __pyx_n_s_total_docs, __pyx_n_s_term_frequency, __pyx_n_s_doc_length, __pyx_n_s_docs_with_term, __pyx_n_s_avg_length, __pyx_n_s_idf, __pyx_n_s_weight, __pyx_n_s_rhs, __pyx_n_s_denom, __pyx_n_s_weights, __pyx_n_s_P_O, __pyx_n_s_C_O, __pyx_n_s_N_O, __pyx_n_s_L_O, __pyx_n_s_X_O, __pyx_n_s_iphrase, __pyx_n_s_icol, __pyx_n_s_x, __pyx_n_s_score, __pyx_n_s_tf, __pyx_n_s_fieldNorms); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 28, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_lucene, 795, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) __PYX_ERR(0, 795, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":837
 * 
 * 
 * def peewee_bm25(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */
  __pyx_tuple__36 = PyTuple_Pack(32, __pyx_n_s_py_match_info, __pyx_n_s_raw_weights, __pyx_n_s_match_info, __pyx_n_s_match_info_buf, __pyx_n_s_match_info_buf_2, __pyx_n_s_nphrase, __pyx_n_s_ncol, __pyx_n_s_B, __pyx_n_s_K, __pyx_n_s_total_docs, __pyx_n_s_term_frequency, __pyx_n_s_doc_length, __pyx_n_s_docs_with_term, __pyx_n_s_avg_length, __pyx_n_s_idf, __pyx_n_s_weight, __pyx_n_s_ratio, __pyx_n_s_num, __pyx_n_s_b_part, __pyx_n_s_denom, __pyx_n_s_pc_score, __pyx_n_s_weights, __pyx_n_s_P_O, __pyx_n_s_C_O, __pyx_n_s_N_O, __pyx_n_s_A_O, __pyx_n_s_L_O, __pyx_n_s_X_O, __pyx_n_s_iphrase, __pyx_n_s_icol, __pyx_n_s_x, __pyx_n_s_score); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 32, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__36, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_bm25, 837, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) __PYX_ERR(0, 837, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":908
 * 
 * 
 * def peewee_bm25f(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25f(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */
  __pyx_tuple__38 = PyTuple_Pack(33, __pyx_n_s_py_match_info, __pyx_n_s_raw_weights, __pyx_n_s_match_info, __pyx_n_s_match_info_buf, __pyx_n_s_match_info_buf_2, __pyx_n_s_nphrase, __pyx_n_s_ncol, __pyx_n_s_B, __pyx_n_s_K, __pyx_n_s_epsilon, __pyx_n_s_total_docs, __pyx_n_s_term_frequency, __pyx_n_s_docs_with_term, __pyx_n_s_doc_length, __pyx_n_s_avg_length, __pyx_n_s_idf, __pyx_n_s_weight, __pyx_n_s_ratio, __pyx_n_s_num, __pyx_n_s_b_part, __pyx_n_s_denom, __pyx_n_s_pc_score, __pyx_n_s_weights, __pyx_n_s_P_O, __pyx_n_s_C_O, __pyx_n_s_N_O, __pyx_n_s_A_O, __pyx_n_s_L_O, __pyx_n_s_X_O, __pyx_n_s_iphrase, __pyx_n_s_icol, __pyx_n_s_x, __pyx_n_s_score); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 33, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__38, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_bm25f, 908, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(0, 908, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1007
 * 
 * 
 * def peewee_murmurhash(key, seed=None):             # <<<<<<<<<<<<<<
 *     if key is None:
 *         return
 */
  __pyx_tuple__40 = PyTuple_Pack(4, __pyx_n_s_key, __pyx_n_s_seed, __pyx_n_s_bkey, __pyx_n_s_nseed); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__40, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_murmurhash, 1007, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __pyx_tuple__42 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "playhouse/_sqlite_ext.pyx":1020
 * 
 * 
 * def make_hash(hash_impl):             # <<<<<<<<<<<<<<
 *     def inner(*items):
 *         state = hash_impl()
 */
  __pyx_tuple__43 = PyTuple_Pack(3, __pyx_n_s_hash_impl, __pyx_n_s_inner, __pyx_n_s_inner); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);
  __pyx_codeobj__44 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__43, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_make_hash, 1020, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__44)) __PYX_ERR(0, 1020, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1034
 * 
 * 
 * def _register_functions(database, pairs):             # <<<<<<<<<<<<<<
 *     for func, name in pairs:
 *         database.register_function(func, name)
 */
  __pyx_tuple__45 = PyTuple_Pack(4, __pyx_n_s_database, __pyx_n_s_pairs, __pyx_n_s_func, __pyx_n_s_name); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);
  __pyx_codeobj__46 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__45, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_register_functions, 1034, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__46)) __PYX_ERR(0, 1034, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1039
 * 
 * 
 * def register_hash_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_murmurhash, 'murmurhash'),
 */
  __pyx_tuple__47 = PyTuple_Pack(1, __pyx_n_s_database); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);
  __pyx_codeobj__48 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_register_hash_functions, 1039, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__48)) __PYX_ERR(0, 1039, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1049
 * 
 * 
 * def register_rank_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_bm25, 'fts_bm25'),
 */
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_register_rank_functions, 1049, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 1049, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1124
 *         return self.bf.size
 * 
 *     def add(self, *keys):             # <<<<<<<<<<<<<<
 *         cdef bytes bkey
 * 
 */
  __pyx_tuple__50 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_keys, __pyx_n_s_bkey, __pyx_n_s_key); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__50, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_add, 1124, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(0, 1124, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1135
 *         return bf_contains(self.bf, <unsigned char *>bkey)
 * 
 *     def to_buffer(self):             # <<<<<<<<<<<<<<
 *         # We have to do this so that embedded NULL bytes are preserved.
 *         cdef bytes buf = PyBytes_FromStringAndSize(<char *>(self.bf.bits),
 */
  __pyx_tuple__52 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_buf); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 1135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__52, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_to_buffer, 1135, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(0, 1135, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1143
 *         return buf
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_buffer(cls, data):
 *         cdef:
 */
  __pyx_tuple__54 = PyTuple_Pack(5, __pyx_n_s_cls, __pyx_n_s_data, __pyx_n_s_buf, __pyx_n_s_buflen, __pyx_n_s_bloom); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__54, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_from_buffer, 1143, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(0, 1143, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1156
 *         return bloom
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def calculate_size(cls, double n, double p):
 *         cdef double m = ceil((n * log(p)) / log(1.0 / (pow(2.0, log(2.0)))))
 */
  __pyx_tuple__56 = PyTuple_Pack(4, __pyx_n_s_cls, __pyx_n_s_n, __pyx_n_s_p, __pyx_n_s_m); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__56, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_calculate_size, 1156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(0, 1156, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__58 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__58)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 */
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1169
 *         self.bf = None
 * 
 *     def step(self, value, size=None):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             size = size or 1024
 */
  __pyx_tuple__60 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_value, __pyx_n_s_size); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__60, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_step, 1169, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __pyx_tuple__62 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "playhouse/_sqlite_ext.pyx":1176
 *         self.bf.add(value)
 * 
 *     def finalize(self):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             return None
 */
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_finalize, 1176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 1176, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_tuple__64 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_dict_2, __pyx_n_s_use_setstate); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__64, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BloomFilterAggregate__set_state(self, __pyx_state)
 */
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1183
 * 
 * 
 * def peewee_bloomfilter_contains(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */
  __pyx_tuple__67 = PyTuple_Pack(6, __pyx_n_s_key, __pyx_n_s_data, __pyx_n_s_bf, __pyx_n_s_bkey, __pyx_n_s_bdata, __pyx_n_s_cdata); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__67, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_bloomfilter_contains, 1183, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(0, 1183, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1196
 *     return bf_contains(&bf, <unsigned char *>bkey)
 * 
 * def peewee_bloomfilter_add(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */
  __pyx_tuple__69 = PyTuple_Pack(6, __pyx_n_s_key, __pyx_n_s_data, __pyx_n_s_bf, __pyx_n_s_bkey, __pyx_n_s_buf, __pyx_n_s_buflen); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__69, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_bloomfilter_add, 1196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 1196, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1211
 *     return data
 * 
 * def peewee_bloomfilter_calculate_size(n_items, error_p):             # <<<<<<<<<<<<<<
 *     return BloomFilter.calculate_size(n_items, error_p)
 * 
 */
  __pyx_tuple__71 = PyTuple_Pack(2, __pyx_n_s_n_items, __pyx_n_s_error_p); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__71, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_peewee_bloomfilter_calculate_siz, 1211, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(0, 1211, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1215
 * 
 * 
 * def register_bloomfilter(database):             # <<<<<<<<<<<<<<
 *     database.register_aggregate(BloomFilterAggregate, 'bloomfilter')
 *     database.register_function(peewee_bloomfilter_add,
 */
  __pyx_codeobj__73 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_register_bloomfilter, 1215, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__73)) __PYX_ERR(0, 1215, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1236
 * 
 * class ZeroBlob(Node):
 *     def __init__(self, length):             # <<<<<<<<<<<<<<
 *         if not isinstance(length, int) or length < 0:
 *             raise ValueError('Length must be a positive integer.')
 */
  __pyx_tuple__74 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_length); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 1236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);
  __pyx_codeobj__75 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__74, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_init, 1236, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__75)) __PYX_ERR(0, 1236, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1241
 *         self.length = length
 * 
 *     def __sql__(self, ctx):             # <<<<<<<<<<<<<<
 *         return ctx.literal('zeroblob(%s)' % self.length)
 * 
 */
  __pyx_tuple__76 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_ctx); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);
  __pyx_codeobj__77 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__76, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_sql, 1241, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__77)) __PYX_ERR(0, 1241, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1324
 *         return PyBytes_FromStringAndSize(<char *>&c, 1)
 * 
 *     def read(self, n=None):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes pybuf
 */
  __pyx_tuple__78 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_n, __pyx_n_s_pybuf, __pyx_n_s_length, __pyx_n_s_max_length, __pyx_n_s_rc, __pyx_n_s_size, __pyx_n_s_buf); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_read, 1324, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(0, 1324, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1357
 *         return bytes(pybuf)
 * 
 *     def seek(self, offset, frame_of_reference=0):             # <<<<<<<<<<<<<<
 *         cdef int size
 *         _check_blob_closed(self)
 */
  __pyx_tuple__80 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_offset, __pyx_n_s_frame_of_reference, __pyx_n_s_size); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__80, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_seek, 1357, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __pyx_tuple__82 = PyTuple_Pack(1, __pyx_int_0); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);

  /* "playhouse/_sqlite_ext.pyx":1374
 *         self.offset = offset
 * 
 *     def tell(self):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         return self.offset
 */
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_tell, 1374, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 1374, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1378
 *         return self.offset
 * 
 *     def write(self, bytes data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             char *buf
 */
  __pyx_tuple__84 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_data, __pyx_n_s_buf, __pyx_n_s_rc, __pyx_n_s_remaining, __pyx_n_s_size, __pyx_n_s_buflen); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 1378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_write, 1378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(0, 1378, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1400
 *         self.offset += <int>buflen
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         _check_connection(self.conn)
 *         self._close()
 */
  __pyx_codeobj__86 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_close, 1400, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__86)) __PYX_ERR(0, 1400, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1404
 *         self._close()
 * 
 *     def reopen(self, rowid):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         self.offset = 0
 */
  __pyx_tuple__87 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_rowid); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 1404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);
  __pyx_codeobj__88 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__87, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_reopen, 1404, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__88)) __PYX_ERR(0, 1404, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 */
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1412
 * 
 * 
 * def sqlite_get_status(flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */
  __pyx_tuple__91 = PyTuple_Pack(4, __pyx_n_s_flag, __pyx_n_s_current, __pyx_n_s_highwater, __pyx_n_s_rc); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);
  __pyx_codeobj__92 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__91, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_sqlite_get_status, 1412, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__92)) __PYX_ERR(0, 1412, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1422
 * 
 * 
 * def sqlite_get_db_status(conn, flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */
  __pyx_tuple__93 = PyTuple_Pack(6, __pyx_n_s_conn, __pyx_n_s_flag, __pyx_n_s_current, __pyx_n_s_highwater, __pyx_n_s_rc, __pyx_n_s_c_conn); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_sqlite_get_db_status, 1422, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) __PYX_ERR(0, 1422, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1458
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 * 
 *     def set_commit_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */
  __pyx_tuple__95 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_fn); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 1458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_set_commit_hook, 1458, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) __PYX_ERR(0, 1458, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1468
 *             sqlite3_commit_hook(self.conn.db, _commit_callback, <void *>fn)
 * 
 *     def set_rollback_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */
  __pyx_codeobj__97 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_set_rollback_hook, 1468, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__97)) __PYX_ERR(0, 1468, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1478
 *             sqlite3_rollback_hook(self.conn.db, _rollback_callback, <void *>fn)
 * 
 *     def set_update_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_set_update_hook, 1478, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) __PYX_ERR(0, 1478, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1488
 *             sqlite3_update_hook(self.conn.db, _update_callback, <void *>fn)
 * 
 *     def set_busy_handler(self, timeout=5):             # <<<<<<<<<<<<<<
 *         """
 *         Replace the default busy handler with one that introduces some "jitter"
 */
  __pyx_tuple__99 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_timeout, __pyx_n_s_n); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 1488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);
  __pyx_codeobj__100 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__99, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_set_busy_handler, 1488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__100)) __PYX_ERR(0, 1488, __pyx_L1_error)
  __pyx_tuple__101 = PyTuple_Pack(1, __pyx_int_5); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 1488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "playhouse/_sqlite_ext.pyx":1500
 *         return True
 * 
 *     def changes(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_changes(self.conn.db)
 */
  __pyx_codeobj__102 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_changes, 1500, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__102)) __PYX_ERR(0, 1500, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1504
 *             return sqlite3_changes(self.conn.db)
 * 
 *     def last_insert_rowid(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 */
  __pyx_codeobj__103 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_last_insert_rowid, 1504, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__103)) __PYX_ERR(0, 1504, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1508
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 * 
 *     def autocommit(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_get_autocommit(self.conn.db) != 0
 */
  __pyx_codeobj__104 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_autocommit, 1508, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__104)) __PYX_ERR(0, 1508, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__105 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__105)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 */
  __pyx_codeobj__106 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__106)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":1552
 * 
 * 
 * def backup(src_conn, dest_conn, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bytes bname = encode(name or 'main')
 */
  __pyx_tuple__107 = PyTuple_Pack(15, __pyx_n_s_src_conn, __pyx_n_s_dest_conn, __pyx_n_s_pages, __pyx_n_s_name, __pyx_n_s_progress, __pyx_n_s_bname, __pyx_n_s_page_step, __pyx_n_s_rc, __pyx_n_s_src, __pyx_n_s_dest, __pyx_n_s_src_db, __pyx_n_s_dest_db, __pyx_n_s_backup, __pyx_n_s_remaining, __pyx_n_s_page_count); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);
  __pyx_codeobj__108 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 15, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__107, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_backup, 1552, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__108)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __pyx_tuple__109 = PyTuple_Pack(3, ((PyObject *)Py_None), ((PyObject *)Py_None), ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "playhouse/_sqlite_ext.pyx":1597
 * 
 * 
 * def backup_to_file(src_conn, filename, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     dest_conn = pysqlite.connect(filename)
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)
 */
  __pyx_tuple__110 = PyTuple_Pack(6, __pyx_n_s_src_conn, __pyx_n_s_filename, __pyx_n_s_pages, __pyx_n_s_name, __pyx_n_s_progress, __pyx_n_s_dest_conn); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);
  __pyx_codeobj__111 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__110, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_playhouse__sqlite_ext_pyx, __pyx_n_s_backup_to_file, 1597, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__111)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __pyx_tuple__112 = PyTuple_Pack(3, ((PyObject *)Py_None), ((PyObject *)Py_None), ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);

  /* "(tree fragment)":1
 * def __pyx_unpickle_BloomFilterAggregate(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__113 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__113)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__113);
  __Pyx_GIVEREF(__pyx_tuple__113);
  __pyx_codeobj__114 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__113, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_BloomFilterAggreg, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__114)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_float_1_0 = PyFloat_FromDouble(1.0); if (unlikely(!__pyx_float_1_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_0 = PyFloat_FromDouble(2.0); if (unlikely(!__pyx_float_2_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1000 = PyInt_FromLong(1000); if (unlikely(!__pyx_int_1000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_32768 = PyInt_FromLong(32768L); if (unlikely(!__pyx_int_32768)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5135835 = PyInt_FromLong(5135835L); if (unlikely(!__pyx_int_5135835)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_211787133 = PyInt_FromLong(211787133L); if (unlikely(!__pyx_int_211787133)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_230328617 = PyInt_FromLong(230328617L); if (unlikely(!__pyx_int_230328617)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_9playhouse_11_sqlite_ext__TableFunctionImpl = &__pyx_vtable_9playhouse_11_sqlite_ext__TableFunctionImpl;
  __pyx_vtable_9playhouse_11_sqlite_ext__TableFunctionImpl.create_module = (PyObject *(*)(struct __pyx_obj_9playhouse_11_sqlite_ext__TableFunctionImpl *, pysqlite_Connection *))__pyx_f_9playhouse_11_sqlite_ext_18_TableFunctionImpl_create_module;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl_spec, NULL); if (unlikely(!__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl)) __PYX_ERR(0, 625, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl_spec, __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  #else
  __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl = &__pyx_type_9playhouse_11_sqlite_ext__TableFunctionImpl;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl->tp_dictoffset && __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl, __pyx_vtabptr_9playhouse_11_sqlite_ext__TableFunctionImpl) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TableFunctionImpl, (PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext__TableFunctionImpl) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9playhouse_11_sqlite_ext_BloomFilter_spec, NULL); if (unlikely(!__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter)) __PYX_ERR(0, 1110, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9playhouse_11_sqlite_ext_BloomFilter_spec, __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter) < 0) __PYX_ERR(0, 1110, __pyx_L1_error)
  #else
  __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter = &__pyx_type_9playhouse_11_sqlite_ext_BloomFilter;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter) < 0) __PYX_ERR(0, 1110, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_dictoffset && __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BloomFilter, (PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter) < 0) __PYX_ERR(0, 1110, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter) < 0) __PYX_ERR(0, 1110, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate_spec, NULL); if (unlikely(!__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate)) __PYX_ERR(0, 1162, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate_spec, __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate) < 0) __PYX_ERR(0, 1162, __pyx_L1_error)
  #else
  __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate = &__pyx_type_9playhouse_11_sqlite_ext_BloomFilterAggregate;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate) < 0) __PYX_ERR(0, 1162, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_dictoffset && __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BloomFilterAggregate, (PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate) < 0) __PYX_ERR(0, 1162, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate) < 0) __PYX_ERR(0, 1162, __pyx_L1_error)
  #endif
  __pyx_vtabptr_9playhouse_11_sqlite_ext_Blob = &__pyx_vtable_9playhouse_11_sqlite_ext_Blob;
  __pyx_vtable_9playhouse_11_sqlite_ext_Blob._close = (PyObject *(*)(struct __pyx_obj_9playhouse_11_sqlite_ext_Blob *))__pyx_f_9playhouse_11_sqlite_ext_4Blob__close;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9playhouse_11_sqlite_ext_Blob = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9playhouse_11_sqlite_ext_Blob_spec, NULL); if (unlikely(!__pyx_ptype_9playhouse_11_sqlite_ext_Blob)) __PYX_ERR(0, 1255, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9playhouse_11_sqlite_ext_Blob_spec, __pyx_ptype_9playhouse_11_sqlite_ext_Blob) < 0) __PYX_ERR(0, 1255, __pyx_L1_error)
  #else
  __pyx_ptype_9playhouse_11_sqlite_ext_Blob = &__pyx_type_9playhouse_11_sqlite_ext_Blob;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9playhouse_11_sqlite_ext_Blob) < 0) __PYX_ERR(0, 1255, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_dictoffset && __pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_9playhouse_11_sqlite_ext_Blob, __pyx_vtabptr_9playhouse_11_sqlite_ext_Blob) < 0) __PYX_ERR(0, 1255, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_9playhouse_11_sqlite_ext_Blob) < 0) __PYX_ERR(0, 1255, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Blob, (PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_Blob) < 0) __PYX_ERR(0, 1255, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_Blob) < 0) __PYX_ERR(0, 1255, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper_spec, NULL); if (unlikely(!__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper)) __PYX_ERR(0, 1436, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper_spec, __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper) < 0) __PYX_ERR(0, 1436, __pyx_L1_error)
  #else
  __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper = &__pyx_type_9playhouse_11_sqlite_ext_ConnectionHelper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper) < 0) __PYX_ERR(0, 1436, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dictoffset && __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ConnectionHelper, (PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper) < 0) __PYX_ERR(0, 1436, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper) < 0) __PYX_ERR(0, 1436, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash_spec, NULL); if (unlikely(!__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash)) __PYX_ERR(0, 1020, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash_spec, __pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)
  #else
  __pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash = &__pyx_type_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash->tp_dictoffset && __pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9playhouse_11_sqlite_ext___pyx_scope_struct__make_hash->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_0_0(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(4, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType_3_0_0(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "bool", sizeof(PyBoolObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyBoolObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_4bool_bool) __PYX_ERR(5, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType_3_0_0(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "complex", sizeof(PyComplexObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyComplexObject),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_7complex_complex) __PYX_ERR(6, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("datetime"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_8datetime_date = __Pyx_ImportType_3_0_0(__pyx_t_1, "datetime", "date", sizeof(PyDateTime_Date), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyDateTime_Date),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_8datetime_date) __PYX_ERR(3, 70, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_time = __Pyx_ImportType_3_0_0(__pyx_t_1, "datetime", "time", sizeof(PyDateTime_Time), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyDateTime_Time),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_8datetime_time) __PYX_ERR(3, 83, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_datetime = __Pyx_ImportType_3_0_0(__pyx_t_1, "datetime", "datetime", sizeof(PyDateTime_DateTime), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyDateTime_DateTime),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_8datetime_datetime) __PYX_ERR(3, 109, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_timedelta = __Pyx_ImportType_3_0_0(__pyx_t_1, "datetime", "timedelta", sizeof(PyDateTime_Delta), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyDateTime_Delta),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_8datetime_timedelta) __PYX_ERR(3, 147, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_tzinfo = __Pyx_ImportType_3_0_0(__pyx_t_1, "datetime", "tzinfo", sizeof(PyDateTime_TZInfo), __PYX_GET_STRUCT_ALIGNMENT_3_0_0(PyDateTime_TZInfo),__Pyx_ImportType_CheckSize_Warn_3_0_0); if (!__pyx_ptype_7cpython_8datetime_tzinfo) __PYX_ERR(3, 160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__sqlite_ext(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__sqlite_ext},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_sqlite_ext",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC init_sqlite_ext(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC init_sqlite_ext(void)
#else
__Pyx_PyMODINIT_FUNC PyInit__sqlite_ext(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__sqlite_ext(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec__sqlite_ext(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  static int __pyx_t_7[10];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_sqlite_ext' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("_sqlite_ext", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to _sqlite_ext pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit__sqlite_ext(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_playhouse___sqlite_ext) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "playhouse._sqlite_ext")) {
      if (unlikely((PyDict_SetItemString(modules, "playhouse._sqlite_ext", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "playhouse/_sqlite_ext.pyx":2
 * # cython: language_level=3
 * import hashlib             # <<<<<<<<<<<<<<
 * import zlib
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_hashlib, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_hashlib, __pyx_t_2) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":3
 * # cython: language_level=3
 * import hashlib
 * import zlib             # <<<<<<<<<<<<<<
 * 
 * cimport cython
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_zlib, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_zlib, __pyx_t_2) < 0) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":26
 * from libc.string cimport memcpy, memset, strlen
 * 
 * from peewee import InterfaceError             # <<<<<<<<<<<<<<
 * from peewee import Node
 * from peewee import OperationalError
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_InterfaceError);
  __Pyx_GIVEREF(__pyx_n_s_InterfaceError);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_InterfaceError);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_peewee, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_InterfaceError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_InterfaceError, __pyx_t_2) < 0) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":27
 * 
 * from peewee import InterfaceError
 * from peewee import Node             # <<<<<<<<<<<<<<
 * from peewee import OperationalError
 * from peewee import sqlite3 as pysqlite
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_Node);
  __Pyx_GIVEREF(__pyx_n_s_Node);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_Node);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_peewee, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Node); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Node, __pyx_t_3) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":28
 * from peewee import InterfaceError
 * from peewee import Node
 * from peewee import OperationalError             # <<<<<<<<<<<<<<
 * from peewee import sqlite3 as pysqlite
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_OperationalError);
  __Pyx_GIVEREF(__pyx_n_s_OperationalError);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_OperationalError);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_peewee, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OperationalError, __pyx_t_2) < 0) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":29
 * from peewee import Node
 * from peewee import OperationalError
 * from peewee import sqlite3 as pysqlite             # <<<<<<<<<<<<<<
 * 
 * import traceback
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_sqlite3);
  __Pyx_GIVEREF(__pyx_n_s_sqlite3);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_sqlite3);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_peewee, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_sqlite3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pysqlite, __pyx_t_3) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":31
 * from peewee import sqlite3 as pysqlite
 * 
 * import traceback             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_traceback, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_traceback, __pyx_t_2) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":363
 * 
 * 
 * cdef int SQLITE_CONSTRAINT = 19  # Abort due to constraint violation.             # <<<<<<<<<<<<<<
 * 
 * USE_SQLITE_CONSTRAINT = sqlite3_version[:4] >= b'3.26'
 */
  __pyx_v_9playhouse_11_sqlite_ext_SQLITE_CONSTRAINT = 19;

  /* "playhouse/_sqlite_ext.pyx":365
 * cdef int SQLITE_CONSTRAINT = 19  # Abort due to constraint violation.
 * 
 * USE_SQLITE_CONSTRAINT = sqlite3_version[:4] >= b'3.26'             # <<<<<<<<<<<<<<
 * 
 * # The peewee_vtab struct embeds the base sqlite3_vtab struct, and adds a field
 */
  __pyx_t_2 = __Pyx_PyBytes_FromStringAndSize(((const char*)sqlite3_version) + 0, 4 - 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_kp_b_3_26, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_USE_SQLITE_CONSTRAINT, __pyx_t_3) < 0) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_18_TableFunctionImpl_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_TableFunctionImpl___reduce_cyth, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__19)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_18_TableFunctionImpl_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_TableFunctionImpl___setstate_cy, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__21)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":673
 * 
 * 
 * class TableFunction(object):             # <<<<<<<<<<<<<<
 *     columns = None
 *     params = None
 */
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_tuple__23); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_TableFunction, __pyx_n_s_TableFunction, (PyObject *) NULL, __pyx_n_s_playhouse__sqlite_ext, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__pyx_t_3 != __pyx_tuple__23) {
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_tuple__23) < 0))) __PYX_ERR(0, 673, __pyx_L1_error)
  }

  /* "playhouse/_sqlite_ext.pyx":674
 * 
 * class TableFunction(object):
 *     columns = None             # <<<<<<<<<<<<<<
 *     params = None
 *     name = None
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_columns, Py_None) < 0) __PYX_ERR(0, 674, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":675
 * class TableFunction(object):
 *     columns = None
 *     params = None             # <<<<<<<<<<<<<<
 *     name = None
 *     print_tracebacks = True
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_params, Py_None) < 0) __PYX_ERR(0, 675, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":676
 *     columns = None
 *     params = None
 *     name = None             # <<<<<<<<<<<<<<
 *     print_tracebacks = True
 *     _ncols = None
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_name, Py_None) < 0) __PYX_ERR(0, 676, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":677
 *     params = None
 *     name = None
 *     print_tracebacks = True             # <<<<<<<<<<<<<<
 *     _ncols = None
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_print_tracebacks, Py_True) < 0) __PYX_ERR(0, 677, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":678
 *     name = None
 *     print_tracebacks = True
 *     _ncols = None             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ncols, Py_None) < 0) __PYX_ERR(0, 678, __pyx_L1_error)

  /* "playhouse/_sqlite_ext.pyx":680
 *     _ncols = None
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register(cls, conn):
 *         cdef _TableFunctionImpl impl = _TableFunctionImpl(cls)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_1register, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_TableFunction_register, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__25)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_Method_ClassMethod(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_register, __pyx_t_6) < 0) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "playhouse/_sqlite_ext.pyx":686
 *         cls._ncols = len(cls.columns)
 * 
 *     def initialize(self, **filters):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_3initialize, 0, __pyx_n_s_TableFunction_initialize, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__27)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_initialize, __pyx_t_6) < 0) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "playhouse/_sqlite_ext.pyx":689
 *         raise NotImplementedError
 * 
 *     def iterate(self, idx):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_5iterate, 0, __pyx_n_s_TableFunction_iterate, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__29)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_iterate, __pyx_t_6) < 0) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "playhouse/_sqlite_ext.pyx":692
 *         raise NotImplementedError
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def get_table_columns_declaration(cls):
 *         cdef list accum = []
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_13TableFunction_7get_table_columns_declaration, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_TableFunction_get_table_columns, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__31)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_Method_ClassMethod(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_table_columns_declaration, __pyx_t_5) < 0) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "playhouse/_sqlite_ext.pyx":673
 * 
 * 
 * class TableFunction(object):             # <<<<<<<<<<<<<<
 *     columns = None
 *     params = None
 */
  __pyx_t_5 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_TableFunction, __pyx_t_3, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TableFunction, __pyx_t_5) < 0) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":753
 * 
 * 
 * def peewee_rank(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     cdef:
 *         unsigned int *match_info
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_1peewee_rank, 0, __pyx_n_s_peewee_rank, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__33)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_rank, __pyx_t_3) < 0) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":795
 * 
 * 
 * def peewee_lucene(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_lucene(matchinfo(table, 'pcnalx'), 1)
 *     cdef:
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_3peewee_lucene, 0, __pyx_n_s_peewee_lucene, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__35)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_lucene, __pyx_t_3) < 0) __PYX_ERR(0, 795, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":837
 * 
 * 
 * def peewee_bm25(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_5peewee_bm25, 0, __pyx_n_s_peewee_bm25, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__37)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_bm25, __pyx_t_3) < 0) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":908
 * 
 * 
 * def peewee_bm25f(py_match_info, *raw_weights):             # <<<<<<<<<<<<<<
 *     # Usage: peewee_bm25f(matchinfo(table, 'pcnalx'), 1)
 *     # where the second parameter is the index of the column and
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_7peewee_bm25f, 0, __pyx_n_s_peewee_bm25f, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__39)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_bm25f, __pyx_t_3) < 0) __PYX_ERR(0, 908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1007
 * 
 * 
 * def peewee_murmurhash(key, seed=None):             # <<<<<<<<<<<<<<
 *     if key is None:
 *         return
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_9peewee_murmurhash, 0, __pyx_n_s_peewee_murmurhash, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__41)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__42);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_murmurhash, __pyx_t_3) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1020
 * 
 * 
 * def make_hash(hash_impl):             # <<<<<<<<<<<<<<
 *     def inner(*items):
 *         state = hash_impl()
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_11make_hash, 0, __pyx_n_s_make_hash, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__44)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_make_hash, __pyx_t_3) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1029
 * 
 * 
 * peewee_md5 = make_hash(hashlib.md5)             # <<<<<<<<<<<<<<
 * peewee_sha1 = make_hash(hashlib.sha1)
 * peewee_sha256 = make_hash(hashlib.sha256)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_make_hash); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_hashlib); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_md5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_md5, __pyx_t_2) < 0) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1030
 * 
 * peewee_md5 = make_hash(hashlib.md5)
 * peewee_sha1 = make_hash(hashlib.sha1)             # <<<<<<<<<<<<<<
 * peewee_sha256 = make_hash(hashlib.sha256)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_make_hash); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_hashlib); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_sha1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_sha1, __pyx_t_4) < 0) __PYX_ERR(0, 1030, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "playhouse/_sqlite_ext.pyx":1031
 * peewee_md5 = make_hash(hashlib.md5)
 * peewee_sha1 = make_hash(hashlib.sha1)
 * peewee_sha256 = make_hash(hashlib.sha256)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_make_hash); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_hashlib); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_sha256); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_sha256, __pyx_t_3) < 0) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1034
 * 
 * 
 * def _register_functions(database, pairs):             # <<<<<<<<<<<<<<
 *     for func, name in pairs:
 *         database.register_function(func, name)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_13_register_functions, 0, __pyx_n_s_register_functions, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__46)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_register_functions, __pyx_t_3) < 0) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1039
 * 
 * 
 * def register_hash_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_murmurhash, 'murmurhash'),
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_15register_hash_functions, 0, __pyx_n_s_register_hash_functions, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__48)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_register_hash_functions, __pyx_t_3) < 0) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1049
 * 
 * 
 * def register_rank_functions(database):             # <<<<<<<<<<<<<<
 *     _register_functions(database, (
 *         (peewee_bm25, 'fts_bm25'),
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_17register_rank_functions, 0, __pyx_n_s_register_rank_functions, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_register_rank_functions, __pyx_t_3) < 0) __PYX_ERR(0, 1049, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1062
 * 
 * cdef int seeds[10]
 * seeds[:] = [0, 1337, 37, 0xabcd, 0xdead, 0xface, 97, 0xed11, 0xcad9, 0x827b]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7[0] = 0;
  __pyx_t_7[1] = 0x539;
  __pyx_t_7[2] = 37;
  __pyx_t_7[3] = 0xabcd;
  __pyx_t_7[4] = 0xdead;
  __pyx_t_7[5] = 0xface;
  __pyx_t_7[6] = 97;
  __pyx_t_7[7] = 0xed11;
  __pyx_t_7[8] = 0xcad9;
  __pyx_t_7[9] = 0x827b;
  memcpy(&(__pyx_v_9playhouse_11_sqlite_ext_seeds[0]), __pyx_t_7, sizeof(__pyx_v_9playhouse_11_sqlite_ext_seeds[0]) * (10));

  /* "playhouse/_sqlite_ext.pyx":1124
 *         return self.bf.size
 * 
 *     def add(self, *keys):             # <<<<<<<<<<<<<<
 *         cdef bytes bkey
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_7add, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilter_add, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_dict, __pyx_n_s_add, __pyx_t_3) < 0) __PYX_ERR(0, 1124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);

  /* "playhouse/_sqlite_ext.pyx":1135
 *         return bf_contains(self.bf, <unsigned char *>bkey)
 * 
 *     def to_buffer(self):             # <<<<<<<<<<<<<<
 *         # We have to do this so that embedded NULL bytes are preserved.
 *         cdef bytes buf = PyBytes_FromStringAndSize(<char *>(self.bf.bits),
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_11to_buffer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilter_to_buffer, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__53)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_dict, __pyx_n_s_to_buffer, __pyx_t_3) < 0) __PYX_ERR(0, 1135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);

  /* "playhouse/_sqlite_ext.pyx":1143
 *         return buf
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_buffer(cls, data):
 *         cdef:
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_13from_buffer, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilter_from_buffer, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__55)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_dict, __pyx_n_s_from_buffer, __pyx_t_3) < 0) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);
  __Pyx_GetNameInClass(__pyx_t_3, (PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter, __pyx_n_s_from_buffer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_dict, __pyx_n_s_from_buffer, __pyx_t_2) < 0) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);

  /* "playhouse/_sqlite_ext.pyx":1156
 *         return bloom
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def calculate_size(cls, double n, double p):
 *         cdef double m = ceil((n * log(p)) / log(1.0 / (pow(2.0, log(2.0)))))
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_15calculate_size, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilter_calculate_size, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__57)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_dict, __pyx_n_s_calculate_size, __pyx_t_2) < 0) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter, __pyx_n_s_calculate_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter->tp_dict, __pyx_n_s_calculate_size, __pyx_t_3) < 0) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilter);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_17__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilter___reduce_cython, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__58)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.bf cannot be converted to a Python object for pickling"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_11BloomFilter_19__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilter___setstate_cython, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__59)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1169
 *         self.bf = None
 * 
 *     def step(self, value, size=None):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             size = size or 1024
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_3step, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilterAggregate_step, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__61)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__62);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_dict, __pyx_n_s_step, __pyx_t_3) < 0) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate);

  /* "playhouse/_sqlite_ext.pyx":1176
 *         self.bf.add(value)
 * 
 *     def finalize(self):             # <<<<<<<<<<<<<<
 *         if not self.bf:
 *             return None
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_5finalize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilterAggregate_finalize, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_dict, __pyx_n_s_finalize, __pyx_t_3) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilterAggregate___reduce_cy, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__65)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_dict, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BloomFilterAggregate, (type(self), 0x04e5ddb, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BloomFilterAggregate__set_state(self, __pyx_state)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_20BloomFilterAggregate_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BloomFilterAggregate___setstate, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__66)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate->tp_dict, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_BloomFilterAggregate);

  /* "playhouse/_sqlite_ext.pyx":1183
 * 
 * 
 * def peewee_bloomfilter_contains(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_19peewee_bloomfilter_contains, 0, __pyx_n_s_peewee_bloomfilter_contains, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__68)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_bloomfilter_contains, __pyx_t_3) < 0) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1196
 *     return bf_contains(&bf, <unsigned char *>bkey)
 * 
 * def peewee_bloomfilter_add(key, data):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bf_t bf
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_21peewee_bloomfilter_add, 0, __pyx_n_s_peewee_bloomfilter_add, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_bloomfilter_add, __pyx_t_3) < 0) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1211
 *     return data
 * 
 * def peewee_bloomfilter_calculate_size(n_items, error_p):             # <<<<<<<<<<<<<<
 *     return BloomFilter.calculate_size(n_items, error_p)
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_23peewee_bloomfilter_calculate_size, 0, __pyx_n_s_peewee_bloomfilter_calculate_siz, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__72)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_peewee_bloomfilter_calculate_siz, __pyx_t_3) < 0) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1215
 * 
 * 
 * def register_bloomfilter(database):             # <<<<<<<<<<<<<<
 *     database.register_aggregate(BloomFilterAggregate, 'bloomfilter')
 *     database.register_function(peewee_bloomfilter_add,
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_25register_bloomfilter, 0, __pyx_n_s_register_bloomfilter, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__73)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_register_bloomfilter, __pyx_t_3) < 0) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1235
 * 
 * 
 * class ZeroBlob(Node):             # <<<<<<<<<<<<<<
 *     def __init__(self, length):
 *         if not isinstance(length, int) or length < 0:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Node); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare(__pyx_t_4, __pyx_t_3, __pyx_n_s_ZeroBlob, __pyx_n_s_ZeroBlob, (PyObject *) NULL, __pyx_n_s_playhouse__sqlite_ext, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_5, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 1235, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1236
 * 
 * class ZeroBlob(Node):
 *     def __init__(self, length):             # <<<<<<<<<<<<<<
 *         if not isinstance(length, int) or length < 0:
 *             raise ValueError('Length must be a positive integer.')
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_8ZeroBlob_1__init__, 0, __pyx_n_s_ZeroBlob___init, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__75)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 1236, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1241
 *         self.length = length
 * 
 *     def __sql__(self, ctx):             # <<<<<<<<<<<<<<
 *         return ctx.literal('zeroblob(%s)' % self.length)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_8ZeroBlob_3__sql__, 0, __pyx_n_s_ZeroBlob___sql, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__77)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_n_s_sql, __pyx_t_2) < 0) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "playhouse/_sqlite_ext.pyx":1235
 * 
 * 
 * class ZeroBlob(Node):             # <<<<<<<<<<<<<<
 *     def __init__(self, length):
 *         if not isinstance(length, int) or length < 0:
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_4, __pyx_n_s_ZeroBlob, __pyx_t_3, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ZeroBlob, __pyx_t_2) < 0) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1324
 *         return PyBytes_FromStringAndSize(<char *>&c, 1)
 * 
 *     def read(self, n=None):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes pybuf
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_9read, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob_read, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__79)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__62);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_dict, __pyx_n_s_read, __pyx_t_3) < 0) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_Blob);

  /* "playhouse/_sqlite_ext.pyx":1357
 *         return bytes(pybuf)
 * 
 *     def seek(self, offset, frame_of_reference=0):             # <<<<<<<<<<<<<<
 *         cdef int size
 *         _check_blob_closed(self)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_11seek, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob_seek, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__81)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__82);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_dict, __pyx_n_s_seek, __pyx_t_3) < 0) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_Blob);

  /* "playhouse/_sqlite_ext.pyx":1374
 *         self.offset = offset
 * 
 *     def tell(self):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         return self.offset
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_13tell, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob_tell, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_dict, __pyx_n_s_tell, __pyx_t_3) < 0) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_Blob);

  /* "playhouse/_sqlite_ext.pyx":1378
 *         return self.offset
 * 
 *     def write(self, bytes data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             char *buf
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_15write, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob_write, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__85)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_dict, __pyx_n_s_write, __pyx_t_3) < 0) __PYX_ERR(0, 1378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_Blob);

  /* "playhouse/_sqlite_ext.pyx":1400
 *         self.offset += <int>buflen
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         _check_connection(self.conn)
 *         self._close()
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_17close, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob_close, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__86)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_dict, __pyx_n_s_close, __pyx_t_3) < 0) __PYX_ERR(0, 1400, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_Blob);

  /* "playhouse/_sqlite_ext.pyx":1404
 *         self._close()
 * 
 *     def reopen(self, rowid):             # <<<<<<<<<<<<<<
 *         _check_blob_closed(self)
 *         self.offset = 0
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_19reopen, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob_reopen, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__88)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_Blob->tp_dict, __pyx_n_s_reopen, __pyx_t_3) < 0) __PYX_ERR(0, 1404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_Blob);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_21__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob___reduce_cython, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__89)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn,self.pBlob cannot be converted to a Python object for pickling"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_4Blob_23__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Blob___setstate_cython, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1412
 * 
 * 
 * def sqlite_get_status(flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_27sqlite_get_status, 0, __pyx_n_s_sqlite_get_status, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__92)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sqlite_get_status, __pyx_t_3) < 0) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1422
 * 
 * 
 * def sqlite_get_db_status(conn, flag):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int current, highwater, rc
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_29sqlite_get_db_status, 0, __pyx_n_s_sqlite_get_db_status, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__94)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sqlite_get_db_status, __pyx_t_3) < 0) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1458
 *             sqlite3_update_hook(self.conn.db, NULL, NULL)
 * 
 *     def set_commit_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_5set_commit_hook, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper_set_commit_hook, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__96)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dict, __pyx_n_s_set_commit_hook, __pyx_t_3) < 0) __PYX_ERR(0, 1458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);

  /* "playhouse/_sqlite_ext.pyx":1468
 *             sqlite3_commit_hook(self.conn.db, _commit_callback, <void *>fn)
 * 
 *     def set_rollback_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_7set_rollback_hook, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper_set_rollback_ho, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__97)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dict, __pyx_n_s_set_rollback_hook, __pyx_t_3) < 0) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);

  /* "playhouse/_sqlite_ext.pyx":1478
 *             sqlite3_rollback_hook(self.conn.db, _rollback_callback, <void *>fn)
 * 
 *     def set_update_hook(self, fn):             # <<<<<<<<<<<<<<
 *         if not self.conn.initialized or not self.conn.db:
 *             return
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_9set_update_hook, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper_set_update_hook, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__98)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dict, __pyx_n_s_set_update_hook, __pyx_t_3) < 0) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);

  /* "playhouse/_sqlite_ext.pyx":1488
 *             sqlite3_update_hook(self.conn.db, _update_callback, <void *>fn)
 * 
 *     def set_busy_handler(self, timeout=5):             # <<<<<<<<<<<<<<
 *         """
 *         Replace the default busy handler with one that introduces some "jitter"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_11set_busy_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper_set_busy_handle, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__100)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__101);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dict, __pyx_n_s_set_busy_handler, __pyx_t_3) < 0) __PYX_ERR(0, 1488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);

  /* "playhouse/_sqlite_ext.pyx":1500
 *         return True
 * 
 *     def changes(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_changes(self.conn.db)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_13changes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper_changes, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__102)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dict, __pyx_n_s_changes, __pyx_t_3) < 0) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);

  /* "playhouse/_sqlite_ext.pyx":1504
 *             return sqlite3_changes(self.conn.db)
 * 
 *     def last_insert_rowid(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_15last_insert_rowid, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper_last_insert_row, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__103)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dict, __pyx_n_s_last_insert_rowid, __pyx_t_3) < 0) __PYX_ERR(0, 1504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);

  /* "playhouse/_sqlite_ext.pyx":1508
 *             return <int>sqlite3_last_insert_rowid(self.conn.db)
 * 
 *     def autocommit(self):             # <<<<<<<<<<<<<<
 *         if self.conn.initialized and self.conn.db:
 *             return sqlite3_get_autocommit(self.conn.db) != 0
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_17autocommit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper_autocommit, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__104)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper->tp_dict, __pyx_n_s_autocommit, __pyx_t_3) < 0) __PYX_ERR(0, 1508, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_9playhouse_11_sqlite_ext_ConnectionHelper);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_19__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper___reduce_cython, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__105)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.conn cannot be converted to a Python object for pickling"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_16ConnectionHelper_21__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ConnectionHelper___setstate_cyth, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__106)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1552
 * 
 * 
 * def backup(src_conn, dest_conn, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bytes bname = encode(name or 'main')
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_31backup, 0, __pyx_n_s_backup, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__108)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__109);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_backup, __pyx_t_3) < 0) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1597
 * 
 * 
 * def backup_to_file(src_conn, filename, pages=None, name=None, progress=None):             # <<<<<<<<<<<<<<
 *     dest_conn = pysqlite.connect(filename)
 *     backup(src_conn, dest_conn, pages=pages, name=name, progress=progress)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_33backup_to_file, 0, __pyx_n_s_backup_to_file, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__111)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__112);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_backup_to_file, __pyx_t_3) < 0) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_BloomFilterAggregate(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9playhouse_11_sqlite_ext_35__pyx_unpickle_BloomFilterAggregate, 0, __pyx_n_s_pyx_unpickle_BloomFilterAggreg, NULL, __pyx_n_s_playhouse__sqlite_ext, __pyx_d, ((PyObject *)__pyx_codeobj__114)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_BloomFilterAggreg, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "playhouse/_sqlite_ext.pyx":1
 * # cython: language_level=3             # <<<<<<<<<<<<<<
 * import hashlib
 * import zlib
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init playhouse._sqlite_ext", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init playhouse._sqlite_ext");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]);
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
    Py_DECREF(argstuple);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
#if defined(__Pyx_CyFunction_USED) && defined(NDEBUG)
        if (__Pyx_IsCyOrPyCFunction(func))
#else
        if (PyCFunction_Check(func))
#endif
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
                return __Pyx_PyObject_CallMethO(func, NULL);
            }
        }
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (PyCFunction_Check(func))
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
                return __Pyx_PyObject_CallMethO(func, args[0]);
            }
        }
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    #if CYTHON_VECTORCALL
    vectorcallfunc f = _PyVectorcall_Function(func);
    if (f) {
        return f(func, args, (size_t)nargs, kwargs);
    }
    #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
    if (__Pyx_CyFunction_CheckExact(func)) {
        __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
        if (f) return f(func, args, (size_t)nargs, kwargs);
    }
    #endif
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
}

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
    else state = (PyGILState_STATE)0;
#endif
    CYTHON_UNUSED_VAR(clineno);
    CYTHON_UNUSED_VAR(lineno);
    CYTHON_UNUSED_VAR(filename);
    CYTHON_MAYBE_UNUSED_VAR(nogil);
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* ssize_strlen */
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;  // error
            return kwvalues[i];
        }
    }
    return NULL;  // not found (no exception set)
}
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        if (kwds_is_tuple) {
            if (pos >= PyTuple_GET_SIZE(kwds)) break;
            key = PyTuple_GET_ITEM(kwds, pos);
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        if (unlikely(PyTuple_GET_SIZE(kw) == 0))
            return 1;
        if (!kw_allowed) {
            key = PyTuple_GET_ITEM(kw, 0);
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < PyTuple_GET_SIZE(kw); pos++) {
            key = PyTuple_GET_ITEM(kw, pos);
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseClosureNameError */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    PyObject *abi_module = PyImport_AddModule((char*) __PYX_ABI_MODULE_NAME);
    if (unlikely(!abi_module)) return NULL;
    Py_INCREF(abi_module);
    return abi_module;
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
        PyList_SET_ITEM(fromlist, 0, marker);
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    cf->m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#ifdef _Py_TPFLAGS_HAVE_VECTORCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    PyObject* exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* PyFloatBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double a = floatval;
    double b, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op2))) {
#if CYTHON_COMPILING_IN_LIMITED_API
        b = __pyx_PyFloat_AsDouble(op2);
#else
        b = PyFloat_AS_DOUBLE(op2);
#endif
        if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        b = (double) PyInt_AS_LONG(op2);
        if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
    } else
    #endif
    if (likely(PyLong_CheckExact(op2))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op2)) {
            b = 0.0;
            if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
        } else if (__Pyx_PyLong_IsCompact(op2)) {
            b = (double) __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        b = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    b = PyLong_AsDouble(op2);
                    if (unlikely(b == -1.0 && PyErr_Occurred())) return NULL;
                    #if !CYTHON_USE_PYLONG_INTERNALS
                    if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
                    #endif
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
    }
        PyFPE_START_PROTECT("divide", return NULL)
        result = a / b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
#endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSsize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a == b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        
#ifdef HAVE_LONG_LONG
            if (sizeof(PY_LONG_LONG) > sizeof(long)) {
                PY_LONG_LONG result = (PY_LONG_LONG)a * (PY_LONG_LONG)b;
                return (result >= LONG_MIN && result <= LONG_MAX) ?
                    PyInt_FromLong((long)result) : PyLong_FromLongLong(result);
            }
#endif
#if CYTHON_USE_TYPE_SLOTS
            return PyInt_Type.tp_as_number->nb_multiply(op1, op2);
#else
            return PyNumber_Multiply(op1, op2);
#endif
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
            }
        }
                CYTHON_UNUSED_VAR(a);
                CYTHON_UNUSED_VAR(b);
                #ifdef HAVE_LONG_LONG
                lla = a;
                goto long_long;
                #else
                return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
                #endif
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("multiply", return NULL)
            result = ((double)a) * (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#endif

/* ModInt[long] */
static CYTHON_INLINE long __Pyx_mod_long(long a, long b) {
    long r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                #if CYTHON_COMPILING_IN_LIMITED_API
                module = PyImport_ImportModuleLevelObject(
                    name, empty_dict, empty_dict, from_list, 1);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                #endif
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            #if CYTHON_COMPILING_IN_LIMITED_API
            module = PyImport_ImportModuleLevelObject(
                name, empty_dict, empty_dict, from_list, level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__16);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg = NULL;
    return __Pyx_PyObject_FastCall(func, (&arg)+1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n = PyTuple_GET_SIZE(bases);
    for (i = 1; i < n; i++)
    {
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
            return -1;
        }
        if (dictoffset == 0 && b->tp_dictoffset)
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "extension type '%.200s' has no __dict__ slot, "
                "but base type '" __Pyx_FMT_TYPENAME "' has: "
                "either add 'cdef dict __dict__' to the extension type "
                "or add '__slots__ = [...]' to the base type",
                type_name, b_name);
            __Pyx_DECREF_TypeName(b_name);
            return -1;
        }
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_n_s_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_n_s_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_n_s_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_n_s_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i;
    void** base_vtables;
    __Pyx_TypeName tp_base_name;
    __Pyx_TypeName base_name;
    void* unknown = (void*)-1;
    PyObject* bases = type->tp_bases;
    int base_depth = 0;
    {
        PyTypeObject* base = type->tp_base;
        while (base) {
            base_depth += 1;
            base = base->tp_base;
        }
    }
    base_vtables = (void**) malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
    for (i = 1; i < PyTuple_GET_SIZE(bases); i++) {
        void* base_vtable = __Pyx_GetVtable(((PyTypeObject*)PyTuple_GET_ITEM(bases, i)));
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = type->tp_base;
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = base->tp_base;
            }
        }
    }
    PyErr_Clear();
    free(base_vtables);
    return 0;
bad:
    tp_base_name = __Pyx_PyType_GetName(type->tp_base);
    base_name = __Pyx_PyType_GetName((PyTypeObject*)PyTuple_GET_ITEM(bases, i));
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
    free(base_vtables);
    return -1;
}
#endif

/* SetupReduce */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_0_0
#define __PYX_HAVE_RT_ImportType_3_0_0
static PyTypeObject *__Pyx_ImportType_3_0_0(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_0 check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_0_0 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_0_0 && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__17;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base, *meth, *new_base, *result, *new_bases = NULL;
    size_bases = PyTuple_GET_SIZE(bases);
    for (i = 0; i < size_bases; i++) {
        base  = PyTuple_GET_ITEM(bases, i);
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_n_s_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                base = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base);
                Py_INCREF(base);
            }
        }
        j = PyList_GET_SIZE(new_bases);
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
    return result;
error:
    Py_XDECREF(new_bases);
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    #if PY_MAJOR_VERSION == 2
    static PyTypeObject *methoddescr_type = NULL;
    if (unlikely(methoddescr_type == NULL)) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (unlikely(!meth)) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    #else
    PyTypeObject *methoddescr_type = &PyMethodDescr_Type;
    #endif
    if (__Pyx_TypeCheck(method, methoddescr_type))
#endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
}

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_n_s_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    _PyTraceback_Add(funcname, filename, py_line);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE sqlite3_int64 __Pyx_PyInt_As_sqlite3_int64(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const sqlite3_int64 neg_one = (sqlite3_int64) -1, const_zero = (sqlite3_int64) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(sqlite3_int64) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(sqlite3_int64, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (sqlite3_int64) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(sqlite3_int64, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(sqlite3_int64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) >= 2 * PyLong_SHIFT)) {
                                return (sqlite3_int64) (((((sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(sqlite3_int64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) >= 3 * PyLong_SHIFT)) {
                                return (sqlite3_int64) (((((((sqlite3_int64)digits[2]) << PyLong_SHIFT) | (sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(sqlite3_int64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) >= 4 * PyLong_SHIFT)) {
                                return (sqlite3_int64) (((((((((sqlite3_int64)digits[3]) << PyLong_SHIFT) | (sqlite3_int64)digits[2]) << PyLong_SHIFT) | (sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (sqlite3_int64) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(sqlite3_int64) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(sqlite3_int64, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(sqlite3_int64) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(sqlite3_int64, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(sqlite3_int64, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(sqlite3_int64) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) - 1 > 2 * PyLong_SHIFT)) {
                                return (sqlite3_int64) (((sqlite3_int64)-1)*(((((sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(sqlite3_int64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) - 1 > 2 * PyLong_SHIFT)) {
                                return (sqlite3_int64) ((((((sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(sqlite3_int64) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) - 1 > 3 * PyLong_SHIFT)) {
                                return (sqlite3_int64) (((sqlite3_int64)-1)*(((((((sqlite3_int64)digits[2]) << PyLong_SHIFT) | (sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(sqlite3_int64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) - 1 > 3 * PyLong_SHIFT)) {
                                return (sqlite3_int64) ((((((((sqlite3_int64)digits[2]) << PyLong_SHIFT) | (sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(sqlite3_int64) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) - 1 > 4 * PyLong_SHIFT)) {
                                return (sqlite3_int64) (((sqlite3_int64)-1)*(((((((((sqlite3_int64)digits[3]) << PyLong_SHIFT) | (sqlite3_int64)digits[2]) << PyLong_SHIFT) | (sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(sqlite3_int64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(sqlite3_int64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(sqlite3_int64) - 1 > 4 * PyLong_SHIFT)) {
                                return (sqlite3_int64) ((((((((((sqlite3_int64)digits[3]) << PyLong_SHIFT) | (sqlite3_int64)digits[2]) << PyLong_SHIFT) | (sqlite3_int64)digits[1]) << PyLong_SHIFT) | (sqlite3_int64)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(sqlite3_int64) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(sqlite3_int64, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(sqlite3_int64) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(sqlite3_int64, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            sqlite3_int64 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (sqlite3_int64) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (sqlite3_int64) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (sqlite3_int64) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (sqlite3_int64) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (sqlite3_int64) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(sqlite3_int64) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((sqlite3_int64) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(sqlite3_int64) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((sqlite3_int64) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((sqlite3_int64) 1) << (sizeof(sqlite3_int64) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (sqlite3_int64) -1;
        }
    } else {
        sqlite3_int64 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (sqlite3_int64) -1;
        val = __Pyx_PyInt_As_sqlite3_int64(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to sqlite3_int64");
    return (sqlite3_int64) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to sqlite3_int64");
    return (sqlite3_int64) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_PY_LONG_LONG(PY_LONG_LONG value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PY_LONG_LONG neg_one = (PY_LONG_LONG) -1, const_zero = (PY_LONG_LONG) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(PY_LONG_LONG) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(PY_LONG_LONG) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(PY_LONG_LONG) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(PY_LONG_LONG) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(PY_LONG_LONG) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(PY_LONG_LONG),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint32_t(uint32_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint32_t neg_one = (uint32_t) -1, const_zero = (uint32_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint32_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(uint32_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint32_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint32_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint32_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(uint32_t),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(size_t) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 2 * PyLong_SHIFT)) {
                                return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 3 * PyLong_SHIFT)) {
                                return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 4 * PyLong_SHIFT)) {
                                return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(size_t) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(size_t) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(size_t) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (size_t) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (size_t) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (size_t) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (size_t) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (size_t) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(size_t) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((size_t) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(size_t) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((size_t) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((size_t) 1) << (sizeof(size_t) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntFromPy */
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PY_LONG_LONG neg_one = (PY_LONG_LONG) -1, const_zero = (PY_LONG_LONG) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(PY_LONG_LONG) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (PY_LONG_LONG) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(PY_LONG_LONG) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) >= 2 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) (((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(PY_LONG_LONG) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) >= 3 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) (((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(PY_LONG_LONG) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) >= 4 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) (((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (PY_LONG_LONG) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(PY_LONG_LONG) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(PY_LONG_LONG) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(PY_LONG_LONG) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(PY_LONG_LONG) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) ((((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(PY_LONG_LONG) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) ((((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(PY_LONG_LONG) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT)) {
                                return (PY_LONG_LONG) ((((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(PY_LONG_LONG) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(PY_LONG_LONG) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            PY_LONG_LONG val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (PY_LONG_LONG) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (PY_LONG_LONG) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (PY_LONG_LONG) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (PY_LONG_LONG) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (PY_LONG_LONG) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(PY_LONG_LONG) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((PY_LONG_LONG) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(PY_LONG_LONG) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((PY_LONG_LONG) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((PY_LONG_LONG) 1) << (sizeof(PY_LONG_LONG) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (PY_LONG_LONG) -1;
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (PY_LONG_LONG) -1;
        val = __Pyx_PyInt_As_PY_LONG_LONG(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XSETREF(name, __Pyx_NewRef(__pyx_n_s__115));
    }
    return name;
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[5];
    int same=1, i, found_dot;
    const char* rt_from_call = Py_GetVersion();
    PyOS_snprintf(ctversion, 5, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    found_dot = 0;
    for (i = 0; i < 4; i++) {
        if (!ctversion[i]) {
            same = (rt_from_call[i] < '0' || rt_from_call[i] > '9');
            break;
        }
        if (rt_from_call[i] != ctversion[i]) {
            same = 0;
            break;
        }
    }
    if (!same) {
        char rtversion[5] = {'\0'};
        char message[200];
        for (i=0; i<4; ++i) {
            if (rt_from_call[i] == '.') {
                if (found_dot) break;
                found_dot = 1;
            } else if (rt_from_call[i] < '0' || rt_from_call[i] > '9') {
                break;
            }
            rtversion[i] = rt_from_call[i];
        }
        PyOS_snprintf(message, sizeof(message),
                      "compile time version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
